/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qbitarray_wrapper.h"

// Extra includes
#include <qbitarray.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBitArray_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBitArray >()))
        return -1;

    ::QBitArray* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QBitArray(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QBitArray", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QBitArray()
    // 1: QBitArray(QBitArray)
    // 2: QBitArray(int,bool)
    if (numArgs == 0) {
        overloadId = 0; // QBitArray()
    } else if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QBitArray(int,bool)
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 2; // QBitArray(int,bool)
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QBitArray >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QBitArray(QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArray_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QBitArray()
        {

            if(!PyErr_Occurred()) {
                // QBitArray()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QBitArray();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QBitArray(QBitArray)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QBitArray(QBitArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QBitArray(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QBitArray(int,bool)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "val");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "val";
                    else if (SbkNumber_Check(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QBitArray_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QBitArray(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            bool cppArg1 = pyArgs[1] ? Shiboken::Converter< bool >::toCpp(pyArgs[1]) : false;

            if(!PyErr_Occurred()) {
                // QBitArray(int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QBitArray(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBitArray >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QBitArray_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QBitArray_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QBitArray", "int, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBitArray", overloads);
        return -1;
}

static PyObject* Sbk_QBitArrayFunc_at(PyObject* self, PyObject* pyArg)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_at_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // at(int)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QBitArray*>(cppSelf)->at(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.at", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_clear(PyObject* self)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // clear()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->clear();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QBitArrayFunc_clearBit(PyObject* self, PyObject* pyArg)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: clearBit(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // clearBit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_clearBit_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // clearBit(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->clearBit(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_clearBit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.clearBit", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_count(PyObject* self, PyObject* args)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "count", 0, 1, &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: count()const
    // 1: count(bool)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 1; // count(bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_count_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // count()const
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QBitArray*>(cppSelf)->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
        case 1: // count(bool)const
        {
            bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // count(bool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QBitArray*>(cppSelf)->count(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_count_TypeError:
        const char* overloads[] = {"", "bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBitArray.count", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_fill(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QBitArray.fill(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QBitArray.fill(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:fill", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: fill(bool,int,int)
    // 1: fill(bool,int)
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // fill(bool,int)
        } else if (SbkNumber_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // fill(bool,int)
            } else if (numArgs == 3
                && SbkNumber_Check(pyArgs[2])) {
                overloadId = 0; // fill(bool,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_fill_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // fill(bool,int,int)
        {
            bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);
            int cppArg2 = Shiboken::Converter< int >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // fill(bool,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->fill(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // fill(bool,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "size");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "size";
                    else if (SbkNumber_Check(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QBitArrayFunc_fill_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QBitArray.fill(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArgs[0]);
            int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : -1;

            if(!PyErr_Occurred()) {
                // fill(bool,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->fill(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_fill_TypeError:
        const char* overloads[] = {"bool, int, int", "bool, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBitArray.fill", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_isEmpty(PyObject* self)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isEmpty()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QBitArray*>(cppSelf)->isEmpty();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBitArrayFunc_isNull(PyObject* self)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isNull()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QBitArray*>(cppSelf)->isNull();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBitArrayFunc_resize(PyObject* self, PyObject* pyArg)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_resize_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // resize(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->resize(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.resize", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_setBit(PyObject* self, PyObject* args)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBit", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setBit(int)
    // 1: setBit(int,bool)
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setBit(int)
        } else if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 1; // setBit(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_setBit_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setBit(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setBit(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setBit(int,bool)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            bool cppArg1 = Shiboken::Converter< bool >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setBit(int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBit(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_setBit_TypeError:
        const char* overloads[] = {"int", "int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBitArray.setBit", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_size(PyObject* self)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // size()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QBitArray*>(cppSelf)->size();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBitArrayFunc_swap(PyObject* self, PyObject* pyArg)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: swap(QBitArray&)
    if (Shiboken::Converter< ::QBitArray & >::isConvertible(pyArg)) {
        overloadId = 0; // swap(QBitArray&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_swap_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QBitArray & cppArg0 = Shiboken::Converter< ::QBitArray & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // swap(QBitArray&)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->swap(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_swap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.swap", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_testBit(PyObject* self, PyObject* pyArg)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testBit(int)const
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // testBit(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_testBit_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // testBit(int)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QBitArray*>(cppSelf)->testBit(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_testBit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.testBit", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_toggleBit(PyObject* self, PyObject* pyArg)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toggleBit(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // toggleBit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_toggleBit_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // toggleBit(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->toggleBit(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_toggleBit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.toggleBit", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_truncate(PyObject* self, PyObject* pyArg)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: truncate(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // truncate(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_truncate_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // truncate(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->truncate(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_truncate_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.truncate", overloads);
        return 0;
}

static PyObject* Sbk_QBitArray___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QBitArray& cppSelf = *(Shiboken::Converter< ::QBitArray* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QBitArray_methods[] = {
    {"at", (PyCFunction)Sbk_QBitArrayFunc_at, METH_O},
    {"clear", (PyCFunction)Sbk_QBitArrayFunc_clear, METH_NOARGS},
    {"clearBit", (PyCFunction)Sbk_QBitArrayFunc_clearBit, METH_O},
    {"count", (PyCFunction)Sbk_QBitArrayFunc_count, METH_VARARGS},
    {"fill", (PyCFunction)Sbk_QBitArrayFunc_fill, METH_VARARGS|METH_KEYWORDS},
    {"isEmpty", (PyCFunction)Sbk_QBitArrayFunc_isEmpty, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QBitArrayFunc_isNull, METH_NOARGS},
    {"resize", (PyCFunction)Sbk_QBitArrayFunc_resize, METH_O},
    {"setBit", (PyCFunction)Sbk_QBitArrayFunc_setBit, METH_VARARGS},
    {"size", (PyCFunction)Sbk_QBitArrayFunc_size, METH_NOARGS},
    {"swap", (PyCFunction)Sbk_QBitArrayFunc_swap, METH_O},
    {"testBit", (PyCFunction)Sbk_QBitArrayFunc_testBit, METH_O},
    {"toggleBit", (PyCFunction)Sbk_QBitArrayFunc_toggleBit, METH_O},
    {"truncate", (PyCFunction)Sbk_QBitArrayFunc_truncate, METH_O},

    {"__copy__", (PyCFunction)Sbk_QBitArray___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QBitArray___nb_bool(PyObject* self)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return -1;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QBitArrayFunc___and__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(pyArg)
                    && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QBitArray,QBitArray)
    if (!isReverse
        && Shiboken::Converter< ::QBitArray >::isConvertible(pyArg)) {
        overloadId = 0; // operator&(QBitArray,QBitArray)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___and___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator&(QBitArray,QBitArray)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QBitArray cppResult = (*cppSelf) & (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.__and__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___iand__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(pyArg)
                    && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator&=(QBitArray)
    if (!isReverse
        && Shiboken::Converter< ::QBitArray >::isConvertible(pyArg)) {
        overloadId = 0; // operator&=(QBitArray)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___iand___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator&=(QBitArray)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            (*cppSelf) &= (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QBitArrayFunc___iand___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.__iand__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___xor__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(pyArg)
                    && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rxor__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rxor__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator^(QBitArray,QBitArray)
    if (!isReverse
        && Shiboken::Converter< ::QBitArray >::isConvertible(pyArg)) {
        overloadId = 0; // operator^(QBitArray,QBitArray)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___xor___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator^(QBitArray,QBitArray)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QBitArray cppResult = (*cppSelf) ^ (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc___xor___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.__xor__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___ixor__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(pyArg)
                    && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator^=(QBitArray)
    if (!isReverse
        && Shiboken::Converter< ::QBitArray >::isConvertible(pyArg)) {
        overloadId = 0; // operator^=(QBitArray)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___ixor___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator^=(QBitArray)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            (*cppSelf) ^= (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QBitArrayFunc___ixor___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.__ixor__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___or__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(pyArg)
                    && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QBitArray,QBitArray)
    if (!isReverse
        && Shiboken::Converter< ::QBitArray >::isConvertible(pyArg)) {
        overloadId = 0; // operator|(QBitArray,QBitArray)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___or___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator|(QBitArray,QBitArray)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QBitArray cppResult = (*cppSelf) | (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.__or__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___ior__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(pyArg)
                    && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QBitArray)
    if (!isReverse
        && Shiboken::Converter< ::QBitArray >::isConvertible(pyArg)) {
        overloadId = 0; // operator|=(QBitArray)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___ior___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator|=(QBitArray)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            (*cppSelf) |= (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QBitArrayFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QBitArray.__ior__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___invert__(PyObject* self)
{
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // operator~()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QBitArray cppResult = ~ (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

Py_ssize_t Sbk_QBitArrayFunc___len__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    // Begin code injection

    return cppSelf->size();

    // End of code injection
}

PyObject* Sbk_QBitArrayFunc___getitem__(PyObject* self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    // Begin code injection

    if (_i < 0 || _i >= cppSelf->size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    }
    bool ret = cppSelf->at(_i);
    return Shiboken::Converter< bool >::toPython(ret);

    // End of code injection
}

int Sbk_QBitArrayFunc___setitem__(PyObject* self, Py_ssize_t _i, PyObject* _value)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    // Begin code injection

    PyObject* args = Py_BuildValue("(iiO)", _i, 1, _value);
    PyObject* result = Sbk_QBitArrayFunc_setBit(self, args);
    Py_DECREF(args);
    Py_XDECREF(result);
    return !result ? -1 : 0;

    // End of code injection
}

// Rich comparison
static PyObject* Sbk_QBitArray_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QBitArray& cppSelf = *(Shiboken::Converter< ::QBitArray* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QBitArray >::isConvertible(pyArg)) {
                // operator!=(const QBitArray & a) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QBitArray >::isConvertible(pyArg)) {
                // operator==(const QBitArray & a) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QBitArray_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QBitArray_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static long Sbk_QBitArray_HashFunc(PyObject* self) {
    ::QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QBitArray* >::toCpp(self);
    return qHash(*cppSelf);
}

static int Sbk_QBitArray_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QBitArray_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QBitArray_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QBitArray",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &Sbk_QBitArray_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QBitArray_traverse,
    /*tp_clear*/            Sbk_QBitArray_clear,
    /*tp_richcompare*/      Sbk_QBitArray_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QBitArray_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QBitArray_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QBitArray(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QBitArray_Type.super.as_number, 0, sizeof(PyNumberMethods));
    Sbk_QBitArray_Type.super.as_number.nb_inplace_or = Sbk_QBitArrayFunc___ior__;
    Sbk_QBitArray_Type.super.as_number.nb_or = Sbk_QBitArrayFunc___or__;
    Sbk_QBitArray_Type.super.as_number.nb_inplace_and = Sbk_QBitArrayFunc___iand__;
    Sbk_QBitArray_Type.super.as_number.nb_and = Sbk_QBitArrayFunc___and__;
    Sbk_QBitArray_Type.super.as_number.nb_xor = Sbk_QBitArrayFunc___xor__;
    SBK_NB_BOOL(Sbk_QBitArray_Type.super.as_number) = Sbk_QBitArray___nb_bool;
    Sbk_QBitArray_Type.super.as_number.nb_invert = Sbk_QBitArrayFunc___invert__;
    Sbk_QBitArray_Type.super.as_number.nb_inplace_xor = Sbk_QBitArrayFunc___ixor__;
    Sbk_QBitArray_Type.super.ht_type.tp_as_number = &Sbk_QBitArray_Type.super.as_number;

    // type supports sequence protocol
    memset(&Sbk_QBitArray_Type.super.as_sequence, 0, sizeof(PySequenceMethods));
    Sbk_QBitArray_Type.super.as_sequence.sq_length = &Sbk_QBitArrayFunc___len__;
    Sbk_QBitArray_Type.super.as_sequence.sq_item = &Sbk_QBitArrayFunc___getitem__;
    Sbk_QBitArray_Type.super.as_sequence.sq_ass_item = &Sbk_QBitArrayFunc___setitem__;
    Sbk_QBitArray_Type.super.ht_type.tp_as_sequence = &Sbk_QBitArray_Type.super.as_sequence;

    SbkPySide_QtCoreTypes[SBK_QBITARRAY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QBitArray_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QBitArray", "QBitArray",
        &Sbk_QBitArray_Type, &Shiboken::callCppDestructor< ::QBitArray >)) {
        return;
    }


    Shiboken::TypeResolver::createValueTypeResolver< ::QBitArray >("QBitArray");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QBitArray >("QBitArray*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QBitArray >(typeid(::QBitArray).name());
    qRegisterMetaType< ::QBitArray >("QBitArray");
}
