/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qstatemachine_signalevent_wrapper.h"

// Extra includes
#include <QList>
#include <qobject.h>


// Native ---------------------------------------------------------

SignalEventWrapper::SignalEventWrapper(QObject * sender, int signalIndex, const QList<QVariant > & arguments) : QStateMachine::SignalEvent(sender, signalIndex, arguments) {
    // ... middle
}

SignalEventWrapper::~SignalEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStateMachine_SignalEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStateMachine::SignalEvent >()))
        return -1;

    ::SignalEventWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto Sbk_QStateMachine_SignalEvent_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "SignalEvent", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return -1;


    // Overloaded function decisor
    // 0: SignalEvent(QObject*,int,QList<QVariant>)
    // 1: SignalEvent(QStateMachine::SignalEvent)
    if (numArgs == 1
        && Shiboken::Converter< ::QStateMachine::SignalEvent >::isConvertible(pyArgs[0])) {
        overloadId = 1; // SignalEvent(QStateMachine::SignalEvent)
    } else if (numArgs == 3
        && Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && Shiboken::Converter< ::QList<QVariant > >::isConvertible(pyArgs[2])) {
        overloadId = 0; // SignalEvent(QObject*,int,QList<QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachine_SignalEvent_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // SignalEvent(QObject*,int,QList<QVariant>)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject * cppArg0 = Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);
            ::QList<QVariant > cppArg2 = Shiboken::Converter< ::QList<QVariant > >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // SignalEvent(QObject*,int,QList<QVariant>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::SignalEventWrapper(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // SignalEvent(QStateMachine::SignalEvent)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStateMachine::SignalEvent cppArg0 = Shiboken::Converter< ::QStateMachine::SignalEvent >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // SignalEvent(QStateMachine::SignalEvent)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::SignalEventWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStateMachine::SignalEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStateMachine_SignalEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStateMachine_SignalEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, int, list", "PySide.QtCore.QStateMachine::SignalEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.SignalEvent", overloads);
        return -1;
}

static PyObject* Sbk_QStateMachine_SignalEventFunc_arguments(PyObject* self)
{
    ::QStateMachine::SignalEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStateMachine::SignalEvent* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // arguments()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QVariant > cppResult = const_cast<const ::QStateMachine::SignalEvent*>(cppSelf)->arguments();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QVariant > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachine_SignalEventFunc_sender(PyObject* self)
{
    ::QStateMachine::SignalEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStateMachine::SignalEvent* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // sender()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QObject * cppResult = const_cast<const ::QStateMachine::SignalEvent*>(cppSelf)->sender();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachine_SignalEventFunc_signalIndex(PyObject* self)
{
    ::QStateMachine::SignalEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStateMachine::SignalEvent* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // signalIndex()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QStateMachine::SignalEvent*>(cppSelf)->signalIndex();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachine_SignalEvent___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QStateMachine::SignalEvent& cppSelf = *(Shiboken::Converter< ::QStateMachine::SignalEvent* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QStateMachine::SignalEvent >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QStateMachine_SignalEvent_methods[] = {
    {"arguments", (PyCFunction)Sbk_QStateMachine_SignalEventFunc_arguments, METH_NOARGS},
    {"sender", (PyCFunction)Sbk_QStateMachine_SignalEventFunc_sender, METH_NOARGS},
    {"signalIndex", (PyCFunction)Sbk_QStateMachine_SignalEventFunc_signalIndex, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QStateMachine_SignalEvent___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static int Sbk_QStateMachine_SignalEvent_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStateMachine_SignalEvent_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStateMachine_SignalEvent_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QStateMachine.SignalEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStateMachine_SignalEvent_traverse,
    /*tp_clear*/            Sbk_QStateMachine_SignalEvent_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStateMachine_SignalEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStateMachine_SignalEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QStateMachine_SignalEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QEvent >()))
        return dynamic_cast< ::QStateMachine::SignalEvent*>(reinterpret_cast< ::QEvent*>(cptr));
    return 0;
}


void init_QStateMachine_SignalEvent(PyObject* enclosingClass)
{
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_SIGNALEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStateMachine_SignalEvent_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(enclosingClass, "SignalEvent", "QStateMachine::SignalEvent",
        &Sbk_QStateMachine_SignalEvent_Type, &Shiboken::callCppDestructor< ::SignalEventWrapper >, (SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QEVENT_IDX], 0, true)) {
        return;
    }

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QStateMachine_SignalEvent_Type, &Sbk_QStateMachine_SignalEvent_typeDiscovery);


    Shiboken::TypeResolver::createValueTypeResolver< ::QStateMachine::SignalEvent >("QStateMachine::SignalEvent");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStateMachine::SignalEvent >("QStateMachine::SignalEvent*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QStateMachine::SignalEvent >(typeid(::QStateMachine::SignalEvent).name());
    Shiboken::TypeResolver::createValueTypeResolver< ::QStateMachine::SignalEvent >(typeid(::SignalEventWrapper).name());
}
