/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qsysinfo_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSysInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSysInfo >()))
        return -1;

    ::QSysInfo* cptr = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // QSysInfo()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = new ::QSysInfo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSysInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyMethodDef Sbk_QSysInfo_methods[] = {

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QSysInfo_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QSysInfo_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSysInfo_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QSysInfo",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QSysInfo_traverse,
    /*tp_clear*/            Sbk_QSysInfo_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSysInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSysInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSysInfo(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSYSINFO_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSysInfo_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QSysInfo", "QSysInfo*",
        &Sbk_QSysInfo_Type, &Shiboken::callCppDestructor< ::QSysInfo >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'Endian'.
    SbkPySide_QtCoreTypes[SBK_QSYSINFO_ENDIAN_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QSysInfo_Type,
        "Endian",
        "PySide.QtCore.QSysInfo.Endian",
        "QSysInfo::Endian");
    if (!SbkPySide_QtCoreTypes[SBK_QSYSINFO_ENDIAN_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSINFO_ENDIAN_IDX],
        &Sbk_QSysInfo_Type, "BigEndian", (long) QSysInfo::BigEndian))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSINFO_ENDIAN_IDX],
        &Sbk_QSysInfo_Type, "LittleEndian", (long) QSysInfo::LittleEndian))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSINFO_ENDIAN_IDX],
        &Sbk_QSysInfo_Type, "ByteOrder", (long) QSysInfo::ByteOrder))
        return ;
    // End of 'Endian' enum.

    // Initialization of enum 'Sizes'.
    SbkPySide_QtCoreTypes[SBK_QSYSINFO_SIZES_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QSysInfo_Type,
        "Sizes",
        "PySide.QtCore.QSysInfo.Sizes",
        "QSysInfo::Sizes");
    if (!SbkPySide_QtCoreTypes[SBK_QSYSINFO_SIZES_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSINFO_SIZES_IDX],
        &Sbk_QSysInfo_Type, "WordSize", (long) QSysInfo::WordSize))
        return ;
    // End of 'Sizes' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QSysInfo >("QSysInfo*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QSysInfo >(typeid(::QSysInfo).name());
    qRegisterMetaType< ::QSysInfo::Endian >("QSysInfo::Endian");
    qRegisterMetaType< ::QSysInfo::Sizes >("QSysInfo::Sizes");
}
