/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "quuid_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <quuid.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUuid_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QUuid >()))
        return -1;

    ::QUuid* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8 || numArgs == 9 || numArgs == 10)
        goto Sbk_QUuid_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QUuid", 0, 11, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9]), &(pyArgs[10])))
        return -1;


    // Overloaded function decisor
    // 0: QUuid()
    // 1: QUuid(QByteArray)
    // 2: QUuid(QString)
    // 3: QUuid(QUuid)
    // 4: QUuid(const char*)
    // 5: QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
    if (numArgs == 0) {
        overloadId = 0; // QUuid()
    } else if (numArgs == 11
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< unsigned short int >::isConvertible(pyArgs[1])
        && Shiboken::Converter< unsigned short int >::isConvertible(pyArgs[2])
        && Shiboken::Converter< unsigned char >::isConvertible(pyArgs[3])
        && Shiboken::Converter< unsigned char >::isConvertible(pyArgs[4])
        && Shiboken::Converter< unsigned char >::isConvertible(pyArgs[5])
        && Shiboken::Converter< unsigned char >::isConvertible(pyArgs[6])
        && Shiboken::Converter< unsigned char >::isConvertible(pyArgs[7])
        && Shiboken::Converter< unsigned char >::isConvertible(pyArgs[8])
        && Shiboken::Converter< unsigned char >::isConvertible(pyArgs[9])
        && Shiboken::Converter< unsigned char >::isConvertible(pyArgs[10])) {
        overloadId = 5; // QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
    } else if (numArgs == 1
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])) {
        overloadId = 4; // QUuid(const char*)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        overloadId = 2; // QUuid(QString)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QUuid(QByteArray)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QUuid >::isConvertible(pyArgs[0])) {
        overloadId = 3; // QUuid(QUuid)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUuid_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QUuid()
        {

            if(!PyErr_Occurred()) {
                // QUuid()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QUuid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QUuid(QByteArray)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QUuid(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QUuid(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QUuid(QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QUuid(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QUuid(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QUuid(QUuid)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QUuid(QUuid)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QUuid(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // QUuid(const char*)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QUuid(const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QUuid(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 5: // QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
        {
            uint cppArg0 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[0]);
            ushort cppArg1 = Shiboken::Converter< unsigned short int >::toCpp(pyArgs[1]);
            ushort cppArg2 = Shiboken::Converter< unsigned short int >::toCpp(pyArgs[2]);
            uchar cppArg3 = Shiboken::Converter< unsigned char >::toCpp(pyArgs[3]);
            uchar cppArg4 = Shiboken::Converter< unsigned char >::toCpp(pyArgs[4]);
            uchar cppArg5 = Shiboken::Converter< unsigned char >::toCpp(pyArgs[5]);
            uchar cppArg6 = Shiboken::Converter< unsigned char >::toCpp(pyArgs[6]);
            uchar cppArg7 = Shiboken::Converter< unsigned char >::toCpp(pyArgs[7]);
            uchar cppArg8 = Shiboken::Converter< unsigned char >::toCpp(pyArgs[8]);
            uchar cppArg9 = Shiboken::Converter< unsigned char >::toCpp(pyArgs[9]);
            uchar cppArg10 = Shiboken::Converter< unsigned char >::toCpp(pyArgs[10]);

            if(!PyErr_Occurred()) {
                // QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QUuid(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QUuid >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QUuid_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QUuid_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray", "unicode", "PySide.QtCore.QUuid", ""SBK_STR_NAME"", "unsigned int, unsigned short int, unsigned short int, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUuid", overloads);
        return -1;
}

static PyObject* Sbk_QUuidFunc___reduce__(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __reduce__()
            // Begin code injection

            // TEMPLATE - reduce_code - START
            pyResult = Py_BuildValue("(N(s))", PyObject_Type(self), qPrintable(cppSelf->toString()));
            // TEMPLATE - reduce_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc___repr__(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __repr__()
            // Begin code injection

            // TEMPLATE - repr_code - START
            QString format = QString().sprintf("%s('%s')", ((PyObject*)self)->ob_type->tp_name, qPrintable(cppSelf->toString()));
            pyResult = Shiboken::String::fromCString(qPrintable(format));
            // TEMPLATE - repr_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_createUuid(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // createUuid()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUuid cppResult = QUuid::createUuid();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QUuid >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_fromRfc4122(PyObject* self, PyObject* pyArg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromRfc4122(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArg)) {
        overloadId = 0; // fromRfc4122(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUuidFunc_fromRfc4122_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // fromRfc4122(QByteArray)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUuid cppResult = QUuid::fromRfc4122(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QUuid >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUuidFunc_fromRfc4122_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QUuid.fromRfc4122", overloads);
        return 0;
}

static PyObject* Sbk_QUuidFunc_isNull(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isNull()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QUuid*>(cppSelf)->isNull();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_toByteArray(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toByteArray()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QByteArray cppResult = const_cast<const ::QUuid*>(cppSelf)->toByteArray();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_toRfc4122(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toRfc4122()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QByteArray cppResult = const_cast<const ::QUuid*>(cppSelf)->toRfc4122();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_toString(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toString()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QUuid*>(cppSelf)->toString();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_variant(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // variant()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUuid::Variant cppResult = const_cast<const ::QUuid*>(cppSelf)->variant();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QUuid::Variant >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_version(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // version()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUuid::Version cppResult = const_cast<const ::QUuid*>(cppSelf)->version();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QUuid::Version >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuid___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QUuid& cppSelf = *(Shiboken::Converter< ::QUuid* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QUuid >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QUuid_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QUuidFunc___reduce__, METH_NOARGS},
    {"createUuid", (PyCFunction)Sbk_QUuidFunc_createUuid, METH_NOARGS|METH_STATIC},
    {"fromRfc4122", (PyCFunction)Sbk_QUuidFunc_fromRfc4122, METH_O|METH_STATIC},
    {"isNull", (PyCFunction)Sbk_QUuidFunc_isNull, METH_NOARGS},
    {"toByteArray", (PyCFunction)Sbk_QUuidFunc_toByteArray, METH_NOARGS},
    {"toRfc4122", (PyCFunction)Sbk_QUuidFunc_toRfc4122, METH_NOARGS},
    {"toString", (PyCFunction)Sbk_QUuidFunc_toString, METH_NOARGS},
    {"variant", (PyCFunction)Sbk_QUuidFunc_variant, METH_NOARGS},
    {"version", (PyCFunction)Sbk_QUuidFunc_version, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QUuid___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QUuid___nb_bool(PyObject* self)
{
    ::QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return -1;
    cppSelf = Shiboken::Converter< ::QUuid* >::toCpp(self);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

// Rich comparison
static PyObject* Sbk_QUuid_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QUuid& cppSelf = *(Shiboken::Converter< ::QUuid* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QUuid >::isConvertible(pyArg)) {
                // operator!=(const QUuid & orig) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if (Shiboken::Converter< ::QUuid >::isConvertible(pyArg)) {
                // operator<(const QUuid & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(pyArg);
                bool cppResult = cppSelf < cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                goto Sbk_QUuid_RichComparison_TypeError;
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QUuid >::isConvertible(pyArg)) {
                // operator==(const QUuid & orig) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if (Shiboken::Converter< ::QUuid >::isConvertible(pyArg)) {
                // operator>(const QUuid & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(pyArg);
                bool cppResult = cppSelf > cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                goto Sbk_QUuid_RichComparison_TypeError;
            }

            break;
        default:
            goto Sbk_QUuid_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QUuid_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QUuid_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QUuid_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QUuid_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QUuid",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QUuidFunc___repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QUuid_traverse,
    /*tp_clear*/            Sbk_QUuid_clear,
    /*tp_richcompare*/      Sbk_QUuid_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QUuid_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QUuid_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QUuid(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QUuid_Type.super.as_number, 0, sizeof(PyNumberMethods));
    SBK_NB_BOOL(Sbk_QUuid_Type.super.as_number) = Sbk_QUuid___nb_bool;
    Sbk_QUuid_Type.super.ht_type.tp_as_number = &Sbk_QUuid_Type.super.as_number;

    SbkPySide_QtCoreTypes[SBK_QUUID_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QUuid_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QUuid", "QUuid",
        &Sbk_QUuid_Type, &Shiboken::callCppDestructor< ::QUuid >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'Variant'.
    SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QUuid_Type,
        "Variant",
        "PySide.QtCore.QUuid.Variant",
        "QUuid::Variant");
    if (!SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX],
        &Sbk_QUuid_Type, "VarUnknown", (long) QUuid::VarUnknown))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX],
        &Sbk_QUuid_Type, "NCS", (long) QUuid::NCS))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX],
        &Sbk_QUuid_Type, "DCE", (long) QUuid::DCE))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX],
        &Sbk_QUuid_Type, "Microsoft", (long) QUuid::Microsoft))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX],
        &Sbk_QUuid_Type, "Reserved", (long) QUuid::Reserved))
        return ;
    // End of 'Variant' enum.

    // Initialization of enum 'Version'.
    SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QUuid_Type,
        "Version",
        "PySide.QtCore.QUuid.Version",
        "QUuid::Version");
    if (!SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX],
        &Sbk_QUuid_Type, "VerUnknown", (long) QUuid::VerUnknown))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX],
        &Sbk_QUuid_Type, "Time", (long) QUuid::Time))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX],
        &Sbk_QUuid_Type, "EmbeddedPOSIX", (long) QUuid::EmbeddedPOSIX))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX],
        &Sbk_QUuid_Type, "Name", (long) QUuid::Name))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX],
        &Sbk_QUuid_Type, "Random", (long) QUuid::Random))
        return ;
    // End of 'Version' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QUuid >("QUuid");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QUuid >("QUuid*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QUuid >(typeid(::QUuid).name());
    qRegisterMetaType< ::QUuid >("QUuid");
    qRegisterMetaType< ::QUuid::Variant >("QUuid::Variant");
    qRegisterMetaType< ::QUuid::Version >("QUuid::Version");
}
