/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qwritelocker_wrapper.h"

// Extra includes
#include <qreadwritelock.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWriteLocker_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWriteLocker >()))
        return -1;

    ::QWriteLocker* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWriteLocker", 1, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QWriteLocker(QReadWriteLock*)
    if (numArgs == 1
        && Shiboken::Converter< ::QReadWriteLock * >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QWriteLocker(QReadWriteLock*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWriteLocker_Init_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QReadWriteLock * cppArg0 = Shiboken::Converter< ::QReadWriteLock * >::toCpp(pyArgs[0]);

        if(!PyErr_Occurred()) {
            // QWriteLocker(QReadWriteLock*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = new ::QWriteLocker(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject*>(self), "QWriteLocker(QReadWriteLock*)1", pyArgs[0]);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWriteLocker >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWriteLocker_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QWriteLocker_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QReadWriteLock", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QWriteLocker", overloads);
        return -1;
}

static PyObject* Sbk_QWriteLockerFunc___enter__(PyObject* self)
{
    ::QWriteLocker* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QWriteLocker* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __enter__()
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWriteLockerFunc___exit__(PyObject* self, PyObject* args)
{
    ::QWriteLocker* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QWriteLocker* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "__exit__", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: __exit__(PyObject*,PyObject*,PyObject*)
    if (numArgs == 3
        && PyObject_Check(pyArgs[0])
        && PyObject_Check(pyArgs[1])
        && PyObject_Check(pyArgs[2])) {
        overloadId = 0; // __exit__(PyObject*,PyObject*,PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWriteLockerFunc___exit___TypeError;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __exit__(PyObject*,PyObject*,PyObject*)
            // Begin code injection

            cppSelf->unlock();

            // End of code injection


        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWriteLockerFunc___exit___TypeError:
        const char* overloads[] = {"object, object, object", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QWriteLocker.__exit__", overloads);
        return 0;
}

static PyObject* Sbk_QWriteLockerFunc_readWriteLock(PyObject* self)
{
    ::QWriteLocker* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QWriteLocker* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // readWriteLock()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QReadWriteLock * cppResult = const_cast<const ::QWriteLocker*>(cppSelf)->readWriteLock();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QReadWriteLock * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWriteLockerFunc_relock(PyObject* self)
{
    ::QWriteLocker* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QWriteLocker* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // relock()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->relock();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWriteLockerFunc_unlock(PyObject* self)
{
    ::QWriteLocker* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QWriteLocker* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // unlock()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->unlock();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QWriteLocker_methods[] = {
    {"__enter__", (PyCFunction)Sbk_QWriteLockerFunc___enter__, METH_NOARGS},
    {"__exit__", (PyCFunction)Sbk_QWriteLockerFunc___exit__, METH_VARARGS},
    {"readWriteLock", (PyCFunction)Sbk_QWriteLockerFunc_readWriteLock, METH_NOARGS},
    {"relock", (PyCFunction)Sbk_QWriteLockerFunc_relock, METH_NOARGS},
    {"unlock", (PyCFunction)Sbk_QWriteLockerFunc_unlock, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QWriteLocker_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QWriteLocker_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWriteLocker_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QWriteLocker",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QWriteLocker_traverse,
    /*tp_clear*/            Sbk_QWriteLocker_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWriteLocker_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWriteLocker_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QWriteLocker(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QWRITELOCKER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWriteLocker_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QWriteLocker", "QWriteLocker*",
        &Sbk_QWriteLocker_Type, &Shiboken::callCppDestructor< ::QWriteLocker >)) {
        return;
    }


    Shiboken::TypeResolver::createObjectTypeResolver< ::QWriteLocker >("QWriteLocker*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QWriteLocker >(typeid(::QWriteLocker).name());
}
