/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamwriter_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>
#include <qtextcodec.h>
#include <qxmlstream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamWriter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QXmlStreamWriter >()))
        return -1;

    ::QXmlStreamWriter* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamWriter", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QXmlStreamWriter()
    // 1: QXmlStreamWriter(QByteArray*)
    // 2: QXmlStreamWriter(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamWriter()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QIODevice * >::isConvertible(pyArgs[0])) {
        overloadId = 2; // QXmlStreamWriter(QIODevice*)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QByteArray * >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QXmlStreamWriter(QByteArray*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriter_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QXmlStreamWriter()
        {

            if(!PyErr_Occurred()) {
                // QXmlStreamWriter()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QXmlStreamWriter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QXmlStreamWriter(QByteArray*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray * cppArg0 = Shiboken::Converter< ::QByteArray * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QXmlStreamWriter(QByteArray*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QXmlStreamWriter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QXmlStreamWriter(QIODevice*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice * cppArg0 = Shiboken::Converter< ::QIODevice * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QXmlStreamWriter(QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QXmlStreamWriter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QXmlStreamWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlStreamWriter_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlStreamWriter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray", "PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter", overloads);
        return -1;
}

static PyObject* Sbk_QXmlStreamWriterFunc_autoFormatting(PyObject* self)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // autoFormatting()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QXmlStreamWriter*>(cppSelf)->autoFormatting();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamWriterFunc_autoFormattingIndent(PyObject* self)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // autoFormattingIndent()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QXmlStreamWriter*>(cppSelf)->autoFormattingIndent();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamWriterFunc_codec(PyObject* self)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // codec()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextCodec * cppResult = const_cast<const ::QXmlStreamWriter*>(cppSelf)->codec();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextCodec * >::toPython(cppResult);

            // Ownership transferences.
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamWriterFunc_device(PyObject* self)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // device()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QIODevice * cppResult = const_cast<const ::QXmlStreamWriter*>(cppSelf)->device();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamWriterFunc_hasError(PyObject* self)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // hasError()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QXmlStreamWriter*>(cppSelf)->hasError();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamWriterFunc_setAutoFormatting(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoFormatting(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setAutoFormatting(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_setAutoFormatting_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setAutoFormatting(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAutoFormatting(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_setAutoFormatting_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.setAutoFormatting", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_setAutoFormattingIndent(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoFormattingIndent(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setAutoFormattingIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_setAutoFormattingIndent_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setAutoFormattingIndent(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAutoFormattingIndent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_setAutoFormattingIndent_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.setAutoFormattingIndent", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_setCodec(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodec(QTextCodec*)
    // 1: setCodec(const char*)
    if (Shiboken::Converter< const char * >::isConvertible(pyArg)) {
        overloadId = 1; // setCodec(const char*)
    } else if (Shiboken::Converter< ::QTextCodec * >::isConvertible(pyArg)) {
        overloadId = 0; // setCodec(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_setCodec_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setCodec(QTextCodec*)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QTextCodec * cppArg0 = Shiboken::Converter< ::QTextCodec * >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // setCodec(QTextCodec*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCodec(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setCodec(const char*)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // setCodec(const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCodec(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_setCodec_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", ""SBK_STR_NAME"", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.setCodec", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_setDevice(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyArg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_setDevice_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QIODevice * cppArg0 = Shiboken::Converter< ::QIODevice * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setDevice(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.setDevice", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeAttribute(PyObject* self, PyObject* args)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeAttribute", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: writeAttribute(QString,QString,QString)
    // 1: writeAttribute(QString,QString)
    // 2: writeAttribute(QXmlStreamAttribute)
    if (numArgs == 1
        && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyArgs[0])) {
        overloadId = 2; // writeAttribute(QXmlStreamAttribute)
    } else if (numArgs >= 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // writeAttribute(QString,QString)
        } else if (numArgs == 3
            && Shiboken::Converter< ::QString >::isConvertible(pyArgs[2])) {
            overloadId = 0; // writeAttribute(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeAttribute_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // writeAttribute(QString,QString,QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);
            ::QString cppArg2 = Shiboken::Converter< ::QString >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // writeAttribute(QString,QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeAttribute(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // writeAttribute(QString,QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // writeAttribute(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeAttribute(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // writeAttribute(QXmlStreamAttribute)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QXmlStreamAttribute cppArg0 = Shiboken::Converter< ::QXmlStreamAttribute >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // writeAttribute(QXmlStreamAttribute)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeAttribute_TypeError:
        const char* overloads[] = {"unicode, unicode, unicode", "unicode, unicode", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeAttributes(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeAttributes(QXmlStreamAttributes)
    if (Shiboken::Converter< ::QXmlStreamAttributes >::isConvertible(pyArg)) {
        overloadId = 0; // writeAttributes(QXmlStreamAttributes)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeAttributes_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QXmlStreamAttributes cppArg0 = Shiboken::Converter< ::QXmlStreamAttributes >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // writeAttributes(QXmlStreamAttributes)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeAttributes(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeAttributes_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttributes", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.writeAttributes", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeCDATA(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeCDATA(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // writeCDATA(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeCDATA_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // writeCDATA(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeCDATA(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeCDATA_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.writeCDATA", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeCharacters(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeCharacters(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // writeCharacters(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeCharacters_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // writeCharacters(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeCharacters(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeCharacters_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.writeCharacters", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeComment(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeComment(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // writeComment(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeComment_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // writeComment(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeComment(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeComment_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.writeComment", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeCurrentToken(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeCurrentToken(QXmlStreamReader)
    if (Shiboken::Converter< ::QXmlStreamReader >::isConvertible(pyArg)) {
        overloadId = 0; // writeCurrentToken(QXmlStreamReader)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeCurrentToken_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        const QXmlStreamReader & cppArg0 = Shiboken::Converter< ::QXmlStreamReader >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // writeCurrentToken(QXmlStreamReader)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeCurrentToken(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeCurrentToken_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamReader", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.writeCurrentToken", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeDTD(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeDTD(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // writeDTD(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeDTD_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // writeDTD(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeDTD(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeDTD_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.writeDTD", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeDefaultNamespace(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeDefaultNamespace(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // writeDefaultNamespace(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeDefaultNamespace_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // writeDefaultNamespace(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeDefaultNamespace(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeDefaultNamespace_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.writeDefaultNamespace", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeEmptyElement(PyObject* self, PyObject* args)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeEmptyElement", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeEmptyElement(QString,QString)
    // 1: writeEmptyElement(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // writeEmptyElement(QString)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 0; // writeEmptyElement(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeEmptyElement_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // writeEmptyElement(QString,QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // writeEmptyElement(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeEmptyElement(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // writeEmptyElement(QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // writeEmptyElement(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeEmptyElement(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeEmptyElement_TypeError:
        const char* overloads[] = {"unicode, unicode", "unicode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeEmptyElement", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeEndDocument(PyObject* self)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // writeEndDocument()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeEndDocument();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeEndElement(PyObject* self)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // writeEndElement()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeEndElement();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeEntityReference(PyObject* self, PyObject* pyArg)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeEntityReference(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // writeEntityReference(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeEntityReference_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // writeEntityReference(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeEntityReference(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeEntityReference_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QXmlStreamWriter.writeEntityReference", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeNamespace(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeNamespace(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeNamespace(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:writeNamespace", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeNamespace(QString,QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // writeNamespace(QString,QString)
        } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 0; // writeNamespace(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeNamespace_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "prefix");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "prefix";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QXmlStreamWriterFunc_writeNamespace_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeNamespace(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        ::QString cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[1]) : QString();

        if(!PyErr_Occurred()) {
            // writeNamespace(QString,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeNamespace(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeNamespace_TypeError:
        const char* overloads[] = {"unicode, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeNamespace", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeProcessingInstruction(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:writeProcessingInstruction", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeProcessingInstruction(QString,QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // writeProcessingInstruction(QString,QString)
        } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 0; // writeProcessingInstruction(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeProcessingInstruction_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "data");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "data";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QXmlStreamWriterFunc_writeProcessingInstruction_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        ::QString cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[1]) : QString();

        if(!PyErr_Occurred()) {
            // writeProcessingInstruction(QString,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->writeProcessingInstruction(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeProcessingInstruction_TypeError:
        const char* overloads[] = {"unicode, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeStartDocument(PyObject* self, PyObject* args)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeStartDocument", 0, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeStartDocument()
    // 1: writeStartDocument(QString)
    // 2: writeStartDocument(QString,bool)
    if (numArgs == 0) {
        overloadId = 0; // writeStartDocument()
    } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // writeStartDocument(QString)
        } else if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 2; // writeStartDocument(QString,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeStartDocument_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // writeStartDocument()
        {

            if(!PyErr_Occurred()) {
                // writeStartDocument()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeStartDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // writeStartDocument(QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // writeStartDocument(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeStartDocument(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // writeStartDocument(QString,bool)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            bool cppArg1 = Shiboken::Converter< bool >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // writeStartDocument(QString,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeStartDocument(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeStartDocument_TypeError:
        const char* overloads[] = {"", "unicode", "unicode, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeStartDocument", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeStartElement(PyObject* self, PyObject* args)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeStartElement", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeStartElement(QString,QString)
    // 1: writeStartElement(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // writeStartElement(QString)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 0; // writeStartElement(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeStartElement_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // writeStartElement(QString,QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // writeStartElement(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeStartElement(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // writeStartElement(QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // writeStartElement(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeStartElement(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeStartElement_TypeError:
        const char* overloads[] = {"unicode, unicode", "unicode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeStartElement", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamWriterFunc_writeTextElement(PyObject* self, PyObject* args)
{
    ::QXmlStreamWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QXmlStreamWriter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeTextElement", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: writeTextElement(QString,QString,QString)
    // 1: writeTextElement(QString,QString)
    if (numArgs >= 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // writeTextElement(QString,QString)
        } else if (numArgs == 3
            && Shiboken::Converter< ::QString >::isConvertible(pyArgs[2])) {
            overloadId = 0; // writeTextElement(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamWriterFunc_writeTextElement_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // writeTextElement(QString,QString,QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);
            ::QString cppArg2 = Shiboken::Converter< ::QString >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // writeTextElement(QString,QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeTextElement(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // writeTextElement(QString,QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // writeTextElement(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->writeTextElement(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamWriterFunc_writeTextElement_TypeError:
        const char* overloads[] = {"unicode, unicode, unicode", "unicode, unicode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeTextElement", overloads);
        return 0;
}

static PyMethodDef Sbk_QXmlStreamWriter_methods[] = {
    {"autoFormatting", (PyCFunction)Sbk_QXmlStreamWriterFunc_autoFormatting, METH_NOARGS},
    {"autoFormattingIndent", (PyCFunction)Sbk_QXmlStreamWriterFunc_autoFormattingIndent, METH_NOARGS},
    {"codec", (PyCFunction)Sbk_QXmlStreamWriterFunc_codec, METH_NOARGS},
    {"device", (PyCFunction)Sbk_QXmlStreamWriterFunc_device, METH_NOARGS},
    {"hasError", (PyCFunction)Sbk_QXmlStreamWriterFunc_hasError, METH_NOARGS},
    {"setAutoFormatting", (PyCFunction)Sbk_QXmlStreamWriterFunc_setAutoFormatting, METH_O},
    {"setAutoFormattingIndent", (PyCFunction)Sbk_QXmlStreamWriterFunc_setAutoFormattingIndent, METH_O},
    {"setCodec", (PyCFunction)Sbk_QXmlStreamWriterFunc_setCodec, METH_O},
    {"setDevice", (PyCFunction)Sbk_QXmlStreamWriterFunc_setDevice, METH_O},
    {"writeAttribute", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeAttribute, METH_VARARGS},
    {"writeAttributes", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeAttributes, METH_O},
    {"writeCDATA", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeCDATA, METH_O},
    {"writeCharacters", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeCharacters, METH_O},
    {"writeComment", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeComment, METH_O},
    {"writeCurrentToken", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeCurrentToken, METH_O},
    {"writeDTD", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeDTD, METH_O},
    {"writeDefaultNamespace", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeDefaultNamespace, METH_O},
    {"writeEmptyElement", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeEmptyElement, METH_VARARGS},
    {"writeEndDocument", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeEndDocument, METH_NOARGS},
    {"writeEndElement", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeEndElement, METH_NOARGS},
    {"writeEntityReference", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeEntityReference, METH_O},
    {"writeNamespace", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeNamespace, METH_VARARGS|METH_KEYWORDS},
    {"writeProcessingInstruction", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeProcessingInstruction, METH_VARARGS|METH_KEYWORDS},
    {"writeStartDocument", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeStartDocument, METH_VARARGS},
    {"writeStartElement", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeStartElement, METH_VARARGS},
    {"writeTextElement", (PyCFunction)Sbk_QXmlStreamWriterFunc_writeTextElement, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QXmlStreamWriter_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QXmlStreamWriter_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlStreamWriter_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QXmlStreamWriter",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QXmlStreamWriter_traverse,
    /*tp_clear*/            Sbk_QXmlStreamWriter_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlStreamWriter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlStreamWriter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlStreamWriter(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMWRITER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlStreamWriter_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QXmlStreamWriter", "QXmlStreamWriter*",
        &Sbk_QXmlStreamWriter_Type, &Shiboken::callCppDestructor< ::QXmlStreamWriter >)) {
        return;
    }


    Shiboken::TypeResolver::createObjectTypeResolver< ::QXmlStreamWriter >("QXmlStreamWriter*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QXmlStreamWriter >(typeid(::QXmlStreamWriter).name());
}
