/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <pyside.h>
#include "pyside_qtdeclarative_python.h"



// Extra includes
#include <QtDeclarative>
#include "pysideqmlregistertype.h"


void cleanTypesAttributes(void) {
    for (int i = 0, imax = SBK_QtDeclarative_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject*>(SbkPySide_QtDeclarativeTypes[i]);
        if (pyType && PyObject_HasAttrString(pyType, "staticMetaObject"))
            PyObject_SetAttrString(pyType, "staticMetaObject", Py_None);
    }
}
// Global functions ------------------------------------------------------------
static PyObject* SbkQtDeclarativeModule_qmlRegisterType(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qmlRegisterType", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])))
        return 0;


    // Overloaded function decisor
    // 0: qmlRegisterType(PyTypeObject,const char*,int,int,const char*)
    if (numArgs == 5
        && PyType_Check(pyArgs[0])
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[4])) {
        overloadId = 0; // qmlRegisterType(PyTypeObject,const char*,int,int,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtDeclarativeModule_qmlRegisterType_TypeError;

    // Call function/method
    {
        const char * cppArg1 = Shiboken::Converter< const char * >::toCpp(pyArgs[1]);
        SBK_UNUSED(cppArg1)
        int cppArg2 = Shiboken::Converter< int >::toCpp(pyArgs[2]);
        SBK_UNUSED(cppArg2)
        int cppArg3 = Shiboken::Converter< int >::toCpp(pyArgs[3]);
        SBK_UNUSED(cppArg3)
        const char * cppArg4 = Shiboken::Converter< const char * >::toCpp(pyArgs[4]);
        SBK_UNUSED(cppArg4)

        if(!PyErr_Occurred()) {
            // qmlRegisterType(PyTypeObject,const char*,int,int,const char*)
            // Begin code injection

            int cppResult = PySide::qmlRegisterType(pyArgs[0], cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Converter< int >::toPython(cppResult);

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtDeclarativeModule_qmlRegisterType_TypeError:
        const char* overloads[] = {"PyTypeObject, "SBK_STR_NAME", int, int, "SBK_STR_NAME"", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qmlRegisterType", overloads);
        return 0;
}


static PyMethodDef QtDeclarative_methods[] = {
    {"qmlRegisterType", (PyCFunction)SbkQtDeclarativeModule_qmlRegisterType, METH_VARARGS},
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QDeclarativeScriptString(PyObject* module);
void init_QDeclarativeProperty(PyObject* module);
void init_QDeclarativeNetworkAccessManagerFactory(PyObject* module);
void init_QDeclarativeImageProvider(PyObject* module);
void init_QDeclarativeExtensionInterface(PyObject* module);
void init_QDeclarativeError(PyObject* module);
void init_QDeclarativeListReference(PyObject* module);
void init_QDeclarativePropertyValueSource(PyObject* module);
void init_QDeclarativeParserStatus(PyObject* module);
void init_QDeclarativeView(PyObject* module);
void init_QDeclarativeItem(PyObject* module);
void init_QDeclarativeExtensionPlugin(PyObject* module);
void init_QDeclarativeExpression(PyObject* module);
void init_QDeclarativeEngine(PyObject* module);
void init_QDeclarativeContext(PyObject* module);
void init_QDeclarativePropertyMap(PyObject* module);
void init_QDeclarativeComponent(PyObject* module);

// Enum definitions ------------------------------------------------------------
// Current module's type array.
PyTypeObject** SbkPySide_QtDeclarativeTypes;
// Required modules' type arrays.
PyTypeObject** SbkPySide_QtCoreTypes;
PyTypeObject** SbkPySide_QtNetworkTypes;
PyTypeObject** SbkPySide_QtGuiTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

#ifdef IS_PY3K
static int QtDeclarative_moduleTraverse(PyObject*, visitproc, void *)
{
    PySide::runCleanupFunctions();
}

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtDeclarative",
    /* m_doc      */ 0,
    /* m_size     */ -1,
    /* m_methods  */ QtDeclarative_methods,
    /* m_reload   */ 0,
    /* m_traverse */ QtDeclarative_moduleTraverse,
    /* m_clear    */ 0,
    /* m_free     */ 0
};

#endif
SBK_MODULE_INIT_FUNCTION_BEGIN(QtDeclarative)

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtCore"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtNetwork"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtNetworkTypes = Shiboken::Module::getTypes(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtGui"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtGuiTypes = Shiboken::Module::getTypes(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject* cppApi[SBK_QtDeclarative_IDX_COUNT];
    SbkPySide_QtDeclarativeTypes = cppApi;

#ifdef IS_PY3K
    PyObject* module = Shiboken::Module::create("QtDeclarative", &moduledef);
#else
    PyObject* module = Shiboken::Module::create("QtDeclarative", QtDeclarative_methods);
#endif

    // Initialize classes in the type system
    init_QDeclarativeScriptString(module);
    init_QDeclarativeProperty(module);
    init_QDeclarativeNetworkAccessManagerFactory(module);
    init_QDeclarativeImageProvider(module);
    init_QDeclarativeExtensionInterface(module);
    init_QDeclarativeError(module);
    init_QDeclarativeListReference(module);
    init_QDeclarativePropertyValueSource(module);
    init_QDeclarativeParserStatus(module);
    init_QDeclarativeView(module);
    init_QDeclarativeItem(module);
    init_QDeclarativeExtensionPlugin(module);
    init_QDeclarativeExpression(module);
    init_QDeclarativeEngine(module);
    init_QDeclarativeContext(module);
    init_QDeclarativePropertyMap(module);
    init_QDeclarativeComponent(module);

    // Initialization of enums.

    // Initialization of anonymous enum identified by enum value 'QML_HAS_ATTACHED_PROPERTIES'.
    if (PyModule_AddIntConstant(module, "QML_HAS_ATTACHED_PROPERTIES", (long) QML_HAS_ATTACHED_PROPERTIES) < 0)
        return SBK_MODULE_INIT_ERROR;
    // End of 'QML_HAS_ATTACHED_PROPERTIES' enum.

    // Register primitive types on TypeResolver
    Shiboken::TypeResolver::createValueTypeResolver< QList<QDeclarativeError> >("QList<QDeclarativeError>");

    Shiboken::Module::registerTypes(module, SbkPySide_QtDeclarativeTypes);

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtDeclarative");
    }
    // Begin code injection

    Shiboken::TypeResolver::createValueTypeResolver< QList<QObject*> >("QList<QObject*>");
    PySide::initQmlSupport(module);

    // End of code injection


    PySide::registerCleanupFunction(cleanTypesAttributes);
SBK_MODULE_INIT_FUNCTION_END
