/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgradient_wrapper.h"

// Extra includes
#include <QPair>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGradient_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGradient >()))
        return -1;

    ::QGradient* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGradient", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QGradient()
    // 1: QGradient(QGradient)
    if (numArgs == 0) {
        overloadId = 0; // QGradient()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QGradient >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QGradient(QGradient)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradient_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QGradient()
        {

            if(!PyErr_Occurred()) {
                // QGradient()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QGradient();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QGradient(QGradient)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGradient cppArg0 = Shiboken::Converter< ::QGradient >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QGradient(QGradient)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QGradient(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGradient >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGradient_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGradient_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QGradient", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGradient", overloads);
        return -1;
}

static PyObject* Sbk_QGradientFunc_coordinateMode(PyObject* self)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // coordinateMode()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QGradient::CoordinateMode cppResult = const_cast<const ::QGradient*>(cppSelf)->coordinateMode();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QGradient::CoordinateMode >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradientFunc_interpolationMode(PyObject* self)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // interpolationMode()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QGradient::InterpolationMode cppResult = const_cast<const ::QGradient*>(cppSelf)->interpolationMode();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QGradient::InterpolationMode >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradientFunc_setColorAt(PyObject* self, PyObject* args)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColorAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setColorAt(qreal,QColor)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QColor >::isConvertible(pyArgs[1])) {
        overloadId = 0; // setColorAt(qreal,QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setColorAt_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QColor cppArg1 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // setColorAt(qreal,QColor)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setColorAt(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setColorAt_TypeError:
        const char* overloads[] = {"float, PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGradient.setColorAt", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_setCoordinateMode(PyObject* self, PyObject* pyArg)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCoordinateMode(QGradient::CoordinateMode)
    if (Shiboken::Converter< ::QGradient::CoordinateMode >::isConvertible(pyArg)) {
        overloadId = 0; // setCoordinateMode(QGradient::CoordinateMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setCoordinateMode_TypeError;

    // Call function/method
    {
        QGradient::CoordinateMode cppArg0 = Shiboken::Converter< ::QGradient::CoordinateMode >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCoordinateMode(QGradient::CoordinateMode)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCoordinateMode(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setCoordinateMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGradient.CoordinateMode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QGradient.setCoordinateMode", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_setInterpolationMode(PyObject* self, PyObject* pyArg)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInterpolationMode(QGradient::InterpolationMode)
    if (Shiboken::Converter< ::QGradient::InterpolationMode >::isConvertible(pyArg)) {
        overloadId = 0; // setInterpolationMode(QGradient::InterpolationMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setInterpolationMode_TypeError;

    // Call function/method
    {
        QGradient::InterpolationMode cppArg0 = Shiboken::Converter< ::QGradient::InterpolationMode >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setInterpolationMode(QGradient::InterpolationMode)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setInterpolationMode(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setInterpolationMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGradient.InterpolationMode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QGradient.setInterpolationMode", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_setSpread(PyObject* self, PyObject* pyArg)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSpread(QGradient::Spread)
    if (Shiboken::Converter< ::QGradient::Spread >::isConvertible(pyArg)) {
        overloadId = 0; // setSpread(QGradient::Spread)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setSpread_TypeError;

    // Call function/method
    {
        QGradient::Spread cppArg0 = Shiboken::Converter< ::QGradient::Spread >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setSpread(QGradient::Spread)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setSpread(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setSpread_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGradient.Spread", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QGradient.setSpread", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_setStops(PyObject* self, PyObject* pyArg)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStops(QVector<QPair<qreal,QColor> >)
    if (Shiboken::Converter< ::QVector<QPair<qreal, QColor > > >::isConvertible(pyArg)) {
        overloadId = 0; // setStops(QVector<QPair<qreal,QColor> >)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setStops_TypeError;

    // Call function/method
    {
        ::QVector<QPair<qreal, QColor > > cppArg0 = Shiboken::Converter< ::QVector<QPair<qreal, QColor > > >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setStops(QVector<QPair<qreal,QColor> >)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setStops(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setStops_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QGradient.setStops", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_spread(PyObject* self)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // spread()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QGradient::Spread cppResult = const_cast<const ::QGradient*>(cppSelf)->spread();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QGradient::Spread >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradientFunc_stops(PyObject* self)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // stops()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVector<QPair<qreal, QColor > > cppResult = const_cast<const ::QGradient*>(cppSelf)->stops();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVector<QPair<qreal, QColor > > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradientFunc_type(PyObject* self)
{
    ::QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // type()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QGradient::Type cppResult = const_cast<const ::QGradient*>(cppSelf)->type();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QGradient::Type >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradient___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QGradient& cppSelf = *(Shiboken::Converter< ::QGradient* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QGradient >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QGradient_methods[] = {
    {"coordinateMode", (PyCFunction)Sbk_QGradientFunc_coordinateMode, METH_NOARGS},
    {"interpolationMode", (PyCFunction)Sbk_QGradientFunc_interpolationMode, METH_NOARGS},
    {"setColorAt", (PyCFunction)Sbk_QGradientFunc_setColorAt, METH_VARARGS},
    {"setCoordinateMode", (PyCFunction)Sbk_QGradientFunc_setCoordinateMode, METH_O},
    {"setInterpolationMode", (PyCFunction)Sbk_QGradientFunc_setInterpolationMode, METH_O},
    {"setSpread", (PyCFunction)Sbk_QGradientFunc_setSpread, METH_O},
    {"setStops", (PyCFunction)Sbk_QGradientFunc_setStops, METH_O},
    {"spread", (PyCFunction)Sbk_QGradientFunc_spread, METH_NOARGS},
    {"stops", (PyCFunction)Sbk_QGradientFunc_stops, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QGradientFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QGradient___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QGradient_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QGradient& cppSelf = *(Shiboken::Converter< ::QGradient* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QGradient >::isConvertible(pyArg)) {
                // operator!=(const QGradient & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QGradient cppArg0 = Shiboken::Converter< ::QGradient >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QGradient >::isConvertible(pyArg)) {
                // operator==(const QGradient & gradient) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QGradient cppArg0 = Shiboken::Converter< ::QGradient >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else if (Shiboken::Converter< ::QGradient >::isConvertible(pyArg)) {
                // operator==(const QGradient & gradient)
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QGradient cppArg0 = Shiboken::Converter< ::QGradient >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QGradient_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QGradient_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QGradient_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QGradient_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGradient_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QGradient",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QGradient_traverse,
    /*tp_clear*/            Sbk_QGradient_clear,
    /*tp_richcompare*/      Sbk_QGradient_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGradient_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGradient_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QGradient(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGradient_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QGradient", "QGradient",
        &Sbk_QGradient_Type, &Shiboken::callCppDestructor< ::QGradient >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'CoordinateMode'.
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_COORDINATEMODE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QGradient_Type,
        "CoordinateMode",
        "PySide.QtGui.QGradient.CoordinateMode",
        "QGradient::CoordinateMode");
    if (!SbkPySide_QtGuiTypes[SBK_QGRADIENT_COORDINATEMODE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_COORDINATEMODE_IDX],
        &Sbk_QGradient_Type, "LogicalMode", (long) QGradient::LogicalMode))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_COORDINATEMODE_IDX],
        &Sbk_QGradient_Type, "StretchToDeviceMode", (long) QGradient::StretchToDeviceMode))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_COORDINATEMODE_IDX],
        &Sbk_QGradient_Type, "ObjectBoundingMode", (long) QGradient::ObjectBoundingMode))
        return ;
    // End of 'CoordinateMode' enum.

    // Initialization of enum 'Spread'.
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_SPREAD_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QGradient_Type,
        "Spread",
        "PySide.QtGui.QGradient.Spread",
        "QGradient::Spread");
    if (!SbkPySide_QtGuiTypes[SBK_QGRADIENT_SPREAD_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_SPREAD_IDX],
        &Sbk_QGradient_Type, "PadSpread", (long) QGradient::PadSpread))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_SPREAD_IDX],
        &Sbk_QGradient_Type, "ReflectSpread", (long) QGradient::ReflectSpread))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_SPREAD_IDX],
        &Sbk_QGradient_Type, "RepeatSpread", (long) QGradient::RepeatSpread))
        return ;
    // End of 'Spread' enum.

    // Initialization of enum 'Type'.
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_TYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QGradient_Type,
        "Type",
        "PySide.QtGui.QGradient.Type",
        "QGradient::Type");
    if (!SbkPySide_QtGuiTypes[SBK_QGRADIENT_TYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_TYPE_IDX],
        &Sbk_QGradient_Type, "LinearGradient", (long) QGradient::LinearGradient))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_TYPE_IDX],
        &Sbk_QGradient_Type, "RadialGradient", (long) QGradient::RadialGradient))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_TYPE_IDX],
        &Sbk_QGradient_Type, "ConicalGradient", (long) QGradient::ConicalGradient))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_TYPE_IDX],
        &Sbk_QGradient_Type, "NoGradient", (long) QGradient::NoGradient))
        return ;
    // End of 'Type' enum.

    // Initialization of enum 'InterpolationMode'.
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_INTERPOLATIONMODE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QGradient_Type,
        "InterpolationMode",
        "PySide.QtGui.QGradient.InterpolationMode",
        "QGradient::InterpolationMode");
    if (!SbkPySide_QtGuiTypes[SBK_QGRADIENT_INTERPOLATIONMODE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_INTERPOLATIONMODE_IDX],
        &Sbk_QGradient_Type, "ColorInterpolation", (long) QGradient::ColorInterpolation))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QGRADIENT_INTERPOLATIONMODE_IDX],
        &Sbk_QGradient_Type, "ComponentInterpolation", (long) QGradient::ComponentInterpolation))
        return ;
    // End of 'InterpolationMode' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QGradient >("QGradient");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QGradient >("QGradient*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QGradient >(typeid(::QGradient).name());
    qRegisterMetaType< ::QGradient >("QGradient");
    qRegisterMetaType< ::QGradient::CoordinateMode >("QGradient::CoordinateMode");
    qRegisterMetaType< ::QGradient::Spread >("QGradient::Spread");
    qRegisterMetaType< ::QGradient::Type >("QGradient::Type");
    qRegisterMetaType< ::QGradient::InterpolationMode >("QGradient::InterpolationMode");
}
