/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qlistwidgetitem_wrapper.h"

// Extra includes
#include <qbrush.h>
#include <qdatastream.h>
#include <qfont.h>
#include <qicon.h>
#include <qlistwidget.h>
#include <qsize.h>


// Native ---------------------------------------------------------

QListWidgetItemWrapper::QListWidgetItemWrapper(QListWidget * view, int type) : QListWidgetItem(view, type) {
    // ... middle
}

QListWidgetItemWrapper::QListWidgetItemWrapper(const QIcon & icon, const QString & text, QListWidget * view, int type) : QListWidgetItem(icon, text, view, type) {
    // ... middle
}

QListWidgetItemWrapper::QListWidgetItemWrapper(const QString & text, QListWidget * view, int type) : QListWidgetItem(text, view, type) {
    // ... middle
}

QListWidgetItem * QListWidgetItemWrapper::clone() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QListWidgetItem*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "clone"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QListWidgetItem::clone();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QListWidgetItem*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QListWidgetItem * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QListWidgetItem.clone", Shiboken::SbkType< QListWidgetItem >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QListWidgetItem*)0);
    }
    ::QListWidgetItem * cppResult = Shiboken::Converter< ::QListWidgetItem * >::toCpp(pyResult);
    return cppResult;
}

QVariant QListWidgetItemWrapper::data(int role) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QVariant();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "data"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QListWidgetItem::data(role);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        role
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QVariant();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QListWidgetItem.data", "QVariant", pyResult->ob_type->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult = Shiboken::Converter< ::QVariant >::toCpp(pyResult);
    return cppResult;
}

bool QListWidgetItemWrapper::operator<(const QListWidgetItem & other) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "__lt__"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QListWidgetItem::operator<(other);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QListWidgetItem >::toPython(other)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QListWidgetItem.__lt__", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

void QListWidgetItemWrapper::read(QDataStream & in)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "read"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QListWidgetItem::read(in);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDataStream & >::toPython(in)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QListWidgetItemWrapper::setData(int role, const QVariant & value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "setData"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QListWidgetItem::setData(role, value);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        role,
        Shiboken::Converter< ::QVariant >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListWidgetItemWrapper::write(QDataStream & out) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "write"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QListWidgetItem::write(out);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDataStream & >::toPython(out)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

QListWidgetItemWrapper::~QListWidgetItemWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QListWidgetItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QListWidgetItem >()))
        return -1;

    ::QListWidgetItemWrapper* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QListWidgetItem(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QListWidgetItem", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return -1;


    // Overloaded function decisor
    // 0: QListWidgetItem(QListWidget*,int)
    // 1: QListWidgetItem(QIcon,QString,QListWidget*,int)
    // 2: QListWidgetItem(QListWidgetItem)
    // 3: QListWidgetItem(QString,QListWidget*,int)
    if (numArgs == 0) {
        overloadId = 0; // QListWidgetItem(QListWidget*,int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QListWidgetItem >::isConvertible(pyArgs[0])) {
        overloadId = 2; // QListWidgetItem(QListWidgetItem)
    } else if (numArgs >= 2
        && Shiboken::Converter< ::QIcon >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QListWidgetItem(QIcon,QString,QListWidget*,int)
        } else if (Shiboken::Converter< ::QListWidget * >::isConvertible(pyArgs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // QListWidgetItem(QIcon,QString,QListWidget*,int)
            } else if (SbkNumber_Check(pyArgs[3])) {
                overloadId = 1; // QListWidgetItem(QIcon,QString,QListWidget*,int)
            }
        }
    } else if (Shiboken::Converter< ::QListWidget * >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QListWidgetItem(QListWidget*,int)
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 0; // QListWidgetItem(QListWidget*,int)
        }
    } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QListWidgetItem(QString,QListWidget*,int)
        } else if (Shiboken::Converter< ::QListWidget * >::isConvertible(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // QListWidgetItem(QString,QListWidget*,int)
            } else if (SbkNumber_Check(pyArgs[2])) {
                overloadId = 3; // QListWidgetItem(QString,QListWidget*,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItem_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QListWidgetItem(QListWidget*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "view");
                if (value) {
                    if (pyArgs[0])
                        errorArgName = "view";
                    else if (Shiboken::Converter< ::QListWidget * >::isConvertible(value))
                        pyArgs[0] = value;
                    else
                        goto Sbk_QListWidgetItem_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "type";
                    else if (SbkNumber_Check(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QListWidgetItem_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QListWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QListWidget * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QListWidget * >::toCpp(pyArgs[0]) : 0;
            int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : QListWidgetItem::Type;

            if(!PyErr_Occurred()) {
                // QListWidgetItem(QListWidget*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QListWidgetItemWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QListWidgetItem(QIcon,QString,QListWidget*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "view");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "view";
                    else if (Shiboken::Converter< ::QListWidget * >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QListWidgetItem_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyArgs[3])
                        errorArgName = "type";
                    else if (SbkNumber_Check(value))
                        pyArgs[3] = value;
                    else
                        goto Sbk_QListWidgetItem_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QListWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIcon cppArg0 = Shiboken::Converter< ::QIcon >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QListWidget * cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QListWidget * >::toCpp(pyArgs[2]) : 0;
            int cppArg3 = pyArgs[3] ? Shiboken::Converter< int >::toCpp(pyArgs[3]) : QListWidgetItem::Type;

            if(!PyErr_Occurred()) {
                // QListWidgetItem(QIcon,QString,QListWidget*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QListWidgetItemWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
        case 2: // QListWidgetItem(QListWidgetItem)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QListWidgetItem & cppArg0 = Shiboken::Converter< ::QListWidgetItem >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QListWidgetItem(QListWidgetItem)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QListWidgetItemWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QListWidgetItem(QString,QListWidget*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "view");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "view";
                    else if (Shiboken::Converter< ::QListWidget * >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QListWidgetItem_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "type";
                    else if (SbkNumber_Check(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QListWidgetItem_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QListWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QListWidget * cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QListWidget * >::toCpp(pyArgs[1]) : 0;
            int cppArg2 = pyArgs[2] ? Shiboken::Converter< int >::toCpp(pyArgs[2]) : QListWidgetItem::Type;

            if(!PyErr_Occurred()) {
                // QListWidgetItem(QString,QListWidget*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QListWidgetItemWrapper(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QListWidgetItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QListWidgetItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QListWidgetItem_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QListWidget = None, int = Type", "PySide.QtGui.QIcon, unicode, PySide.QtGui.QListWidget = None, int = Type", "PySide.QtGui.QListWidgetItem", "unicode, PySide.QtGui.QListWidget = None, int = Type", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListWidgetItem", overloads);
        return -1;
}

static PyObject* Sbk_QListWidgetItemFunc_background(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // background()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QBrush cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->background();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_checkState(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // checkState()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Qt::CheckState cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->checkState();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Qt::CheckState >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_clone(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // clone()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QListWidgetItem * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QListWidgetItem*>(cppSelf)->::QListWidgetItem::clone() : const_cast<const ::QListWidgetItem*>(cppSelf)->clone();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QListWidgetItem * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_data(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: data(int)const
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // data(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_data_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // data(int)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QListWidgetItem*>(cppSelf)->::QListWidgetItem::data(cppArg0) : const_cast<const ::QListWidgetItem*>(cppSelf)->data(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVariant >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListWidgetItemFunc_data_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.data", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_flags(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // flags()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFlags<Qt::ItemFlag> cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->flags();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFlags<Qt::ItemFlag> >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_font(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // font()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFont cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->font();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_foreground(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // foreground()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QBrush cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->foreground();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_icon(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // icon()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QIcon cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->icon();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_isHidden(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isHidden()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->isHidden();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_isSelected(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isSelected()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->isSelected();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_listWidget(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // listWidget()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QListWidget * cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->listWidget();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QListWidget * >::toPython(cppResult);

            // Ownership transferences.
            Shiboken::Object::getOwnership(pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_read(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(QDataStream&)
    if (Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // read(QDataStream&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_read_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // read(QDataStream&)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QListWidgetItem::read(cppArg0) : cppSelf->read(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_read_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.read", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setBackground(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackground(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(pyArg)) {
        overloadId = 0; // setBackground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setBackground_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBrush cppArg0 = Shiboken::Converter< ::QBrush >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setBackground(QBrush)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBackground(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setBackground", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setCheckState(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCheckState(Qt::CheckState)
    if (Shiboken::Converter< ::Qt::CheckState >::isConvertible(pyArg)) {
        overloadId = 0; // setCheckState(Qt::CheckState)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setCheckState_TypeError;

    // Call function/method
    {
        Qt::CheckState cppArg0 = Shiboken::Converter< ::Qt::CheckState >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCheckState(Qt::CheckState)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCheckState(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setCheckState_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.CheckState", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setCheckState", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setData(PyObject* self, PyObject* args)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setData", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setData(int,QVariant)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QVariant >::isConvertible(pyArgs[1])) {
        overloadId = 0; // setData(int,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setData_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
        ::QVariant cppArg1 = Shiboken::Converter< ::QVariant >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // setData(int,QVariant)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QListWidgetItem::setData(cppArg0, cppArg1) : cppSelf->setData(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setData_TypeError:
        const char* overloads[] = {"int, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListWidgetItem.setData", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setFlags(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFlags(QFlags<Qt::ItemFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::ItemFlag> >::isConvertible(pyArg)) {
        overloadId = 0; // setFlags(QFlags<Qt::ItemFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setFlags_TypeError;

    // Call function/method
    {
        QFlags<Qt::ItemFlag> cppArg0 = Shiboken::Converter< ::QFlags<Qt::ItemFlag> >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setFlags(QFlags<Qt::ItemFlag>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFlags(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ItemFlags", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setFlags", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setFont(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(pyArg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setFont_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QFont cppArg0 = Shiboken::Converter< ::QFont >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setFont(QFont)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFont(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setFont", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setForeground(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForeground(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(pyArg)) {
        overloadId = 0; // setForeground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setForeground_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBrush cppArg0 = Shiboken::Converter< ::QBrush >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setForeground(QBrush)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setForeground(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setForeground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setForeground", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setHidden(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHidden(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setHidden(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setHidden_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setHidden(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHidden(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setHidden_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setHidden", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setIcon(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIcon(QIcon)
    if (Shiboken::Converter< ::QIcon >::isConvertible(pyArg)) {
        overloadId = 0; // setIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setIcon_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QIcon cppArg0 = Shiboken::Converter< ::QIcon >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setIcon(QIcon)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setIcon(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setIcon", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setSelected(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelected(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setSelected(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setSelected_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setSelected(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setSelected(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setSelected_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setSelected", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setSizeHint(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSizeHint(QSize)
    if (Shiboken::Converter< ::QSize >::isConvertible(pyArg)) {
        overloadId = 0; // setSizeHint(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setSizeHint_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QSize cppArg0 = Shiboken::Converter< ::QSize >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setSizeHint(QSize)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setSizeHint(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setSizeHint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setSizeHint", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setStatusTip(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatusTip(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setStatusTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setStatusTip_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setStatusTip(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setStatusTip(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setStatusTip_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setStatusTip", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setText(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setText(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setText_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setText(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setText(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setText_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setText", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setTextAlignment(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextAlignment(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setTextAlignment(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setTextAlignment_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTextAlignment(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTextAlignment(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setTextAlignment_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setTextAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setToolTip(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolTip(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setToolTip_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setToolTip(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setToolTip(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setToolTip_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setToolTip", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_setWhatsThis(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWhatsThis(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setWhatsThis(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_setWhatsThis_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setWhatsThis(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setWhatsThis(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_setWhatsThis_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.setWhatsThis", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc_sizeHint(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // sizeHint()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSize cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->sizeHint();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_statusTip(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // statusTip()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->statusTip();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_text(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // text()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->text();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_textAlignment(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // textAlignment()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->textAlignment();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_toolTip(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toolTip()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->toolTip();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_type(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // type()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->type();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_whatsThis(PyObject* self)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // whatsThis()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QListWidgetItem*>(cppSelf)->whatsThis();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListWidgetItemFunc_write(PyObject* self, PyObject* pyArg)
{
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: write(QDataStream&)const
    if (Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // write(QDataStream&)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc_write_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // write(QDataStream&)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QListWidgetItem*>(cppSelf)->::QListWidgetItem::write(cppArg0) : const_cast<const ::QListWidgetItem*>(cppSelf)->write(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListWidgetItemFunc_write_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.write", overloads);
        return 0;
}

static PyMethodDef Sbk_QListWidgetItem_methods[] = {
    {"background", (PyCFunction)Sbk_QListWidgetItemFunc_background, METH_NOARGS},
    {"checkState", (PyCFunction)Sbk_QListWidgetItemFunc_checkState, METH_NOARGS},
    {"clone", (PyCFunction)Sbk_QListWidgetItemFunc_clone, METH_NOARGS},
    {"data", (PyCFunction)Sbk_QListWidgetItemFunc_data, METH_O},
    {"flags", (PyCFunction)Sbk_QListWidgetItemFunc_flags, METH_NOARGS},
    {"font", (PyCFunction)Sbk_QListWidgetItemFunc_font, METH_NOARGS},
    {"foreground", (PyCFunction)Sbk_QListWidgetItemFunc_foreground, METH_NOARGS},
    {"icon", (PyCFunction)Sbk_QListWidgetItemFunc_icon, METH_NOARGS},
    {"isHidden", (PyCFunction)Sbk_QListWidgetItemFunc_isHidden, METH_NOARGS},
    {"isSelected", (PyCFunction)Sbk_QListWidgetItemFunc_isSelected, METH_NOARGS},
    {"listWidget", (PyCFunction)Sbk_QListWidgetItemFunc_listWidget, METH_NOARGS},
    {"read", (PyCFunction)Sbk_QListWidgetItemFunc_read, METH_O},
    {"setBackground", (PyCFunction)Sbk_QListWidgetItemFunc_setBackground, METH_O},
    {"setCheckState", (PyCFunction)Sbk_QListWidgetItemFunc_setCheckState, METH_O},
    {"setData", (PyCFunction)Sbk_QListWidgetItemFunc_setData, METH_VARARGS},
    {"setFlags", (PyCFunction)Sbk_QListWidgetItemFunc_setFlags, METH_O},
    {"setFont", (PyCFunction)Sbk_QListWidgetItemFunc_setFont, METH_O},
    {"setForeground", (PyCFunction)Sbk_QListWidgetItemFunc_setForeground, METH_O},
    {"setHidden", (PyCFunction)Sbk_QListWidgetItemFunc_setHidden, METH_O},
    {"setIcon", (PyCFunction)Sbk_QListWidgetItemFunc_setIcon, METH_O},
    {"setSelected", (PyCFunction)Sbk_QListWidgetItemFunc_setSelected, METH_O},
    {"setSizeHint", (PyCFunction)Sbk_QListWidgetItemFunc_setSizeHint, METH_O},
    {"setStatusTip", (PyCFunction)Sbk_QListWidgetItemFunc_setStatusTip, METH_O},
    {"setText", (PyCFunction)Sbk_QListWidgetItemFunc_setText, METH_O},
    {"setTextAlignment", (PyCFunction)Sbk_QListWidgetItemFunc_setTextAlignment, METH_O},
    {"setToolTip", (PyCFunction)Sbk_QListWidgetItemFunc_setToolTip, METH_O},
    {"setWhatsThis", (PyCFunction)Sbk_QListWidgetItemFunc_setWhatsThis, METH_O},
    {"sizeHint", (PyCFunction)Sbk_QListWidgetItemFunc_sizeHint, METH_NOARGS},
    {"statusTip", (PyCFunction)Sbk_QListWidgetItemFunc_statusTip, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QListWidgetItemFunc_text, METH_NOARGS},
    {"textAlignment", (PyCFunction)Sbk_QListWidgetItemFunc_textAlignment, METH_NOARGS},
    {"toolTip", (PyCFunction)Sbk_QListWidgetItemFunc_toolTip, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QListWidgetItemFunc_type, METH_NOARGS},
    {"whatsThis", (PyCFunction)Sbk_QListWidgetItemFunc_whatsThis, METH_NOARGS},
    {"write", (PyCFunction)Sbk_QListWidgetItemFunc_write, METH_O},

    {0} // Sentinel
};

static PyObject* Sbk_QListWidgetItemFunc___lshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QListWidgetItem* >::checkType(pyArg)
                    && !Shiboken::Converter< ::QListWidgetItem* >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QListWidgetItem)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator<<(QDataStream&,QListWidgetItem)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc___lshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QListWidgetItem) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) << (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListWidgetItemFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QListWidgetItemFunc___rshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QListWidgetItem* >::checkType(pyArg)
                    && !Shiboken::Converter< ::QListWidgetItem* >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QListWidgetItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QListWidgetItem* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QListWidgetItem&)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator>>(QDataStream&,QListWidgetItem&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListWidgetItemFunc___rshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QListWidgetItem&) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) >> (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListWidgetItemFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QListWidgetItem.__rshift__", overloads);
        return 0;
}

// Rich comparison
static PyObject* Sbk_QListWidgetItem_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QListWidgetItem& cppSelf = *(Shiboken::Converter< ::QListWidgetItem* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_LT:
            if (Shiboken::Converter< ::QListWidgetItem >::isConvertible(pyArg)) {
                // operator<(const QListWidgetItem & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                const QListWidgetItem & cppArg0 = Shiboken::Converter< ::QListWidgetItem >::toCpp(pyArg);
                bool cppResult = cppSelf < cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                goto Sbk_QListWidgetItem_RichComparison_TypeError;
            }

            break;
        default:
            goto Sbk_QListWidgetItem_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QListWidgetItem_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QListWidgetItem_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QListWidgetItem_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QListWidgetItem_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QListWidgetItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QListWidgetItem_traverse,
    /*tp_clear*/            Sbk_QListWidgetItem_clear,
    /*tp_richcompare*/      Sbk_QListWidgetItem_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QListWidgetItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QListWidgetItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QListWidgetItem(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QListWidgetItem_Type.super.as_number, 0, sizeof(PyNumberMethods));
    Sbk_QListWidgetItem_Type.super.as_number.nb_rshift = Sbk_QListWidgetItemFunc___rshift__;
    Sbk_QListWidgetItem_Type.super.as_number.nb_lshift = Sbk_QListWidgetItemFunc___lshift__;
    Sbk_QListWidgetItem_Type.super.ht_type.tp_as_number = &Sbk_QListWidgetItem_Type.super.as_number;

    SbkPySide_QtGuiTypes[SBK_QLISTWIDGETITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QListWidgetItem_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QListWidgetItem", "QListWidgetItem*",
        &Sbk_QListWidgetItem_Type, &Shiboken::callCppDestructor< ::QListWidgetItem >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'ItemType'.
    SbkPySide_QtGuiTypes[SBK_QLISTWIDGETITEM_ITEMTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QListWidgetItem_Type,
        "ItemType",
        "PySide.QtGui.QListWidgetItem.ItemType",
        "QListWidgetItem::ItemType");
    if (!SbkPySide_QtGuiTypes[SBK_QLISTWIDGETITEM_ITEMTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QLISTWIDGETITEM_ITEMTYPE_IDX],
        &Sbk_QListWidgetItem_Type, "Type", (long) QListWidgetItem::Type))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QLISTWIDGETITEM_ITEMTYPE_IDX],
        &Sbk_QListWidgetItem_Type, "UserType", (long) QListWidgetItem::UserType))
        return ;
    // End of 'ItemType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QListWidgetItem >("QListWidgetItem*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QListWidgetItem >(typeid(::QListWidgetItem).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QListWidgetItem >(typeid(::QListWidgetItemWrapper).name());
    qRegisterMetaType< ::QListWidgetItem::ItemType >("QListWidgetItem::ItemType");
}
