/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpalette_wrapper.h"

// Extra includes
#include <qbrush.h>
#include <qcolor.h>
#include <qdatastream.h>
#include <qpalette.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPalette_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPalette >()))
        return -1;

    ::QPalette* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8)
        goto Sbk_QPalette_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QPalette", 0, 9, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])))
        return -1;


    // Overloaded function decisor
    // 0: QPalette()
    // 1: QPalette(Qt::GlobalColor)
    // 2: QPalette(QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
    // 3: QPalette(QColor)
    // 4: QPalette(QColor,QColor)
    // 5: QPalette(QPalette)
    if (numArgs == 0) {
        overloadId = 0; // QPalette()
    } else if (numArgs == 1
        && Shiboken::Converter< ::Qt::GlobalColor >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QPalette(Qt::GlobalColor)
    } else if (Shiboken::Converter< ::QColor >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QPalette(QColor)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QColor >::isConvertible(pyArgs[1])) {
            overloadId = 4; // QPalette(QColor,QColor)
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPalette >::isConvertible(pyArgs[0])) {
        overloadId = 5; // QPalette(QPalette)
    } else if (numArgs == 9
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[1])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[2])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[3])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[4])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[5])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[6])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[7])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[8])) {
        overloadId = 2; // QPalette(QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPalette_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QPalette()
        {

            if(!PyErr_Occurred()) {
                // QPalette()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPalette();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QPalette(Qt::GlobalColor)
        {
            Qt::GlobalColor cppArg0 = Shiboken::Converter< ::Qt::GlobalColor >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QPalette(Qt::GlobalColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPalette(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QPalette(QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBrush cppArg0 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QBrush cppArg1 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QBrush cppArg2 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[2]);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QBrush cppArg3 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[3]);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QBrush cppArg4 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[4]);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return -1;
            ::QBrush cppArg5 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[5]);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return -1;
            ::QBrush cppArg6 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[6]);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return -1;
            ::QBrush cppArg7 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[7]);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return -1;
            ::QBrush cppArg8 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[8]);

            if(!PyErr_Occurred()) {
                // QPalette(QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPalette(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QPalette(QColor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QColor cppArg0 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QPalette(QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPalette(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // QPalette(QColor,QColor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QColor cppArg0 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QColor cppArg1 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QPalette(QColor,QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPalette(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 5: // QPalette(QPalette)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPalette cppArg0 = Shiboken::Converter< ::QPalette >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QPalette(QPalette)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPalette(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPalette >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPalette_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPalette_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.GlobalColor", "PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush", "PySide.QtGui.QColor", "PySide.QtGui.QColor, PySide.QtGui.QColor", "PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette", overloads);
        return -1;
}

static PyObject* Sbk_QPaletteFunc_alternateBase(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // alternateBase()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->alternateBase();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_base(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // base()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->base();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_brightText(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // brightText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->brightText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_brush(PyObject* self, PyObject* args)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "brush", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: brush(QPalette::ColorGroup,QPalette::ColorRole)const
    // 1: brush(QPalette::ColorRole)const
    if (numArgs == 1
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[0])) {
        overloadId = 1; // brush(QPalette::ColorRole)const
    } else if (numArgs == 2
        && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[1])) {
        overloadId = 0; // brush(QPalette::ColorGroup,QPalette::ColorRole)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_brush_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // brush(QPalette::ColorGroup,QPalette::ColorRole)const
        {
            QPalette::ColorGroup cppArg0 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArgs[0]);
            QPalette::ColorRole cppArg1 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // brush(QPalette::ColorGroup,QPalette::ColorRole)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->brush(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
            break;
        }
        case 1: // brush(QPalette::ColorRole)const
        {
            QPalette::ColorRole cppArg0 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // brush(QPalette::ColorRole)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->brush(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_brush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole", "PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.brush", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_button(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // button()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->button();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_buttonText(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // buttonText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->buttonText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_cacheKey(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // cacheKey()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qint64 cppResult = const_cast<const ::QPalette*>(cppSelf)->cacheKey();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< long long >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_color(PyObject* self, PyObject* args)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "color", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: color(QPalette::ColorGroup,QPalette::ColorRole)const
    // 1: color(QPalette::ColorRole)const
    if (numArgs == 1
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[0])) {
        overloadId = 1; // color(QPalette::ColorRole)const
    } else if (numArgs == 2
        && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[1])) {
        overloadId = 0; // color(QPalette::ColorGroup,QPalette::ColorRole)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_color_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // color(QPalette::ColorGroup,QPalette::ColorRole)const
        {
            QPalette::ColorGroup cppArg0 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArgs[0]);
            QPalette::ColorRole cppArg1 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // color(QPalette::ColorGroup,QPalette::ColorRole)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QColor & cppResult = const_cast<const ::QPalette*>(cppSelf)->color(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
            break;
        }
        case 1: // color(QPalette::ColorRole)const
        {
            QPalette::ColorRole cppArg0 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // color(QPalette::ColorRole)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QColor & cppResult = const_cast<const ::QPalette*>(cppSelf)->color(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_color_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole", "PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.color", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_currentColorGroup(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // currentColorGroup()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPalette::ColorGroup cppResult = const_cast<const ::QPalette*>(cppSelf)->currentColorGroup();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPalette::ColorGroup >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_dark(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // dark()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->dark();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_highlight(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // highlight()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->highlight();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_highlightedText(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // highlightedText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->highlightedText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_isBrushSet(PyObject* self, PyObject* args)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isBrushSet", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isBrushSet(QPalette::ColorGroup,QPalette::ColorRole)const
    if (numArgs == 2
        && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[1])) {
        overloadId = 0; // isBrushSet(QPalette::ColorGroup,QPalette::ColorRole)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_isBrushSet_TypeError;

    // Call function/method
    {
        QPalette::ColorGroup cppArg0 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArgs[0]);
        QPalette::ColorRole cppArg1 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // isBrushSet(QPalette::ColorGroup,QPalette::ColorRole)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPalette*>(cppSelf)->isBrushSet(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_isBrushSet_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.isBrushSet", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_isCopyOf(PyObject* self, PyObject* pyArg)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isCopyOf(QPalette)const
    if (Shiboken::Converter< ::QPalette >::isConvertible(pyArg)) {
        overloadId = 0; // isCopyOf(QPalette)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_isCopyOf_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPalette cppArg0 = Shiboken::Converter< ::QPalette >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // isCopyOf(QPalette)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPalette*>(cppSelf)->isCopyOf(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_isCopyOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPalette.isCopyOf", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_isEqual(PyObject* self, PyObject* args)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isEqual", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isEqual(QPalette::ColorGroup,QPalette::ColorGroup)const
    if (numArgs == 2
        && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArgs[1])) {
        overloadId = 0; // isEqual(QPalette::ColorGroup,QPalette::ColorGroup)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_isEqual_TypeError;

    // Call function/method
    {
        QPalette::ColorGroup cppArg0 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArgs[0]);
        QPalette::ColorGroup cppArg1 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // isEqual(QPalette::ColorGroup,QPalette::ColorGroup)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPalette*>(cppSelf)->isEqual(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_isEqual_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorGroup", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.isEqual", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_light(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // light()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->light();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_link(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // link()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->link();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_linkVisited(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // linkVisited()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->linkVisited();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_mid(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // mid()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->mid();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_midlight(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // midlight()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->midlight();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_resolve(PyObject* self, PyObject* args)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resolve", 0, 1, &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: resolve()const
    // 1: resolve(QPalette)const
    // 2: resolve(uint)
    if (numArgs == 0) {
        overloadId = 0; // resolve()const
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // resolve(uint)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPalette >::isConvertible(pyArgs[0])) {
        overloadId = 1; // resolve(QPalette)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_resolve_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // resolve()const
        {

            if(!PyErr_Occurred()) {
                // resolve()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = const_cast<const ::QPalette*>(cppSelf)->resolve();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
            break;
        }
        case 1: // resolve(QPalette)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPalette cppArg0 = Shiboken::Converter< ::QPalette >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // resolve(QPalette)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPalette cppResult = const_cast<const ::QPalette*>(cppSelf)->resolve(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
            }
            break;
        }
        case 2: // resolve(uint)
        {
            uint cppArg0 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // resolve(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resolve(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_resolve_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPalette", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.resolve", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_setBrush(PyObject* self, PyObject* args)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBrush", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setBrush(QPalette::ColorGroup,QPalette::ColorRole,QBrush)
    // 1: setBrush(QPalette::ColorRole,QBrush)
    if (numArgs == 2
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[1])) {
        overloadId = 1; // setBrush(QPalette::ColorRole,QBrush)
    } else if (numArgs == 3
        && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[1])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[2])) {
        overloadId = 0; // setBrush(QPalette::ColorGroup,QPalette::ColorRole,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_setBrush_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setBrush(QPalette::ColorGroup,QPalette::ColorRole,QBrush)
        {
            QPalette::ColorGroup cppArg0 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArgs[0]);
            QPalette::ColorRole cppArg1 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return 0;
            ::QBrush cppArg2 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // setBrush(QPalette::ColorGroup,QPalette::ColorRole,QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBrush(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setBrush(QPalette::ColorRole,QBrush)
        {
            QPalette::ColorRole cppArg0 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QBrush cppArg1 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setBrush(QPalette::ColorRole,QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBrush(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPaletteFunc_setBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole, PySide.QtGui.QBrush", "PySide.QtGui.QPalette.ColorRole, PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.setBrush", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_setColor(PyObject* self, PyObject* args)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColor", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setColor(QPalette::ColorGroup,QPalette::ColorRole,QColor)
    // 1: setColor(QPalette::ColorRole,QColor)
    if (numArgs == 2
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QColor >::isConvertible(pyArgs[1])) {
        overloadId = 1; // setColor(QPalette::ColorRole,QColor)
    } else if (numArgs == 3
        && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[1])
        && Shiboken::Converter< ::QColor >::isConvertible(pyArgs[2])) {
        overloadId = 0; // setColor(QPalette::ColorGroup,QPalette::ColorRole,QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_setColor_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setColor(QPalette::ColorGroup,QPalette::ColorRole,QColor)
        {
            QPalette::ColorGroup cppArg0 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArgs[0]);
            QPalette::ColorRole cppArg1 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return 0;
            ::QColor cppArg2 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // setColor(QPalette::ColorGroup,QPalette::ColorRole,QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColor(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setColor(QPalette::ColorRole,QColor)
        {
            QPalette::ColorRole cppArg0 = Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QColor cppArg1 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setColor(QPalette::ColorRole,QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColor(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPaletteFunc_setColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole, PySide.QtGui.QColor", "PySide.QtGui.QPalette.ColorRole, PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.setColor", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_setColorGroup(PyObject* self, PyObject* args)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColorGroup", 10, 10, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])))
        return 0;


    // Overloaded function decisor
    // 0: setColorGroup(QPalette::ColorGroup,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
    if (numArgs == 10
        && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[1])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[2])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[3])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[4])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[5])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[6])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[7])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[8])
        && Shiboken::Converter< ::QBrush >::isConvertible(pyArgs[9])) {
        overloadId = 0; // setColorGroup(QPalette::ColorGroup,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_setColorGroup_TypeError;

    // Call function/method
    {
        QPalette::ColorGroup cppArg0 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QBrush cppArg1 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[1]);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return 0;
        ::QBrush cppArg2 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[2]);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return 0;
        ::QBrush cppArg3 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[3]);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return 0;
        ::QBrush cppArg4 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[4]);
        if (!Shiboken::Object::isValid(pyArgs[5]))
            return 0;
        ::QBrush cppArg5 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[5]);
        if (!Shiboken::Object::isValid(pyArgs[6]))
            return 0;
        ::QBrush cppArg6 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[6]);
        if (!Shiboken::Object::isValid(pyArgs[7]))
            return 0;
        ::QBrush cppArg7 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[7]);
        if (!Shiboken::Object::isValid(pyArgs[8]))
            return 0;
        ::QBrush cppArg8 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[8]);
        if (!Shiboken::Object::isValid(pyArgs[9]))
            return 0;
        ::QBrush cppArg9 = Shiboken::Converter< ::QBrush >::toCpp(pyArgs[9]);

        if(!PyErr_Occurred()) {
            // setColorGroup(QPalette::ColorGroup,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setColorGroup(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPaletteFunc_setColorGroup_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.setColorGroup", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_setCurrentColorGroup(PyObject* self, PyObject* pyArg)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentColorGroup(QPalette::ColorGroup)
    if (Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyArg)) {
        overloadId = 0; // setCurrentColorGroup(QPalette::ColorGroup)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_setCurrentColorGroup_TypeError;

    // Call function/method
    {
        QPalette::ColorGroup cppArg0 = Shiboken::Converter< ::QPalette::ColorGroup >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCurrentColorGroup(QPalette::ColorGroup)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCurrentColorGroup(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPaletteFunc_setCurrentColorGroup_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPalette.setCurrentColorGroup", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_shadow(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // shadow()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->shadow();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_text(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // text()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->text();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_toolTipBase(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toolTipBase()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->toolTipBase();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_toolTipText(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toolTipText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->toolTipText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_window(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // window()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->window();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_windowText(PyObject* self)
{
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // windowText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QBrush & cppResult = const_cast<const ::QPalette*>(cppSelf)->windowText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPalette___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QPalette& cppSelf = *(Shiboken::Converter< ::QPalette* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QPalette >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QPalette_methods[] = {
    {"alternateBase", (PyCFunction)Sbk_QPaletteFunc_alternateBase, METH_NOARGS},
    {"base", (PyCFunction)Sbk_QPaletteFunc_base, METH_NOARGS},
    {"brightText", (PyCFunction)Sbk_QPaletteFunc_brightText, METH_NOARGS},
    {"brush", (PyCFunction)Sbk_QPaletteFunc_brush, METH_VARARGS},
    {"button", (PyCFunction)Sbk_QPaletteFunc_button, METH_NOARGS},
    {"buttonText", (PyCFunction)Sbk_QPaletteFunc_buttonText, METH_NOARGS},
    {"cacheKey", (PyCFunction)Sbk_QPaletteFunc_cacheKey, METH_NOARGS},
    {"color", (PyCFunction)Sbk_QPaletteFunc_color, METH_VARARGS},
    {"currentColorGroup", (PyCFunction)Sbk_QPaletteFunc_currentColorGroup, METH_NOARGS},
    {"dark", (PyCFunction)Sbk_QPaletteFunc_dark, METH_NOARGS},
    {"highlight", (PyCFunction)Sbk_QPaletteFunc_highlight, METH_NOARGS},
    {"highlightedText", (PyCFunction)Sbk_QPaletteFunc_highlightedText, METH_NOARGS},
    {"isBrushSet", (PyCFunction)Sbk_QPaletteFunc_isBrushSet, METH_VARARGS},
    {"isCopyOf", (PyCFunction)Sbk_QPaletteFunc_isCopyOf, METH_O},
    {"isEqual", (PyCFunction)Sbk_QPaletteFunc_isEqual, METH_VARARGS},
    {"light", (PyCFunction)Sbk_QPaletteFunc_light, METH_NOARGS},
    {"link", (PyCFunction)Sbk_QPaletteFunc_link, METH_NOARGS},
    {"linkVisited", (PyCFunction)Sbk_QPaletteFunc_linkVisited, METH_NOARGS},
    {"mid", (PyCFunction)Sbk_QPaletteFunc_mid, METH_NOARGS},
    {"midlight", (PyCFunction)Sbk_QPaletteFunc_midlight, METH_NOARGS},
    {"resolve", (PyCFunction)Sbk_QPaletteFunc_resolve, METH_VARARGS},
    {"setBrush", (PyCFunction)Sbk_QPaletteFunc_setBrush, METH_VARARGS},
    {"setColor", (PyCFunction)Sbk_QPaletteFunc_setColor, METH_VARARGS},
    {"setColorGroup", (PyCFunction)Sbk_QPaletteFunc_setColorGroup, METH_VARARGS},
    {"setCurrentColorGroup", (PyCFunction)Sbk_QPaletteFunc_setCurrentColorGroup, METH_O},
    {"shadow", (PyCFunction)Sbk_QPaletteFunc_shadow, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QPaletteFunc_text, METH_NOARGS},
    {"toolTipBase", (PyCFunction)Sbk_QPaletteFunc_toolTipBase, METH_NOARGS},
    {"toolTipText", (PyCFunction)Sbk_QPaletteFunc_toolTipText, METH_NOARGS},
    {"window", (PyCFunction)Sbk_QPaletteFunc_window, METH_NOARGS},
    {"windowText", (PyCFunction)Sbk_QPaletteFunc_windowText, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QPalette___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QPaletteFunc___lshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QPalette >::checkType(pyArg)
                    && !Shiboken::Converter< ::QPalette >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPalette)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator<<(QDataStream&,QPalette)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc___lshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QPalette) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) << (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPalette.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc___rshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QPalette >::checkType(pyArg)
                    && !Shiboken::Converter< ::QPalette >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPalette* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPalette&)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator>>(QDataStream&,QPalette&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc___rshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QPalette&) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) >> (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPalette.__rshift__", overloads);
        return 0;
}

// Rich comparison
static PyObject* Sbk_QPalette_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QPalette& cppSelf = *(Shiboken::Converter< ::QPalette* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QPalette >::isConvertible(pyArg)) {
                // operator!=(const QPalette & p) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QPalette cppArg0 = Shiboken::Converter< ::QPalette >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QPalette >::isConvertible(pyArg)) {
                // operator==(const QPalette & p) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QPalette cppArg0 = Shiboken::Converter< ::QPalette >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QPalette_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QPalette_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QPalette_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QPalette_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPalette_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QPalette",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QPalette_traverse,
    /*tp_clear*/            Sbk_QPalette_clear,
    /*tp_richcompare*/      Sbk_QPalette_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPalette_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPalette_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPalette(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QPalette_Type.super.as_number, 0, sizeof(PyNumberMethods));
    Sbk_QPalette_Type.super.as_number.nb_rshift = Sbk_QPaletteFunc___rshift__;
    Sbk_QPalette_Type.super.as_number.nb_lshift = Sbk_QPaletteFunc___lshift__;
    Sbk_QPalette_Type.super.ht_type.tp_as_number = &Sbk_QPalette_Type.super.as_number;

    SbkPySide_QtGuiTypes[SBK_QPALETTE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPalette_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QPalette", "QPalette",
        &Sbk_QPalette_Type, &Shiboken::callCppDestructor< ::QPalette >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'ColorGroup'.
    SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QPalette_Type,
        "ColorGroup",
        "PySide.QtGui.QPalette.ColorGroup",
        "QPalette::ColorGroup");
    if (!SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX],
        &Sbk_QPalette_Type, "Active", (long) QPalette::Active))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX],
        &Sbk_QPalette_Type, "Disabled", (long) QPalette::Disabled))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX],
        &Sbk_QPalette_Type, "Inactive", (long) QPalette::Inactive))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX],
        &Sbk_QPalette_Type, "NColorGroups", (long) QPalette::NColorGroups))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX],
        &Sbk_QPalette_Type, "Current", (long) QPalette::Current))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX],
        &Sbk_QPalette_Type, "All", (long) QPalette::All))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX],
        &Sbk_QPalette_Type, "Normal", (long) QPalette::Normal))
        return ;
    // End of 'ColorGroup' enum.

    // Initialization of enum 'ColorRole'.
    SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QPalette_Type,
        "ColorRole",
        "PySide.QtGui.QPalette.ColorRole",
        "QPalette::ColorRole");
    if (!SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "WindowText", (long) QPalette::WindowText))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Button", (long) QPalette::Button))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Light", (long) QPalette::Light))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Midlight", (long) QPalette::Midlight))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Dark", (long) QPalette::Dark))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Mid", (long) QPalette::Mid))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Text", (long) QPalette::Text))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "BrightText", (long) QPalette::BrightText))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "ButtonText", (long) QPalette::ButtonText))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Base", (long) QPalette::Base))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Window", (long) QPalette::Window))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Shadow", (long) QPalette::Shadow))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Highlight", (long) QPalette::Highlight))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "HighlightedText", (long) QPalette::HighlightedText))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Link", (long) QPalette::Link))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "LinkVisited", (long) QPalette::LinkVisited))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "AlternateBase", (long) QPalette::AlternateBase))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "NoRole", (long) QPalette::NoRole))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "ToolTipBase", (long) QPalette::ToolTipBase))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "ToolTipText", (long) QPalette::ToolTipText))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "NColorRoles", (long) QPalette::NColorRoles))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Foreground", (long) QPalette::Foreground))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX],
        &Sbk_QPalette_Type, "Background", (long) QPalette::Background))
        return ;
    // End of 'ColorRole' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QPalette >("QPalette");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QPalette >("QPalette*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QPalette >(typeid(::QPalette).name());
    qRegisterMetaType< ::QPalette >("QPalette");
    qRegisterMetaType< ::QPalette::ColorGroup >("QPalette::ColorGroup");
    qRegisterMetaType< ::QPalette::ColorRole >("QPalette::ColorRole");
}
