/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qpinchgesture_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QPinchGestureWrapper::QPinchGestureWrapper(QObject * parent) : QPinchGesture(parent) {
    // ... middle
}

void QPinchGestureWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QPinchGestureWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QPinchGestureWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QPinchGestureWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QPinchGestureWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QPinchGesture.event", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QPinchGestureWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QPinchGesture.eventFilter", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QPinchGestureWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject* QPinchGestureWrapper::metaObject() const
{
    #if QT_VERSION >= 0x040700
    if (QObject::d_ptr->metaObject) return QObject::d_ptr->metaObject;
    #endif
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return PySide::SignalManager::retriveMetaObject(reinterpret_cast<PyObject*>(pySelf));
}

int QPinchGestureWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QPinchGesture::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void* QPinchGestureWrapper::qt_metacast(const char* _clname)
{
        if (!_clname) return 0;
        SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void*>(const_cast< QPinchGestureWrapper* >(this));
        return QPinchGesture::qt_metacast(_clname);
}

QPinchGestureWrapper::~QPinchGestureWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPinchGesture_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPinchGesture >()))
        return -1;

    ::QPinchGestureWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QPinchGesture", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QPinchGesture(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QPinchGesture(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QPinchGesture(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGesture_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QPinchGesture_Init_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPinchGesture(): got multiple values for keyword argument '%s'", errorArgName);
                return -1;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]) : 0;

        if(!PyErr_Occurred()) {
            // QPinchGesture(QObject*)
            void* addr = PySide::nextQObjectMemoryAddr();
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = addr ? new (addr) ::QPinchGestureWrapper(cppArg0) : new ::QPinchGestureWrapper(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPinchGesture >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPinchGesture_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QPinchGesture_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPinchGesture", overloads);
        return -1;
}

static PyObject* Sbk_QPinchGestureFunc_centerPoint(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // centerPoint()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->centerPoint();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_changeFlags(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // changeFlags()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFlags<QPinchGesture::ChangeFlag> cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->changeFlags();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_lastCenterPoint(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // lastCenterPoint()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->lastCenterPoint();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_lastRotationAngle(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // lastRotationAngle()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->lastRotationAngle();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_lastScaleFactor(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // lastScaleFactor()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->lastScaleFactor();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_rotationAngle(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // rotationAngle()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->rotationAngle();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_scaleFactor(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // scaleFactor()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->scaleFactor();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_setCenterPoint(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCenterPoint(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // setCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setCenterPoint_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCenterPoint(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCenterPoint(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setCenterPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setChangeFlags(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    if (Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::isConvertible(pyArg)) {
        overloadId = 0; // setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setChangeFlags_TypeError;

    // Call function/method
    {
        QFlags<QPinchGesture::ChangeFlag> cppArg0 = Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setChangeFlags(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setChangeFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPinchGesture.ChangeFlags", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setChangeFlags", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setLastCenterPoint(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastCenterPoint(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // setLastCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setLastCenterPoint_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLastCenterPoint(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLastCenterPoint(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setLastCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setLastCenterPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setLastRotationAngle(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastRotationAngle(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setLastRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setLastRotationAngle_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLastRotationAngle(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLastRotationAngle(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setLastRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setLastRotationAngle", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setLastScaleFactor(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastScaleFactor(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setLastScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setLastScaleFactor_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLastScaleFactor(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLastScaleFactor(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setLastScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setLastScaleFactor", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setRotationAngle(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRotationAngle(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setRotationAngle_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setRotationAngle(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setRotationAngle(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setRotationAngle", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setScaleFactor(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScaleFactor(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setScaleFactor_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setScaleFactor(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setScaleFactor(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setScaleFactor", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setStartCenterPoint(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartCenterPoint(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // setStartCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setStartCenterPoint_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setStartCenterPoint(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setStartCenterPoint(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setStartCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setStartCenterPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setTotalChangeFlags(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    if (Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::isConvertible(pyArg)) {
        overloadId = 0; // setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setTotalChangeFlags_TypeError;

    // Call function/method
    {
        QFlags<QPinchGesture::ChangeFlag> cppArg0 = Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTotalChangeFlags(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setTotalChangeFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPinchGesture.ChangeFlags", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setTotalChangeFlags", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setTotalRotationAngle(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalRotationAngle(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setTotalRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setTotalRotationAngle_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTotalRotationAngle(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTotalRotationAngle(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setTotalRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setTotalRotationAngle", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setTotalScaleFactor(PyObject* self, PyObject* pyArg)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalScaleFactor(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setTotalScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setTotalScaleFactor_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTotalScaleFactor(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTotalScaleFactor(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setTotalScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPinchGesture.setTotalScaleFactor", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_startCenterPoint(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // startCenterPoint()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->startCenterPoint();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_totalChangeFlags(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // totalChangeFlags()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFlags<QPinchGesture::ChangeFlag> cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->totalChangeFlags();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_totalRotationAngle(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // totalRotationAngle()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->totalRotationAngle();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_totalScaleFactor(PyObject* self)
{
    ::QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPinchGesture* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // totalScaleFactor()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QPinchGesture*>(cppSelf)->totalScaleFactor();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QPinchGesture_methods[] = {
    {"centerPoint", (PyCFunction)Sbk_QPinchGestureFunc_centerPoint, METH_NOARGS},
    {"changeFlags", (PyCFunction)Sbk_QPinchGestureFunc_changeFlags, METH_NOARGS},
    {"lastCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_lastCenterPoint, METH_NOARGS},
    {"lastRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_lastRotationAngle, METH_NOARGS},
    {"lastScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_lastScaleFactor, METH_NOARGS},
    {"rotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_rotationAngle, METH_NOARGS},
    {"scaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_scaleFactor, METH_NOARGS},
    {"setCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_setCenterPoint, METH_O},
    {"setChangeFlags", (PyCFunction)Sbk_QPinchGestureFunc_setChangeFlags, METH_O},
    {"setLastCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_setLastCenterPoint, METH_O},
    {"setLastRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_setLastRotationAngle, METH_O},
    {"setLastScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_setLastScaleFactor, METH_O},
    {"setRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_setRotationAngle, METH_O},
    {"setScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_setScaleFactor, METH_O},
    {"setStartCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_setStartCenterPoint, METH_O},
    {"setTotalChangeFlags", (PyCFunction)Sbk_QPinchGestureFunc_setTotalChangeFlags, METH_O},
    {"setTotalRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_setTotalRotationAngle, METH_O},
    {"setTotalScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_setTotalScaleFactor, METH_O},
    {"startCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_startCenterPoint, METH_NOARGS},
    {"totalChangeFlags", (PyCFunction)Sbk_QPinchGestureFunc_totalChangeFlags, METH_NOARGS},
    {"totalRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_totalRotationAngle, METH_NOARGS},
    {"totalScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_totalScaleFactor, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QPinchGesture_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QPinchGesture_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPinchGesture_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QPinchGesture",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QPinchGesture_traverse,
    /*tp_clear*/            Sbk_QPinchGesture_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPinchGesture_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPinchGesture_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QPinchGesture_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QPinchGesture*>(reinterpret_cast< ::QObject*>(cptr));
    return 0;
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___and__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter< ::QPinchGesture::ChangeFlags>::toCpp(self)
        & Shiboken::Converter< ::QPinchGesture::ChangeFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___or__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter< ::QPinchGesture::ChangeFlags>::toCpp(self)
        | Shiboken::Converter< ::QPinchGesture::ChangeFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___xor__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter< ::QPinchGesture::ChangeFlags>::toCpp(self)
        ^ Shiboken::Converter< ::QPinchGesture::ChangeFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___invert__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        ~Shiboken::Converter< ::QPinchGesture::ChangeFlags >::toCpp(self)
    );
}

static PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag_long(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QPinchGesture::ChangeFlags>::toCpp(v);
    return PyLong_FromLong(val);
}
static int SbkPySide_QtGui_QPinchGesture_ChangeFlag__nonzero(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QPinchGesture::ChangeFlags>::toCpp(v);
    return val != 0;
}

static PyNumberMethods SbkPySide_QtGui_QPinchGesture_ChangeFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    #ifndef IS_PY3K
    /* nb_divide */             0,
    #endif
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              SbkPySide_QtGui_QPinchGesture_ChangeFlag__nonzero,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___or__,
    #ifndef IS_PY3K
    /* nb_coerce */             0,
    #endif
    /*nb_int*/                  SbkPySide_QtGui_QPinchGesture_ChangeFlag_long,
    #ifdef IS_PY3K
    /*nb_reserved*/             0,
    /*nb_float*/                0,
    #else
    /*nb_long*/                 SbkPySide_QtGui_QPinchGesture_ChangeFlag_long,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    #endif
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    #ifndef IS_PY3K
    /*nb_inplace_divide*/       0,
    #endif
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type = {
    PyVarObject_HEAD_INIT(&PyType_Type, 0)
    /*tp_name*/             "ChangeFlags",
    /*tp_basicsize*/        sizeof(PySideQFlagsObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QPinchGesture_ChangeFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      &PySideQFlagsRichCompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              &PySideQFlagsNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QPinchGesture(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPinchGesture_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QPinchGesture", "QPinchGesture*",
        &Sbk_QPinchGesture_Type, &Shiboken::callCppDestructor< ::QPinchGesture >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QGESTURE_IDX])) {
        return;
    }

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QPinchGesture_Type, &Sbk_QPinchGesture_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'ChangeFlag'.
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QPINCHGESTURE_CHANGEFLAG__IDX] = &SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type;
    SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_CHANGEFLAG_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QPinchGesture_Type,
        "ChangeFlag",
        "PySide.QtGui.QPinchGesture.ChangeFlag",
        "QPinchGesture::ChangeFlag",
        SbkPySide_QtGuiTypes[SBK_QFLAGS_QPINCHGESTURE_CHANGEFLAG__IDX]);
    if (!SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_CHANGEFLAG_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_CHANGEFLAG_IDX],
        &Sbk_QPinchGesture_Type, "ScaleFactorChanged", (long) QPinchGesture::ScaleFactorChanged))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_CHANGEFLAG_IDX],
        &Sbk_QPinchGesture_Type, "RotationAngleChanged", (long) QPinchGesture::RotationAngleChanged))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_CHANGEFLAG_IDX],
        &Sbk_QPinchGesture_Type, "CenterPointChanged", (long) QPinchGesture::CenterPointChanged))
        return ;
    // End of 'ChangeFlag' enum.

    PySide::Signal::registerSignals(&Sbk_QPinchGesture_Type, &::QPinchGesture::staticMetaObject);

    Shiboken::TypeResolver::createObjectTypeResolver< ::QPinchGesture >("QPinchGesture*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QPinchGesture >(typeid(::QPinchGesture).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QPinchGesture >(typeid(::QPinchGestureWrapper).name());
    qRegisterMetaType< ::QPinchGesture::ChangeFlag >("QPinchGesture::ChangeFlag");
    qRegisterMetaType< ::QPinchGesture::ChangeFlags >("QPinchGesture::ChangeFlags");
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QPinchGesture_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QPinchGesture_Type, &::QPinchGesture::staticMetaObject, sizeof(::QPinchGesture));
}
