/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qradialgradient_wrapper.h"

// Extra includes
#include <QPair>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qpoint.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRadialGradient_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRadialGradient >()))
        return -1;

    ::QRadialGradient* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QRadialGradient", 0, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])))
        return -1;


    // Overloaded function decisor
    // 0: QRadialGradient()
    // 1: QRadialGradient(QPointF,qreal,QPointF,qreal)
    // 2: QRadialGradient(QPointF,qreal)
    // 3: QRadialGradient(QPointF,qreal,QPointF)
    // 4: QRadialGradient(QRadialGradient)
    // 5: QRadialGradient(qreal,qreal,qreal,qreal,qreal,qreal)
    // 6: QRadialGradient(qreal,qreal,qreal)
    // 7: QRadialGradient(qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QRadialGradient()
    } else if (numArgs >= 3
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])) {
        if (numArgs == 3) {
            overloadId = 6; // QRadialGradient(qreal,qreal,qreal)
        } else if (numArgs >= 5
            && SbkNumber_Check(pyArgs[3])
            && SbkNumber_Check(pyArgs[4])) {
            if (numArgs == 5) {
                overloadId = 7; // QRadialGradient(qreal,qreal,qreal,qreal,qreal)
            } else if (numArgs == 6
                && SbkNumber_Check(pyArgs[5])) {
                overloadId = 5; // QRadialGradient(qreal,qreal,qreal,qreal,qreal,qreal)
            }
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QRadialGradient >::isConvertible(pyArgs[0])) {
        overloadId = 4; // QRadialGradient(QRadialGradient)
    } else if (numArgs >= 2
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QRadialGradient(QPointF,qreal)
        } else if (Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // QRadialGradient(QPointF,qreal,QPointF)
            } else if (numArgs == 4
                && SbkNumber_Check(pyArgs[3])) {
                overloadId = 1; // QRadialGradient(QPointF,qreal,QPointF,qreal)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRadialGradient_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QRadialGradient()
        {

            if(!PyErr_Occurred()) {
                // QRadialGradient()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRadialGradient();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QRadialGradient(QPointF,qreal,QPointF,qreal)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[2]);
            qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);

            if(!PyErr_Occurred()) {
                // QRadialGradient(QPointF,qreal,QPointF,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRadialGradient(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QRadialGradient(QPointF,qreal)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QRadialGradient(QPointF,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRadialGradient(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QRadialGradient(QPointF,qreal,QPointF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // QRadialGradient(QPointF,qreal,QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRadialGradient(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // QRadialGradient(QRadialGradient)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRadialGradient cppArg0 = Shiboken::Converter< ::QRadialGradient >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QRadialGradient(QRadialGradient)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRadialGradient(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 5: // QRadialGradient(qreal,qreal,qreal,qreal,qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
            qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
            qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);
            qreal cppArg4 = Shiboken::Converter< double >::toCpp(pyArgs[4]);
            qreal cppArg5 = Shiboken::Converter< double >::toCpp(pyArgs[5]);

            if(!PyErr_Occurred()) {
                // QRadialGradient(qreal,qreal,qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRadialGradient(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 6: // QRadialGradient(qreal,qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
            qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // QRadialGradient(qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRadialGradient(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 7: // QRadialGradient(qreal,qreal,qreal,qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
            qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
            qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);
            qreal cppArg4 = Shiboken::Converter< double >::toCpp(pyArgs[4]);

            if(!PyErr_Occurred()) {
                // QRadialGradient(qreal,qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRadialGradient(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRadialGradient >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QRadialGradient_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QRadialGradient_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPointF, float, PySide.QtCore.QPointF, float", "PySide.QtCore.QPointF, float", "PySide.QtCore.QPointF, float, PySide.QtCore.QPointF", "PySide.QtGui.QRadialGradient", "float, float, float, float, float, float", "float, float, float", "float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QRadialGradient", overloads);
        return -1;
}

static PyObject* Sbk_QRadialGradientFunc_center(PyObject* self)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // center()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QRadialGradient*>(cppSelf)->center();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRadialGradientFunc_centerRadius(PyObject* self)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // centerRadius()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRadialGradient*>(cppSelf)->centerRadius();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRadialGradientFunc_focalPoint(PyObject* self)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // focalPoint()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QRadialGradient*>(cppSelf)->focalPoint();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRadialGradientFunc_focalRadius(PyObject* self)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // focalRadius()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRadialGradient*>(cppSelf)->focalRadius();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRadialGradientFunc_radius(PyObject* self)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // radius()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRadialGradient*>(cppSelf)->radius();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRadialGradientFunc_setCenter(PyObject* self, PyObject* args)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCenter", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCenter(QPointF)
    // 1: setCenter(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 1; // setCenter(qreal,qreal)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])) {
        overloadId = 0; // setCenter(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRadialGradientFunc_setCenter_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setCenter(QPointF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setCenter(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCenter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setCenter(qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setCenter(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCenter(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRadialGradientFunc_setCenter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QRadialGradient.setCenter", overloads);
        return 0;
}

static PyObject* Sbk_QRadialGradientFunc_setCenterRadius(PyObject* self, PyObject* pyArg)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCenterRadius(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setCenterRadius(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRadialGradientFunc_setCenterRadius_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCenterRadius(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCenterRadius(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRadialGradientFunc_setCenterRadius_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QRadialGradient.setCenterRadius", overloads);
        return 0;
}

static PyObject* Sbk_QRadialGradientFunc_setFocalPoint(PyObject* self, PyObject* args)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFocalPoint", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFocalPoint(QPointF)
    // 1: setFocalPoint(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 1; // setFocalPoint(qreal,qreal)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])) {
        overloadId = 0; // setFocalPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRadialGradientFunc_setFocalPoint_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setFocalPoint(QPointF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setFocalPoint(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFocalPoint(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setFocalPoint(qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setFocalPoint(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFocalPoint(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRadialGradientFunc_setFocalPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QRadialGradient.setFocalPoint", overloads);
        return 0;
}

static PyObject* Sbk_QRadialGradientFunc_setFocalRadius(PyObject* self, PyObject* pyArg)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocalRadius(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setFocalRadius(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRadialGradientFunc_setFocalRadius_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setFocalRadius(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFocalRadius(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRadialGradientFunc_setFocalRadius_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QRadialGradient.setFocalRadius", overloads);
        return 0;
}

static PyObject* Sbk_QRadialGradientFunc_setRadius(PyObject* self, PyObject* pyArg)
{
    ::QRadialGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRadialGradient* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRadius(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setRadius(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRadialGradientFunc_setRadius_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setRadius(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setRadius(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRadialGradientFunc_setRadius_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QRadialGradient.setRadius", overloads);
        return 0;
}

static PyObject* Sbk_QRadialGradient___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QRadialGradient& cppSelf = *(Shiboken::Converter< ::QRadialGradient* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QRadialGradient >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QRadialGradient_methods[] = {
    {"center", (PyCFunction)Sbk_QRadialGradientFunc_center, METH_NOARGS},
    {"centerRadius", (PyCFunction)Sbk_QRadialGradientFunc_centerRadius, METH_NOARGS},
    {"focalPoint", (PyCFunction)Sbk_QRadialGradientFunc_focalPoint, METH_NOARGS},
    {"focalRadius", (PyCFunction)Sbk_QRadialGradientFunc_focalRadius, METH_NOARGS},
    {"radius", (PyCFunction)Sbk_QRadialGradientFunc_radius, METH_NOARGS},
    {"setCenter", (PyCFunction)Sbk_QRadialGradientFunc_setCenter, METH_VARARGS},
    {"setCenterRadius", (PyCFunction)Sbk_QRadialGradientFunc_setCenterRadius, METH_O},
    {"setFocalPoint", (PyCFunction)Sbk_QRadialGradientFunc_setFocalPoint, METH_VARARGS},
    {"setFocalRadius", (PyCFunction)Sbk_QRadialGradientFunc_setFocalRadius, METH_O},
    {"setRadius", (PyCFunction)Sbk_QRadialGradientFunc_setRadius, METH_O},

    {"__copy__", (PyCFunction)Sbk_QRadialGradient___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static int Sbk_QRadialGradient_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QRadialGradient_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QRadialGradient_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QRadialGradient",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QRadialGradient_traverse,
    /*tp_clear*/            Sbk_QRadialGradient_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QRadialGradient_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QRadialGradient_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QRadialGradient(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QRADIALGRADIENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QRadialGradient_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QRadialGradient", "QRadialGradient",
        &Sbk_QRadialGradient_Type, &Shiboken::callCppDestructor< ::QRadialGradient >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QGRADIENT_IDX])) {
        return;
    }


    Shiboken::TypeResolver::createValueTypeResolver< ::QRadialGradient >("QRadialGradient");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QRadialGradient >("QRadialGradient*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QRadialGradient >(typeid(::QRadialGradient).name());
    qRegisterMetaType< ::QRadialGradient >("QRadialGradient");
}
