/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qsizepolicy_wrapper.h"

// Extra includes
#include <qdatastream.h>
#include <qsizepolicy.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSizePolicy_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSizePolicy >()))
        return -1;

    ::QSizePolicy* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSizePolicy", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return -1;


    // Overloaded function decisor
    // 0: QSizePolicy()
    // 1: QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
    // 2: QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
    // 3: QSizePolicy(QSizePolicy)
    if (numArgs == 0) {
        overloadId = 0; // QSizePolicy()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QSizePolicy >::isConvertible(pyArgs[0])) {
        overloadId = 3; // QSizePolicy(QSizePolicy)
    } else if (numArgs >= 2
        && Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
        } else if (numArgs == 3
            && Shiboken::Converter< ::QSizePolicy::ControlType >::isConvertible(pyArgs[2])) {
            overloadId = 2; // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicy_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QSizePolicy()
        {

            if(!PyErr_Occurred()) {
                // QSizePolicy()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSizePolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
        {
            QSizePolicy::Policy cppArg0 = Shiboken::Converter< ::QSizePolicy::Policy >::toCpp(pyArgs[0]);
            QSizePolicy::Policy cppArg1 = Shiboken::Converter< ::QSizePolicy::Policy >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSizePolicy(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
        {
            QSizePolicy::Policy cppArg0 = Shiboken::Converter< ::QSizePolicy::Policy >::toCpp(pyArgs[0]);
            QSizePolicy::Policy cppArg1 = Shiboken::Converter< ::QSizePolicy::Policy >::toCpp(pyArgs[1]);
            QSizePolicy::ControlType cppArg2 = Shiboken::Converter< ::QSizePolicy::ControlType >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSizePolicy(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QSizePolicy(QSizePolicy)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSizePolicy cppArg0 = Shiboken::Converter< ::QSizePolicy >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QSizePolicy(QSizePolicy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSizePolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSizePolicy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSizePolicy_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSizePolicy_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.Policy", "PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.ControlType", "PySide.QtGui.QSizePolicy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QSizePolicy", overloads);
        return -1;
}

static PyObject* Sbk_QSizePolicyFunc_controlType(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // controlType()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSizePolicy::ControlType cppResult = const_cast<const ::QSizePolicy*>(cppSelf)->controlType();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSizePolicy::ControlType >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_expandingDirections(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // expandingDirections()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFlags<Qt::Orientation> cppResult = const_cast<const ::QSizePolicy*>(cppSelf)->expandingDirections();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFlags<Qt::Orientation> >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_hasHeightForWidth(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // hasHeightForWidth()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QSizePolicy*>(cppSelf)->hasHeightForWidth();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_hasWidthForHeight(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // hasWidthForHeight()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QSizePolicy*>(cppSelf)->hasWidthForHeight();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_horizontalPolicy(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // horizontalPolicy()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSizePolicy::Policy cppResult = const_cast<const ::QSizePolicy*>(cppSelf)->horizontalPolicy();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSizePolicy::Policy >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_horizontalStretch(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // horizontalStretch()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QSizePolicy*>(cppSelf)->horizontalStretch();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_setControlType(PyObject* self, PyObject* pyArg)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setControlType(QSizePolicy::ControlType)
    if (Shiboken::Converter< ::QSizePolicy::ControlType >::isConvertible(pyArg)) {
        overloadId = 0; // setControlType(QSizePolicy::ControlType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setControlType_TypeError;

    // Call function/method
    {
        QSizePolicy::ControlType cppArg0 = Shiboken::Converter< ::QSizePolicy::ControlType >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setControlType(QSizePolicy::ControlType)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setControlType(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setControlType_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.ControlType", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.setControlType", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setHeightForWidth(PyObject* self, PyObject* pyArg)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeightForWidth(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setHeightForWidth(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setHeightForWidth_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setHeightForWidth(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHeightForWidth(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setHeightForWidth_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.setHeightForWidth", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setHorizontalPolicy(PyObject* self, PyObject* pyArg)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalPolicy(QSizePolicy::Policy)
    if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyArg)) {
        overloadId = 0; // setHorizontalPolicy(QSizePolicy::Policy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setHorizontalPolicy_TypeError;

    // Call function/method
    {
        QSizePolicy::Policy cppArg0 = Shiboken::Converter< ::QSizePolicy::Policy >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setHorizontalPolicy(QSizePolicy::Policy)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHorizontalPolicy(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setHorizontalPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.Policy", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.setHorizontalPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setHorizontalStretch(PyObject* self, PyObject* pyArg)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalStretch(uchar)
    if (Shiboken::Converter< unsigned char >::isConvertible(pyArg)) {
        overloadId = 0; // setHorizontalStretch(uchar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setHorizontalStretch_TypeError;

    // Call function/method
    {
        uchar cppArg0 = Shiboken::Converter< unsigned char >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setHorizontalStretch(uchar)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHorizontalStretch(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setHorizontalStretch_TypeError:
        const char* overloads[] = {"unsigned char", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.setHorizontalStretch", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setVerticalPolicy(PyObject* self, PyObject* pyArg)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalPolicy(QSizePolicy::Policy)
    if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyArg)) {
        overloadId = 0; // setVerticalPolicy(QSizePolicy::Policy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setVerticalPolicy_TypeError;

    // Call function/method
    {
        QSizePolicy::Policy cppArg0 = Shiboken::Converter< ::QSizePolicy::Policy >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setVerticalPolicy(QSizePolicy::Policy)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setVerticalPolicy(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setVerticalPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.Policy", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.setVerticalPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setVerticalStretch(PyObject* self, PyObject* pyArg)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalStretch(uchar)
    if (Shiboken::Converter< unsigned char >::isConvertible(pyArg)) {
        overloadId = 0; // setVerticalStretch(uchar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setVerticalStretch_TypeError;

    // Call function/method
    {
        uchar cppArg0 = Shiboken::Converter< unsigned char >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setVerticalStretch(uchar)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setVerticalStretch(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setVerticalStretch_TypeError:
        const char* overloads[] = {"unsigned char", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.setVerticalStretch", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setWidthForHeight(PyObject* self, PyObject* pyArg)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidthForHeight(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setWidthForHeight(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setWidthForHeight_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setWidthForHeight(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setWidthForHeight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setWidthForHeight_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.setWidthForHeight", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_transpose(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // transpose()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->transpose();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QSizePolicyFunc_verticalPolicy(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // verticalPolicy()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSizePolicy::Policy cppResult = const_cast<const ::QSizePolicy*>(cppSelf)->verticalPolicy();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSizePolicy::Policy >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_verticalStretch(PyObject* self)
{
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // verticalStretch()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QSizePolicy*>(cppSelf)->verticalStretch();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicy___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QSizePolicy& cppSelf = *(Shiboken::Converter< ::QSizePolicy* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QSizePolicy >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QSizePolicy_methods[] = {
    {"controlType", (PyCFunction)Sbk_QSizePolicyFunc_controlType, METH_NOARGS},
    {"expandingDirections", (PyCFunction)Sbk_QSizePolicyFunc_expandingDirections, METH_NOARGS},
    {"hasHeightForWidth", (PyCFunction)Sbk_QSizePolicyFunc_hasHeightForWidth, METH_NOARGS},
    {"hasWidthForHeight", (PyCFunction)Sbk_QSizePolicyFunc_hasWidthForHeight, METH_NOARGS},
    {"horizontalPolicy", (PyCFunction)Sbk_QSizePolicyFunc_horizontalPolicy, METH_NOARGS},
    {"horizontalStretch", (PyCFunction)Sbk_QSizePolicyFunc_horizontalStretch, METH_NOARGS},
    {"setControlType", (PyCFunction)Sbk_QSizePolicyFunc_setControlType, METH_O},
    {"setHeightForWidth", (PyCFunction)Sbk_QSizePolicyFunc_setHeightForWidth, METH_O},
    {"setHorizontalPolicy", (PyCFunction)Sbk_QSizePolicyFunc_setHorizontalPolicy, METH_O},
    {"setHorizontalStretch", (PyCFunction)Sbk_QSizePolicyFunc_setHorizontalStretch, METH_O},
    {"setVerticalPolicy", (PyCFunction)Sbk_QSizePolicyFunc_setVerticalPolicy, METH_O},
    {"setVerticalStretch", (PyCFunction)Sbk_QSizePolicyFunc_setVerticalStretch, METH_O},
    {"setWidthForHeight", (PyCFunction)Sbk_QSizePolicyFunc_setWidthForHeight, METH_O},
    {"transpose", (PyCFunction)Sbk_QSizePolicyFunc_transpose, METH_NOARGS},
    {"verticalPolicy", (PyCFunction)Sbk_QSizePolicyFunc_verticalPolicy, METH_NOARGS},
    {"verticalStretch", (PyCFunction)Sbk_QSizePolicyFunc_verticalStretch, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSizePolicy___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QSizePolicyFunc___lshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QSizePolicy >::checkType(pyArg)
                    && !Shiboken::Converter< ::QSizePolicy >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QSizePolicy)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator<<(QDataStream&,QSizePolicy)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc___lshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QSizePolicy) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) << (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizePolicyFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc___rshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QSizePolicy >::checkType(pyArg)
                    && !Shiboken::Converter< ::QSizePolicy >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSizePolicy* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QSizePolicy&)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator>>(QDataStream&,QSizePolicy&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc___rshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QSizePolicy&) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) >> (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizePolicyFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QSizePolicy.__rshift__", overloads);
        return 0;
}

// Rich comparison
static PyObject* Sbk_QSizePolicy_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QSizePolicy& cppSelf = *(Shiboken::Converter< ::QSizePolicy* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSizePolicy >::isConvertible(pyArg)) {
                // operator!=(const QSizePolicy & s) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QSizePolicy cppArg0 = Shiboken::Converter< ::QSizePolicy >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSizePolicy >::isConvertible(pyArg)) {
                // operator==(const QSizePolicy & s) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QSizePolicy cppArg0 = Shiboken::Converter< ::QSizePolicy >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QSizePolicy_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSizePolicy_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QSizePolicy_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QSizePolicy_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSizePolicy_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QSizePolicy",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QSizePolicy_traverse,
    /*tp_clear*/            Sbk_QSizePolicy_clear,
    /*tp_richcompare*/      Sbk_QSizePolicy_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSizePolicy_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSizePolicy_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QSizePolicy_ControlType___and__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QSizePolicy::ControlTypes >::toPython(
        Shiboken::Converter< ::QSizePolicy::ControlTypes>::toCpp(self)
        & Shiboken::Converter< ::QSizePolicy::ControlTypes >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QSizePolicy_ControlType___or__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QSizePolicy::ControlTypes >::toPython(
        Shiboken::Converter< ::QSizePolicy::ControlTypes>::toCpp(self)
        | Shiboken::Converter< ::QSizePolicy::ControlTypes >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QSizePolicy_ControlType___xor__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QSizePolicy::ControlTypes >::toPython(
        Shiboken::Converter< ::QSizePolicy::ControlTypes>::toCpp(self)
        ^ Shiboken::Converter< ::QSizePolicy::ControlTypes >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QSizePolicy_ControlType___invert__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< QSizePolicy::ControlTypes >::toPython(
        ~Shiboken::Converter< ::QSizePolicy::ControlTypes >::toCpp(self)
    );
}

static PyObject* SbkPySide_QtGui_QSizePolicy_ControlType_long(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QSizePolicy::ControlTypes>::toCpp(v);
    return PyLong_FromLong(val);
}
static int SbkPySide_QtGui_QSizePolicy_ControlType__nonzero(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QSizePolicy::ControlTypes>::toCpp(v);
    return val != 0;
}

static PyNumberMethods SbkPySide_QtGui_QSizePolicy_ControlType_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    #ifndef IS_PY3K
    /* nb_divide */             0,
    #endif
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              SbkPySide_QtGui_QSizePolicy_ControlType__nonzero,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QSizePolicy_ControlType___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QSizePolicy_ControlType___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QSizePolicy_ControlType___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QSizePolicy_ControlType___or__,
    #ifndef IS_PY3K
    /* nb_coerce */             0,
    #endif
    /*nb_int*/                  SbkPySide_QtGui_QSizePolicy_ControlType_long,
    #ifdef IS_PY3K
    /*nb_reserved*/             0,
    /*nb_float*/                0,
    #else
    /*nb_long*/                 SbkPySide_QtGui_QSizePolicy_ControlType_long,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    #endif
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    #ifndef IS_PY3K
    /*nb_inplace_divide*/       0,
    #endif
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QSizePolicy_ControlTypes_Type = {
    PyVarObject_HEAD_INIT(&PyType_Type, 0)
    /*tp_name*/             "ControlTypes",
    /*tp_basicsize*/        sizeof(PySideQFlagsObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QSizePolicy_ControlType_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      &PySideQFlagsRichCompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              &PySideQFlagsNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QSizePolicy(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QSizePolicy_Type.super.as_number, 0, sizeof(PyNumberMethods));
    Sbk_QSizePolicy_Type.super.as_number.nb_rshift = Sbk_QSizePolicyFunc___rshift__;
    Sbk_QSizePolicy_Type.super.as_number.nb_lshift = Sbk_QSizePolicyFunc___lshift__;
    Sbk_QSizePolicy_Type.super.ht_type.tp_as_number = &Sbk_QSizePolicy_Type.super.as_number;

    SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSizePolicy_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QSizePolicy", "QSizePolicy",
        &Sbk_QSizePolicy_Type, &Shiboken::callCppDestructor< ::QSizePolicy >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'ControlType'.
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QSIZEPOLICY_CONTROLTYPE__IDX] = &SbkPySide_QtGui_QSizePolicy_ControlTypes_Type;
    SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QSizePolicy_Type,
        "ControlType",
        "PySide.QtGui.QSizePolicy.ControlType",
        "QSizePolicy::ControlType",
        SbkPySide_QtGuiTypes[SBK_QFLAGS_QSIZEPOLICY_CONTROLTYPE__IDX]);
    if (!SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "DefaultType", (long) QSizePolicy::DefaultType))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "ButtonBox", (long) QSizePolicy::ButtonBox))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "CheckBox", (long) QSizePolicy::CheckBox))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "ComboBox", (long) QSizePolicy::ComboBox))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "Frame", (long) QSizePolicy::Frame))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "GroupBox", (long) QSizePolicy::GroupBox))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "Label", (long) QSizePolicy::Label))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "Line", (long) QSizePolicy::Line))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "LineEdit", (long) QSizePolicy::LineEdit))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "PushButton", (long) QSizePolicy::PushButton))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "RadioButton", (long) QSizePolicy::RadioButton))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "Slider", (long) QSizePolicy::Slider))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "SpinBox", (long) QSizePolicy::SpinBox))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "TabWidget", (long) QSizePolicy::TabWidget))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX],
        &Sbk_QSizePolicy_Type, "ToolButton", (long) QSizePolicy::ToolButton))
        return ;
    // End of 'ControlType' enum.

    // Initialization of enum 'PolicyFlag'.
    SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICYFLAG_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QSizePolicy_Type,
        "PolicyFlag",
        "PySide.QtGui.QSizePolicy.PolicyFlag",
        "QSizePolicy::PolicyFlag");
    if (!SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICYFLAG_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICYFLAG_IDX],
        &Sbk_QSizePolicy_Type, "GrowFlag", (long) QSizePolicy::GrowFlag))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICYFLAG_IDX],
        &Sbk_QSizePolicy_Type, "ExpandFlag", (long) QSizePolicy::ExpandFlag))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICYFLAG_IDX],
        &Sbk_QSizePolicy_Type, "ShrinkFlag", (long) QSizePolicy::ShrinkFlag))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICYFLAG_IDX],
        &Sbk_QSizePolicy_Type, "IgnoreFlag", (long) QSizePolicy::IgnoreFlag))
        return ;
    // End of 'PolicyFlag' enum.

    // Initialization of enum 'Policy'.
    SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QSizePolicy_Type,
        "Policy",
        "PySide.QtGui.QSizePolicy.Policy",
        "QSizePolicy::Policy");
    if (!SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX],
        &Sbk_QSizePolicy_Type, "Fixed", (long) QSizePolicy::Fixed))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX],
        &Sbk_QSizePolicy_Type, "Minimum", (long) QSizePolicy::Minimum))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX],
        &Sbk_QSizePolicy_Type, "Maximum", (long) QSizePolicy::Maximum))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX],
        &Sbk_QSizePolicy_Type, "Preferred", (long) QSizePolicy::Preferred))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX],
        &Sbk_QSizePolicy_Type, "MinimumExpanding", (long) QSizePolicy::MinimumExpanding))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX],
        &Sbk_QSizePolicy_Type, "Expanding", (long) QSizePolicy::Expanding))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX],
        &Sbk_QSizePolicy_Type, "Ignored", (long) QSizePolicy::Ignored))
        return ;
    // End of 'Policy' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QSizePolicy >("QSizePolicy");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QSizePolicy >("QSizePolicy*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QSizePolicy >(typeid(::QSizePolicy).name());
    qRegisterMetaType< ::QSizePolicy >("QSizePolicy");
    qRegisterMetaType< ::QSizePolicy::ControlType >("QSizePolicy::ControlType");
    qRegisterMetaType< ::QSizePolicy::ControlTypes >("QSizePolicy::ControlTypes");
    qRegisterMetaType< ::QSizePolicy::PolicyFlag >("QSizePolicy::PolicyFlag");
    qRegisterMetaType< ::QSizePolicy::Policy >("QSizePolicy::Policy");
}
