/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionbutton_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionButton_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionButton >()))
        return -1;

    ::QStyleOptionButton* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionButton", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionButton()
    // 1: QStyleOptionButton(QStyleOptionButton)
    // 2: QStyleOptionButton(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionButton()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionButton(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionButton >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionButton(QStyleOptionButton)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionButton_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionButton()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionButton()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionButton();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionButton(QStyleOptionButton)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionButton & cppArg0 = Shiboken::Converter< ::QStyleOptionButton >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionButton(QStyleOptionButton)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionButton(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionButton(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionButton(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionButton(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionButton >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionButton_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionButton_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionButton", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionButton", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionButton_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionButton_get_iconSize(PyObject* self, void*)
{
    ::QStyleOptionButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionButton* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QSIZE_IDX], &(cppSelf->iconSize), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionButton_set_iconSize(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'iconSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'iconSize', 'QSize' or convertible type expected");
        return -1;
    }

    cppSelf->iconSize = Shiboken::Converter< ::QSize >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionButton_get_features(PyObject* self, void*)
{
    ::QStyleOptionButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionButton* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<QStyleOptionButton::ButtonFeature> >::toPython(cppSelf->features);
    return value;
}
static int Sbk_QStyleOptionButton_set_features(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'features' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QStyleOptionButton::ButtonFeature> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'features', 'ButtonFeatures' or convertible type expected");
        return -1;
    }

    cppSelf->features = Shiboken::Converter< ::QFlags<QStyleOptionButton::ButtonFeature> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionButton_get_icon(PyObject* self, void*)
{
    ::QStyleOptionButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionButton* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QICON_IDX], &(cppSelf->icon), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionButton_set_icon(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'icon' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QIcon >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'icon', 'QIcon' or convertible type expected");
        return -1;
    }

    cppSelf->icon = Shiboken::Converter< ::QIcon >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionButton_get_text(PyObject* self, void*)
{
    ::QStyleOptionButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionButton* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QString >::toPython(cppSelf->text);
    return value;
}
static int Sbk_QStyleOptionButton_set_text(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'text' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'text', 'QString' or convertible type expected");
        return -1;
    }

    cppSelf->text = Shiboken::Converter< ::QString >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionButton
static PyGetSetDef Sbk_QStyleOptionButton_getsetlist[] = {
    {const_cast<char*>("iconSize"), Sbk_QStyleOptionButton_get_iconSize, Sbk_QStyleOptionButton_set_iconSize},
    {const_cast<char*>("features"), Sbk_QStyleOptionButton_get_features, Sbk_QStyleOptionButton_set_features},
    {const_cast<char*>("icon"), Sbk_QStyleOptionButton_get_icon, Sbk_QStyleOptionButton_set_icon},
    {const_cast<char*>("text"), Sbk_QStyleOptionButton_get_text, Sbk_QStyleOptionButton_set_text},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionButton_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionButton_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionButton_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionButton",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionButton_traverse,
    /*tp_clear*/            Sbk_QStyleOptionButton_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionButton_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionButton_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionButton_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QStyleOptionButton_ButtonFeature___and__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures >::toPython(
        Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures>::toCpp(self)
        & Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionButton_ButtonFeature___or__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures >::toPython(
        Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures>::toCpp(self)
        | Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionButton_ButtonFeature___xor__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures >::toPython(
        Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures>::toCpp(self)
        ^ Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionButton_ButtonFeature___invert__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< QStyleOptionButton::ButtonFeatures >::toPython(
        ~Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures >::toCpp(self)
    );
}

static PyObject* SbkPySide_QtGui_QStyleOptionButton_ButtonFeature_long(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures>::toCpp(v);
    return PyLong_FromLong(val);
}
static int SbkPySide_QtGui_QStyleOptionButton_ButtonFeature__nonzero(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QStyleOptionButton::ButtonFeatures>::toCpp(v);
    return val != 0;
}

static PyNumberMethods SbkPySide_QtGui_QStyleOptionButton_ButtonFeature_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    #ifndef IS_PY3K
    /* nb_divide */             0,
    #endif
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              SbkPySide_QtGui_QStyleOptionButton_ButtonFeature__nonzero,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QStyleOptionButton_ButtonFeature___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QStyleOptionButton_ButtonFeature___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QStyleOptionButton_ButtonFeature___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QStyleOptionButton_ButtonFeature___or__,
    #ifndef IS_PY3K
    /* nb_coerce */             0,
    #endif
    /*nb_int*/                  SbkPySide_QtGui_QStyleOptionButton_ButtonFeature_long,
    #ifdef IS_PY3K
    /*nb_reserved*/             0,
    /*nb_float*/                0,
    #else
    /*nb_long*/                 SbkPySide_QtGui_QStyleOptionButton_ButtonFeature_long,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    #endif
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    #ifndef IS_PY3K
    /*nb_inplace_divide*/       0,
    #endif
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QStyleOptionButton_ButtonFeatures_Type = {
    PyVarObject_HEAD_INIT(&PyType_Type, 0)
    /*tp_name*/             "ButtonFeatures",
    /*tp_basicsize*/        sizeof(PySideQFlagsObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QStyleOptionButton_ButtonFeature_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      &PySideQFlagsRichCompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              &PySideQFlagsNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QStyleOptionButton(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionButton_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionButton", "QStyleOptionButton*",
        &Sbk_QStyleOptionButton_Type, &Shiboken::callCppDestructor< ::QStyleOptionButton >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionButton_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionButton.StyleOptionVersion",
        "QStyleOptionButton::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionButton_Type, "Version", (long) QStyleOptionButton::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'ButtonFeature'.
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QSTYLEOPTIONBUTTON_BUTTONFEATURE__IDX] = &SbkPySide_QtGui_QStyleOptionButton_ButtonFeatures_Type;
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_BUTTONFEATURE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionButton_Type,
        "ButtonFeature",
        "PySide.QtGui.QStyleOptionButton.ButtonFeature",
        "QStyleOptionButton::ButtonFeature",
        SbkPySide_QtGuiTypes[SBK_QFLAGS_QSTYLEOPTIONBUTTON_BUTTONFEATURE__IDX]);
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_BUTTONFEATURE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_BUTTONFEATURE_IDX],
        &Sbk_QStyleOptionButton_Type, "None", (long) QStyleOptionButton::None))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_BUTTONFEATURE_IDX],
        &Sbk_QStyleOptionButton_Type, "Flat", (long) QStyleOptionButton::Flat))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_BUTTONFEATURE_IDX],
        &Sbk_QStyleOptionButton_Type, "HasMenu", (long) QStyleOptionButton::HasMenu))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_BUTTONFEATURE_IDX],
        &Sbk_QStyleOptionButton_Type, "DefaultButton", (long) QStyleOptionButton::DefaultButton))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_BUTTONFEATURE_IDX],
        &Sbk_QStyleOptionButton_Type, "AutoDefaultButton", (long) QStyleOptionButton::AutoDefaultButton))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_BUTTONFEATURE_IDX],
        &Sbk_QStyleOptionButton_Type, "CommandLinkButton", (long) QStyleOptionButton::CommandLinkButton))
        return ;
    // End of 'ButtonFeature' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionButton_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionButton.StyleOptionType",
        "QStyleOptionButton::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONBUTTON_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionButton_Type, "Type", (long) QStyleOptionButton::Type))
        return ;
    // End of 'StyleOptionType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionButton >("QStyleOptionButton*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionButton >(typeid(::QStyleOptionButton).name());
    qRegisterMetaType< ::QStyleOptionButton::StyleOptionVersion >("QStyleOptionButton::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionButton::ButtonFeature >("QStyleOptionButton::ButtonFeature");
    qRegisterMetaType< ::QStyleOptionButton::ButtonFeatures >("QStyleOptionButton::ButtonFeatures");
    qRegisterMetaType< ::QStyleOptionButton::StyleOptionType >("QStyleOptionButton::StyleOptionType");
}
