/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiondockwidgetv2_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionDockWidgetV2_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionDockWidgetV2 >()))
        return -1;

    ::QStyleOptionDockWidgetV2* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionDockWidgetV2", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionDockWidgetV2()
    // 1: QStyleOptionDockWidgetV2(QStyleOptionDockWidget)
    // 2: QStyleOptionDockWidgetV2(QStyleOptionDockWidgetV2)
    // 3: QStyleOptionDockWidgetV2(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionDockWidgetV2()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 3; // QStyleOptionDockWidgetV2(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionDockWidgetV2 >::isConvertible(pyArgs[0])) {
        overloadId = 2; // QStyleOptionDockWidgetV2(QStyleOptionDockWidgetV2)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionDockWidget >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionDockWidgetV2(QStyleOptionDockWidget)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionDockWidgetV2_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionDockWidgetV2()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionDockWidgetV2()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionDockWidgetV2();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionDockWidgetV2(QStyleOptionDockWidget)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionDockWidget & cppArg0 = Shiboken::Converter< ::QStyleOptionDockWidget >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionDockWidgetV2(QStyleOptionDockWidget)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionDockWidgetV2(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionDockWidgetV2(QStyleOptionDockWidgetV2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionDockWidgetV2 & cppArg0 = Shiboken::Converter< ::QStyleOptionDockWidgetV2 >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionDockWidgetV2(QStyleOptionDockWidgetV2)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionDockWidgetV2(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QStyleOptionDockWidgetV2(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionDockWidgetV2(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionDockWidgetV2(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionDockWidgetV2 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionDockWidgetV2_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionDockWidgetV2_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionDockWidget", "PySide.QtGui.QStyleOptionDockWidgetV2", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionDockWidgetV2", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionDockWidgetV2_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionDockWidgetV2_get_verticalTitleBar(PyObject* self, void*)
{
    ::QStyleOptionDockWidgetV2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionDockWidgetV2* >::toCpp(self);
    PyObject* value = Shiboken::Converter< bool >::toPython(cppSelf->verticalTitleBar);
    return value;
}
static int Sbk_QStyleOptionDockWidgetV2_set_verticalTitleBar(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionDockWidgetV2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionDockWidgetV2* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'verticalTitleBar' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'verticalTitleBar', 'bool' or convertible type expected");
        return -1;
    }

    cppSelf->verticalTitleBar = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionDockWidgetV2
static PyGetSetDef Sbk_QStyleOptionDockWidgetV2_getsetlist[] = {
    {const_cast<char*>("verticalTitleBar"), Sbk_QStyleOptionDockWidgetV2_get_verticalTitleBar, Sbk_QStyleOptionDockWidgetV2_set_verticalTitleBar},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionDockWidgetV2_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionDockWidgetV2_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionDockWidgetV2_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionDockWidgetV2",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionDockWidgetV2_traverse,
    /*tp_clear*/            Sbk_QStyleOptionDockWidgetV2_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionDockWidgetV2_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionDockWidgetV2_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionDockWidgetV2_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionDockWidgetV2(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGETV2_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionDockWidgetV2_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionDockWidgetV2", "QStyleOptionDockWidgetV2*",
        &Sbk_QStyleOptionDockWidgetV2_Type, &Shiboken::callCppDestructor< ::QStyleOptionDockWidgetV2 >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGET_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGETV2_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionDockWidgetV2_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionDockWidgetV2.StyleOptionVersion",
        "QStyleOptionDockWidgetV2::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGETV2_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGETV2_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionDockWidgetV2_Type, "Version", (long) QStyleOptionDockWidgetV2::Version))
        return ;
    // End of 'StyleOptionVersion' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionDockWidgetV2 >("QStyleOptionDockWidgetV2*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionDockWidgetV2 >(typeid(::QStyleOptionDockWidgetV2).name());
    qRegisterMetaType< ::QStyleOptionDockWidgetV2::StyleOptionVersion >("QStyleOptionDockWidgetV2::StyleOptionVersion");
}
