/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionheader_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionHeader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionHeader >()))
        return -1;

    ::QStyleOptionHeader* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionHeader", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionHeader()
    // 1: QStyleOptionHeader(QStyleOptionHeader)
    // 2: QStyleOptionHeader(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionHeader()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionHeader(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionHeader >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionHeader(QStyleOptionHeader)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionHeader_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionHeader()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionHeader()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionHeader();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionHeader(QStyleOptionHeader)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionHeader & cppArg0 = Shiboken::Converter< ::QStyleOptionHeader >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionHeader(QStyleOptionHeader)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionHeader(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionHeader(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionHeader(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionHeader(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionHeader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionHeader_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionHeader_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionHeader", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionHeader", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionHeader_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionHeader_get_section(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->section);
    return value;
}
static int Sbk_QStyleOptionHeader_set_section(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'section' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'section', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->section = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionHeader_get_sortIndicator(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QStyleOptionHeader::SortIndicator >::toPython(cppSelf->sortIndicator);
    return value;
}
static int Sbk_QStyleOptionHeader_set_sortIndicator(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'sortIndicator' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionHeader::SortIndicator >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'sortIndicator', 'SortIndicator' or convertible type expected");
        return -1;
    }

    cppSelf->sortIndicator = Shiboken::Converter< ::QStyleOptionHeader::SortIndicator >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionHeader_get_position(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QStyleOptionHeader::SectionPosition >::toPython(cppSelf->position);
    return value;
}
static int Sbk_QStyleOptionHeader_set_position(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'position' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionHeader::SectionPosition >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'position', 'SectionPosition' or convertible type expected");
        return -1;
    }

    cppSelf->position = Shiboken::Converter< ::QStyleOptionHeader::SectionPosition >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionHeader_get_icon(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QICON_IDX], &(cppSelf->icon), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionHeader_set_icon(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'icon' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QIcon >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'icon', 'QIcon' or convertible type expected");
        return -1;
    }

    cppSelf->icon = Shiboken::Converter< ::QIcon >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionHeader_get_textAlignment(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppSelf->textAlignment);
    return value;
}
static int Sbk_QStyleOptionHeader_set_textAlignment(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'textAlignment' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'textAlignment', 'Alignment' or convertible type expected");
        return -1;
    }

    cppSelf->textAlignment = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionHeader_get_text(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QString >::toPython(cppSelf->text);
    return value;
}
static int Sbk_QStyleOptionHeader_set_text(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'text' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'text', 'QString' or convertible type expected");
        return -1;
    }

    cppSelf->text = Shiboken::Converter< ::QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionHeader_get_selectedPosition(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QStyleOptionHeader::SelectedPosition >::toPython(cppSelf->selectedPosition);
    return value;
}
static int Sbk_QStyleOptionHeader_set_selectedPosition(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'selectedPosition' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionHeader::SelectedPosition >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'selectedPosition', 'SelectedPosition' or convertible type expected");
        return -1;
    }

    cppSelf->selectedPosition = Shiboken::Converter< ::QStyleOptionHeader::SelectedPosition >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionHeader_get_iconAlignment(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppSelf->iconAlignment);
    return value;
}
static int Sbk_QStyleOptionHeader_set_iconAlignment(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'iconAlignment' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'iconAlignment', 'Alignment' or convertible type expected");
        return -1;
    }

    cppSelf->iconAlignment = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionHeader_get_orientation(PyObject* self, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::Qt::Orientation >::toPython(cppSelf->orientation);
    return value;
}
static int Sbk_QStyleOptionHeader_set_orientation(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionHeader* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'orientation' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::Orientation >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'orientation', 'Orientation' or convertible type expected");
        return -1;
    }

    cppSelf->orientation = Shiboken::Converter< ::Qt::Orientation >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionHeader
static PyGetSetDef Sbk_QStyleOptionHeader_getsetlist[] = {
    {const_cast<char*>("section"), Sbk_QStyleOptionHeader_get_section, Sbk_QStyleOptionHeader_set_section},
    {const_cast<char*>("sortIndicator"), Sbk_QStyleOptionHeader_get_sortIndicator, Sbk_QStyleOptionHeader_set_sortIndicator},
    {const_cast<char*>("position"), Sbk_QStyleOptionHeader_get_position, Sbk_QStyleOptionHeader_set_position},
    {const_cast<char*>("icon"), Sbk_QStyleOptionHeader_get_icon, Sbk_QStyleOptionHeader_set_icon},
    {const_cast<char*>("textAlignment"), Sbk_QStyleOptionHeader_get_textAlignment, Sbk_QStyleOptionHeader_set_textAlignment},
    {const_cast<char*>("text"), Sbk_QStyleOptionHeader_get_text, Sbk_QStyleOptionHeader_set_text},
    {const_cast<char*>("selectedPosition"), Sbk_QStyleOptionHeader_get_selectedPosition, Sbk_QStyleOptionHeader_set_selectedPosition},
    {const_cast<char*>("iconAlignment"), Sbk_QStyleOptionHeader_get_iconAlignment, Sbk_QStyleOptionHeader_set_iconAlignment},
    {const_cast<char*>("orientation"), Sbk_QStyleOptionHeader_get_orientation, Sbk_QStyleOptionHeader_set_orientation},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionHeader_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionHeader_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionHeader_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionHeader",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionHeader_traverse,
    /*tp_clear*/            Sbk_QStyleOptionHeader_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionHeader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionHeader_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionHeader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionHeader(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionHeader_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionHeader", "QStyleOptionHeader*",
        &Sbk_QStyleOptionHeader_Type, &Shiboken::callCppDestructor< ::QStyleOptionHeader >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionHeader_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionHeader.StyleOptionVersion",
        "QStyleOptionHeader::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionHeader_Type, "Version", (long) QStyleOptionHeader::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'SectionPosition'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SECTIONPOSITION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionHeader_Type,
        "SectionPosition",
        "PySide.QtGui.QStyleOptionHeader.SectionPosition",
        "QStyleOptionHeader::SectionPosition");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SECTIONPOSITION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SECTIONPOSITION_IDX],
        &Sbk_QStyleOptionHeader_Type, "Beginning", (long) QStyleOptionHeader::Beginning))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SECTIONPOSITION_IDX],
        &Sbk_QStyleOptionHeader_Type, "Middle", (long) QStyleOptionHeader::Middle))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SECTIONPOSITION_IDX],
        &Sbk_QStyleOptionHeader_Type, "End", (long) QStyleOptionHeader::End))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SECTIONPOSITION_IDX],
        &Sbk_QStyleOptionHeader_Type, "OnlyOneSection", (long) QStyleOptionHeader::OnlyOneSection))
        return ;
    // End of 'SectionPosition' enum.

    // Initialization of enum 'SelectedPosition'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SELECTEDPOSITION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionHeader_Type,
        "SelectedPosition",
        "PySide.QtGui.QStyleOptionHeader.SelectedPosition",
        "QStyleOptionHeader::SelectedPosition");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SELECTEDPOSITION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SELECTEDPOSITION_IDX],
        &Sbk_QStyleOptionHeader_Type, "NotAdjacent", (long) QStyleOptionHeader::NotAdjacent))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SELECTEDPOSITION_IDX],
        &Sbk_QStyleOptionHeader_Type, "NextIsSelected", (long) QStyleOptionHeader::NextIsSelected))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SELECTEDPOSITION_IDX],
        &Sbk_QStyleOptionHeader_Type, "PreviousIsSelected", (long) QStyleOptionHeader::PreviousIsSelected))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SELECTEDPOSITION_IDX],
        &Sbk_QStyleOptionHeader_Type, "NextAndPreviousAreSelected", (long) QStyleOptionHeader::NextAndPreviousAreSelected))
        return ;
    // End of 'SelectedPosition' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionHeader_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionHeader.StyleOptionType",
        "QStyleOptionHeader::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionHeader_Type, "Type", (long) QStyleOptionHeader::Type))
        return ;
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'SortIndicator'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SORTINDICATOR_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionHeader_Type,
        "SortIndicator",
        "PySide.QtGui.QStyleOptionHeader.SortIndicator",
        "QStyleOptionHeader::SortIndicator");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SORTINDICATOR_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SORTINDICATOR_IDX],
        &Sbk_QStyleOptionHeader_Type, "None", (long) QStyleOptionHeader::None))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SORTINDICATOR_IDX],
        &Sbk_QStyleOptionHeader_Type, "SortUp", (long) QStyleOptionHeader::SortUp))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONHEADER_SORTINDICATOR_IDX],
        &Sbk_QStyleOptionHeader_Type, "SortDown", (long) QStyleOptionHeader::SortDown))
        return ;
    // End of 'SortIndicator' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionHeader >("QStyleOptionHeader*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionHeader >(typeid(::QStyleOptionHeader).name());
    qRegisterMetaType< ::QStyleOptionHeader::StyleOptionVersion >("QStyleOptionHeader::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionHeader::SectionPosition >("QStyleOptionHeader::SectionPosition");
    qRegisterMetaType< ::QStyleOptionHeader::SelectedPosition >("QStyleOptionHeader::SelectedPosition");
    qRegisterMetaType< ::QStyleOptionHeader::StyleOptionType >("QStyleOptionHeader::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionHeader::SortIndicator >("QStyleOptionHeader::SortIndicator");
}
