/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionmenuitem_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionMenuItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionMenuItem >()))
        return -1;

    ::QStyleOptionMenuItem* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionMenuItem", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionMenuItem()
    // 1: QStyleOptionMenuItem(QStyleOptionMenuItem)
    // 2: QStyleOptionMenuItem(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionMenuItem()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionMenuItem(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionMenuItem >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionMenuItem(QStyleOptionMenuItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionMenuItem_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionMenuItem()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionMenuItem()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionMenuItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionMenuItem(QStyleOptionMenuItem)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionMenuItem & cppArg0 = Shiboken::Converter< ::QStyleOptionMenuItem >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionMenuItem(QStyleOptionMenuItem)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionMenuItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionMenuItem(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionMenuItem(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionMenuItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionMenuItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionMenuItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionMenuItem_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionMenuItem", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionMenuItem", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionMenuItem_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionMenuItem_get_menuHasCheckableItems(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< bool >::toPython(cppSelf->menuHasCheckableItems);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_menuHasCheckableItems(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'menuHasCheckableItems' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'menuHasCheckableItems', 'bool' or convertible type expected");
        return -1;
    }

    cppSelf->menuHasCheckableItems = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_menuRect(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QRECT_IDX], &(cppSelf->menuRect), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_menuRect(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'menuRect' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QRect >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'menuRect', 'QRect' or convertible type expected");
        return -1;
    }

    cppSelf->menuRect = Shiboken::Converter< ::QRect >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_checkType(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QStyleOptionMenuItem::CheckType >::toPython(cppSelf->checkType);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_checkType(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'checkType' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionMenuItem::CheckType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'checkType', 'CheckType' or convertible type expected");
        return -1;
    }

    cppSelf->checkType = Shiboken::Converter< ::QStyleOptionMenuItem::CheckType >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_icon(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QICON_IDX], &(cppSelf->icon), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_icon(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'icon' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QIcon >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'icon', 'QIcon' or convertible type expected");
        return -1;
    }

    cppSelf->icon = Shiboken::Converter< ::QIcon >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_checked(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< bool >::toPython(cppSelf->checked);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_checked(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'checked' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'checked', 'bool' or convertible type expected");
        return -1;
    }

    cppSelf->checked = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_maxIconWidth(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->maxIconWidth);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_maxIconWidth(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'maxIconWidth' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'maxIconWidth', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->maxIconWidth = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_tabWidth(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->tabWidth);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_tabWidth(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'tabWidth' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'tabWidth', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->tabWidth = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_text(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QString >::toPython(cppSelf->text);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_text(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'text' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'text', 'QString' or convertible type expected");
        return -1;
    }

    cppSelf->text = Shiboken::Converter< ::QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_font(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QFONT_IDX], &(cppSelf->font), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_font(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'font' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFont >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'font', 'QFont' or convertible type expected");
        return -1;
    }

    cppSelf->font = Shiboken::Converter< ::QFont >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_menuItemType(PyObject* self, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QStyleOptionMenuItem::MenuItemType >::toPython(cppSelf->menuItemType);
    return value;
}
static int Sbk_QStyleOptionMenuItem_set_menuItemType(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionMenuItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionMenuItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'menuItemType' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionMenuItem::MenuItemType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'menuItemType', 'MenuItemType' or convertible type expected");
        return -1;
    }

    cppSelf->menuItemType = Shiboken::Converter< ::QStyleOptionMenuItem::MenuItemType >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionMenuItem
static PyGetSetDef Sbk_QStyleOptionMenuItem_getsetlist[] = {
    {const_cast<char*>("menuHasCheckableItems"), Sbk_QStyleOptionMenuItem_get_menuHasCheckableItems, Sbk_QStyleOptionMenuItem_set_menuHasCheckableItems},
    {const_cast<char*>("menuRect"), Sbk_QStyleOptionMenuItem_get_menuRect, Sbk_QStyleOptionMenuItem_set_menuRect},
    {const_cast<char*>("checkType"), Sbk_QStyleOptionMenuItem_get_checkType, Sbk_QStyleOptionMenuItem_set_checkType},
    {const_cast<char*>("icon"), Sbk_QStyleOptionMenuItem_get_icon, Sbk_QStyleOptionMenuItem_set_icon},
    {const_cast<char*>("checked"), Sbk_QStyleOptionMenuItem_get_checked, Sbk_QStyleOptionMenuItem_set_checked},
    {const_cast<char*>("maxIconWidth"), Sbk_QStyleOptionMenuItem_get_maxIconWidth, Sbk_QStyleOptionMenuItem_set_maxIconWidth},
    {const_cast<char*>("tabWidth"), Sbk_QStyleOptionMenuItem_get_tabWidth, Sbk_QStyleOptionMenuItem_set_tabWidth},
    {const_cast<char*>("text"), Sbk_QStyleOptionMenuItem_get_text, Sbk_QStyleOptionMenuItem_set_text},
    {const_cast<char*>("font"), Sbk_QStyleOptionMenuItem_get_font, Sbk_QStyleOptionMenuItem_set_font},
    {const_cast<char*>("menuItemType"), Sbk_QStyleOptionMenuItem_get_menuItemType, Sbk_QStyleOptionMenuItem_set_menuItemType},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionMenuItem_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionMenuItem_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionMenuItem_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionMenuItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionMenuItem_traverse,
    /*tp_clear*/            Sbk_QStyleOptionMenuItem_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionMenuItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionMenuItem_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionMenuItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionMenuItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionMenuItem_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionMenuItem", "QStyleOptionMenuItem*",
        &Sbk_QStyleOptionMenuItem_Type, &Shiboken::callCppDestructor< ::QStyleOptionMenuItem >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionMenuItem_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionMenuItem.StyleOptionVersion",
        "QStyleOptionMenuItem::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "Version", (long) QStyleOptionMenuItem::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionMenuItem_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionMenuItem.StyleOptionType",
        "QStyleOptionMenuItem::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "Type", (long) QStyleOptionMenuItem::Type))
        return ;
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'CheckType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_CHECKTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionMenuItem_Type,
        "CheckType",
        "PySide.QtGui.QStyleOptionMenuItem.CheckType",
        "QStyleOptionMenuItem::CheckType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_CHECKTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_CHECKTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "NotCheckable", (long) QStyleOptionMenuItem::NotCheckable))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_CHECKTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "Exclusive", (long) QStyleOptionMenuItem::Exclusive))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_CHECKTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "NonExclusive", (long) QStyleOptionMenuItem::NonExclusive))
        return ;
    // End of 'CheckType' enum.

    // Initialization of enum 'MenuItemType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionMenuItem_Type,
        "MenuItemType",
        "PySide.QtGui.QStyleOptionMenuItem.MenuItemType",
        "QStyleOptionMenuItem::MenuItemType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "Normal", (long) QStyleOptionMenuItem::Normal))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "DefaultItem", (long) QStyleOptionMenuItem::DefaultItem))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "Separator", (long) QStyleOptionMenuItem::Separator))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "SubMenu", (long) QStyleOptionMenuItem::SubMenu))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "Scroller", (long) QStyleOptionMenuItem::Scroller))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "TearOff", (long) QStyleOptionMenuItem::TearOff))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "Margin", (long) QStyleOptionMenuItem::Margin))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX],
        &Sbk_QStyleOptionMenuItem_Type, "EmptyArea", (long) QStyleOptionMenuItem::EmptyArea))
        return ;
    // End of 'MenuItemType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionMenuItem >("QStyleOptionMenuItem*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionMenuItem >(typeid(::QStyleOptionMenuItem).name());
    qRegisterMetaType< ::QStyleOptionMenuItem::StyleOptionVersion >("QStyleOptionMenuItem::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionMenuItem::StyleOptionType >("QStyleOptionMenuItem::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionMenuItem::CheckType >("QStyleOptionMenuItem::CheckType");
    qRegisterMetaType< ::QStyleOptionMenuItem::MenuItemType >("QStyleOptionMenuItem::MenuItemType");
}
