/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionslider_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionSlider_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionSlider >()))
        return -1;

    ::QStyleOptionSlider* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionSlider", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionSlider()
    // 1: QStyleOptionSlider(QStyleOptionSlider)
    // 2: QStyleOptionSlider(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionSlider()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionSlider(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionSlider >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionSlider(QStyleOptionSlider)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionSlider_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionSlider()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionSlider()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSlider();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionSlider(QStyleOptionSlider)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionSlider & cppArg0 = Shiboken::Converter< ::QStyleOptionSlider >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionSlider(QStyleOptionSlider)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSlider(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionSlider(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionSlider(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSlider(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionSlider >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionSlider_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionSlider_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionSlider", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionSlider", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionSlider_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionSlider_get_tickInterval(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->tickInterval);
    return value;
}
static int Sbk_QStyleOptionSlider_set_tickInterval(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'tickInterval' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'tickInterval', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->tickInterval = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_minimum(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->minimum);
    return value;
}
static int Sbk_QStyleOptionSlider_set_minimum(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'minimum' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'minimum', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->minimum = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_notchTarget(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< double >::toPython(cppSelf->notchTarget);
    return value;
}
static int Sbk_QStyleOptionSlider_set_notchTarget(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'notchTarget' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'notchTarget', 'qreal' or convertible type expected");
        return -1;
    }

    cppSelf->notchTarget = Shiboken::Converter< double >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_maximum(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->maximum);
    return value;
}
static int Sbk_QStyleOptionSlider_set_maximum(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'maximum' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'maximum', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->maximum = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_sliderPosition(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->sliderPosition);
    return value;
}
static int Sbk_QStyleOptionSlider_set_sliderPosition(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'sliderPosition' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'sliderPosition', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->sliderPosition = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_dialWrapping(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< bool >::toPython(cppSelf->dialWrapping);
    return value;
}
static int Sbk_QStyleOptionSlider_set_dialWrapping(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'dialWrapping' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'dialWrapping', 'bool' or convertible type expected");
        return -1;
    }

    cppSelf->dialWrapping = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_sliderValue(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->sliderValue);
    return value;
}
static int Sbk_QStyleOptionSlider_set_sliderValue(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'sliderValue' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'sliderValue', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->sliderValue = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_singleStep(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->singleStep);
    return value;
}
static int Sbk_QStyleOptionSlider_set_singleStep(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'singleStep' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'singleStep', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->singleStep = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_tickPosition(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QSlider::TickPosition >::toPython(cppSelf->tickPosition);
    return value;
}
static int Sbk_QStyleOptionSlider_set_tickPosition(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'tickPosition' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSlider::TickPosition >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'tickPosition', 'TickPosition' or convertible type expected");
        return -1;
    }

    cppSelf->tickPosition = Shiboken::Converter< ::QSlider::TickPosition >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_pageStep(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->pageStep);
    return value;
}
static int Sbk_QStyleOptionSlider_set_pageStep(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'pageStep' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'pageStep', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->pageStep = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_orientation(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::Qt::Orientation >::toPython(cppSelf->orientation);
    return value;
}
static int Sbk_QStyleOptionSlider_set_orientation(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'orientation' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::Orientation >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'orientation', 'Orientation' or convertible type expected");
        return -1;
    }

    cppSelf->orientation = Shiboken::Converter< ::Qt::Orientation >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSlider_get_upsideDown(PyObject* self, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    PyObject* value = Shiboken::Converter< bool >::toPython(cppSelf->upsideDown);
    return value;
}
static int Sbk_QStyleOptionSlider_set_upsideDown(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSlider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSlider* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'upsideDown' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'upsideDown', 'bool' or convertible type expected");
        return -1;
    }

    cppSelf->upsideDown = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionSlider
static PyGetSetDef Sbk_QStyleOptionSlider_getsetlist[] = {
    {const_cast<char*>("tickInterval"), Sbk_QStyleOptionSlider_get_tickInterval, Sbk_QStyleOptionSlider_set_tickInterval},
    {const_cast<char*>("minimum"), Sbk_QStyleOptionSlider_get_minimum, Sbk_QStyleOptionSlider_set_minimum},
    {const_cast<char*>("notchTarget"), Sbk_QStyleOptionSlider_get_notchTarget, Sbk_QStyleOptionSlider_set_notchTarget},
    {const_cast<char*>("maximum"), Sbk_QStyleOptionSlider_get_maximum, Sbk_QStyleOptionSlider_set_maximum},
    {const_cast<char*>("sliderPosition"), Sbk_QStyleOptionSlider_get_sliderPosition, Sbk_QStyleOptionSlider_set_sliderPosition},
    {const_cast<char*>("dialWrapping"), Sbk_QStyleOptionSlider_get_dialWrapping, Sbk_QStyleOptionSlider_set_dialWrapping},
    {const_cast<char*>("sliderValue"), Sbk_QStyleOptionSlider_get_sliderValue, Sbk_QStyleOptionSlider_set_sliderValue},
    {const_cast<char*>("singleStep"), Sbk_QStyleOptionSlider_get_singleStep, Sbk_QStyleOptionSlider_set_singleStep},
    {const_cast<char*>("tickPosition"), Sbk_QStyleOptionSlider_get_tickPosition, Sbk_QStyleOptionSlider_set_tickPosition},
    {const_cast<char*>("pageStep"), Sbk_QStyleOptionSlider_get_pageStep, Sbk_QStyleOptionSlider_set_pageStep},
    {const_cast<char*>("orientation"), Sbk_QStyleOptionSlider_get_orientation, Sbk_QStyleOptionSlider_set_orientation},
    {const_cast<char*>("upsideDown"), Sbk_QStyleOptionSlider_get_upsideDown, Sbk_QStyleOptionSlider_set_upsideDown},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionSlider_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionSlider_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionSlider_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionSlider",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionSlider_traverse,
    /*tp_clear*/            Sbk_QStyleOptionSlider_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionSlider_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionSlider_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionSlider_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionSlider(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSLIDER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionSlider_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionSlider", "QStyleOptionSlider*",
        &Sbk_QStyleOptionSlider_Type, &Shiboken::callCppDestructor< ::QStyleOptionSlider >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSLIDER_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionSlider_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionSlider.StyleOptionVersion",
        "QStyleOptionSlider::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSLIDER_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSLIDER_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionSlider_Type, "Version", (long) QStyleOptionSlider::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSLIDER_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionSlider_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionSlider.StyleOptionType",
        "QStyleOptionSlider::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSLIDER_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSLIDER_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionSlider_Type, "Type", (long) QStyleOptionSlider::Type))
        return ;
    // End of 'StyleOptionType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionSlider >("QStyleOptionSlider*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionSlider >(typeid(::QStyleOptionSlider).name());
    qRegisterMetaType< ::QStyleOptionSlider::StyleOptionVersion >("QStyleOptionSlider::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionSlider::StyleOptionType >("QStyleOptionSlider::StyleOptionType");
}
