/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionspinbox_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionSpinBox_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionSpinBox >()))
        return -1;

    ::QStyleOptionSpinBox* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionSpinBox", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionSpinBox()
    // 1: QStyleOptionSpinBox(QStyleOptionSpinBox)
    // 2: QStyleOptionSpinBox(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionSpinBox()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionSpinBox(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionSpinBox >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionSpinBox(QStyleOptionSpinBox)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionSpinBox_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionSpinBox()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionSpinBox()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSpinBox();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionSpinBox(QStyleOptionSpinBox)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionSpinBox & cppArg0 = Shiboken::Converter< ::QStyleOptionSpinBox >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionSpinBox(QStyleOptionSpinBox)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSpinBox(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionSpinBox(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionSpinBox(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSpinBox(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionSpinBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionSpinBox_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionSpinBox_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionSpinBox", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionSpinBox", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionSpinBox_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionSpinBox_get_stepEnabled(PyObject* self, void*)
{
    ::QStyleOptionSpinBox* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSpinBox* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<QAbstractSpinBox::StepEnabledFlag> >::toPython(cppSelf->stepEnabled);
    return value;
}
static int Sbk_QStyleOptionSpinBox_set_stepEnabled(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSpinBox* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSpinBox* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'stepEnabled' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QAbstractSpinBox::StepEnabledFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'stepEnabled', 'StepEnabled' or convertible type expected");
        return -1;
    }

    cppSelf->stepEnabled = Shiboken::Converter< ::QFlags<QAbstractSpinBox::StepEnabledFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSpinBox_get_buttonSymbols(PyObject* self, void*)
{
    ::QStyleOptionSpinBox* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSpinBox* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QAbstractSpinBox::ButtonSymbols >::toPython(cppSelf->buttonSymbols);
    return value;
}
static int Sbk_QStyleOptionSpinBox_set_buttonSymbols(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSpinBox* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSpinBox* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'buttonSymbols' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QAbstractSpinBox::ButtonSymbols >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'buttonSymbols', 'ButtonSymbols' or convertible type expected");
        return -1;
    }

    cppSelf->buttonSymbols = Shiboken::Converter< ::QAbstractSpinBox::ButtonSymbols >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSpinBox_get_frame(PyObject* self, void*)
{
    ::QStyleOptionSpinBox* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSpinBox* >::toCpp(self);
    PyObject* value = Shiboken::Converter< bool >::toPython(cppSelf->frame);
    return value;
}
static int Sbk_QStyleOptionSpinBox_set_frame(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSpinBox* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSpinBox* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'frame' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'frame', 'bool' or convertible type expected");
        return -1;
    }

    cppSelf->frame = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionSpinBox
static PyGetSetDef Sbk_QStyleOptionSpinBox_getsetlist[] = {
    {const_cast<char*>("stepEnabled"), Sbk_QStyleOptionSpinBox_get_stepEnabled, Sbk_QStyleOptionSpinBox_set_stepEnabled},
    {const_cast<char*>("buttonSymbols"), Sbk_QStyleOptionSpinBox_get_buttonSymbols, Sbk_QStyleOptionSpinBox_set_buttonSymbols},
    {const_cast<char*>("frame"), Sbk_QStyleOptionSpinBox_get_frame, Sbk_QStyleOptionSpinBox_set_frame},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionSpinBox_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionSpinBox_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionSpinBox_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionSpinBox",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionSpinBox_traverse,
    /*tp_clear*/            Sbk_QStyleOptionSpinBox_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionSpinBox_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionSpinBox_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionSpinBox_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionSpinBox(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionSpinBox_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionSpinBox", "QStyleOptionSpinBox*",
        &Sbk_QStyleOptionSpinBox_Type, &Shiboken::callCppDestructor< ::QStyleOptionSpinBox >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionSpinBox_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionSpinBox.StyleOptionVersion",
        "QStyleOptionSpinBox::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionSpinBox_Type, "Version", (long) QStyleOptionSpinBox::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionSpinBox_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionSpinBox.StyleOptionType",
        "QStyleOptionSpinBox::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionSpinBox_Type, "Type", (long) QStyleOptionSpinBox::Type))
        return ;
    // End of 'StyleOptionType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionSpinBox >("QStyleOptionSpinBox*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionSpinBox >(typeid(::QStyleOptionSpinBox).name());
    qRegisterMetaType< ::QStyleOptionSpinBox::StyleOptionVersion >("QStyleOptionSpinBox::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionSpinBox::StyleOptionType >("QStyleOptionSpinBox::StyleOptionType");
}
