/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiontabv3_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionTabV3_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionTabV3 >()))
        return -1;

    ::QStyleOptionTabV3* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionTabV3", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionTabV3()
    // 1: QStyleOptionTabV3(QStyleOptionTab)
    // 2: QStyleOptionTabV3(QStyleOptionTabV2)
    // 3: QStyleOptionTabV3(QStyleOptionTabV3)
    // 4: QStyleOptionTabV3(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionTabV3()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 4; // QStyleOptionTabV3(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionTabV3 >::isConvertible(pyArgs[0])) {
        overloadId = 3; // QStyleOptionTabV3(QStyleOptionTabV3)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionTabV2 >::isConvertible(pyArgs[0])) {
        overloadId = 2; // QStyleOptionTabV3(QStyleOptionTabV2)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionTab >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionTabV3(QStyleOptionTab)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionTabV3_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionTabV3()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionTabV3()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionTabV3();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionTabV3(QStyleOptionTab)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionTab & cppArg0 = Shiboken::Converter< ::QStyleOptionTab >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionTabV3(QStyleOptionTab)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionTabV3(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionTabV3(QStyleOptionTabV2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionTabV2 & cppArg0 = Shiboken::Converter< ::QStyleOptionTabV2 >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionTabV3(QStyleOptionTabV2)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionTabV3(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QStyleOptionTabV3(QStyleOptionTabV3)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionTabV3 & cppArg0 = Shiboken::Converter< ::QStyleOptionTabV3 >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionTabV3(QStyleOptionTabV3)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionTabV3(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // QStyleOptionTabV3(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionTabV3(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionTabV3(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionTabV3 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionTabV3_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionTabV3_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionTab", "PySide.QtGui.QStyleOptionTabV2", "PySide.QtGui.QStyleOptionTabV3", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionTabV3", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionTabV3_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionTabV3_get_documentMode(PyObject* self, void*)
{
    ::QStyleOptionTabV3* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabV3* >::toCpp(self);
    PyObject* value = Shiboken::Converter< bool >::toPython(cppSelf->documentMode);
    return value;
}
static int Sbk_QStyleOptionTabV3_set_documentMode(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionTabV3* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabV3* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'documentMode' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'documentMode', 'bool' or convertible type expected");
        return -1;
    }

    cppSelf->documentMode = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTabV3_get_rightButtonSize(PyObject* self, void*)
{
    ::QStyleOptionTabV3* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabV3* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QSIZE_IDX], &(cppSelf->rightButtonSize), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionTabV3_set_rightButtonSize(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionTabV3* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabV3* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'rightButtonSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'rightButtonSize', 'QSize' or convertible type expected");
        return -1;
    }

    cppSelf->rightButtonSize = Shiboken::Converter< ::QSize >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTabV3_get_leftButtonSize(PyObject* self, void*)
{
    ::QStyleOptionTabV3* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabV3* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QSIZE_IDX], &(cppSelf->leftButtonSize), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionTabV3_set_leftButtonSize(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionTabV3* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabV3* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'leftButtonSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'leftButtonSize', 'QSize' or convertible type expected");
        return -1;
    }

    cppSelf->leftButtonSize = Shiboken::Converter< ::QSize >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionTabV3
static PyGetSetDef Sbk_QStyleOptionTabV3_getsetlist[] = {
    {const_cast<char*>("documentMode"), Sbk_QStyleOptionTabV3_get_documentMode, Sbk_QStyleOptionTabV3_set_documentMode},
    {const_cast<char*>("rightButtonSize"), Sbk_QStyleOptionTabV3_get_rightButtonSize, Sbk_QStyleOptionTabV3_set_rightButtonSize},
    {const_cast<char*>("leftButtonSize"), Sbk_QStyleOptionTabV3_get_leftButtonSize, Sbk_QStyleOptionTabV3_set_leftButtonSize},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionTabV3_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionTabV3_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionTabV3_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionTabV3",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionTabV3_traverse,
    /*tp_clear*/            Sbk_QStyleOptionTabV3_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionTabV3_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionTabV3_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionTabV3_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionTabV3(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV3_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionTabV3_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionTabV3", "QStyleOptionTabV3*",
        &Sbk_QStyleOptionTabV3_Type, &Shiboken::callCppDestructor< ::QStyleOptionTabV3 >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV2_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV3_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionTabV3_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionTabV3.StyleOptionVersion",
        "QStyleOptionTabV3::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV3_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV3_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionTabV3_Type, "Version", (long) QStyleOptionTabV3::Version))
        return ;
    // End of 'StyleOptionVersion' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionTabV3 >("QStyleOptionTabV3*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionTabV3 >(typeid(::QStyleOptionTabV3).name());
    qRegisterMetaType< ::QStyleOptionTabV3::StyleOptionVersion >("QStyleOptionTabV3::StyleOptionVersion");
}
