/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiontoolbutton_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionToolButton_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionToolButton >()))
        return -1;

    ::QStyleOptionToolButton* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionToolButton", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionToolButton()
    // 1: QStyleOptionToolButton(QStyleOptionToolButton)
    // 2: QStyleOptionToolButton(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionToolButton()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionToolButton(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionToolButton >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionToolButton(QStyleOptionToolButton)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionToolButton_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionToolButton()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionToolButton()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionToolButton();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionToolButton(QStyleOptionToolButton)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionToolButton & cppArg0 = Shiboken::Converter< ::QStyleOptionToolButton >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionToolButton(QStyleOptionToolButton)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionToolButton(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionToolButton(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionToolButton(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionToolButton(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionToolButton >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionToolButton_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionToolButton_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionToolButton", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionToolButton", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionToolButton_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionToolButton_get_iconSize(PyObject* self, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QSIZE_IDX], &(cppSelf->iconSize), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionToolButton_set_iconSize(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'iconSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'iconSize', 'QSize' or convertible type expected");
        return -1;
    }

    cppSelf->iconSize = Shiboken::Converter< ::QSize >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolButton_get_toolButtonStyle(PyObject* self, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::Qt::ToolButtonStyle >::toPython(cppSelf->toolButtonStyle);
    return value;
}
static int Sbk_QStyleOptionToolButton_set_toolButtonStyle(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'toolButtonStyle' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::ToolButtonStyle >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'toolButtonStyle', 'ToolButtonStyle' or convertible type expected");
        return -1;
    }

    cppSelf->toolButtonStyle = Shiboken::Converter< ::Qt::ToolButtonStyle >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolButton_get_features(PyObject* self, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<QStyleOptionToolButton::ToolButtonFeature> >::toPython(cppSelf->features);
    return value;
}
static int Sbk_QStyleOptionToolButton_set_features(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'features' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QStyleOptionToolButton::ToolButtonFeature> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'features', 'ToolButtonFeatures' or convertible type expected");
        return -1;
    }

    cppSelf->features = Shiboken::Converter< ::QFlags<QStyleOptionToolButton::ToolButtonFeature> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolButton_get_arrowType(PyObject* self, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::Qt::ArrowType >::toPython(cppSelf->arrowType);
    return value;
}
static int Sbk_QStyleOptionToolButton_set_arrowType(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'arrowType' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::ArrowType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'arrowType', 'ArrowType' or convertible type expected");
        return -1;
    }

    cppSelf->arrowType = Shiboken::Converter< ::Qt::ArrowType >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolButton_get_icon(PyObject* self, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QICON_IDX], &(cppSelf->icon), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionToolButton_set_icon(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'icon' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QIcon >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'icon', 'QIcon' or convertible type expected");
        return -1;
    }

    cppSelf->icon = Shiboken::Converter< ::QIcon >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolButton_get_pos(PyObject* self, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QPOINT_IDX], &(cppSelf->pos), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionToolButton_set_pos(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'pos' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QPoint >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'pos', 'QPoint' or convertible type expected");
        return -1;
    }

    cppSelf->pos = Shiboken::Converter< ::QPoint >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolButton_get_text(PyObject* self, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QString >::toPython(cppSelf->text);
    return value;
}
static int Sbk_QStyleOptionToolButton_set_text(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'text' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'text', 'QString' or convertible type expected");
        return -1;
    }

    cppSelf->text = Shiboken::Converter< ::QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolButton_get_font(PyObject* self, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QFONT_IDX], &(cppSelf->font), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionToolButton_set_font(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionToolButton* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionToolButton* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'font' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFont >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'font', 'QFont' or convertible type expected");
        return -1;
    }

    cppSelf->font = Shiboken::Converter< ::QFont >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionToolButton
static PyGetSetDef Sbk_QStyleOptionToolButton_getsetlist[] = {
    {const_cast<char*>("iconSize"), Sbk_QStyleOptionToolButton_get_iconSize, Sbk_QStyleOptionToolButton_set_iconSize},
    {const_cast<char*>("toolButtonStyle"), Sbk_QStyleOptionToolButton_get_toolButtonStyle, Sbk_QStyleOptionToolButton_set_toolButtonStyle},
    {const_cast<char*>("features"), Sbk_QStyleOptionToolButton_get_features, Sbk_QStyleOptionToolButton_set_features},
    {const_cast<char*>("arrowType"), Sbk_QStyleOptionToolButton_get_arrowType, Sbk_QStyleOptionToolButton_set_arrowType},
    {const_cast<char*>("icon"), Sbk_QStyleOptionToolButton_get_icon, Sbk_QStyleOptionToolButton_set_icon},
    {const_cast<char*>("pos"), Sbk_QStyleOptionToolButton_get_pos, Sbk_QStyleOptionToolButton_set_pos},
    {const_cast<char*>("text"), Sbk_QStyleOptionToolButton_get_text, Sbk_QStyleOptionToolButton_set_text},
    {const_cast<char*>("font"), Sbk_QStyleOptionToolButton_get_font, Sbk_QStyleOptionToolButton_set_font},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionToolButton_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionToolButton_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionToolButton_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionToolButton",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionToolButton_traverse,
    /*tp_clear*/            Sbk_QStyleOptionToolButton_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionToolButton_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionToolButton_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionToolButton_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature___and__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures >::toPython(
        Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures>::toCpp(self)
        & Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature___or__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures >::toPython(
        Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures>::toCpp(self)
        | Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature___xor__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures >::toPython(
        Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures>::toCpp(self)
        ^ Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature___invert__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< QStyleOptionToolButton::ToolButtonFeatures >::toPython(
        ~Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures >::toCpp(self)
    );
}

static PyObject* SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature_long(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures>::toCpp(v);
    return PyLong_FromLong(val);
}
static int SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature__nonzero(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QStyleOptionToolButton::ToolButtonFeatures>::toCpp(v);
    return val != 0;
}

static PyNumberMethods SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    #ifndef IS_PY3K
    /* nb_divide */             0,
    #endif
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature__nonzero,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature___or__,
    #ifndef IS_PY3K
    /* nb_coerce */             0,
    #endif
    /*nb_int*/                  SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature_long,
    #ifdef IS_PY3K
    /*nb_reserved*/             0,
    /*nb_float*/                0,
    #else
    /*nb_long*/                 SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature_long,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    #endif
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    #ifndef IS_PY3K
    /*nb_inplace_divide*/       0,
    #endif
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeatures_Type = {
    PyVarObject_HEAD_INIT(&PyType_Type, 0)
    /*tp_name*/             "ToolButtonFeatures",
    /*tp_basicsize*/        sizeof(PySideQFlagsObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeature_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      &PySideQFlagsRichCompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              &PySideQFlagsNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QStyleOptionToolButton(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionToolButton_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionToolButton", "QStyleOptionToolButton*",
        &Sbk_QStyleOptionToolButton_Type, &Shiboken::callCppDestructor< ::QStyleOptionToolButton >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionToolButton_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionToolButton.StyleOptionVersion",
        "QStyleOptionToolButton::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionToolButton_Type, "Version", (long) QStyleOptionToolButton::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'ToolButtonFeature'.
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE__IDX] = &SbkPySide_QtGui_QStyleOptionToolButton_ToolButtonFeatures_Type;
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionToolButton_Type,
        "ToolButtonFeature",
        "PySide.QtGui.QStyleOptionToolButton.ToolButtonFeature",
        "QStyleOptionToolButton::ToolButtonFeature",
        SbkPySide_QtGuiTypes[SBK_QFLAGS_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE__IDX]);
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE_IDX],
        &Sbk_QStyleOptionToolButton_Type, "None", (long) QStyleOptionToolButton::None))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE_IDX],
        &Sbk_QStyleOptionToolButton_Type, "Arrow", (long) QStyleOptionToolButton::Arrow))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE_IDX],
        &Sbk_QStyleOptionToolButton_Type, "Menu", (long) QStyleOptionToolButton::Menu))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE_IDX],
        &Sbk_QStyleOptionToolButton_Type, "MenuButtonPopup", (long) QStyleOptionToolButton::MenuButtonPopup))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE_IDX],
        &Sbk_QStyleOptionToolButton_Type, "PopupDelay", (long) QStyleOptionToolButton::PopupDelay))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_TOOLBUTTONFEATURE_IDX],
        &Sbk_QStyleOptionToolButton_Type, "HasMenu", (long) QStyleOptionToolButton::HasMenu))
        return ;
    // End of 'ToolButtonFeature' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionToolButton_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionToolButton.StyleOptionType",
        "QStyleOptionToolButton::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBUTTON_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionToolButton_Type, "Type", (long) QStyleOptionToolButton::Type))
        return ;
    // End of 'StyleOptionType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionToolButton >("QStyleOptionToolButton*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionToolButton >(typeid(::QStyleOptionToolButton).name());
    qRegisterMetaType< ::QStyleOptionToolButton::StyleOptionVersion >("QStyleOptionToolButton::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionToolButton::ToolButtonFeature >("QStyleOptionToolButton::ToolButtonFeature");
    qRegisterMetaType< ::QStyleOptionToolButton::ToolButtonFeatures >("QStyleOptionToolButton::ToolButtonFeatures");
    qRegisterMetaType< ::QStyleOptionToolButton::StyleOptionType >("QStyleOptionToolButton::StyleOptionType");
}
