/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionviewitem_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionViewItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionViewItem >()))
        return -1;

    ::QStyleOptionViewItem* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionViewItem", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionViewItem()
    // 1: QStyleOptionViewItem(QStyleOptionViewItem)
    // 2: QStyleOptionViewItem(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionViewItem()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionViewItem(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionViewItem >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionViewItem(QStyleOptionViewItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionViewItem_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionViewItem()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionViewItem()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionViewItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionViewItem(QStyleOptionViewItem)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionViewItem & cppArg0 = Shiboken::Converter< ::QStyleOptionViewItem >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionViewItem(QStyleOptionViewItem)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionViewItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionViewItem(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionViewItem(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionViewItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionViewItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionViewItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionViewItem_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionViewItem", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionViewItem", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionViewItem_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionViewItem_get_showDecorationSelected(PyObject* self, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< bool >::toPython(cppSelf->showDecorationSelected);
    return value;
}
static int Sbk_QStyleOptionViewItem_set_showDecorationSelected(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'showDecorationSelected' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'showDecorationSelected', 'bool' or convertible type expected");
        return -1;
    }

    cppSelf->showDecorationSelected = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_decorationPosition(PyObject* self, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QStyleOptionViewItem::Position >::toPython(cppSelf->decorationPosition);
    return value;
}
static int Sbk_QStyleOptionViewItem_set_decorationPosition(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'decorationPosition' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionViewItem::Position >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'decorationPosition', 'Position' or convertible type expected");
        return -1;
    }

    cppSelf->decorationPosition = Shiboken::Converter< ::QStyleOptionViewItem::Position >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_decorationAlignment(PyObject* self, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppSelf->decorationAlignment);
    return value;
}
static int Sbk_QStyleOptionViewItem_set_decorationAlignment(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'decorationAlignment' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'decorationAlignment', 'Alignment' or convertible type expected");
        return -1;
    }

    cppSelf->decorationAlignment = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_displayAlignment(PyObject* self, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppSelf->displayAlignment);
    return value;
}
static int Sbk_QStyleOptionViewItem_set_displayAlignment(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'displayAlignment' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'displayAlignment', 'Alignment' or convertible type expected");
        return -1;
    }

    cppSelf->displayAlignment = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_textElideMode(PyObject* self, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::Qt::TextElideMode >::toPython(cppSelf->textElideMode);
    return value;
}
static int Sbk_QStyleOptionViewItem_set_textElideMode(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'textElideMode' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::TextElideMode >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'textElideMode', 'TextElideMode' or convertible type expected");
        return -1;
    }

    cppSelf->textElideMode = Shiboken::Converter< ::Qt::TextElideMode >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_decorationSize(PyObject* self, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QSIZE_IDX], &(cppSelf->decorationSize), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionViewItem_set_decorationSize(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'decorationSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'decorationSize', 'QSize' or convertible type expected");
        return -1;
    }

    cppSelf->decorationSize = Shiboken::Converter< ::QSize >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_font(PyObject* self, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QFONT_IDX], &(cppSelf->font), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionViewItem_set_font(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionViewItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionViewItem* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'font' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFont >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'font', 'QFont' or convertible type expected");
        return -1;
    }

    cppSelf->font = Shiboken::Converter< ::QFont >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionViewItem
static PyGetSetDef Sbk_QStyleOptionViewItem_getsetlist[] = {
    {const_cast<char*>("showDecorationSelected"), Sbk_QStyleOptionViewItem_get_showDecorationSelected, Sbk_QStyleOptionViewItem_set_showDecorationSelected},
    {const_cast<char*>("decorationPosition"), Sbk_QStyleOptionViewItem_get_decorationPosition, Sbk_QStyleOptionViewItem_set_decorationPosition},
    {const_cast<char*>("decorationAlignment"), Sbk_QStyleOptionViewItem_get_decorationAlignment, Sbk_QStyleOptionViewItem_set_decorationAlignment},
    {const_cast<char*>("displayAlignment"), Sbk_QStyleOptionViewItem_get_displayAlignment, Sbk_QStyleOptionViewItem_set_displayAlignment},
    {const_cast<char*>("textElideMode"), Sbk_QStyleOptionViewItem_get_textElideMode, Sbk_QStyleOptionViewItem_set_textElideMode},
    {const_cast<char*>("decorationSize"), Sbk_QStyleOptionViewItem_get_decorationSize, Sbk_QStyleOptionViewItem_set_decorationSize},
    {const_cast<char*>("font"), Sbk_QStyleOptionViewItem_get_font, Sbk_QStyleOptionViewItem_set_font},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionViewItem_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionViewItem_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionViewItem_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionViewItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionViewItem_traverse,
    /*tp_clear*/            Sbk_QStyleOptionViewItem_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionViewItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionViewItem_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionViewItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionViewItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionViewItem_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionViewItem", "QStyleOptionViewItem*",
        &Sbk_QStyleOptionViewItem_Type, &Shiboken::callCppDestructor< ::QStyleOptionViewItem >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionViewItem_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionViewItem.StyleOptionVersion",
        "QStyleOptionViewItem::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionViewItem_Type, "Version", (long) QStyleOptionViewItem::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionViewItem_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionViewItem.StyleOptionType",
        "QStyleOptionViewItem::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionViewItem_Type, "Type", (long) QStyleOptionViewItem::Type))
        return ;
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'Position'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_POSITION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionViewItem_Type,
        "Position",
        "PySide.QtGui.QStyleOptionViewItem.Position",
        "QStyleOptionViewItem::Position");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_POSITION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_POSITION_IDX],
        &Sbk_QStyleOptionViewItem_Type, "Left", (long) QStyleOptionViewItem::Left))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_POSITION_IDX],
        &Sbk_QStyleOptionViewItem_Type, "Right", (long) QStyleOptionViewItem::Right))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_POSITION_IDX],
        &Sbk_QStyleOptionViewItem_Type, "Top", (long) QStyleOptionViewItem::Top))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_POSITION_IDX],
        &Sbk_QStyleOptionViewItem_Type, "Bottom", (long) QStyleOptionViewItem::Bottom))
        return ;
    // End of 'Position' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionViewItem >("QStyleOptionViewItem*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionViewItem >(typeid(::QStyleOptionViewItem).name());
    qRegisterMetaType< ::QStyleOptionViewItem::StyleOptionVersion >("QStyleOptionViewItem::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionViewItem::StyleOptionType >("QStyleOptionViewItem::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionViewItem::Position >("QStyleOptionViewItem::Position");
}
