/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstylepainter_wrapper.h"

// Extra includes
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qimage.h>
#include <qline.h>
#include <qmatrix.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainterpath.h>
#include <qpalette.h>
#include <qpen.h>
#include <qpicture.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qstylepainter.h>
#include <qtextoption.h>
#include <qtransform.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStylePainter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStylePainter >()))
        return -1;

    ::QStylePainter* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStylePainter", 0, 2, &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QStylePainter()
    // 1: QStylePainter(QPaintDevice*,QWidget*)
    // 2: QStylePainter(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QStylePainter()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[0])) {
        overloadId = 2; // QStylePainter(QWidget*)
    } else if (numArgs == 2
        && Shiboken::Converter< ::QPaintDevice * >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[1])) {
        overloadId = 1; // QStylePainter(QPaintDevice*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStylePainter_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStylePainter()
        {

            if(!PyErr_Occurred()) {
                // QStylePainter()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStylePainter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStylePainter(QPaintDevice*,QWidget*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPaintDevice * cppArg0 = Shiboken::Converter< ::QPaintDevice * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget * cppArg1 = Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QStylePainter(QPaintDevice*,QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStylePainter(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStylePainter(QWidget*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget * cppArg0 = Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStylePainter(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStylePainter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStylePainter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStylePainter_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStylePainter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPaintDevice, PySide.QtGui.QWidget", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter", overloads);
        return -1;
}

static PyObject* Sbk_QStylePainterFunc_begin(PyObject* self, PyObject* args)
{
    ::QStylePainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStylePainter* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "begin", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: begin(QPaintDevice*,QWidget*)
    // 1: begin(QWidget*)
    if (numArgs == 1
        && Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[0])) {
        overloadId = 1; // begin(QWidget*)
    } else if (numArgs == 2
        && Shiboken::Converter< ::QPaintDevice * >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[1])) {
        overloadId = 0; // begin(QPaintDevice*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStylePainterFunc_begin_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // begin(QPaintDevice*,QWidget*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPaintDevice * cppArg0 = Shiboken::Converter< ::QPaintDevice * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QWidget * cppArg1 = Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // begin(QPaintDevice*,QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->begin(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
        case 1: // begin(QWidget*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QWidget * cppArg0 = Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // begin(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->begin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStylePainterFunc_begin_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice, PySide.QtGui.QWidget", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.begin", overloads);
        return 0;
}

static PyObject* Sbk_QStylePainterFunc_drawComplexControl(PyObject* self, PyObject* args)
{
    ::QStylePainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStylePainter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawComplexControl", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
    if (numArgs == 2
        && Shiboken::Converter< ::QStyle::ComplexControl >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QStyleOptionComplex >::isConvertible(pyArgs[1])) {
        overloadId = 0; // drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStylePainterFunc_drawComplexControl_TypeError;

    // Call function/method
    {
        QStyle::ComplexControl cppArg0 = Shiboken::Converter< ::QStyle::ComplexControl >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        const QStyleOptionComplex & cppArg1 = Shiboken::Converter< ::QStyleOptionComplex >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->drawComplexControl(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStylePainterFunc_drawComplexControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ComplexControl, PySide.QtGui.QStyleOptionComplex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawComplexControl", overloads);
        return 0;
}

static PyObject* Sbk_QStylePainterFunc_drawControl(PyObject* self, PyObject* args)
{
    ::QStylePainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStylePainter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawControl", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawControl(QStyle::ControlElement,QStyleOption)
    if (numArgs == 2
        && Shiboken::Converter< ::QStyle::ControlElement >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QStyleOption >::isConvertible(pyArgs[1])) {
        overloadId = 0; // drawControl(QStyle::ControlElement,QStyleOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStylePainterFunc_drawControl_TypeError;

    // Call function/method
    {
        QStyle::ControlElement cppArg0 = Shiboken::Converter< ::QStyle::ControlElement >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        const QStyleOption & cppArg1 = Shiboken::Converter< ::QStyleOption >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // drawControl(QStyle::ControlElement,QStyleOption)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->drawControl(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStylePainterFunc_drawControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ControlElement, PySide.QtGui.QStyleOption", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawControl", overloads);
        return 0;
}

static PyObject* Sbk_QStylePainterFunc_drawItemPixmap(PyObject* self, PyObject* args)
{
    ::QStylePainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStylePainter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawItemPixmap", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawItemPixmap(QRect,int,QPixmap)
    if (numArgs == 3
        && Shiboken::Converter< ::QRect >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && Shiboken::Converter< ::QPixmap >::isConvertible(pyArgs[2])) {
        overloadId = 0; // drawItemPixmap(QRect,int,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStylePainterFunc_drawItemPixmap_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QRect cppArg0 = Shiboken::Converter< ::QRect >::toCpp(pyArgs[0]);
        int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return 0;
        ::QPixmap cppArg2 = Shiboken::Converter< ::QPixmap >::toCpp(pyArgs[2]);

        if(!PyErr_Occurred()) {
            // drawItemPixmap(QRect,int,QPixmap)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->drawItemPixmap(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStylePainterFunc_drawItemPixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawItemPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QStylePainterFunc_drawItemText(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QStylePainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStylePainter* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStylePainter.drawItemText(): too many arguments");
        return 0;
    } else if (numArgs < 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStylePainter.drawItemText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:drawItemText", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
    if (numArgs >= 5
        && Shiboken::Converter< ::QRect >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && Shiboken::Converter< ::QPalette >::isConvertible(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[4])) {
        if (numArgs == 5) {
            overloadId = 0; // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
        } else if (Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyArgs[5])) {
            overloadId = 0; // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStylePainterFunc_drawItemText_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "textRole");
            if (value) {
                if (pyArgs[5])
                    errorArgName = "textRole";
                else if (Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(value))
                    pyArgs[5] = value;
                else
                    goto Sbk_QStylePainterFunc_drawItemText_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStylePainter.drawItemText(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QRect cppArg0 = Shiboken::Converter< ::QRect >::toCpp(pyArgs[0]);
        int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return 0;
        ::QPalette cppArg2 = Shiboken::Converter< ::QPalette >::toCpp(pyArgs[2]);
        bool cppArg3 = Shiboken::Converter< bool >::toCpp(pyArgs[3]);
        ::QString cppArg4 = Shiboken::Converter< ::QString >::toCpp(pyArgs[4]);
        QPalette::ColorRole cppArg5 = pyArgs[5] ? Shiboken::Converter< ::QPalette::ColorRole >::toCpp(pyArgs[5]) : QPalette::NoRole;

        if(!PyErr_Occurred()) {
            // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->drawItemText(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStylePainterFunc_drawItemText_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, PySide.QtGui.QPalette, bool, unicode, PySide.QtGui.QPalette.ColorRole = QPalette.NoRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawItemText", overloads);
        return 0;
}

static PyObject* Sbk_QStylePainterFunc_drawPrimitive(PyObject* self, PyObject* args)
{
    ::QStylePainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStylePainter* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawPrimitive", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
    if (numArgs == 2
        && Shiboken::Converter< ::QStyle::PrimitiveElement >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QStyleOption >::isConvertible(pyArgs[1])) {
        overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStylePainterFunc_drawPrimitive_TypeError;

    // Call function/method
    {
        QStyle::PrimitiveElement cppArg0 = Shiboken::Converter< ::QStyle::PrimitiveElement >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        const QStyleOption & cppArg1 = Shiboken::Converter< ::QStyleOption >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->drawPrimitive(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStylePainterFunc_drawPrimitive_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.PrimitiveElement, PySide.QtGui.QStyleOption", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawPrimitive", overloads);
        return 0;
}

static PyObject* Sbk_QStylePainterFunc_style(PyObject* self)
{
    ::QStylePainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStylePainter* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // style()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStyle * cppResult = const_cast<const ::QStylePainter*>(cppSelf)->style();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStyle * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QStylePainter_methods[] = {
    {"begin", (PyCFunction)Sbk_QStylePainterFunc_begin, METH_VARARGS},
    {"drawComplexControl", (PyCFunction)Sbk_QStylePainterFunc_drawComplexControl, METH_VARARGS},
    {"drawControl", (PyCFunction)Sbk_QStylePainterFunc_drawControl, METH_VARARGS},
    {"drawItemPixmap", (PyCFunction)Sbk_QStylePainterFunc_drawItemPixmap, METH_VARARGS},
    {"drawItemText", (PyCFunction)Sbk_QStylePainterFunc_drawItemText, METH_VARARGS|METH_KEYWORDS},
    {"drawPrimitive", (PyCFunction)Sbk_QStylePainterFunc_drawPrimitive, METH_VARARGS},
    {"style", (PyCFunction)Sbk_QStylePainterFunc_style, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QStylePainter_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStylePainter_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStylePainter_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStylePainter",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStylePainter_traverse,
    /*tp_clear*/            Sbk_QStylePainter_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStylePainter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStylePainter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStylePainter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEPAINTER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStylePainter_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStylePainter", "QStylePainter*",
        &Sbk_QStylePainter_Type, &Shiboken::callCppDestructor< ::QStylePainter >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QPAINTER_IDX])) {
        return;
    }


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStylePainter >("QStylePainter*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStylePainter >(typeid(::QStylePainter).name());
}
