/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextframe_iterator_wrapper.h"

// Extra includes
#include <QTextFrame>
#include <qtextobject.h>



// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QTextFrame_iteratorFunc___iter__(PyObject* self)
{
    ::QTextFrame::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __iter__()
            // Begin code injection

            // TEMPLATE - __iter__ - START
            Py_INCREF(self);
            pyResult = self;
            // TEMPLATE - __iter__ - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrame_iteratorFunc___next__(PyObject* self)
{
    ::QTextFrame::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __next__()
            // Begin code injection

            // TEMPLATE - __next__ - START
            if (!cppSelf->atEnd()) {
              pyResult = Shiboken::Converter< ::QTextFrame::iterator >::toPython(*cppSelf);
              ++(*cppSelf);
            }
            // TEMPLATE - __next__ - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrame_iteratorFunc_atEnd(PyObject* self)
{
    ::QTextFrame::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // atEnd()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextFrame::iterator*>(cppSelf)->atEnd();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrame_iteratorFunc_currentBlock(PyObject* self)
{
    ::QTextFrame::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // currentBlock()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextBlock cppResult = const_cast<const ::QTextFrame::iterator*>(cppSelf)->currentBlock();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrame_iteratorFunc_currentFrame(PyObject* self)
{
    ::QTextFrame::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // currentFrame()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextFrame * cppResult = const_cast<const ::QTextFrame::iterator*>(cppSelf)->currentFrame();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextFrame * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static int
Sbk_QTextFrame_iterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextFrame::iterator >()))
        return -1;

    ::QTextFrame::iterator* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "iterator", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: iterator()
    // 1: iterator(QTextFrame::iterator)
    if (numArgs == 0) {
        overloadId = 0; // iterator()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QTextFrame::iterator >::isConvertible(pyArgs[0])) {
        overloadId = 1; // iterator(QTextFrame::iterator)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrame_iterator_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // iterator()
        {

            if(!PyErr_Occurred()) {
                // iterator()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTextFrame::iterator();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // iterator(QTextFrame::iterator)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFrame::iterator cppArg0 = Shiboken::Converter< ::QTextFrame::iterator >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // iterator(QTextFrame::iterator)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTextFrame::iterator(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextFrame::iterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextFrame_iterator_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextFrame_iterator_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextFrame::iterator", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.iterator", overloads);
        return -1;
}

static PyObject* Sbk_QTextFrame_iteratorFunc_parentFrame(PyObject* self)
{
    ::QTextFrame::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // parentFrame()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextFrame * cppResult = const_cast<const ::QTextFrame::iterator*>(cppSelf)->parentFrame();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextFrame * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrame_iterator___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QTextFrame::iterator& cppSelf = *(Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QTextFrame::iterator >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QTextFrame_iterator_methods[] = {
    {"atEnd", (PyCFunction)Sbk_QTextFrame_iteratorFunc_atEnd, METH_NOARGS},
    {"currentBlock", (PyCFunction)Sbk_QTextFrame_iteratorFunc_currentBlock, METH_NOARGS},
    {"currentFrame", (PyCFunction)Sbk_QTextFrame_iteratorFunc_currentFrame, METH_NOARGS},
    {"parentFrame", (PyCFunction)Sbk_QTextFrame_iteratorFunc_parentFrame, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextFrame_iterator___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QTextFrame_iteratorFunc___iadd__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTextFrame::iterator >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTextFrame::iterator >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTextFrame::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__riadd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__riadd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator++(int)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 0; // operator++(int)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrame_iteratorFunc___iadd___TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator++(int)

            for(int i=0; i < cppArg0; i++, (*cppSelf)++);
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextFrame::iterator cppResult = (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextFrame::iterator >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFrame_iteratorFunc___iadd___TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.iterator.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrame_iteratorFunc___isub__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTextFrame::iterator >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTextFrame::iterator >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTextFrame::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__risub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__risub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator--(int)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 0; // operator--(int)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrame_iteratorFunc___isub___TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator--(int)

            for(int i=0; i < cppArg0; i++, (*cppSelf)--);
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextFrame::iterator cppResult = (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextFrame::iterator >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFrame_iteratorFunc___isub___TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.iterator.__isub__", overloads);
        return 0;
}

// Rich comparison
static PyObject* Sbk_QTextFrame_iterator_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QTextFrame::iterator& cppSelf = *(Shiboken::Converter< ::QTextFrame::iterator* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QTextFrame::iterator >::isConvertible(pyArg)) {
                // operator!=(const QTextFrame::iterator & o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QTextFrame::iterator cppArg0 = Shiboken::Converter< ::QTextFrame::iterator >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QTextFrame::iterator >::isConvertible(pyArg)) {
                // operator==(const QTextFrame::iterator & o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QTextFrame::iterator cppArg0 = Shiboken::Converter< ::QTextFrame::iterator >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QTextFrame_iterator_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QTextFrame_iterator_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QTextFrame_iterator_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QTextFrame_iterator_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextFrame_iterator_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QTextFrame.iterator",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QTextFrame_iterator_traverse,
    /*tp_clear*/            Sbk_QTextFrame_iterator_clear,
    /*tp_richcompare*/      Sbk_QTextFrame_iterator_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             Sbk_QTextFrame_iteratorFunc___iter__,
    /*tp_iternext*/         Sbk_QTextFrame_iteratorFunc___next__,
    /*tp_methods*/          Sbk_QTextFrame_iterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextFrame_iterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextFrame_iterator(PyObject* enclosingClass)
{
    // type has number operators
    memset(&Sbk_QTextFrame_iterator_Type.super.as_number, 0, sizeof(PyNumberMethods));
    Sbk_QTextFrame_iterator_Type.super.as_number.nb_inplace_subtract = Sbk_QTextFrame_iteratorFunc___isub__;
    Sbk_QTextFrame_iterator_Type.super.as_number.nb_inplace_add = Sbk_QTextFrame_iteratorFunc___iadd__;
    Sbk_QTextFrame_iterator_Type.super.ht_type.tp_as_number = &Sbk_QTextFrame_iterator_Type.super.as_number;

    SbkPySide_QtGuiTypes[SBK_QTEXTFRAME_ITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextFrame_iterator_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(enclosingClass, "iterator", "QTextFrame::iterator",
        &Sbk_QTextFrame_iterator_Type, &Shiboken::callCppDestructor< ::QTextFrame::iterator >, 0, 0, true)) {
        return;
    }


    Shiboken::TypeResolver::createValueTypeResolver< ::QTextFrame::iterator >("QTextFrame::iterator");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QTextFrame::iterator >("QTextFrame::iterator*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QTextFrame::iterator >(typeid(::QTextFrame::iterator).name());
    qRegisterMetaType< ::QTextFrame::iterator >("iterator");
    qRegisterMetaType< ::QTextFrame::iterator >("QTextFrame::iterator");
}
