/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qundogroup_wrapper.h"

// Extra includes
#include <QList>
#include <qaction.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qundogroup.h>
#include <qundostack.h>


// Native ---------------------------------------------------------

QUndoGroupWrapper::QUndoGroupWrapper(QObject * parent) : QUndoGroup(parent) {
    // ... middle
}

void QUndoGroupWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QUndoGroupWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUndoGroupWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QUndoGroupWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QUndoGroupWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QUndoGroup.event", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QUndoGroupWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QUndoGroup.eventFilter", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QUndoGroupWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject* QUndoGroupWrapper::metaObject() const
{
    #if QT_VERSION >= 0x040700
    if (QObject::d_ptr->metaObject) return QObject::d_ptr->metaObject;
    #endif
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return PySide::SignalManager::retriveMetaObject(reinterpret_cast<PyObject*>(pySelf));
}

int QUndoGroupWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QUndoGroup::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void* QUndoGroupWrapper::qt_metacast(const char* _clname)
{
        if (!_clname) return 0;
        SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void*>(const_cast< QUndoGroupWrapper* >(this));
        return QUndoGroup::qt_metacast(_clname);
}

QUndoGroupWrapper::~QUndoGroupWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUndoGroup_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QUndoGroup >()))
        return -1;

    ::QUndoGroupWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QUndoGroup", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QUndoGroup(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QUndoGroup(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QUndoGroup(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoGroup_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QUndoGroup_Init_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoGroup(): got multiple values for keyword argument '%s'", errorArgName);
                return -1;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]) : 0;

        if(!PyErr_Occurred()) {
            // QUndoGroup(QObject*)
            void* addr = PySide::nextQObjectMemoryAddr();
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = addr ? new (addr) ::QUndoGroupWrapper(cppArg0) : new ::QUndoGroupWrapper(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QUndoGroup >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QUndoGroup_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QUndoGroup_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QUndoGroup", overloads);
        return -1;
}

static PyObject* Sbk_QUndoGroupFunc_activeStack(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // activeStack()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUndoStack * cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->activeStack();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QUndoStack * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoGroupFunc_addStack(PyObject* self, PyObject* pyArg)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addStack(QUndoStack*)
    if (Shiboken::Converter< ::QUndoStack * >::isConvertible(pyArg)) {
        overloadId = 0; // addStack(QUndoStack*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoGroupFunc_addStack_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QUndoStack * cppArg0 = Shiboken::Converter< ::QUndoStack * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // addStack(QUndoStack*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->addStack(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUndoGroupFunc_addStack_TypeError:
        const char* overloads[] = {"PySide.QtGui.QUndoStack", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QUndoGroup.addStack", overloads);
        return 0;
}

static PyObject* Sbk_QUndoGroupFunc_canRedo(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // canRedo()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->canRedo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoGroupFunc_canUndo(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // canUndo()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->canUndo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoGroupFunc_createRedoAction(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoGroup.createRedoAction(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoGroup.createRedoAction(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createRedoAction", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createRedoAction(QObject*,QString)const
    if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createRedoAction(QObject*,QString)const
        } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 0; // createRedoAction(QObject*,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoGroupFunc_createRedoAction_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "prefix");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "prefix";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QUndoGroupFunc_createRedoAction_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoGroup.createRedoAction(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QObject * cppArg0 = Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]);
        ::QString cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[1]) : QString();

        if(!PyErr_Occurred()) {
            // createRedoAction(QObject*,QString)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QAction * cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->createRedoAction(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QAction * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUndoGroupFunc_createRedoAction_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QUndoGroup.createRedoAction", overloads);
        return 0;
}

static PyObject* Sbk_QUndoGroupFunc_createUndoAction(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoGroup.createUndoAction(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoGroup.createUndoAction(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createUndoAction", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createUndoAction(QObject*,QString)const
    if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createUndoAction(QObject*,QString)const
        } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 0; // createUndoAction(QObject*,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoGroupFunc_createUndoAction_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "prefix");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "prefix";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QUndoGroupFunc_createUndoAction_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoGroup.createUndoAction(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QObject * cppArg0 = Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]);
        ::QString cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[1]) : QString();

        if(!PyErr_Occurred()) {
            // createUndoAction(QObject*,QString)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QAction * cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->createUndoAction(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QAction * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUndoGroupFunc_createUndoAction_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QUndoGroup.createUndoAction", overloads);
        return 0;
}

static PyObject* Sbk_QUndoGroupFunc_isClean(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isClean()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->isClean();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoGroupFunc_redo(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // redo()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->redo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUndoGroupFunc_redoText(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // redoText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->redoText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoGroupFunc_removeStack(PyObject* self, PyObject* pyArg)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeStack(QUndoStack*)
    if (Shiboken::Converter< ::QUndoStack * >::isConvertible(pyArg)) {
        overloadId = 0; // removeStack(QUndoStack*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoGroupFunc_removeStack_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QUndoStack * cppArg0 = Shiboken::Converter< ::QUndoStack * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // removeStack(QUndoStack*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->removeStack(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUndoGroupFunc_removeStack_TypeError:
        const char* overloads[] = {"PySide.QtGui.QUndoStack", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QUndoGroup.removeStack", overloads);
        return 0;
}

static PyObject* Sbk_QUndoGroupFunc_setActiveStack(PyObject* self, PyObject* pyArg)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActiveStack(QUndoStack*)
    if (Shiboken::Converter< ::QUndoStack * >::isConvertible(pyArg)) {
        overloadId = 0; // setActiveStack(QUndoStack*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoGroupFunc_setActiveStack_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QUndoStack * cppArg0 = Shiboken::Converter< ::QUndoStack * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setActiveStack(QUndoStack*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setActiveStack(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUndoGroupFunc_setActiveStack_TypeError:
        const char* overloads[] = {"PySide.QtGui.QUndoStack", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QUndoGroup.setActiveStack", overloads);
        return 0;
}

static PyObject* Sbk_QUndoGroupFunc_stacks(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // stacks()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QUndoStack * > cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->stacks();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QUndoStack * > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoGroupFunc_undo(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // undo()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->undo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUndoGroupFunc_undoText(PyObject* self)
{
    ::QUndoGroup* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUndoGroup* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // undoText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QUndoGroup*>(cppSelf)->undoText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QUndoGroup_methods[] = {
    {"activeStack", (PyCFunction)Sbk_QUndoGroupFunc_activeStack, METH_NOARGS},
    {"addStack", (PyCFunction)Sbk_QUndoGroupFunc_addStack, METH_O},
    {"canRedo", (PyCFunction)Sbk_QUndoGroupFunc_canRedo, METH_NOARGS},
    {"canUndo", (PyCFunction)Sbk_QUndoGroupFunc_canUndo, METH_NOARGS},
    {"createRedoAction", (PyCFunction)Sbk_QUndoGroupFunc_createRedoAction, METH_VARARGS|METH_KEYWORDS},
    {"createUndoAction", (PyCFunction)Sbk_QUndoGroupFunc_createUndoAction, METH_VARARGS|METH_KEYWORDS},
    {"isClean", (PyCFunction)Sbk_QUndoGroupFunc_isClean, METH_NOARGS},
    {"redo", (PyCFunction)Sbk_QUndoGroupFunc_redo, METH_NOARGS},
    {"redoText", (PyCFunction)Sbk_QUndoGroupFunc_redoText, METH_NOARGS},
    {"removeStack", (PyCFunction)Sbk_QUndoGroupFunc_removeStack, METH_O},
    {"setActiveStack", (PyCFunction)Sbk_QUndoGroupFunc_setActiveStack, METH_O},
    {"stacks", (PyCFunction)Sbk_QUndoGroupFunc_stacks, METH_NOARGS},
    {"undo", (PyCFunction)Sbk_QUndoGroupFunc_undo, METH_NOARGS},
    {"undoText", (PyCFunction)Sbk_QUndoGroupFunc_undoText, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QUndoGroup_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QUndoGroup_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QUndoGroup_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QUndoGroup",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QUndoGroup_traverse,
    /*tp_clear*/            Sbk_QUndoGroup_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QUndoGroup_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QUndoGroup_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QUndoGroup_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QUndoGroup*>(reinterpret_cast< ::QObject*>(cptr));
    return 0;
}


void init_QUndoGroup(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QUNDOGROUP_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QUndoGroup_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QUndoGroup", "QUndoGroup*",
        &Sbk_QUndoGroup_Type, &Shiboken::callCppDestructor< ::QUndoGroup >, (SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX])) {
        return;
    }

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QUndoGroup_Type, &Sbk_QUndoGroup_typeDiscovery);

    PySide::Signal::registerSignals(&Sbk_QUndoGroup_Type, &::QUndoGroup::staticMetaObject);

    Shiboken::TypeResolver::createObjectTypeResolver< ::QUndoGroup >("QUndoGroup*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QUndoGroup >(typeid(::QUndoGroup).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QUndoGroup >(typeid(::QUndoGroupWrapper).name());
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QUndoGroup_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QUndoGroup_Type, &::QUndoGroup::staticMetaObject, sizeof(::QUndoGroup));
}
