/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qthelp_python.h"

#include "qhelpenginecore_wrapper.h"

// Extra includes
#include <QList>
#include <QMap>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>


// Native ---------------------------------------------------------

QHelpEngineCoreWrapper::QHelpEngineCoreWrapper(const QString & collectionFile, QObject * parent) : QHelpEngineCore(collectionFile, parent) {
    // ... middle
}

void QHelpEngineCoreWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QHelpEngineCoreWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHelpEngineCoreWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QHelpEngineCoreWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QHelpEngineCoreWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QHelpEngineCore.event", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QHelpEngineCoreWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QHelpEngineCore.eventFilter", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QHelpEngineCoreWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject* QHelpEngineCoreWrapper::metaObject() const
{
    #if QT_VERSION >= 0x040700
    if (QObject::d_ptr->metaObject) return QObject::d_ptr->metaObject;
    #endif
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return PySide::SignalManager::retriveMetaObject(reinterpret_cast<PyObject*>(pySelf));
}

int QHelpEngineCoreWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QHelpEngineCore::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void* QHelpEngineCoreWrapper::qt_metacast(const char* _clname)
{
        if (!_clname) return 0;
        SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void*>(const_cast< QHelpEngineCoreWrapper* >(this));
        return QHelpEngineCore::qt_metacast(_clname);
}

QHelpEngineCoreWrapper::~QHelpEngineCoreWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHelpEngineCore_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHelpEngineCore >()))
        return -1;

    ::QHelpEngineCoreWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QHelpEngineCore", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QHelpEngineCore(QString,QObject*)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QHelpEngineCore(QString,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[1])) {
            overloadId = 0; // QHelpEngineCore(QString,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCore_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QHelpEngineCore_Init_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore(): got multiple values for keyword argument '%s'", errorArgName);
                return -1;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject * cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[1]) : 0;

        if(!PyErr_Occurred()) {
            // QHelpEngineCore(QString,QObject*)
            void* addr = PySide::nextQObjectMemoryAddr();
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = addr ? new (addr) ::QHelpEngineCoreWrapper(cppArg0, cppArg1) : new ::QHelpEngineCoreWrapper(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHelpEngineCore >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QHelpEngineCore_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QHelpEngineCore_Init_TypeError:
        const char* overloads[] = {"unicode, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore", overloads);
        return -1;
}

static PyObject* Sbk_QHelpEngineCoreFunc_addCustomFilter(PyObject* self, PyObject* args)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addCustomFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addCustomFilter(QString,QStringList)
    if (numArgs == 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QStringList >::isConvertible(pyArgs[1])) {
        overloadId = 0; // addCustomFilter(QString,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_addCustomFilter_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        ::QStringList cppArg1 = Shiboken::Converter< ::QStringList >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // addCustomFilter(QString,QStringList)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->addCustomFilter(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_addCustomFilter_TypeError:
        const char* overloads[] = {"unicode, QStringList", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.addCustomFilter", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_autoSaveFilter(PyObject* self)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // autoSaveFilter()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->autoSaveFilter();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHelpEngineCoreFunc_collectionFile(PyObject* self)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // collectionFile()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->collectionFile();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHelpEngineCoreFunc_copyCollectionFile(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: copyCollectionFile(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // copyCollectionFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_copyCollectionFile_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // copyCollectionFile(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->copyCollectionFile(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_copyCollectionFile_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.copyCollectionFile", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_currentFilter(PyObject* self)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // currentFilter()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->currentFilter();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHelpEngineCoreFunc_customFilters(PyObject* self)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // customFilters()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->customFilters();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHelpEngineCoreFunc_customValue(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.customValue(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.customValue(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:customValue", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: customValue(QString,QVariant)const
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // customValue(QString,QVariant)const
        } else if (Shiboken::Converter< ::QVariant >::isConvertible(pyArgs[1])) {
            overloadId = 0; // customValue(QString,QVariant)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_customValue_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "defaultValue");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "defaultValue";
                else if (Shiboken::Converter< ::QVariant >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QHelpEngineCoreFunc_customValue_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.customValue(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        ::QVariant cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QVariant >::toCpp(pyArgs[1]) : QVariant();

        if(!PyErr_Occurred()) {
            // customValue(QString,QVariant)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVariant cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->customValue(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVariant >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_customValue_TypeError:
        const char* overloads[] = {"unicode, QVariant = QVariant()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.customValue", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_documentationFileName(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: documentationFileName(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // documentationFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_documentationFileName_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // documentationFileName(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = cppSelf->documentationFileName(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_documentationFileName_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.documentationFileName", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_error(PyObject* self)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // error()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->error();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHelpEngineCoreFunc_fileData(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fileData(QUrl)const
    if (Shiboken::Converter< ::QUrl >::isConvertible(pyArg)) {
        overloadId = 0; // fileData(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_fileData_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QUrl cppArg0 = Shiboken::Converter< ::QUrl >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // fileData(QUrl)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QByteArray cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->fileData(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_fileData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.fileData", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_files(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.files(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.files(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:files", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: files(QString,QStringList,QString)
    if (numArgs >= 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QStringList >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // files(QString,QStringList,QString)
        } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[2])) {
            overloadId = 0; // files(QString,QStringList,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_files_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "extensionFilter");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "extensionFilter";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QHelpEngineCoreFunc_files_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.files(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        ::QStringList cppArg1 = Shiboken::Converter< ::QStringList >::toCpp(pyArgs[1]);
        ::QString cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[2]) : QString();

        if(!PyErr_Occurred()) {
            // files(QString,QStringList,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QUrl > cppResult = cppSelf->files(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QUrl > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_files_TypeError:
        const char* overloads[] = {"unicode, QStringList, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.files", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_filterAttributeSets(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: filterAttributeSets(QString)const
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // filterAttributeSets(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_filterAttributeSets_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // filterAttributeSets(QString)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QStringList > cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->filterAttributeSets(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QStringList > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_filterAttributeSets_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.filterAttributeSets", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_filterAttributes(PyObject* self, PyObject* args)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "filterAttributes", 0, 1, &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: filterAttributes()const
    // 1: filterAttributes(QString)const
    if (numArgs == 0) {
        overloadId = 0; // filterAttributes()const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        overloadId = 1; // filterAttributes(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_filterAttributes_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // filterAttributes()const
        {

            if(!PyErr_Occurred()) {
                // filterAttributes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->filterAttributes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
            break;
        }
        case 1: // filterAttributes(QString)const
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // filterAttributes(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->filterAttributes(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_filterAttributes_TypeError:
        const char* overloads[] = {"", "unicode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.filterAttributes", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_findFile(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findFile(QUrl)const
    if (Shiboken::Converter< ::QUrl >::isConvertible(pyArg)) {
        overloadId = 0; // findFile(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_findFile_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QUrl cppArg0 = Shiboken::Converter< ::QUrl >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // findFile(QUrl)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUrl cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->findFile(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_findFile_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.findFile", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_linksForIdentifier(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: linksForIdentifier(QString)const
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // linksForIdentifier(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_linksForIdentifier_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // linksForIdentifier(QString)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QMap<QString, QUrl > cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->linksForIdentifier(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QMap<QString, QUrl > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_linksForIdentifier_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.linksForIdentifier", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_metaData(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "metaData", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: metaData(QString,QString)
    if (numArgs == 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
        overloadId = 0; // metaData(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_metaData_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // metaData(QString,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVariant cppResult = QHelpEngineCore::metaData(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVariant >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_metaData_TypeError:
        const char* overloads[] = {"unicode, unicode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.metaData", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_namespaceName(PyObject* self, PyObject* pyArg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: namespaceName(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // namespaceName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_namespaceName_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // namespaceName(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = QHelpEngineCore::namespaceName(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_namespaceName_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.namespaceName", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_registerDocumentation(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: registerDocumentation(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // registerDocumentation(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_registerDocumentation_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // registerDocumentation(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->registerDocumentation(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_registerDocumentation_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.registerDocumentation", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_registeredDocumentations(PyObject* self)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // registeredDocumentations()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = const_cast<const ::QHelpEngineCore*>(cppSelf)->registeredDocumentations();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHelpEngineCoreFunc_removeCustomFilter(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeCustomFilter(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // removeCustomFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_removeCustomFilter_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // removeCustomFilter(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->removeCustomFilter(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_removeCustomFilter_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.removeCustomFilter", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_removeCustomValue(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeCustomValue(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // removeCustomValue(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_removeCustomValue_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // removeCustomValue(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->removeCustomValue(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_removeCustomValue_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.removeCustomValue", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_setAutoSaveFilter(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoSaveFilter(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setAutoSaveFilter(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_setAutoSaveFilter_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setAutoSaveFilter(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAutoSaveFilter(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHelpEngineCoreFunc_setAutoSaveFilter_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.setAutoSaveFilter", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_setCollectionFile(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCollectionFile(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setCollectionFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_setCollectionFile_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCollectionFile(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCollectionFile(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHelpEngineCoreFunc_setCollectionFile_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.setCollectionFile", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_setCurrentFilter(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentFilter(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setCurrentFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_setCurrentFilter_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCurrentFilter(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCurrentFilter(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHelpEngineCoreFunc_setCurrentFilter_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.setCurrentFilter", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_setCustomValue(PyObject* self, PyObject* args)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCustomValue", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCustomValue(QString,QVariant)
    if (numArgs == 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QVariant >::isConvertible(pyArgs[1])) {
        overloadId = 0; // setCustomValue(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_setCustomValue_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        ::QVariant cppArg1 = Shiboken::Converter< ::QVariant >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // setCustomValue(QString,QVariant)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->setCustomValue(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_setCustomValue_TypeError:
        const char* overloads[] = {"unicode, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.setCustomValue", overloads);
        return 0;
}

static PyObject* Sbk_QHelpEngineCoreFunc_setupData(PyObject* self)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // setupData()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->setupData();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHelpEngineCoreFunc_unregisterDocumentation(PyObject* self, PyObject* pyArg)
{
    ::QHelpEngineCore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHelpEngineCore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unregisterDocumentation(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // unregisterDocumentation(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpEngineCoreFunc_unregisterDocumentation_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // unregisterDocumentation(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->unregisterDocumentation(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHelpEngineCoreFunc_unregisterDocumentation_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtHelp.QHelpEngineCore.unregisterDocumentation", overloads);
        return 0;
}

static PyMethodDef Sbk_QHelpEngineCore_methods[] = {
    {"addCustomFilter", (PyCFunction)Sbk_QHelpEngineCoreFunc_addCustomFilter, METH_VARARGS},
    {"autoSaveFilter", (PyCFunction)Sbk_QHelpEngineCoreFunc_autoSaveFilter, METH_NOARGS},
    {"collectionFile", (PyCFunction)Sbk_QHelpEngineCoreFunc_collectionFile, METH_NOARGS},
    {"copyCollectionFile", (PyCFunction)Sbk_QHelpEngineCoreFunc_copyCollectionFile, METH_O},
    {"currentFilter", (PyCFunction)Sbk_QHelpEngineCoreFunc_currentFilter, METH_NOARGS},
    {"customFilters", (PyCFunction)Sbk_QHelpEngineCoreFunc_customFilters, METH_NOARGS},
    {"customValue", (PyCFunction)Sbk_QHelpEngineCoreFunc_customValue, METH_VARARGS|METH_KEYWORDS},
    {"documentationFileName", (PyCFunction)Sbk_QHelpEngineCoreFunc_documentationFileName, METH_O},
    {"error", (PyCFunction)Sbk_QHelpEngineCoreFunc_error, METH_NOARGS},
    {"fileData", (PyCFunction)Sbk_QHelpEngineCoreFunc_fileData, METH_O},
    {"files", (PyCFunction)Sbk_QHelpEngineCoreFunc_files, METH_VARARGS|METH_KEYWORDS},
    {"filterAttributeSets", (PyCFunction)Sbk_QHelpEngineCoreFunc_filterAttributeSets, METH_O},
    {"filterAttributes", (PyCFunction)Sbk_QHelpEngineCoreFunc_filterAttributes, METH_VARARGS},
    {"findFile", (PyCFunction)Sbk_QHelpEngineCoreFunc_findFile, METH_O},
    {"linksForIdentifier", (PyCFunction)Sbk_QHelpEngineCoreFunc_linksForIdentifier, METH_O},
    {"metaData", (PyCFunction)Sbk_QHelpEngineCoreFunc_metaData, METH_VARARGS|METH_STATIC},
    {"namespaceName", (PyCFunction)Sbk_QHelpEngineCoreFunc_namespaceName, METH_O|METH_STATIC},
    {"registerDocumentation", (PyCFunction)Sbk_QHelpEngineCoreFunc_registerDocumentation, METH_O},
    {"registeredDocumentations", (PyCFunction)Sbk_QHelpEngineCoreFunc_registeredDocumentations, METH_NOARGS},
    {"removeCustomFilter", (PyCFunction)Sbk_QHelpEngineCoreFunc_removeCustomFilter, METH_O},
    {"removeCustomValue", (PyCFunction)Sbk_QHelpEngineCoreFunc_removeCustomValue, METH_O},
    {"setAutoSaveFilter", (PyCFunction)Sbk_QHelpEngineCoreFunc_setAutoSaveFilter, METH_O},
    {"setCollectionFile", (PyCFunction)Sbk_QHelpEngineCoreFunc_setCollectionFile, METH_O},
    {"setCurrentFilter", (PyCFunction)Sbk_QHelpEngineCoreFunc_setCurrentFilter, METH_O},
    {"setCustomValue", (PyCFunction)Sbk_QHelpEngineCoreFunc_setCustomValue, METH_VARARGS},
    {"setupData", (PyCFunction)Sbk_QHelpEngineCoreFunc_setupData, METH_NOARGS},
    {"unregisterDocumentation", (PyCFunction)Sbk_QHelpEngineCoreFunc_unregisterDocumentation, METH_O},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QHelpEngineCore_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QHelpEngineCore_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QHelpEngineCore_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtHelp.QHelpEngineCore",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QHelpEngineCore_traverse,
    /*tp_clear*/            Sbk_QHelpEngineCore_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QHelpEngineCore_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QHelpEngineCore_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QHelpEngineCore_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QHelpEngineCore*>(reinterpret_cast< ::QObject*>(cptr));
    return 0;
}


void init_QHelpEngineCore(PyObject* module)
{
    SbkPySide_QtHelpTypes[SBK_QHELPENGINECORE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QHelpEngineCore_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QHelpEngineCore", "QHelpEngineCore*",
        &Sbk_QHelpEngineCore_Type, &Shiboken::callCppDestructor< ::QHelpEngineCore >, (SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX])) {
        return;
    }

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QHelpEngineCore_Type, &Sbk_QHelpEngineCore_typeDiscovery);

    PySide::Signal::registerSignals(&Sbk_QHelpEngineCore_Type, &::QHelpEngineCore::staticMetaObject);

    Shiboken::TypeResolver::createObjectTypeResolver< ::QHelpEngineCore >("QHelpEngineCore*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QHelpEngineCore >(typeid(::QHelpEngineCore).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QHelpEngineCore >(typeid(::QHelpEngineCoreWrapper).name());
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QHelpEngineCore_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QHelpEngineCore_Type, &::QHelpEngineCore::staticMetaObject, sizeof(::QHelpEngineCore));
}
