/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <pyside.h>
#include "pyside_qthelp_python.h"



// Extra includes

void cleanTypesAttributes(void) {
    for (int i = 0, imax = SBK_QtHelp_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject*>(SbkPySide_QtHelpTypes[i]);
        if (pyType && PyObject_HasAttrString(pyType, "staticMetaObject"))
            PyObject_SetAttrString(pyType, "staticMetaObject", Py_None);
    }
}
// Global functions ------------------------------------------------------------

static PyMethodDef QtHelp_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QHelpSearchQuery(PyObject* module);
void init_QHelpContentItem(PyObject* module);
void init_QHelpContentWidget(PyObject* module);
void init_QHelpSearchResultWidget(PyObject* module);
void init_QHelpSearchQueryWidget(PyObject* module);
void init_QHelpIndexWidget(PyObject* module);
void init_QHelpContentModel(PyObject* module);
void init_QHelpIndexModel(PyObject* module);
void init_QHelpEngineCore(PyObject* module);
void init_QHelpEngine(PyObject* module);
void init_QHelpSearchEngine(PyObject* module);

// Current module's type array.
PyTypeObject** SbkPySide_QtHelpTypes;
// Required modules' type arrays.
PyTypeObject** SbkPySide_QtGuiTypes;
PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

#ifdef IS_PY3K
static int QtHelp_moduleTraverse(PyObject*, visitproc, void *)
{
    PySide::runCleanupFunctions();
}

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtHelp",
    /* m_doc      */ 0,
    /* m_size     */ -1,
    /* m_methods  */ QtHelp_methods,
    /* m_reload   */ 0,
    /* m_traverse */ QtHelp_moduleTraverse,
    /* m_clear    */ 0,
    /* m_free     */ 0
};

#endif
SBK_MODULE_INIT_FUNCTION_BEGIN(QtHelp)
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtGui"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtGuiTypes = Shiboken::Module::getTypes(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtCore"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject* cppApi[SBK_QtHelp_IDX_COUNT];
    SbkPySide_QtHelpTypes = cppApi;

#ifdef IS_PY3K
    PyObject* module = Shiboken::Module::create("QtHelp", &moduledef);
#else
    PyObject* module = Shiboken::Module::create("QtHelp", QtHelp_methods);
#endif

    // Initialize classes in the type system
    init_QHelpSearchQuery(module);
    init_QHelpContentItem(module);
    init_QHelpContentWidget(module);
    init_QHelpSearchResultWidget(module);
    init_QHelpSearchQueryWidget(module);
    init_QHelpIndexWidget(module);
    init_QHelpContentModel(module);
    init_QHelpIndexModel(module);
    init_QHelpEngineCore(module);
    init_QHelpEngine(module);
    init_QHelpSearchEngine(module);

    // Register primitive types on TypeResolver
    Shiboken::TypeResolver::createValueTypeResolver< QMap<QString,QUrl> >("QMap<QString,QUrl>");

    Shiboken::Module::registerTypes(module, SbkPySide_QtHelpTypes);

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtHelp");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);
SBK_MODULE_INIT_FUNCTION_END
