/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkproxyfactory_wrapper.h"

// Extra includes
#include <QList>
#include <qnetworkproxy.h>


// Native ---------------------------------------------------------

QNetworkProxyFactoryWrapper::QNetworkProxyFactoryWrapper() : QNetworkProxyFactory() {
    // ... middle
}

QList<QNetworkProxy > QNetworkProxyFactoryWrapper::queryProxy(const QNetworkProxyQuery & query)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QList<QNetworkProxy >();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "queryProxy"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QNetworkProxyFactory.queryProxy()' not implemented.");
        return ::QList<QNetworkProxy >();
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QNetworkProxyQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QList<QNetworkProxy >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QNetworkProxy > >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QNetworkProxyFactory.queryProxy", "list", pyResult->ob_type->tp_name);
        return ::QList<QNetworkProxy >();
    }
    ::QList<QNetworkProxy > cppResult = Shiboken::Converter< ::QList<QNetworkProxy > >::toCpp(pyResult);
    return cppResult;
}

QNetworkProxyFactoryWrapper::~QNetworkProxyFactoryWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkProxyFactory_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXYFACTORY_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QNetworkProxyFactory' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }

    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkProxyFactory >()))
        return -1;

    ::QNetworkProxyFactoryWrapper* cptr = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // QNetworkProxyFactory()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = new ::QNetworkProxyFactoryWrapper();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkProxyFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QNetworkProxyFactoryFunc_proxyForQuery(PyObject* self, PyObject* pyArg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: proxyForQuery(QNetworkProxyQuery)
    if (Shiboken::Converter< ::QNetworkProxyQuery >::isConvertible(pyArg)) {
        overloadId = 0; // proxyForQuery(QNetworkProxyQuery)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFactoryFunc_proxyForQuery_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QNetworkProxyQuery cppArg0 = Shiboken::Converter< ::QNetworkProxyQuery >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // proxyForQuery(QNetworkProxyQuery)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QNetworkProxy > cppResult = QNetworkProxyFactory::proxyForQuery(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QNetworkProxy > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkProxyFactoryFunc_proxyForQuery_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxyQuery", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QNetworkProxyFactory.proxyForQuery", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFactoryFunc_queryProxy(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QNetworkProxyFactory* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QNetworkProxyFactory* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxyFactory.queryProxy(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:queryProxy", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: queryProxy(QNetworkProxyQuery)
    if (numArgs == 0) {
        overloadId = 0; // queryProxy(QNetworkProxyQuery)
    } else if (Shiboken::Converter< ::QNetworkProxyQuery >::isConvertible(pyArgs[0])) {
        overloadId = 0; // queryProxy(QNetworkProxyQuery)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFactoryFunc_queryProxy_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "query");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "query";
                else if (Shiboken::Converter< ::QNetworkProxyQuery >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QNetworkProxyFactoryFunc_queryProxy_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxyFactory.queryProxy(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        QNetworkProxyQuery cppArg0_tmp = QNetworkProxyQuery();
        ::QNetworkProxyQuery cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QNetworkProxyQuery >::toCpp(pyArgs[0]) : cppArg0_tmp;

        if(!PyErr_Occurred()) {
            // queryProxy(QNetworkProxyQuery)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QNetworkProxyFactory.queryProxy()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QNetworkProxy > cppResult = cppSelf->queryProxy(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QNetworkProxy > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkProxyFactoryFunc_queryProxy_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxyQuery = QNetworkProxyQuery()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkProxyFactory.queryProxy", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFactoryFunc_setApplicationProxyFactory(PyObject* self, PyObject* pyArg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setApplicationProxyFactory(QNetworkProxyFactory*)
    if (Shiboken::Converter< ::QNetworkProxyFactory * >::isConvertible(pyArg)) {
        overloadId = 0; // setApplicationProxyFactory(QNetworkProxyFactory*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFactoryFunc_setApplicationProxyFactory_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QNetworkProxyFactory * cppArg0 = Shiboken::Converter< ::QNetworkProxyFactory * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setApplicationProxyFactory(QNetworkProxyFactory*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QNetworkProxyFactory::setApplicationProxyFactory(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFactoryFunc_setApplicationProxyFactory_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxyFactory", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QNetworkProxyFactory.setApplicationProxyFactory", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFactoryFunc_setUseSystemConfiguration(PyObject* self, PyObject* pyArg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUseSystemConfiguration(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setUseSystemConfiguration(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFactoryFunc_setUseSystemConfiguration_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setUseSystemConfiguration(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QNetworkProxyFactory::setUseSystemConfiguration(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFactoryFunc_setUseSystemConfiguration_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QNetworkProxyFactory.setUseSystemConfiguration", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFactoryFunc_systemProxyForQuery(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxyFactory.systemProxyForQuery(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:systemProxyForQuery", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: systemProxyForQuery(QNetworkProxyQuery)
    if (numArgs == 0) {
        overloadId = 0; // systemProxyForQuery(QNetworkProxyQuery)
    } else if (Shiboken::Converter< ::QNetworkProxyQuery >::isConvertible(pyArgs[0])) {
        overloadId = 0; // systemProxyForQuery(QNetworkProxyQuery)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFactoryFunc_systemProxyForQuery_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "query");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "query";
                else if (Shiboken::Converter< ::QNetworkProxyQuery >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QNetworkProxyFactoryFunc_systemProxyForQuery_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxyFactory.systemProxyForQuery(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        QNetworkProxyQuery cppArg0_tmp = QNetworkProxyQuery();
        ::QNetworkProxyQuery cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QNetworkProxyQuery >::toCpp(pyArgs[0]) : cppArg0_tmp;

        if(!PyErr_Occurred()) {
            // systemProxyForQuery(QNetworkProxyQuery)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QNetworkProxy > cppResult = QNetworkProxyFactory::systemProxyForQuery(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QNetworkProxy > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkProxyFactoryFunc_systemProxyForQuery_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxyQuery = QNetworkProxyQuery()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkProxyFactory.systemProxyForQuery", overloads);
        return 0;
}

static PyMethodDef Sbk_QNetworkProxyFactory_methods[] = {
    {"proxyForQuery", (PyCFunction)Sbk_QNetworkProxyFactoryFunc_proxyForQuery, METH_O|METH_STATIC},
    {"queryProxy", (PyCFunction)Sbk_QNetworkProxyFactoryFunc_queryProxy, METH_VARARGS|METH_KEYWORDS},
    {"setApplicationProxyFactory", (PyCFunction)Sbk_QNetworkProxyFactoryFunc_setApplicationProxyFactory, METH_O|METH_STATIC},
    {"setUseSystemConfiguration", (PyCFunction)Sbk_QNetworkProxyFactoryFunc_setUseSystemConfiguration, METH_O|METH_STATIC},
    {"systemProxyForQuery", (PyCFunction)Sbk_QNetworkProxyFactoryFunc_systemProxyForQuery, METH_VARARGS|METH_KEYWORDS|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QNetworkProxyFactory_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QNetworkProxyFactory_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkProxyFactory_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtNetwork.QNetworkProxyFactory",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QNetworkProxyFactory_traverse,
    /*tp_clear*/            Sbk_QNetworkProxyFactory_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkProxyFactory_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkProxyFactory_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QNetworkProxyFactory(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXYFACTORY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkProxyFactory_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QNetworkProxyFactory", "QNetworkProxyFactory*",
        &Sbk_QNetworkProxyFactory_Type, &Shiboken::callCppDestructor< ::QNetworkProxyFactory >)) {
        return;
    }


    Shiboken::TypeResolver::createObjectTypeResolver< ::QNetworkProxyFactory >("QNetworkProxyFactory*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QNetworkProxyFactory >("QNetworkProxyFactory$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QNetworkProxyFactory >(typeid(::QNetworkProxyFactory).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QNetworkProxyFactory >(typeid(::QNetworkProxyFactoryWrapper).name());
}
