/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qsslkey_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>
#include <qsslkey.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSslKey_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSslKey >()))
        return -1;

    ::QSslKey* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QSslKey", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])))
        return -1;


    // Overloaded function decisor
    // 0: QSslKey()
    // 1: QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
    // 2: QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
    // 3: QSslKey(QSslKey)
    if (numArgs == 0) {
        overloadId = 0; // QSslKey()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QSslKey >::isConvertible(pyArgs[0])) {
        overloadId = 3; // QSslKey(QSslKey)
    } else if (numArgs >= 2
        && Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QSsl::KeyAlgorithm >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
        } else if (Shiboken::Converter< ::QSsl::EncodingFormat >::isConvertible(pyArgs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            } else if (Shiboken::Converter< ::QSsl::KeyType >::isConvertible(pyArgs[3])) {
                if (numArgs == 4) {
                    overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[4])) {
                    overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                }
            }
        }
    } else if (numArgs >= 2
        && Shiboken::Converter< ::QIODevice * >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QSsl::KeyAlgorithm >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
        } else if (Shiboken::Converter< ::QSsl::EncodingFormat >::isConvertible(pyArgs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            } else if (Shiboken::Converter< ::QSsl::KeyType >::isConvertible(pyArgs[3])) {
                if (numArgs == 4) {
                    overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[4])) {
                    overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslKey_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QSslKey()
        {

            if(!PyErr_Occurred()) {
                // QSslKey()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSslKey();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QSsl::EncodingFormat >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QSslKey_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyArgs[3])
                        errorArgName = "type";
                    else if (Shiboken::Converter< ::QSsl::KeyType >::isConvertible(value))
                        pyArgs[3] = value;
                    else
                        goto Sbk_QSslKey_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "passPhrase");
                if (value) {
                    if (pyArgs[4])
                        errorArgName = "passPhrase";
                    else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                        pyArgs[4] = value;
                    else
                        goto Sbk_QSslKey_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice * cppArg0 = Shiboken::Converter< ::QIODevice * >::toCpp(pyArgs[0]);
            QSsl::KeyAlgorithm cppArg1 = Shiboken::Converter< ::QSsl::KeyAlgorithm >::toCpp(pyArgs[1]);
            QSsl::EncodingFormat cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QSsl::EncodingFormat >::toCpp(pyArgs[2]) : QSsl::Pem;
            QSsl::KeyType cppArg3 = pyArgs[3] ? Shiboken::Converter< ::QSsl::KeyType >::toCpp(pyArgs[3]) : QSsl::PrivateKey;
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            QByteArray cppArg4_tmp = QByteArray();
            ::QByteArray cppArg4 = pyArgs[4] ? Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[4]) : cppArg4_tmp;

            if(!PyErr_Occurred()) {
                // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSslKey(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QSsl::EncodingFormat >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QSslKey_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyArgs[3])
                        errorArgName = "type";
                    else if (Shiboken::Converter< ::QSsl::KeyType >::isConvertible(value))
                        pyArgs[3] = value;
                    else
                        goto Sbk_QSslKey_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "passPhrase");
                if (value) {
                    if (pyArgs[4])
                        errorArgName = "passPhrase";
                    else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                        pyArgs[4] = value;
                    else
                        goto Sbk_QSslKey_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[0]);
            QSsl::KeyAlgorithm cppArg1 = Shiboken::Converter< ::QSsl::KeyAlgorithm >::toCpp(pyArgs[1]);
            QSsl::EncodingFormat cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QSsl::EncodingFormat >::toCpp(pyArgs[2]) : QSsl::Pem;
            QSsl::KeyType cppArg3 = pyArgs[3] ? Shiboken::Converter< ::QSsl::KeyType >::toCpp(pyArgs[3]) : QSsl::PrivateKey;
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            QByteArray cppArg4_tmp = QByteArray();
            ::QByteArray cppArg4 = pyArgs[4] ? Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[4]) : cppArg4_tmp;

            if(!PyErr_Occurred()) {
                // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSslKey(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QSslKey(QSslKey)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSslKey cppArg0 = Shiboken::Converter< ::QSslKey >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QSslKey(QSslKey)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSslKey(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSslKey >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSslKey_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSslKey_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice, PySide.QtNetwork.QSsl.KeyAlgorithm, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtNetwork.QSsl.KeyType = QSsl.PrivateKey, PySide.QtCore.QByteArray = QByteArray()", "PySide.QtCore.QByteArray, PySide.QtNetwork.QSsl.KeyAlgorithm, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtNetwork.QSsl.KeyType = QSsl.PrivateKey, PySide.QtCore.QByteArray = QByteArray()", "PySide.QtNetwork.QSslKey", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslKey", overloads);
        return -1;
}

static PyObject* Sbk_QSslKeyFunc_algorithm(PyObject* self)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // algorithm()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSsl::KeyAlgorithm cppResult = const_cast<const ::QSslKey*>(cppSelf)->algorithm();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSsl::KeyAlgorithm >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKeyFunc_clear(PyObject* self)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // clear()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->clear();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QSslKeyFunc_handle(PyObject* self)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // handle()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Qt::HANDLE cppResult = const_cast<const ::QSslKey*>(cppSelf)->handle();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Qt::HANDLE >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKeyFunc_isNull(PyObject* self)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isNull()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QSslKey*>(cppSelf)->isNull();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKeyFunc_length(PyObject* self)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // length()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QSslKey*>(cppSelf)->length();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKeyFunc_toDer(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toDer(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toDer", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toDer(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toDer(QByteArray)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[0])) {
        overloadId = 0; // toDer(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslKeyFunc_toDer_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "passPhrase");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "passPhrase";
                else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QSslKeyFunc_toDer_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toDer(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        QByteArray cppArg0_tmp = QByteArray();
        ::QByteArray cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[0]) : cppArg0_tmp;

        if(!PyErr_Occurred()) {
            // toDer(QByteArray)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QByteArray cppResult = const_cast<const ::QSslKey*>(cppSelf)->toDer(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSslKeyFunc_toDer_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslKey.toDer", overloads);
        return 0;
}

static PyObject* Sbk_QSslKeyFunc_toPem(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toPem(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toPem", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toPem(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toPem(QByteArray)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[0])) {
        overloadId = 0; // toPem(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslKeyFunc_toPem_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "passPhrase");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "passPhrase";
                else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QSslKeyFunc_toPem_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toPem(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        QByteArray cppArg0_tmp = QByteArray();
        ::QByteArray cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[0]) : cppArg0_tmp;

        if(!PyErr_Occurred()) {
            // toPem(QByteArray)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QByteArray cppResult = const_cast<const ::QSslKey*>(cppSelf)->toPem(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSslKeyFunc_toPem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslKey.toPem", overloads);
        return 0;
}

static PyObject* Sbk_QSslKeyFunc_type(PyObject* self)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // type()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSsl::KeyType cppResult = const_cast<const ::QSslKey*>(cppSelf)->type();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSsl::KeyType >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKey___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QSslKey& cppSelf = *(Shiboken::Converter< ::QSslKey* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QSslKey >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QSslKey_methods[] = {
    {"algorithm", (PyCFunction)Sbk_QSslKeyFunc_algorithm, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QSslKeyFunc_clear, METH_NOARGS},
    {"handle", (PyCFunction)Sbk_QSslKeyFunc_handle, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QSslKeyFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)Sbk_QSslKeyFunc_length, METH_NOARGS},
    {"toDer", (PyCFunction)Sbk_QSslKeyFunc_toDer, METH_VARARGS|METH_KEYWORDS},
    {"toPem", (PyCFunction)Sbk_QSslKeyFunc_toPem, METH_VARARGS|METH_KEYWORDS},
    {"type", (PyCFunction)Sbk_QSslKeyFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSslKey___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QSslKey___nb_bool(PyObject* self)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return -1;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

// Rich comparison
static PyObject* Sbk_QSslKey_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QSslKey& cppSelf = *(Shiboken::Converter< ::QSslKey* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSslKey >::isConvertible(pyArg)) {
                // operator!=(const QSslKey & key) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QSslKey cppArg0 = Shiboken::Converter< ::QSslKey >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSslKey >::isConvertible(pyArg)) {
                // operator==(const QSslKey & key) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QSslKey cppArg0 = Shiboken::Converter< ::QSslKey >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QSslKey_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSslKey_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QSslKey_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QSslKey_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
extern "C"
{
static PyObject* Sbk_QSslKey__repr__(PyObject* self)
{
    ::QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSslKey* >::toCpp(self);
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    int idx = str.indexOf('(');
    if (idx >= 0)
        str.replace(0, idx, Py_TYPE(self)->tp_name);
    PyObject* mod = PyDict_GetItemString(Py_TYPE(self)->tp_dict, "__module__");
    if (mod)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    else
        return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSslKey_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtNetwork.QSslKey",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QSslKey__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QSslKey_traverse,
    /*tp_clear*/            Sbk_QSslKey_clear,
    /*tp_richcompare*/      Sbk_QSslKey_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSslKey_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSslKey_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSslKey(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QSslKey_Type.super.as_number, 0, sizeof(PyNumberMethods));
    SBK_NB_BOOL(Sbk_QSslKey_Type.super.as_number) = Sbk_QSslKey___nb_bool;
    Sbk_QSslKey_Type.super.ht_type.tp_as_number = &Sbk_QSslKey_Type.super.as_number;

    SbkPySide_QtNetworkTypes[SBK_QSSLKEY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSslKey_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QSslKey", "QSslKey",
        &Sbk_QSslKey_Type, &Shiboken::callCppDestructor< ::QSslKey >)) {
        return;
    }


    Shiboken::TypeResolver::createValueTypeResolver< ::QSslKey >("QSslKey");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QSslKey >("QSslKey*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QSslKey >(typeid(::QSslKey).name());
    qRegisterMetaType< ::QSslKey >("QSslKey");
}
