/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptvalue_wrapper.h"

// Extra includes
#include <QList>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qregexp.h>
#include <qscriptclass.h>
#include <qscriptengine.h>
#include <qscriptstring.h>
#include <qscriptvalue.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScriptValue_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScriptValue >()))
        return -1;

    ::QScriptValue* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptValue", 0, 2, &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QScriptValue()
    // 1: QScriptValue(QScriptEngine*,QScriptValue::SpecialValue)
    // 2: QScriptValue(QScriptEngine*,bool)
    // 3: QScriptValue(QScriptEngine*,QString)
    // 4: QScriptValue(QScriptEngine*,const char*)
    // 5: QScriptValue(QScriptEngine*,double)
    // 6: QScriptValue(QScriptEngine*,int)
    // 7: QScriptValue(QScriptEngine*,uint)
    // 8: QScriptValue(QScriptValue::SpecialValue)
    // 9: QScriptValue(bool)
    // 10: QScriptValue(QScriptValue)
    // 11: QScriptValue(QString)
    // 12: QScriptValue(const char*)
    // 13: QScriptValue(double)
    // 14: QScriptValue(int)
    // 15: QScriptValue(uint)
    if (numArgs == 0) {
        overloadId = 0; // QScriptValue()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QScriptValue::SpecialValue >::isConvertible(pyArgs[0])) {
        overloadId = 8; // QScriptValue(QScriptValue::SpecialValue)
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 15; // QScriptValue(uint)
    } else if (numArgs == 1
        && PyFloat_Check(pyArgs[0])) {
        overloadId = 13; // QScriptValue(double)
    } else if (numArgs == 1
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])) {
        overloadId = 12; // QScriptValue(const char*)
    } else if (numArgs == 1
        && PyBool_Check(pyArgs[0])) {
        overloadId = 9; // QScriptValue(bool)
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 14; // QScriptValue(int)
    } else if (Shiboken::Converter< ::QScriptEngine * >::isConvertible(pyArgs[0])) {
        if (numArgs == 2
            && Shiboken::Converter< ::QScriptValue::SpecialValue >::isConvertible(pyArgs[1])) {
            overloadId = 1; // QScriptValue(QScriptEngine*,QScriptValue::SpecialValue)
        } else if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 7; // QScriptValue(QScriptEngine*,uint)
        } else if (numArgs == 2
            && PyFloat_Check(pyArgs[1])) {
            overloadId = 5; // QScriptValue(QScriptEngine*,double)
        } else if (numArgs == 2
            && Shiboken::Converter< const char * >::isConvertible(pyArgs[1])) {
            overloadId = 4; // QScriptValue(QScriptEngine*,const char*)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 3; // QScriptValue(QScriptEngine*,QString)
        } else if (numArgs == 2
            && PyBool_Check(pyArgs[1])) {
            overloadId = 2; // QScriptValue(QScriptEngine*,bool)
        } else if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 6; // QScriptValue(QScriptEngine*,int)
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        overloadId = 11; // QScriptValue(QString)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QScriptValue >::isConvertible(pyArgs[0])) {
        overloadId = 10; // QScriptValue(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValue_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QScriptValue()
        {

            if(!PyErr_Occurred()) {
                // QScriptValue()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QScriptValue(QScriptEngine*,QScriptValue::SpecialValue)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScriptEngine * cppArg0 = Shiboken::Converter< ::QScriptEngine * >::toCpp(pyArgs[0]);
            QScriptValue::SpecialValue cppArg1 = Shiboken::Converter< ::QScriptValue::SpecialValue >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,QScriptValue::SpecialValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QScriptValue(QScriptEngine*,bool)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScriptEngine * cppArg0 = Shiboken::Converter< ::QScriptEngine * >::toCpp(pyArgs[0]);
            bool cppArg1 = Shiboken::Converter< bool >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QScriptValue(QScriptEngine*,QString)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScriptEngine * cppArg0 = Shiboken::Converter< ::QScriptEngine * >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // QScriptValue(QScriptEngine*,const char*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScriptEngine * cppArg0 = Shiboken::Converter< ::QScriptEngine * >::toCpp(pyArgs[0]);
            const char * cppArg1 = Shiboken::Converter< const char * >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 5: // QScriptValue(QScriptEngine*,double)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScriptEngine * cppArg0 = Shiboken::Converter< ::QScriptEngine * >::toCpp(pyArgs[0]);
            double cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 6: // QScriptValue(QScriptEngine*,int)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScriptEngine * cppArg0 = Shiboken::Converter< ::QScriptEngine * >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 7: // QScriptValue(QScriptEngine*,uint)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScriptEngine * cppArg0 = Shiboken::Converter< ::QScriptEngine * >::toCpp(pyArgs[0]);
            uint cppArg1 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 8: // QScriptValue(QScriptValue::SpecialValue)
        {
            QScriptValue::SpecialValue cppArg0 = Shiboken::Converter< ::QScriptValue::SpecialValue >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptValue::SpecialValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 9: // QScriptValue(bool)
        {
            bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValue(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 10: // QScriptValue(QScriptValue)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 11: // QScriptValue(QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValue(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 12: // QScriptValue(const char*)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValue(const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 13: // QScriptValue(double)
        {
            double cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValue(double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 14: // QScriptValue(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValue(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 15: // QScriptValue(uint)
        {
            uint cppArg0 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValue(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QScriptValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QScriptValue >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QScriptValue_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QScriptValue_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtScript.QScriptEngine, PySide.QtScript.QScriptValue.SpecialValue", "PySide.QtScript.QScriptEngine, bool", "PySide.QtScript.QScriptEngine, unicode", "PySide.QtScript.QScriptEngine, "SBK_STR_NAME"", "PySide.QtScript.QScriptEngine, float", "PySide.QtScript.QScriptEngine, int", "PySide.QtScript.QScriptEngine, unsigned int", "PySide.QtScript.QScriptValue.SpecialValue", "bool", "PySide.QtScript.QScriptValue", "unicode", ""SBK_STR_NAME"", "float", "int", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue", overloads);
        return -1;
}

static PyObject* Sbk_QScriptValueFunc___iter__(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __iter__()
            // Begin code injection

            pyResult = Shiboken::createWrapper(new QScriptValueIterator(*cppSelf), true, true);

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc___repr__(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __repr__()
            // Begin code injection

            if (cppSelf->isVariant() || cppSelf->isString()) {
                QString format = QString().sprintf("%s(\"%s\")", ((PyObject*)self)->ob_type->tp_name, qPrintable(cppSelf->toString()));
                pyResult = Shiboken::String::fromCString(qPrintable(format));
             } else {
                pyResult = Shiboken::String::fromCString(
                                ((PyObject* )self)->ob_type->tp_name);
            }

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_call(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.call(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:call", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: call(QScriptValue,QList<QScriptValue>)
    // 1: call(QScriptValue,QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // call(QScriptValue,QList<QScriptValue>)
    } else if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // call(QScriptValue,QList<QScriptValue>)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QScriptValue >::isConvertible(pyArgs[1])) {
            overloadId = 1; // call(QScriptValue,QScriptValue)
        } else if (Shiboken::Converter< ::QList<QScriptValue > >::isConvertible(pyArgs[1])) {
            overloadId = 0; // call(QScriptValue,QList<QScriptValue>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_call_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // call(QScriptValue,QList<QScriptValue>)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "thisObject");
                if (value) {
                    if (pyArgs[0])
                        errorArgName = "thisObject";
                    else if (Shiboken::Converter< ::QScriptValue >::isConvertible(value))
                        pyArgs[0] = value;
                    else
                        goto Sbk_QScriptValueFunc_call_TypeError;
                }
                value = PyDict_GetItemString(kwds, "args");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "args";
                    else if (Shiboken::Converter< ::QList<QScriptValue > >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QScriptValueFunc_call_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.call(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            QScriptValue cppArg0_tmp = QScriptValue();
            ::QScriptValue cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QScriptValue >::toCpp(pyArgs[0]) : cppArg0_tmp;
            ::QList<QScriptValue > cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QList<QScriptValue > >::toCpp(pyArgs[1]) : QScriptValueList();

            if(!PyErr_Occurred()) {
                // call(QScriptValue,QList<QScriptValue>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->call(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
            break;
        }
        case 1: // call(QScriptValue,QScriptValue)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QScriptValue cppArg1 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // call(QScriptValue,QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->call(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptValueFunc_call_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue = QScriptValue(), list = QScriptValueList()", "PySide.QtScript.QScriptValue, PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.call", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_construct(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.construct(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:construct", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: construct(QList<QScriptValue>)
    // 1: construct(QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // construct(QList<QScriptValue>)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QScriptValue >::isConvertible(pyArgs[0])) {
        overloadId = 1; // construct(QScriptValue)
    } else if (Shiboken::Converter< ::QList<QScriptValue > >::isConvertible(pyArgs[0])) {
        overloadId = 0; // construct(QList<QScriptValue>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_construct_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // construct(QList<QScriptValue>)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "args");
                if (value) {
                    if (pyArgs[0])
                        errorArgName = "args";
                    else if (Shiboken::Converter< ::QList<QScriptValue > >::isConvertible(value))
                        pyArgs[0] = value;
                    else
                        goto Sbk_QScriptValueFunc_construct_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.construct(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            ::QList<QScriptValue > cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QList<QScriptValue > >::toCpp(pyArgs[0]) : QScriptValueList();

            if(!PyErr_Occurred()) {
                // construct(QList<QScriptValue>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->construct(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
            break;
        }
        case 1: // construct(QScriptValue)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // construct(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->construct(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptValueFunc_construct_TypeError:
        const char* overloads[] = {"list = QScriptValueList()", "PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.construct", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_data(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // data()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QScriptValue cppResult = const_cast<const ::QScriptValue*>(cppSelf)->data();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_engine(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // engine()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QScriptEngine * cppResult = const_cast<const ::QScriptValue*>(cppSelf)->engine();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QScriptEngine * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_equals(PyObject* self, PyObject* pyArg)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: equals(QScriptValue)const
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyArg)) {
        overloadId = 0; // equals(QScriptValue)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_equals_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // equals(QScriptValue)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->equals(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptValueFunc_equals_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtScript.QScriptValue.equals", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_instanceOf(PyObject* self, PyObject* pyArg)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: instanceOf(QScriptValue)const
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyArg)) {
        overloadId = 0; // instanceOf(QScriptValue)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_instanceOf_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // instanceOf(QScriptValue)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->instanceOf(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptValueFunc_instanceOf_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtScript.QScriptValue.instanceOf", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_isArray(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isArray()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isArray();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isBool(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isBool()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isBool();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isBoolean(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isBoolean()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isBoolean();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isDate(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isDate()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isDate();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isError(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isError()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isError();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isFunction(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isFunction()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isFunction();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isNull(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isNull()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isNull();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isNumber(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isNumber()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isNumber();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isObject(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isObject()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isObject();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isQMetaObject(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isQMetaObject()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isQMetaObject();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isQObject(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isQObject()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isQObject();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isRegExp(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isRegExp()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isRegExp();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isString(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isString()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isString();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isUndefined(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isUndefined()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isUndefined();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isValid(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isValid()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isValid();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_isVariant(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isVariant()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->isVariant();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_lessThan(PyObject* self, PyObject* pyArg)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: lessThan(QScriptValue)const
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyArg)) {
        overloadId = 0; // lessThan(QScriptValue)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_lessThan_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // lessThan(QScriptValue)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->lessThan(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptValueFunc_lessThan_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtScript.QScriptValue.lessThan", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_objectId(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // objectId()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qint64 cppResult = const_cast<const ::QScriptValue*>(cppSelf)->objectId();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< long long >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_property(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:property", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
    // 1: property(QString,QFlags<QScriptValue::ResolveFlag>)const
    // 2: property(quint32,QFlags<QScriptValue::ResolveFlag>)const
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // property(quint32,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(pyArgs[1])) {
            overloadId = 2; // property(quint32,QFlags<QScriptValue::ResolveFlag>)const
        }
    } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // property(QString,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(pyArgs[1])) {
            overloadId = 1; // property(QString,QFlags<QScriptValue::ResolveFlag>)const
        }
    } else if (Shiboken::Converter< ::QScriptString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(pyArgs[1])) {
            overloadId = 0; // property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_property_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QScriptValueFunc_property_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QScriptString cppArg0 = Shiboken::Converter< ::QScriptString >::toCpp(pyArgs[0]);
            const QFlags<QScriptValue::ResolveFlag> & cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::toCpp(pyArgs[1]) : QScriptValue::ResolvePrototype;

            if(!PyErr_Occurred()) {
                // property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const ::QScriptValue*>(cppSelf)->property(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
            break;
        }
        case 1: // property(QString,QFlags<QScriptValue::ResolveFlag>)const
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QScriptValueFunc_property_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            const QFlags<QScriptValue::ResolveFlag> & cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::toCpp(pyArgs[1]) : QScriptValue::ResolvePrototype;

            if(!PyErr_Occurred()) {
                // property(QString,QFlags<QScriptValue::ResolveFlag>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const ::QScriptValue*>(cppSelf)->property(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
            break;
        }
        case 2: // property(quint32,QFlags<QScriptValue::ResolveFlag>)const
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QScriptValueFunc_property_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            quint32 cppArg0 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[0]);
            const QFlags<QScriptValue::ResolveFlag> & cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::toCpp(pyArgs[1]) : QScriptValue::ResolvePrototype;

            if(!PyErr_Occurred()) {
                // property(quint32,QFlags<QScriptValue::ResolveFlag>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const ::QScriptValue*>(cppSelf)->property(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptValueFunc_property_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptString, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", "unicode, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", "unsigned int, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.property", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_propertyFlags(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:propertyFlags", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
    // 1: propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(pyArgs[1])) {
            overloadId = 1; // propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
        }
    } else if (Shiboken::Converter< ::QScriptString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(pyArgs[1])) {
            overloadId = 0; // propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_propertyFlags_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QScriptValueFunc_propertyFlags_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QScriptString cppArg0 = Shiboken::Converter< ::QScriptString >::toCpp(pyArgs[0]);
            const QFlags<QScriptValue::ResolveFlag> & cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::toCpp(pyArgs[1]) : QScriptValue::ResolvePrototype;

            if(!PyErr_Occurred()) {
                // propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QScriptValue::PropertyFlag> cppResult = const_cast<const ::QScriptValue*>(cppSelf)->propertyFlags(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::toPython(cppResult);
            }
            break;
        }
        case 1: // propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QScriptValueFunc_propertyFlags_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            const QFlags<QScriptValue::ResolveFlag> & cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QFlags<QScriptValue::ResolveFlag> >::toCpp(pyArgs[1]) : QScriptValue::ResolvePrototype;

            if(!PyErr_Occurred()) {
                // propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QScriptValue::PropertyFlag> cppResult = const_cast<const ::QScriptValue*>(cppSelf)->propertyFlags(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptValueFunc_propertyFlags_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptString, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", "unicode, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.propertyFlags", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_prototype(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // prototype()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QScriptValue cppResult = const_cast<const ::QScriptValue*>(cppSelf)->prototype();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_scope(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // scope()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QScriptValue cppResult = const_cast<const ::QScriptValue*>(cppSelf)->scope();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_scriptClass(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // scriptClass()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QScriptClass * cppResult = const_cast<const ::QScriptValue*>(cppSelf)->scriptClass();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QScriptClass * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_setData(PyObject* self, PyObject* pyArg)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setData(QScriptValue)
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyArg)) {
        overloadId = 0; // setData(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_setData_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setData(QScriptValue)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setData(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptValueFunc_setData_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtScript.QScriptValue.setData", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_setProperty(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setProperty", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
    // 1: setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
    // 2: setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
    if (numArgs >= 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QScriptValue >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        } else if (Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::isConvertible(pyArgs[2])) {
            overloadId = 2; // setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        }
    } else if (numArgs >= 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QScriptValue >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        } else if (Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::isConvertible(pyArgs[2])) {
            overloadId = 1; // setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        }
    } else if (numArgs >= 2
        && Shiboken::Converter< ::QScriptString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QScriptValue >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        } else if (Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::isConvertible(pyArgs[2])) {
            overloadId = 0; // setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_setProperty_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QScriptValueFunc_setProperty_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QScriptString cppArg0 = Shiboken::Converter< ::QScriptString >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QScriptValue cppArg1 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArgs[1]);
            const QFlags<QScriptValue::PropertyFlag> & cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::toCpp(pyArgs[2]) : QScriptValue::KeepExistingFlags;

            if(!PyErr_Occurred()) {
                // setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProperty(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QScriptValueFunc_setProperty_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QScriptValue cppArg1 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArgs[1]);
            const QFlags<QScriptValue::PropertyFlag> & cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::toCpp(pyArgs[2]) : QScriptValue::KeepExistingFlags;

            if(!PyErr_Occurred()) {
                // setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProperty(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QScriptValueFunc_setProperty_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            quint32 cppArg0 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QScriptValue cppArg1 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArgs[1]);
            const QFlags<QScriptValue::PropertyFlag> & cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::toCpp(pyArgs[2]) : QScriptValue::KeepExistingFlags;

            if(!PyErr_Occurred()) {
                // setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProperty(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptValueFunc_setProperty_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptString, PySide.QtScript.QScriptValue, PySide.QtScript.QScriptValue.PropertyFlags = QScriptValue.KeepExistingFlags", "unicode, PySide.QtScript.QScriptValue, PySide.QtScript.QScriptValue.PropertyFlags = QScriptValue.KeepExistingFlags", "unsigned int, PySide.QtScript.QScriptValue, PySide.QtScript.QScriptValue.PropertyFlags = QScriptValue.KeepExistingFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.setProperty", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_setPrototype(PyObject* self, PyObject* pyArg)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrototype(QScriptValue)
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyArg)) {
        overloadId = 0; // setPrototype(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_setPrototype_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setPrototype(QScriptValue)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPrototype(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptValueFunc_setPrototype_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtScript.QScriptValue.setPrototype", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_setScope(PyObject* self, PyObject* pyArg)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScope(QScriptValue)
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyArg)) {
        overloadId = 0; // setScope(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_setScope_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setScope(QScriptValue)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setScope(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptValueFunc_setScope_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtScript.QScriptValue.setScope", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_setScriptClass(PyObject* self, PyObject* pyArg)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScriptClass(QScriptClass*)
    if (Shiboken::Converter< ::QScriptClass * >::isConvertible(pyArg)) {
        overloadId = 0; // setScriptClass(QScriptClass*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_setScriptClass_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QScriptClass * cppArg0 = Shiboken::Converter< ::QScriptClass * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setScriptClass(QScriptClass*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setScriptClass(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptValueFunc_setScriptClass_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptClass", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtScript.QScriptValue.setScriptClass", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_strictlyEquals(PyObject* self, PyObject* pyArg)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: strictlyEquals(QScriptValue)const
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyArg)) {
        overloadId = 0; // strictlyEquals(QScriptValue)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueFunc_strictlyEquals_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QScriptValue cppArg0 = Shiboken::Converter< ::QScriptValue >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // strictlyEquals(QScriptValue)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->strictlyEquals(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptValueFunc_strictlyEquals_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtScript.QScriptValue.strictlyEquals", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueFunc_toBool(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toBool()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toBool();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toBoolean(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toBoolean()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toBoolean();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toDateTime(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toDateTime()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDateTime cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toDateTime();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toInt32(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toInt32()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qint32 cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toInt32();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toInteger(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toInteger()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            double cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toInteger();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toNumber(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toNumber()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            double cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toNumber();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toObject(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toObject()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QScriptValue cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toObject();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toQMetaObject(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toQMetaObject()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QMetaObject * cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toQMetaObject();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QMetaObject * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toQObject(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toQObject()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QObject * cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toQObject();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toRegExp(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toRegExp()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRegExp cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toRegExp();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRegExp >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toString(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toString()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toString();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toUInt16(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toUInt16()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            quint16 cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toUInt16();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< unsigned short >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toUInt32(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toUInt32()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            quint32 cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toUInt32();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueFunc_toVariant(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toVariant()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVariant cppResult = const_cast<const ::QScriptValue*>(cppSelf)->toVariant();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVariant >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValue___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QScriptValue& cppSelf = *(Shiboken::Converter< ::QScriptValue* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QScriptValue_methods[] = {
    {"call", (PyCFunction)Sbk_QScriptValueFunc_call, METH_VARARGS|METH_KEYWORDS},
    {"construct", (PyCFunction)Sbk_QScriptValueFunc_construct, METH_VARARGS|METH_KEYWORDS},
    {"data", (PyCFunction)Sbk_QScriptValueFunc_data, METH_NOARGS},
    {"engine", (PyCFunction)Sbk_QScriptValueFunc_engine, METH_NOARGS},
    {"equals", (PyCFunction)Sbk_QScriptValueFunc_equals, METH_O},
    {"instanceOf", (PyCFunction)Sbk_QScriptValueFunc_instanceOf, METH_O},
    {"isArray", (PyCFunction)Sbk_QScriptValueFunc_isArray, METH_NOARGS},
    {"isBool", (PyCFunction)Sbk_QScriptValueFunc_isBool, METH_NOARGS},
    {"isBoolean", (PyCFunction)Sbk_QScriptValueFunc_isBoolean, METH_NOARGS},
    {"isDate", (PyCFunction)Sbk_QScriptValueFunc_isDate, METH_NOARGS},
    {"isError", (PyCFunction)Sbk_QScriptValueFunc_isError, METH_NOARGS},
    {"isFunction", (PyCFunction)Sbk_QScriptValueFunc_isFunction, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QScriptValueFunc_isNull, METH_NOARGS},
    {"isNumber", (PyCFunction)Sbk_QScriptValueFunc_isNumber, METH_NOARGS},
    {"isObject", (PyCFunction)Sbk_QScriptValueFunc_isObject, METH_NOARGS},
    {"isQMetaObject", (PyCFunction)Sbk_QScriptValueFunc_isQMetaObject, METH_NOARGS},
    {"isQObject", (PyCFunction)Sbk_QScriptValueFunc_isQObject, METH_NOARGS},
    {"isRegExp", (PyCFunction)Sbk_QScriptValueFunc_isRegExp, METH_NOARGS},
    {"isString", (PyCFunction)Sbk_QScriptValueFunc_isString, METH_NOARGS},
    {"isUndefined", (PyCFunction)Sbk_QScriptValueFunc_isUndefined, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QScriptValueFunc_isValid, METH_NOARGS},
    {"isVariant", (PyCFunction)Sbk_QScriptValueFunc_isVariant, METH_NOARGS},
    {"lessThan", (PyCFunction)Sbk_QScriptValueFunc_lessThan, METH_O},
    {"objectId", (PyCFunction)Sbk_QScriptValueFunc_objectId, METH_NOARGS},
    {"property", (PyCFunction)Sbk_QScriptValueFunc_property, METH_VARARGS|METH_KEYWORDS},
    {"propertyFlags", (PyCFunction)Sbk_QScriptValueFunc_propertyFlags, METH_VARARGS|METH_KEYWORDS},
    {"prototype", (PyCFunction)Sbk_QScriptValueFunc_prototype, METH_NOARGS},
    {"scope", (PyCFunction)Sbk_QScriptValueFunc_scope, METH_NOARGS},
    {"scriptClass", (PyCFunction)Sbk_QScriptValueFunc_scriptClass, METH_NOARGS},
    {"setData", (PyCFunction)Sbk_QScriptValueFunc_setData, METH_O},
    {"setProperty", (PyCFunction)Sbk_QScriptValueFunc_setProperty, METH_VARARGS|METH_KEYWORDS},
    {"setPrototype", (PyCFunction)Sbk_QScriptValueFunc_setPrototype, METH_O},
    {"setScope", (PyCFunction)Sbk_QScriptValueFunc_setScope, METH_O},
    {"setScriptClass", (PyCFunction)Sbk_QScriptValueFunc_setScriptClass, METH_O},
    {"strictlyEquals", (PyCFunction)Sbk_QScriptValueFunc_strictlyEquals, METH_O},
    {"toBool", (PyCFunction)Sbk_QScriptValueFunc_toBool, METH_NOARGS},
    {"toBoolean", (PyCFunction)Sbk_QScriptValueFunc_toBoolean, METH_NOARGS},
    {"toDateTime", (PyCFunction)Sbk_QScriptValueFunc_toDateTime, METH_NOARGS},
    {"toInt32", (PyCFunction)Sbk_QScriptValueFunc_toInt32, METH_NOARGS},
    {"toInteger", (PyCFunction)Sbk_QScriptValueFunc_toInteger, METH_NOARGS},
    {"toNumber", (PyCFunction)Sbk_QScriptValueFunc_toNumber, METH_NOARGS},
    {"toObject", (PyCFunction)Sbk_QScriptValueFunc_toObject, METH_NOARGS},
    {"toQMetaObject", (PyCFunction)Sbk_QScriptValueFunc_toQMetaObject, METH_NOARGS},
    {"toQObject", (PyCFunction)Sbk_QScriptValueFunc_toQObject, METH_NOARGS},
    {"toRegExp", (PyCFunction)Sbk_QScriptValueFunc_toRegExp, METH_NOARGS},
    {"toString", (PyCFunction)Sbk_QScriptValueFunc_toString, METH_NOARGS},
    {"toUInt16", (PyCFunction)Sbk_QScriptValueFunc_toUInt16, METH_NOARGS},
    {"toUInt32", (PyCFunction)Sbk_QScriptValueFunc_toUInt32, METH_NOARGS},
    {"toVariant", (PyCFunction)Sbk_QScriptValueFunc_toVariant, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QScriptValue___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QScriptValue___nb_bool(PyObject* self)
{
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return -1;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

PyObject* Sbk_QScriptValueFunc___mgetitem__(PyObject* self, PyObject* _key)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QScriptValue* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QScriptValue* >::toCpp(self);
    // Begin code injection

    Shiboken::AutoDecRef key(PyObject_Str(_key));
    QVariant res = cppSelf->property(Shiboken::String::toCString(key.object())).toVariant();
    if (res.isValid()) {
        return Shiboken::Converter< ::QVariant >::toPython(res);
    } else {
        PyObject* errorType = PyInt_Check(_key) ? PyExc_IndexError : PyExc_KeyError;
        PyErr_SetString(errorType, "Key not found.");
        return 0;
    }

    // End of code injection
}

} // extern "C"

static int Sbk_QScriptValue_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QScriptValue_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QScriptValue_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtScript.QScriptValue",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QScriptValueFunc___repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QScriptValue_traverse,
    /*tp_clear*/            Sbk_QScriptValue_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             Sbk_QScriptValueFunc___iter__,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QScriptValue_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QScriptValue_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag___and__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QScriptValue::ResolveFlags >::toPython(
        Shiboken::Converter< ::QScriptValue::ResolveFlags>::toCpp(self)
        & Shiboken::Converter< ::QScriptValue::ResolveFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag___or__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QScriptValue::ResolveFlags >::toPython(
        Shiboken::Converter< ::QScriptValue::ResolveFlags>::toCpp(self)
        | Shiboken::Converter< ::QScriptValue::ResolveFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag___xor__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QScriptValue::ResolveFlags >::toPython(
        Shiboken::Converter< ::QScriptValue::ResolveFlags>::toCpp(self)
        ^ Shiboken::Converter< ::QScriptValue::ResolveFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag___invert__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< QScriptValue::ResolveFlags >::toPython(
        ~Shiboken::Converter< ::QScriptValue::ResolveFlags >::toCpp(self)
    );
}

static PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag_long(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QScriptValue::ResolveFlags>::toCpp(v);
    return PyLong_FromLong(val);
}
static int SbkPySide_QtScript_QScriptValue_ResolveFlag__nonzero(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QScriptValue::ResolveFlags>::toCpp(v);
    return val != 0;
}

static PyNumberMethods SbkPySide_QtScript_QScriptValue_ResolveFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    #ifndef IS_PY3K
    /* nb_divide */             0,
    #endif
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              SbkPySide_QtScript_QScriptValue_ResolveFlag__nonzero,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtScript_QScriptValue_ResolveFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtScript_QScriptValue_ResolveFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtScript_QScriptValue_ResolveFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtScript_QScriptValue_ResolveFlag___or__,
    #ifndef IS_PY3K
    /* nb_coerce */             0,
    #endif
    /*nb_int*/                  SbkPySide_QtScript_QScriptValue_ResolveFlag_long,
    #ifdef IS_PY3K
    /*nb_reserved*/             0,
    /*nb_float*/                0,
    #else
    /*nb_long*/                 SbkPySide_QtScript_QScriptValue_ResolveFlag_long,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    #endif
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    #ifndef IS_PY3K
    /*nb_inplace_divide*/       0,
    #endif
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtScript_QScriptValue_ResolveFlags_Type = {
    PyVarObject_HEAD_INIT(&PyType_Type, 0)
    /*tp_name*/             "ResolveFlags",
    /*tp_basicsize*/        sizeof(PySideQFlagsObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtScript_QScriptValue_ResolveFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      &PySideQFlagsRichCompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              &PySideQFlagsNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag___and__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QScriptValue::PropertyFlags >::toPython(
        Shiboken::Converter< ::QScriptValue::PropertyFlags>::toCpp(self)
        & Shiboken::Converter< ::QScriptValue::PropertyFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag___or__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QScriptValue::PropertyFlags >::toPython(
        Shiboken::Converter< ::QScriptValue::PropertyFlags>::toCpp(self)
        | Shiboken::Converter< ::QScriptValue::PropertyFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag___xor__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QScriptValue::PropertyFlags >::toPython(
        Shiboken::Converter< ::QScriptValue::PropertyFlags>::toCpp(self)
        ^ Shiboken::Converter< ::QScriptValue::PropertyFlags >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag___invert__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< QScriptValue::PropertyFlags >::toPython(
        ~Shiboken::Converter< ::QScriptValue::PropertyFlags >::toCpp(self)
    );
}

static PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag_long(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QScriptValue::PropertyFlags>::toCpp(v);
    return PyLong_FromLong(val);
}
static int SbkPySide_QtScript_QScriptValue_PropertyFlag__nonzero(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QScriptValue::PropertyFlags>::toCpp(v);
    return val != 0;
}

static PyNumberMethods SbkPySide_QtScript_QScriptValue_PropertyFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    #ifndef IS_PY3K
    /* nb_divide */             0,
    #endif
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              SbkPySide_QtScript_QScriptValue_PropertyFlag__nonzero,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtScript_QScriptValue_PropertyFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtScript_QScriptValue_PropertyFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtScript_QScriptValue_PropertyFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtScript_QScriptValue_PropertyFlag___or__,
    #ifndef IS_PY3K
    /* nb_coerce */             0,
    #endif
    /*nb_int*/                  SbkPySide_QtScript_QScriptValue_PropertyFlag_long,
    #ifdef IS_PY3K
    /*nb_reserved*/             0,
    /*nb_float*/                0,
    #else
    /*nb_long*/                 SbkPySide_QtScript_QScriptValue_PropertyFlag_long,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    #endif
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    #ifndef IS_PY3K
    /*nb_inplace_divide*/       0,
    #endif
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtScript_QScriptValue_PropertyFlags_Type = {
    PyVarObject_HEAD_INIT(&PyType_Type, 0)
    /*tp_name*/             "PropertyFlags",
    /*tp_basicsize*/        sizeof(PySideQFlagsObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtScript_QScriptValue_PropertyFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      &PySideQFlagsRichCompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              &PySideQFlagsNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QScriptValue(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QScriptValue_Type.super.as_number, 0, sizeof(PyNumberMethods));
    SBK_NB_BOOL(Sbk_QScriptValue_Type.super.as_number) = Sbk_QScriptValue___nb_bool;
    Sbk_QScriptValue_Type.super.ht_type.tp_as_number = &Sbk_QScriptValue_Type.super.as_number;

    // type supports mapping protocol
    memset(&Sbk_QScriptValue_Type.super.as_mapping, 0, sizeof(PyMappingMethods));
    Sbk_QScriptValue_Type.super.as_mapping.mp_ass_subscript = 0;
    Sbk_QScriptValue_Type.super.as_mapping.mp_length = 0;
    Sbk_QScriptValue_Type.super.as_mapping.mp_subscript = &Sbk_QScriptValueFunc___mgetitem__;
    Sbk_QScriptValue_Type.super.ht_type.tp_as_mapping = &Sbk_QScriptValue_Type.super.as_mapping;

    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QScriptValue_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QScriptValue", "QScriptValue",
        &Sbk_QScriptValue_Type, &Shiboken::callCppDestructor< ::QScriptValue >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'ResolveFlag'.
    SbkPySide_QtScriptTypes[SBK_QFLAGS_QSCRIPTVALUE_RESOLVEFLAG__IDX] = &SbkPySide_QtScript_QScriptValue_ResolveFlags_Type;
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_RESOLVEFLAG_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QScriptValue_Type,
        "ResolveFlag",
        "PySide.QtScript.QScriptValue.ResolveFlag",
        "QScriptValue::ResolveFlag",
        SbkPySide_QtScriptTypes[SBK_QFLAGS_QSCRIPTVALUE_RESOLVEFLAG__IDX]);
    if (!SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_RESOLVEFLAG_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_RESOLVEFLAG_IDX],
        &Sbk_QScriptValue_Type, "ResolveLocal", (long) QScriptValue::ResolveLocal))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_RESOLVEFLAG_IDX],
        &Sbk_QScriptValue_Type, "ResolvePrototype", (long) QScriptValue::ResolvePrototype))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_RESOLVEFLAG_IDX],
        &Sbk_QScriptValue_Type, "ResolveScope", (long) QScriptValue::ResolveScope))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_RESOLVEFLAG_IDX],
        &Sbk_QScriptValue_Type, "ResolveFull", (long) QScriptValue::ResolveFull))
        return ;
    // End of 'ResolveFlag' enum.

    // Initialization of enum 'PropertyFlag'.
    SbkPySide_QtScriptTypes[SBK_QFLAGS_QSCRIPTVALUE_PROPERTYFLAG__IDX] = &SbkPySide_QtScript_QScriptValue_PropertyFlags_Type;
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QScriptValue_Type,
        "PropertyFlag",
        "PySide.QtScript.QScriptValue.PropertyFlag",
        "QScriptValue::PropertyFlag",
        SbkPySide_QtScriptTypes[SBK_QFLAGS_QSCRIPTVALUE_PROPERTYFLAG__IDX]);
    if (!SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX],
        &Sbk_QScriptValue_Type, "ReadOnly", (long) QScriptValue::ReadOnly))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX],
        &Sbk_QScriptValue_Type, "Undeletable", (long) QScriptValue::Undeletable))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX],
        &Sbk_QScriptValue_Type, "SkipInEnumeration", (long) QScriptValue::SkipInEnumeration))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX],
        &Sbk_QScriptValue_Type, "PropertyGetter", (long) QScriptValue::PropertyGetter))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX],
        &Sbk_QScriptValue_Type, "PropertySetter", (long) QScriptValue::PropertySetter))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX],
        &Sbk_QScriptValue_Type, "QObjectMember", (long) QScriptValue::QObjectMember))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX],
        &Sbk_QScriptValue_Type, "KeepExistingFlags", (long) QScriptValue::KeepExistingFlags))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX],
        &Sbk_QScriptValue_Type, "UserRange", (long) QScriptValue::UserRange))
        return ;
    // End of 'PropertyFlag' enum.

    // Initialization of enum 'SpecialValue'.
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_SPECIALVALUE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QScriptValue_Type,
        "SpecialValue",
        "PySide.QtScript.QScriptValue.SpecialValue",
        "QScriptValue::SpecialValue");
    if (!SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_SPECIALVALUE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_SPECIALVALUE_IDX],
        &Sbk_QScriptValue_Type, "NullValue", (long) QScriptValue::NullValue))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_SPECIALVALUE_IDX],
        &Sbk_QScriptValue_Type, "UndefinedValue", (long) QScriptValue::UndefinedValue))
        return ;
    // End of 'SpecialValue' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QScriptValue >("QScriptValue");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QScriptValue >("QScriptValue*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QScriptValue >(typeid(::QScriptValue).name());
    qRegisterMetaType< ::QScriptValue >("QScriptValue");
    qRegisterMetaType< ::QScriptValue::ResolveFlag >("QScriptValue::ResolveFlag");
    qRegisterMetaType< ::QScriptValue::ResolveFlags >("QScriptValue::ResolveFlags");
    qRegisterMetaType< ::QScriptValue::PropertyFlag >("QScriptValue::PropertyFlag");
    qRegisterMetaType< ::QScriptValue::PropertyFlags >("QScriptValue::PropertyFlags");
    qRegisterMetaType< ::QScriptValue::SpecialValue >("QScriptValue::SpecialValue");
}
