/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtuitools_python.h"

#include "quiloader_wrapper.h"

// Extra includes
#include <QList>
#include "glue/plugins.h"
#include "glue/uitools_loadui.h"
#include <qaction.h>
#include <qactiongroup.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdir.h>
#include <qiodevice.h>
#include <qlayout.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <quiloader.h>
#include <qwidget.h>



// Native ---------------------------------------------------------

QUiLoaderWrapper::QUiLoaderWrapper(QObject * parent) : QUiLoader(parent) {
    // ... middle
}

void QUiLoaderWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QUiLoaderWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QAction * QUiLoaderWrapper::createAction(QObject * parent, const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QAction*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createAction"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QUiLoader::createAction(parent, name);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(parent),
        Shiboken::Converter< ::QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QAction*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAction * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.createAction", Shiboken::SbkType< QAction >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QAction*)0);
    }
    ::QAction * cppResult = Shiboken::Converter< ::QAction * >::toCpp(pyResult);
    return cppResult;
}

QActionGroup * QUiLoaderWrapper::createActionGroup(QObject * parent, const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QActionGroup*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createActionGroup"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QUiLoader::createActionGroup(parent, name);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(parent),
        Shiboken::Converter< ::QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QActionGroup*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QActionGroup * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.createActionGroup", Shiboken::SbkType< QActionGroup >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QActionGroup*)0);
    }
    ::QActionGroup * cppResult = Shiboken::Converter< ::QActionGroup * >::toCpp(pyResult);
    return cppResult;
}

QLayout * QUiLoaderWrapper::createLayout(const QString & className, QObject * parent, const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QLayout*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createLayout"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QUiLoader::createLayout(className, parent, name);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QString >::toPython(className),
        Shiboken::Converter< ::QObject * >::toPython(parent),
        Shiboken::Converter< ::QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QLayout*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayout * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.createLayout", Shiboken::SbkType< QLayout >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QLayout*)0);
    }
    ::QLayout * cppResult = Shiboken::Converter< ::QLayout * >::toCpp(pyResult);
    return cppResult;
}

QWidget * QUiLoaderWrapper::createWidget(const QString & className, QWidget * parent, const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QWidget*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createWidget"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QUiLoader::createWidget(className, parent, name);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QString >::toPython(className),
        Shiboken::Converter< ::QWidget * >::toPython(parent),
        Shiboken::Converter< ::QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QWidget*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QWidget * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.createWidget", Shiboken::SbkType< QWidget >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QWidget*)0);
    }
    ::QWidget * cppResult = Shiboken::Converter< ::QWidget * >::toCpp(pyResult);
    return cppResult;
}

void QUiLoaderWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QUiLoaderWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QUiLoaderWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.event", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QUiLoaderWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.eventFilter", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QUiLoaderWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject* QUiLoaderWrapper::metaObject() const
{
    #if QT_VERSION >= 0x040700
    if (QObject::d_ptr->metaObject) return QObject::d_ptr->metaObject;
    #endif
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return PySide::SignalManager::retriveMetaObject(reinterpret_cast<PyObject*>(pySelf));
}

int QUiLoaderWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QUiLoader::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void* QUiLoaderWrapper::qt_metacast(const char* _clname)
{
        if (!_clname) return 0;
        SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void*>(const_cast< QUiLoaderWrapper* >(this));
        return QUiLoader::qt_metacast(_clname);
}

QUiLoaderWrapper::~QUiLoaderWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUiLoader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QUiLoader >()))
        return -1;

    ::QUiLoaderWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QUiLoader", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QUiLoader(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QUiLoader(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QUiLoader(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoader_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QUiLoader_Init_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader(): got multiple values for keyword argument '%s'", errorArgName);
                return -1;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]) : 0;

        if(!PyErr_Occurred()) {
            // QUiLoader(QObject*)
            void* addr = PySide::nextQObjectMemoryAddr();
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = addr ? new (addr) ::QUiLoaderWrapper(cppArg0) : new ::QUiLoaderWrapper(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QUiLoader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QUiLoader_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QUiLoader_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader", overloads);
        return -1;
}

static PyObject* Sbk_QUiLoaderFunc_addPluginPath(PyObject* self, PyObject* pyArg)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPluginPath(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // addPluginPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_addPluginPath_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // addPluginPath(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->addPluginPath(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_addPluginPath_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtUiTools.QUiLoader.addPluginPath", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_availableLayouts(PyObject* self)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // availableLayouts()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = const_cast<const ::QUiLoader*>(cppSelf)->availableLayouts();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_availableWidgets(PyObject* self)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // availableWidgets()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = const_cast<const ::QUiLoader*>(cppSelf)->availableWidgets();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_clearPluginPaths(PyObject* self)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // clearPluginPaths()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->clearPluginPaths();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUiLoaderFunc_createAction(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createAction(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createAction", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createAction(QObject*,QString)
    if (numArgs == 0) {
        overloadId = 0; // createAction(QObject*,QString)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createAction(QObject*,QString)
        } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 0; // createAction(QObject*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_createAction_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QUiLoaderFunc_createAction_TypeError;
            }
            value = PyDict_GetItemString(kwds, "name");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "name";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QUiLoaderFunc_createAction_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createAction(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QObject * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]) : 0;
        ::QString cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[1]) : QString();

        if(!PyErr_Occurred()) {
            // createAction(QObject*,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QAction * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QUiLoader::createAction(cppArg0, cppArg1) : cppSelf->createAction(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QAction * >::toPython(cppResult);
            Shiboken::Object::setParent(pyArgs[0], pyResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_createAction_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.createAction", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_createActionGroup(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createActionGroup(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createActionGroup", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createActionGroup(QObject*,QString)
    if (numArgs == 0) {
        overloadId = 0; // createActionGroup(QObject*,QString)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createActionGroup(QObject*,QString)
        } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 0; // createActionGroup(QObject*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_createActionGroup_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QUiLoaderFunc_createActionGroup_TypeError;
            }
            value = PyDict_GetItemString(kwds, "name");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "name";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QUiLoaderFunc_createActionGroup_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createActionGroup(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QObject * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]) : 0;
        ::QString cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[1]) : QString();

        if(!PyErr_Occurred()) {
            // createActionGroup(QObject*,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QActionGroup * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QUiLoader::createActionGroup(cppArg0, cppArg1) : cppSelf->createActionGroup(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QActionGroup * >::toPython(cppResult);
            Shiboken::Object::setParent(pyArgs[0], pyResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_createActionGroup_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.createActionGroup", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_createLayout(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createLayout(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createLayout(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createLayout", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createLayout(QString,QObject*,QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createLayout(QString,QObject*,QString)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // createLayout(QString,QObject*,QString)
            } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[2])) {
                overloadId = 0; // createLayout(QString,QObject*,QString)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_createLayout_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QUiLoaderFunc_createLayout_TypeError;
            }
            value = PyDict_GetItemString(kwds, "name");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "name";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QUiLoaderFunc_createLayout_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createLayout(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QObject * cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[1]) : 0;
        ::QString cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[2]) : QString();

        if(!PyErr_Occurred()) {
            // createLayout(QString,QObject*,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QLayout * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QUiLoader::createLayout(cppArg0, cppArg1, cppArg2) : cppSelf->createLayout(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QLayout * >::toPython(cppResult);
            Shiboken::Object::setParent(pyArgs[1], pyResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_createLayout_TypeError:
        const char* overloads[] = {"unicode, PySide.QtCore.QObject = None, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.createLayout", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_createWidget(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createWidget(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createWidget(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createWidget", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createWidget(QString,QWidget*,QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createWidget(QString,QWidget*,QString)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // createWidget(QString,QWidget*,QString)
            } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[2])) {
                overloadId = 0; // createWidget(QString,QWidget*,QString)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_createWidget_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QUiLoaderFunc_createWidget_TypeError;
            }
            value = PyDict_GetItemString(kwds, "name");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "name";
                else if (Shiboken::Converter< ::QString >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QUiLoaderFunc_createWidget_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createWidget(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QWidget * cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[1]) : 0;
        ::QString cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[2]) : QString();

        if(!PyErr_Occurred()) {
            // createWidget(QString,QWidget*,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QWidget * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QUiLoader::createWidget(cppArg0, cppArg1, cppArg2) : cppSelf->createWidget(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
            Shiboken::Object::setParent(pyArgs[1], pyResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_createWidget_TypeError:
        const char* overloads[] = {"unicode, PySide.QtGui.QWidget = None, unicode = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.createWidget", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_isLanguageChangeEnabled(PyObject* self)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isLanguageChangeEnabled()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QUiLoader*>(cppSelf)->isLanguageChangeEnabled();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_isScriptingEnabled(PyObject* self)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isScriptingEnabled()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QUiLoader*>(cppSelf)->isScriptingEnabled();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_isTranslationEnabled(PyObject* self)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isTranslationEnabled()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QUiLoader*>(cppSelf)->isTranslationEnabled();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_load(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.load(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.load(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:load", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: load(QIODevice*,QWidget*)
    // 1: load(QString,QWidget*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // load(QIODevice*,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[1])) {
            overloadId = 0; // load(QIODevice*,QWidget*)
        }
    } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // load(QString,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[1])) {
            overloadId = 1; // load(QString,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_load_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // load(QIODevice*,QWidget*)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parentWidget");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "parentWidget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QUiLoaderFunc_load_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.load(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QIODevice * cppArg0 = Shiboken::Converter< ::QIODevice * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QWidget * cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[1]) : 0;

            if(!PyErr_Occurred()) {
                // load(QIODevice*,QWidget*)
                // Begin code injection

                // Avoid calling the original function: cppSelf->load()
                pyResult = QUiLoadedLoadUiFromDevice(cppSelf, cppArg0, cppArg1);

                // End of code injection



                // Ownership transferences.
                Shiboken::Object::getOwnership(pyResult);
            }
            break;
        }
        case 1: // load(QString,QWidget*)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parentWidget");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "parentWidget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QUiLoaderFunc_load_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.load(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QWidget * cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[1]) : 0;
            SBK_UNUSED(cppArg1)

            if(!PyErr_Occurred()) {
                // load(QString,QWidget*)
                // Begin code injection

                // Avoid calling the original function: cppSelf->load()
                pyResult = QUiLoaderLoadUiFromFileName(cppSelf, cppArg0, cppArg1);

                // End of code injection



                // Ownership transferences.
                Shiboken::Object::getOwnership(pyResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_load_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, PySide.QtGui.QWidget = None", "unicode, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.load", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_pluginPaths(PyObject* self)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // pluginPaths()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = const_cast<const ::QUiLoader*>(cppSelf)->pluginPaths();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_registerCustomWidget(PyObject* self, PyObject* pyArg)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: registerCustomWidget(PyObject*)
    if (PyObject_Check(pyArg)) {
        overloadId = 0; // registerCustomWidget(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_registerCustomWidget_TypeError;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // registerCustomWidget(PyObject*)
            // Begin code injection

            registerCustomWidget(pyArg);
            cppSelf->addPluginPath(""); // force reload widgets

            // End of code injection


        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_registerCustomWidget_TypeError:
        const char* overloads[] = {"object", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtUiTools.QUiLoader.registerCustomWidget", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_setLanguageChangeEnabled(PyObject* self, PyObject* pyArg)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLanguageChangeEnabled(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setLanguageChangeEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_setLanguageChangeEnabled_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLanguageChangeEnabled(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLanguageChangeEnabled(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_setLanguageChangeEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtUiTools.QUiLoader.setLanguageChangeEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_setScriptingEnabled(PyObject* self, PyObject* pyArg)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScriptingEnabled(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setScriptingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_setScriptingEnabled_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setScriptingEnabled(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setScriptingEnabled(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_setScriptingEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtUiTools.QUiLoader.setScriptingEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_setTranslationEnabled(PyObject* self, PyObject* pyArg)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTranslationEnabled(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setTranslationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_setTranslationEnabled_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTranslationEnabled(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTranslationEnabled(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_setTranslationEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtUiTools.QUiLoader.setTranslationEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_setWorkingDirectory(PyObject* self, PyObject* pyArg)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWorkingDirectory(QDir)
    if (Shiboken::Converter< ::QDir >::isConvertible(pyArg)) {
        overloadId = 0; // setWorkingDirectory(QDir)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_setWorkingDirectory_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QDir cppArg0 = Shiboken::Converter< ::QDir >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setWorkingDirectory(QDir)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setWorkingDirectory(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_setWorkingDirectory_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtUiTools.QUiLoader.setWorkingDirectory", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_workingDirectory(PyObject* self)
{
    ::QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QUiLoader* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // workingDirectory()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDir cppResult = const_cast<const ::QUiLoader*>(cppSelf)->workingDirectory();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDir >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QUiLoader_methods[] = {
    {"addPluginPath", (PyCFunction)Sbk_QUiLoaderFunc_addPluginPath, METH_O},
    {"availableLayouts", (PyCFunction)Sbk_QUiLoaderFunc_availableLayouts, METH_NOARGS},
    {"availableWidgets", (PyCFunction)Sbk_QUiLoaderFunc_availableWidgets, METH_NOARGS},
    {"clearPluginPaths", (PyCFunction)Sbk_QUiLoaderFunc_clearPluginPaths, METH_NOARGS},
    {"createAction", (PyCFunction)Sbk_QUiLoaderFunc_createAction, METH_VARARGS|METH_KEYWORDS},
    {"createActionGroup", (PyCFunction)Sbk_QUiLoaderFunc_createActionGroup, METH_VARARGS|METH_KEYWORDS},
    {"createLayout", (PyCFunction)Sbk_QUiLoaderFunc_createLayout, METH_VARARGS|METH_KEYWORDS},
    {"createWidget", (PyCFunction)Sbk_QUiLoaderFunc_createWidget, METH_VARARGS|METH_KEYWORDS},
    {"isLanguageChangeEnabled", (PyCFunction)Sbk_QUiLoaderFunc_isLanguageChangeEnabled, METH_NOARGS},
    {"isScriptingEnabled", (PyCFunction)Sbk_QUiLoaderFunc_isScriptingEnabled, METH_NOARGS},
    {"isTranslationEnabled", (PyCFunction)Sbk_QUiLoaderFunc_isTranslationEnabled, METH_NOARGS},
    {"load", (PyCFunction)Sbk_QUiLoaderFunc_load, METH_VARARGS|METH_KEYWORDS},
    {"pluginPaths", (PyCFunction)Sbk_QUiLoaderFunc_pluginPaths, METH_NOARGS},
    {"registerCustomWidget", (PyCFunction)Sbk_QUiLoaderFunc_registerCustomWidget, METH_O},
    {"setLanguageChangeEnabled", (PyCFunction)Sbk_QUiLoaderFunc_setLanguageChangeEnabled, METH_O},
    {"setScriptingEnabled", (PyCFunction)Sbk_QUiLoaderFunc_setScriptingEnabled, METH_O},
    {"setTranslationEnabled", (PyCFunction)Sbk_QUiLoaderFunc_setTranslationEnabled, METH_O},
    {"setWorkingDirectory", (PyCFunction)Sbk_QUiLoaderFunc_setWorkingDirectory, METH_O},
    {"workingDirectory", (PyCFunction)Sbk_QUiLoaderFunc_workingDirectory, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QUiLoader_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QUiLoader_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QUiLoader_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtUiTools.QUiLoader",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QUiLoader_traverse,
    /*tp_clear*/            Sbk_QUiLoader_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QUiLoader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QUiLoader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QUiLoader_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QUiLoader*>(reinterpret_cast< ::QObject*>(cptr));
    return 0;
}


void init_QUiLoader(PyObject* module)
{
    SbkPySide_QtUiToolsTypes[SBK_QUILOADER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QUiLoader_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QUiLoader", "QUiLoader*",
        &Sbk_QUiLoader_Type, &Shiboken::callCppDestructor< ::QUiLoader >, (SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX])) {
        return;
    }

    // Begin code injection

    Q_IMPORT_PLUGIN(uiplugin);

    // End of code injection

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QUiLoader_Type, &Sbk_QUiLoader_typeDiscovery);

    PySide::Signal::registerSignals(&Sbk_QUiLoader_Type, &::QUiLoader::staticMetaObject);


    Shiboken::TypeResolver::createObjectTypeResolver< ::QUiLoader >("QUiLoader*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QUiLoader >(typeid(::QUiLoader).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QUiLoader >(typeid(::QUiLoaderWrapper).name());
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QUiLoader_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QUiLoader_Type, &::QUiLoader::staticMetaObject, sizeof(::QUiLoader));
}

