/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <pyside.h>
#include "pyside_qtxmlpatterns_python.h"



// Extra includes

void cleanTypesAttributes(void) {
    for (int i = 0, imax = SBK_QtXmlPatterns_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject*>(SbkPySide_QtXmlPatternsTypes[i]);
        if (pyType && PyObject_HasAttrString(pyType, "staticMetaObject"))
            PyObject_SetAttrString(pyType, "staticMetaObject", Py_None);
    }
}
// Global functions ------------------------------------------------------------

static PyMethodDef QtXmlPatterns_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QXmlResultItems(PyObject* module);
void init_QXmlNamePool(PyObject* module);
void init_QAbstractXmlReceiver(PyObject* module);
void init_QXmlSerializer(PyObject* module);
void init_QXmlFormatter(PyObject* module);
void init_QXmlItem(PyObject* module);
void init_QAbstractXmlNodeModel(PyObject* module);
void init_QXmlNodeModelIndex(PyObject* module);
void init_QXmlName(PyObject* module);
void init_QSourceLocation(PyObject* module);
void init_QXmlSchemaValidator(PyObject* module);
void init_QXmlSchema(PyObject* module);
void init_QXmlQuery(PyObject* module);
void init_QAbstractUriResolver(PyObject* module);
void init_QAbstractMessageHandler(PyObject* module);

// Current module's type array.
PyTypeObject** SbkPySide_QtXmlPatternsTypes;
// Required modules' type arrays.
PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

#ifdef IS_PY3K
static int QtXmlPatterns_moduleTraverse(PyObject*, visitproc, void *)
{
    PySide::runCleanupFunctions();
}

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtXmlPatterns",
    /* m_doc      */ 0,
    /* m_size     */ -1,
    /* m_methods  */ QtXmlPatterns_methods,
    /* m_reload   */ 0,
    /* m_traverse */ QtXmlPatterns_moduleTraverse,
    /* m_clear    */ 0,
    /* m_free     */ 0
};

#endif
SBK_MODULE_INIT_FUNCTION_BEGIN(QtXmlPatterns)
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtCore"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject* cppApi[SBK_QtXmlPatterns_IDX_COUNT];
    SbkPySide_QtXmlPatternsTypes = cppApi;

#ifdef IS_PY3K
    PyObject* module = Shiboken::Module::create("QtXmlPatterns", &moduledef);
#else
    PyObject* module = Shiboken::Module::create("QtXmlPatterns", QtXmlPatterns_methods);
#endif

    // Initialize classes in the type system
    init_QXmlResultItems(module);
    init_QXmlNamePool(module);
    init_QAbstractXmlReceiver(module);
    init_QXmlSerializer(module);
    init_QXmlFormatter(module);
    init_QXmlItem(module);
    init_QAbstractXmlNodeModel(module);
    init_QXmlNodeModelIndex(module);
    init_QXmlName(module);
    init_QSourceLocation(module);
    init_QXmlSchemaValidator(module);
    init_QXmlSchema(module);
    init_QXmlQuery(module);
    init_QAbstractUriResolver(module);
    init_QAbstractMessageHandler(module);

    // Register primitive types on TypeResolver

    Shiboken::Module::registerTypes(module, SbkPySide_QtXmlPatternsTypes);

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtXmlPatterns");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);
SBK_MODULE_INIT_FUNCTION_END
