/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_backendinterface_wrapper.h"

// Extra includes
#include <QList>
#include <QSet>
#include <pysideconversions.h>
#include <qbytearray.h>
#include <qobject.h>

using namespace Phonon;

// Native ---------------------------------------------------------

BackendInterfaceWrapper::BackendInterfaceWrapper() : Phonon::BackendInterface() {
    // ... middle
}

QStringList BackendInterfaceWrapper::availableMimeTypes() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QStringList();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "availableMimeTypes"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.availableMimeTypes()' not implemented.");
        return ::QStringList();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.availableMimeTypes", "QStringList", pyResult->ob_type->tp_name);
        return ::QStringList();
    }
    ::QStringList cppResult = Shiboken::Converter< ::QStringList >::toCpp(pyResult);
    return cppResult;
}

bool BackendInterfaceWrapper::connectNodes(QObject * arg__1, QObject * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNodes"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.connectNodes()' not implemented.");
        return ((bool)0);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QObject * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.connectNodes", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

QObject * BackendInterfaceWrapper::createObject(Phonon::BackendInterface::Class c, QObject * parent, const QList<QVariant > & args)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QObject*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createObject"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.createObject()' not implemented.");
        return ((::QObject*)0);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::Phonon::BackendInterface::Class >::toPython(c),
        Shiboken::Converter< ::QObject * >::toPython(parent),
        Shiboken::Converter< ::QList<QVariant > >::toPython(args)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QObject*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QObject * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.createObject", Shiboken::SbkType< QObject >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QObject*)0);
    }
    ::QObject * cppResult = Shiboken::Converter< ::QObject * >::toCpp(pyResult);
    return cppResult;
}

bool BackendInterfaceWrapper::disconnectNodes(QObject * arg__1, QObject * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNodes"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.disconnectNodes()' not implemented.");
        return ((bool)0);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QObject * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.disconnectNodes", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

bool BackendInterfaceWrapper::endConnectionChange(QSet<QObject * > arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "endConnectionChange"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.endConnectionChange()' not implemented.");
        return ((bool)0);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QSet<QObject * > >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.endConnectionChange", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

QList<int > BackendInterfaceWrapper::objectDescriptionIndexes(Phonon::ObjectDescriptionType type) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QList<int >();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "objectDescriptionIndexes"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.objectDescriptionIndexes()' not implemented.");
        return ::QList<int >();
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Phonon::ObjectDescriptionType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QList<int >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<int > >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.objectDescriptionIndexes", "list", pyResult->ob_type->tp_name);
        return ::QList<int >();
    }
    ::QList<int > cppResult = Shiboken::Converter< ::QList<int > >::toCpp(pyResult);
    return cppResult;
}

QHash<QByteArray, QVariant > BackendInterfaceWrapper::objectDescriptionProperties(Phonon::ObjectDescriptionType type, int index) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QHash<QByteArray, QVariant >();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "objectDescriptionProperties"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.objectDescriptionProperties()' not implemented.");
        return ::QHash<QByteArray, QVariant >();
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Converter< ::Phonon::ObjectDescriptionType >::toPython(type),
        index
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QHash<QByteArray, QVariant >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QHash<QByteArray, QVariant > >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.objectDescriptionProperties", "hash", pyResult->ob_type->tp_name);
        return ::QHash<QByteArray, QVariant >();
    }
    ::QHash<QByteArray, QVariant > cppResult = Shiboken::Converter< ::QHash<QByteArray, QVariant > >::toCpp(pyResult);
    return cppResult;
}

bool BackendInterfaceWrapper::startConnectionChange(QSet<QObject * > arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "startConnectionChange"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.startConnectionChange()' not implemented.");
        return ((bool)0);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QSet<QObject * > >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.startConnectionChange", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

BackendInterfaceWrapper::~BackendInterfaceWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Phonon_BackendInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'Phonon::BackendInterface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }

    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Phonon::BackendInterface >()))
        return -1;

    ::BackendInterfaceWrapper* cptr = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // BackendInterface()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = new ::BackendInterfaceWrapper();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Phonon::BackendInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_Phonon_BackendInterfaceFunc_availableMimeTypes(PyObject* self)
{
    ::Phonon::BackendInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::BackendInterface* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // availableMimeTypes()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.availableMimeTypes()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = const_cast<const ::Phonon::BackendInterface*>(cppSelf)->availableMimeTypes();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_BackendInterfaceFunc_connectNodes(PyObject* self, PyObject* args)
{
    ::Phonon::BackendInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::BackendInterface* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "connectNodes", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: connectNodes(QObject*,QObject*)
    if (numArgs == 2
        && Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[1])) {
        overloadId = 0; // connectNodes(QObject*,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_BackendInterfaceFunc_connectNodes_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QObject * cppArg0 = Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QObject * cppArg1 = Shiboken::Converter< ::QObject * >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // connectNodes(QObject*,QObject*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.connectNodes()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->connectNodes(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_BackendInterfaceFunc_connectNodes_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.BackendInterface.connectNodes", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_BackendInterfaceFunc_createObject(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::Phonon::BackendInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::BackendInterface* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.BackendInterface.createObject(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.BackendInterface.createObject(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createObject", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createObject(Phonon::BackendInterface::Class,QObject*,QList<QVariant>)
    if (numArgs >= 2
        && Shiboken::Converter< ::Phonon::BackendInterface::Class >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // createObject(Phonon::BackendInterface::Class,QObject*,QList<QVariant>)
        } else if (Shiboken::Converter< ::QList<QVariant > >::isConvertible(pyArgs[2])) {
            overloadId = 0; // createObject(Phonon::BackendInterface::Class,QObject*,QList<QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_BackendInterfaceFunc_createObject_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "args");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "args";
                else if (Shiboken::Converter< ::QList<QVariant > >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_Phonon_BackendInterfaceFunc_createObject_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.phonon.BackendInterface.createObject(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        Phonon::BackendInterface::Class cppArg0 = Shiboken::Converter< ::Phonon::BackendInterface::Class >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QObject * cppArg1 = Shiboken::Converter< ::QObject * >::toCpp(pyArgs[1]);
        ::QList<QVariant > cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QList<QVariant > >::toCpp(pyArgs[2]) : QList< QVariant >();

        if(!PyErr_Occurred()) {
            // createObject(Phonon::BackendInterface::Class,QObject*,QList<QVariant>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.createObject()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QObject * cppResult = cppSelf->createObject(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_BackendInterfaceFunc_createObject_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::BackendInterface.Class, PySide.QtCore.QObject, list = QList< QVariant >()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.BackendInterface.createObject", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_BackendInterfaceFunc_disconnectNodes(PyObject* self, PyObject* args)
{
    ::Phonon::BackendInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::BackendInterface* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "disconnectNodes", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: disconnectNodes(QObject*,QObject*)
    if (numArgs == 2
        && Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[1])) {
        overloadId = 0; // disconnectNodes(QObject*,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_BackendInterfaceFunc_disconnectNodes_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QObject * cppArg0 = Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QObject * cppArg1 = Shiboken::Converter< ::QObject * >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // disconnectNodes(QObject*,QObject*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.disconnectNodes()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->disconnectNodes(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_BackendInterfaceFunc_disconnectNodes_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.BackendInterface.disconnectNodes", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_BackendInterfaceFunc_endConnectionChange(PyObject* self, PyObject* pyArg)
{
    ::Phonon::BackendInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::BackendInterface* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endConnectionChange(QSet<QObject*>)
    if (Shiboken::Converter< ::QSet<QObject * > >::isConvertible(pyArg)) {
        overloadId = 0; // endConnectionChange(QSet<QObject*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_BackendInterfaceFunc_endConnectionChange_TypeError;

    // Call function/method
    {
        ::QSet<QObject * > cppArg0 = Shiboken::Converter< ::QSet<QObject * > >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // endConnectionChange(QSet<QObject*>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.endConnectionChange()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->endConnectionChange(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_BackendInterfaceFunc_endConnectionChange_TypeError:
        const char* overloads[] = {"QSet", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.phonon.BackendInterface.endConnectionChange", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_BackendInterfaceFunc_objectDescriptionIndexes(PyObject* self, PyObject* pyArg)
{
    ::Phonon::BackendInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::BackendInterface* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
    if (Shiboken::Converter< ::Phonon::ObjectDescriptionType >::isConvertible(pyArg)) {
        overloadId = 0; // objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_BackendInterfaceFunc_objectDescriptionIndexes_TypeError;

    // Call function/method
    {
        Phonon::ObjectDescriptionType cppArg0 = Shiboken::Converter< ::Phonon::ObjectDescriptionType >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.objectDescriptionIndexes()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<int > cppResult = const_cast<const ::Phonon::BackendInterface*>(cppSelf)->objectDescriptionIndexes(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<int > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_BackendInterfaceFunc_objectDescriptionIndexes_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.ObjectDescriptionType", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.phonon.BackendInterface.objectDescriptionIndexes", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_BackendInterfaceFunc_objectDescriptionProperties(PyObject* self, PyObject* args)
{
    ::Phonon::BackendInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::BackendInterface* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "objectDescriptionProperties", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
    if (numArgs == 2
        && Shiboken::Converter< ::Phonon::ObjectDescriptionType >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 0; // objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_BackendInterfaceFunc_objectDescriptionProperties_TypeError;

    // Call function/method
    {
        Phonon::ObjectDescriptionType cppArg0 = Shiboken::Converter< ::Phonon::ObjectDescriptionType >::toCpp(pyArgs[0]);
        int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.objectDescriptionProperties()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QHash<QByteArray, QVariant > cppResult = const_cast<const ::Phonon::BackendInterface*>(cppSelf)->objectDescriptionProperties(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QHash<QByteArray, QVariant > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_BackendInterfaceFunc_objectDescriptionProperties_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.ObjectDescriptionType, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.BackendInterface.objectDescriptionProperties", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_BackendInterfaceFunc_startConnectionChange(PyObject* self, PyObject* pyArg)
{
    ::Phonon::BackendInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::BackendInterface* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startConnectionChange(QSet<QObject*>)
    if (Shiboken::Converter< ::QSet<QObject * > >::isConvertible(pyArg)) {
        overloadId = 0; // startConnectionChange(QSet<QObject*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_BackendInterfaceFunc_startConnectionChange_TypeError;

    // Call function/method
    {
        ::QSet<QObject * > cppArg0 = Shiboken::Converter< ::QSet<QObject * > >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // startConnectionChange(QSet<QObject*>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.startConnectionChange()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->startConnectionChange(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_BackendInterfaceFunc_startConnectionChange_TypeError:
        const char* overloads[] = {"QSet", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.phonon.BackendInterface.startConnectionChange", overloads);
        return 0;
}

static PyMethodDef Sbk_Phonon_BackendInterface_methods[] = {
    {"availableMimeTypes", (PyCFunction)Sbk_Phonon_BackendInterfaceFunc_availableMimeTypes, METH_NOARGS},
    {"connectNodes", (PyCFunction)Sbk_Phonon_BackendInterfaceFunc_connectNodes, METH_VARARGS},
    {"createObject", (PyCFunction)Sbk_Phonon_BackendInterfaceFunc_createObject, METH_VARARGS|METH_KEYWORDS},
    {"disconnectNodes", (PyCFunction)Sbk_Phonon_BackendInterfaceFunc_disconnectNodes, METH_VARARGS},
    {"endConnectionChange", (PyCFunction)Sbk_Phonon_BackendInterfaceFunc_endConnectionChange, METH_O},
    {"objectDescriptionIndexes", (PyCFunction)Sbk_Phonon_BackendInterfaceFunc_objectDescriptionIndexes, METH_O},
    {"objectDescriptionProperties", (PyCFunction)Sbk_Phonon_BackendInterfaceFunc_objectDescriptionProperties, METH_VARARGS},
    {"startConnectionChange", (PyCFunction)Sbk_Phonon_BackendInterfaceFunc_startConnectionChange, METH_O},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_Phonon_BackendInterface_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_Phonon_BackendInterface_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_BackendInterface_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.phonon.Phonon.BackendInterface",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_Phonon_BackendInterface_traverse,
    /*tp_clear*/            Sbk_Phonon_BackendInterface_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_BackendInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_Phonon_BackendInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_Phonon_BackendInterface(PyObject* enclosingClass)
{
    SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_BackendInterface_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(enclosingClass, "BackendInterface", "Phonon::BackendInterface*",
        &Sbk_Phonon_BackendInterface_Type, &Shiboken::callCppDestructor< ::Phonon::BackendInterface >, 0, 0, true)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'Class'.
    SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_BackendInterface_Type,
        "Class",
        "PySide.phonon.Phonon.BackendInterface.Class",
        "Phonon::BackendInterface::Class");
    if (!SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX],
        &Sbk_Phonon_BackendInterface_Type, "MediaObjectClass", (long) Phonon::BackendInterface::MediaObjectClass))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX],
        &Sbk_Phonon_BackendInterface_Type, "VolumeFaderEffectClass", (long) Phonon::BackendInterface::VolumeFaderEffectClass))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX],
        &Sbk_Phonon_BackendInterface_Type, "AudioOutputClass", (long) Phonon::BackendInterface::AudioOutputClass))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX],
        &Sbk_Phonon_BackendInterface_Type, "AudioDataOutputClass", (long) Phonon::BackendInterface::AudioDataOutputClass))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX],
        &Sbk_Phonon_BackendInterface_Type, "VisualizationClass", (long) Phonon::BackendInterface::VisualizationClass))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX],
        &Sbk_Phonon_BackendInterface_Type, "VideoDataOutputClass", (long) Phonon::BackendInterface::VideoDataOutputClass))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX],
        &Sbk_Phonon_BackendInterface_Type, "EffectClass", (long) Phonon::BackendInterface::EffectClass))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX],
        &Sbk_Phonon_BackendInterface_Type, "VideoWidgetClass", (long) Phonon::BackendInterface::VideoWidgetClass))
        return ;
    // End of 'Class' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::Phonon::BackendInterface >("Phonon::BackendInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::Phonon::BackendInterface >("Phonon::BackendInterface$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::Phonon::BackendInterface >(typeid(::Phonon::BackendInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::Phonon::BackendInterface >(typeid(::BackendInterfaceWrapper).name());
    qRegisterMetaType< ::Phonon::BackendInterface::Class >("BackendInterface::Class");
    qRegisterMetaType< ::Phonon::BackendInterface::Class >("Phonon::BackendInterface::Class");
}
