/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_wrapper.h"
#include "phonon_backendcapabilities_wrapper.h"
#include "phonon_audiochanneldescription_wrapper.h"
#include "phonon_audiooutputdevice_wrapper.h"
#include "phonon_audiocapturedevice_wrapper.h"
#include "phonon_subtitledescription_wrapper.h"
#include "phonon_effectdescriptionmodel_wrapper.h"
#include "phonon_videocapturedevice_wrapper.h"
#include "phonon_effectdescription_wrapper.h"
#include "phonon_audiooutputdevicemodel_wrapper.h"
#include "phonon_volumeslider_wrapper.h"
#include "phonon_volumefaderinterface_wrapper.h"
#include "phonon_videowidgetinterface_wrapper.h"
#include "phonon_videoplayer_wrapper.h"
#include "phonon_streaminterface_wrapper.h"
#include "phonon_seekslider_wrapper.h"
#include "phonon_platformplugin_wrapper.h"
#include "phonon_mediaobjectinterface_wrapper.h"
#include "phonon_mediasource_wrapper.h"
#include "phonon_mediacontroller_wrapper.h"
#include "phonon_effectwidget_wrapper.h"
#include "phonon_effectparameter_wrapper.h"
#include "phonon_effectinterface_wrapper.h"
#include "phonon_backendinterface_wrapper.h"
#include "phonon_addoninterface_wrapper.h"
#include "phonon_abstractmediastream_wrapper.h"
#include "phonon_medianode_wrapper.h"
#include "phonon_mediaobject_wrapper.h"
#include "phonon_effect_wrapper.h"
#include "phonon_volumefadereffect_wrapper.h"
#include "phonon_abstractvideooutput_wrapper.h"
#include "phonon_videowidget_wrapper.h"
#include "phonon_abstractaudiooutput_wrapper.h"
#include "phonon_audiooutput_wrapper.h"
#include "phonon_path_wrapper.h"

// Extra includes
#include <effectparameter.h>
#include <medianode.h>
#include <mediaobject.h>
#include <mediasource.h>
#include <path.h>
#include <phononnamespace.h>



// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_PhononFunc_categoryToString(PyObject* self, PyObject* pyArg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: categoryToString(Phonon::CaptureCategory)
    // 1: categoryToString(Phonon::Category)
    if (Shiboken::Converter< ::Phonon::Category >::isConvertible(pyArg)) {
        overloadId = 1; // categoryToString(Phonon::Category)
    } else if (Shiboken::Converter< ::Phonon::CaptureCategory >::isConvertible(pyArg)) {
        overloadId = 0; // categoryToString(Phonon::CaptureCategory)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_PhononFunc_categoryToString_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // categoryToString(Phonon::CaptureCategory)
        {
            Phonon::CaptureCategory cppArg0 = Shiboken::Converter< ::Phonon::CaptureCategory >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // categoryToString(Phonon::CaptureCategory)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = Phonon::categoryToString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
            }
            break;
        }
        case 1: // categoryToString(Phonon::Category)
        {
            Phonon::Category cppArg0 = Shiboken::Converter< ::Phonon::Category >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // categoryToString(Phonon::Category)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = Phonon::categoryToString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_PhononFunc_categoryToString_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.CaptureCategory", "PySide.phonon.Phonon.Category", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.phonon.Phonon.categoryToString", overloads);
        return 0;
}

static PyObject* Sbk_PhononFunc_createPath(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createPath", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createPath(Phonon::MediaNode*,Phonon::MediaNode*)
    if (numArgs == 2
        && Shiboken::Converter< ::Phonon::MediaNode * >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::Phonon::MediaNode * >::isConvertible(pyArgs[1])) {
        overloadId = 0; // createPath(Phonon::MediaNode*,Phonon::MediaNode*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_PhononFunc_createPath_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::Phonon::MediaNode * cppArg0 = Shiboken::Converter< ::Phonon::MediaNode * >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::Phonon::MediaNode * cppArg1 = Shiboken::Converter< ::Phonon::MediaNode * >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // createPath(Phonon::MediaNode*,Phonon::MediaNode*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Phonon::Path cppResult = Phonon::createPath(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Phonon::Path >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_PhononFunc_createPath_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaNode, PySide.phonon.Phonon::MediaNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.Phonon.createPath", overloads);
        return 0;
}

static PyObject* Sbk_PhononFunc_createPlayer(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.Phonon.createPlayer(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.Phonon.createPlayer(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createPlayer", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createPlayer(Phonon::Category,Phonon::MediaSource)
    if (Shiboken::Converter< ::Phonon::Category >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createPlayer(Phonon::Category,Phonon::MediaSource)
        } else if (Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(pyArgs[1])) {
            overloadId = 0; // createPlayer(Phonon::Category,Phonon::MediaSource)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_PhononFunc_createPlayer_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "source");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "source";
                else if (Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_PhononFunc_createPlayer_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.phonon.Phonon.createPlayer(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        Phonon::Category cppArg0 = Shiboken::Converter< ::Phonon::Category >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        Phonon::MediaSource cppArg1_tmp = Phonon::MediaSource();
        ::Phonon::MediaSource cppArg1 = pyArgs[1] ? Shiboken::Converter< ::Phonon::MediaSource >::toCpp(pyArgs[1]) : cppArg1_tmp;

        if(!PyErr_Occurred()) {
            // createPlayer(Phonon::Category,Phonon::MediaSource)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Phonon::MediaObject * cppResult = Phonon::createPlayer(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Phonon::MediaObject * >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_PhononFunc_createPlayer_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.Category, PySide.phonon.Phonon::MediaSource = Phonon.MediaSource()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.Phonon.createPlayer", overloads);
        return 0;
}

static PyObject* Sbk_PhononFunc_phononVersion(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // phononVersion()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const char * cppResult = Phonon::phononVersion();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< const char * >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_PhononFunc_qHash(PyObject* self, PyObject* pyArg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qHash(Phonon::EffectParameter)
    if (Shiboken::Converter< ::Phonon::EffectParameter >::isConvertible(pyArg)) {
        overloadId = 0; // qHash(Phonon::EffectParameter)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_PhononFunc_qHash_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::Phonon::EffectParameter cppArg0 = Shiboken::Converter< ::Phonon::EffectParameter >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // qHash(Phonon::EffectParameter)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            uint cppResult = Phonon::qHash(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_PhononFunc_qHash_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::EffectParameter", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.phonon.Phonon.qHash", overloads);
        return 0;
}

static PyObject* Sbk_PhononFunc_registerMetaTypes(PyObject* self)
{

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // registerMetaTypes()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Phonon::registerMetaTypes();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_Phonon_methods[] = {
    {"categoryToString", (PyCFunction)Sbk_PhononFunc_categoryToString, METH_O|METH_STATIC},
    {"createPath", (PyCFunction)Sbk_PhononFunc_createPath, METH_VARARGS|METH_STATIC},
    {"createPlayer", (PyCFunction)Sbk_PhononFunc_createPlayer, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"phononVersion", (PyCFunction)Sbk_PhononFunc_phononVersion, METH_NOARGS|METH_STATIC},
    {"qHash", (PyCFunction)Sbk_PhononFunc_qHash, METH_O|METH_STATIC},
    {"registerMetaTypes", (PyCFunction)Sbk_PhononFunc_registerMetaTypes, METH_NOARGS|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_Phonon_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_Phonon_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.phonon.Phonon",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_Phonon_traverse,
    /*tp_clear*/            Sbk_Phonon_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_Phonon(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "Phonon", "Phonon",
        &Sbk_Phonon_Type)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'DiscType'.
    SbkPySide_phononTypes[SBK_PHONON_DISCTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_Type,
        "DiscType",
        "PySide.phonon.Phonon.DiscType",
        "Phonon::DiscType");
    if (!SbkPySide_phononTypes[SBK_PHONON_DISCTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_DISCTYPE_IDX],
        &Sbk_Phonon_Type, "NoDisc", (long) Phonon::NoDisc))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_DISCTYPE_IDX],
        &Sbk_Phonon_Type, "Cd", (long) Phonon::Cd))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_DISCTYPE_IDX],
        &Sbk_Phonon_Type, "Dvd", (long) Phonon::Dvd))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_DISCTYPE_IDX],
        &Sbk_Phonon_Type, "Vcd", (long) Phonon::Vcd))
        return ;
    // End of 'DiscType' enum.

    // Initialization of enum 'MetaData'.
    SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_Type,
        "MetaData",
        "PySide.phonon.Phonon.MetaData",
        "Phonon::MetaData");
    if (!SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX],
        &Sbk_Phonon_Type, "ArtistMetaData", (long) Phonon::ArtistMetaData))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX],
        &Sbk_Phonon_Type, "AlbumMetaData", (long) Phonon::AlbumMetaData))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX],
        &Sbk_Phonon_Type, "TitleMetaData", (long) Phonon::TitleMetaData))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX],
        &Sbk_Phonon_Type, "DateMetaData", (long) Phonon::DateMetaData))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX],
        &Sbk_Phonon_Type, "GenreMetaData", (long) Phonon::GenreMetaData))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX],
        &Sbk_Phonon_Type, "TracknumberMetaData", (long) Phonon::TracknumberMetaData))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX],
        &Sbk_Phonon_Type, "DescriptionMetaData", (long) Phonon::DescriptionMetaData))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX],
        &Sbk_Phonon_Type, "MusicBrainzDiscIdMetaData", (long) Phonon::MusicBrainzDiscIdMetaData))
        return ;
    // End of 'MetaData' enum.

    // Initialization of enum 'Category'.
    SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_Type,
        "Category",
        "PySide.phonon.Phonon.Category",
        "Phonon::Category");
    if (!SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX],
        &Sbk_Phonon_Type, "NoCategory", (long) Phonon::NoCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX],
        &Sbk_Phonon_Type, "NotificationCategory", (long) Phonon::NotificationCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX],
        &Sbk_Phonon_Type, "MusicCategory", (long) Phonon::MusicCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX],
        &Sbk_Phonon_Type, "VideoCategory", (long) Phonon::VideoCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX],
        &Sbk_Phonon_Type, "CommunicationCategory", (long) Phonon::CommunicationCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX],
        &Sbk_Phonon_Type, "GameCategory", (long) Phonon::GameCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX],
        &Sbk_Phonon_Type, "AccessibilityCategory", (long) Phonon::AccessibilityCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX],
        &Sbk_Phonon_Type, "LastCategory", (long) Phonon::LastCategory))
        return ;
    // End of 'Category' enum.

    // Initialization of enum 'ObjectDescriptionType'.
    SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_Type,
        "ObjectDescriptionType",
        "PySide.phonon.Phonon.ObjectDescriptionType",
        "Phonon::ObjectDescriptionType");
    if (!SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX],
        &Sbk_Phonon_Type, "AudioOutputDeviceType", (long) Phonon::AudioOutputDeviceType))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX],
        &Sbk_Phonon_Type, "EffectType", (long) Phonon::EffectType))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX],
        &Sbk_Phonon_Type, "AudioChannelType", (long) Phonon::AudioChannelType))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX],
        &Sbk_Phonon_Type, "SubtitleType", (long) Phonon::SubtitleType))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX],
        &Sbk_Phonon_Type, "AudioCaptureDeviceType", (long) Phonon::AudioCaptureDeviceType))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX],
        &Sbk_Phonon_Type, "VideoCaptureDeviceType", (long) Phonon::VideoCaptureDeviceType))
        return ;
    // End of 'ObjectDescriptionType' enum.

    // Initialization of enum 'State'.
    SbkPySide_phononTypes[SBK_PHONON_STATE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_Type,
        "State",
        "PySide.phonon.Phonon.State",
        "Phonon::State");
    if (!SbkPySide_phononTypes[SBK_PHONON_STATE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_STATE_IDX],
        &Sbk_Phonon_Type, "LoadingState", (long) Phonon::LoadingState))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_STATE_IDX],
        &Sbk_Phonon_Type, "StoppedState", (long) Phonon::StoppedState))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_STATE_IDX],
        &Sbk_Phonon_Type, "PlayingState", (long) Phonon::PlayingState))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_STATE_IDX],
        &Sbk_Phonon_Type, "BufferingState", (long) Phonon::BufferingState))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_STATE_IDX],
        &Sbk_Phonon_Type, "PausedState", (long) Phonon::PausedState))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_STATE_IDX],
        &Sbk_Phonon_Type, "ErrorState", (long) Phonon::ErrorState))
        return ;
    // End of 'State' enum.

    // Initialization of enum 'CaptureCategory'.
    SbkPySide_phononTypes[SBK_PHONON_CAPTURECATEGORY_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_Type,
        "CaptureCategory",
        "PySide.phonon.Phonon.CaptureCategory",
        "Phonon::CaptureCategory");
    if (!SbkPySide_phononTypes[SBK_PHONON_CAPTURECATEGORY_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CAPTURECATEGORY_IDX],
        &Sbk_Phonon_Type, "NoCaptureCategory", (long) Phonon::NoCaptureCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CAPTURECATEGORY_IDX],
        &Sbk_Phonon_Type, "CommunicationCaptureCategory", (long) Phonon::CommunicationCaptureCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CAPTURECATEGORY_IDX],
        &Sbk_Phonon_Type, "RecordingCaptureCategory", (long) Phonon::RecordingCaptureCategory))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_CAPTURECATEGORY_IDX],
        &Sbk_Phonon_Type, "ControlCaptureCategory", (long) Phonon::ControlCaptureCategory))
        return ;
    // End of 'CaptureCategory' enum.

    // Initialization of enum 'ErrorType'.
    SbkPySide_phononTypes[SBK_PHONON_ERRORTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_Type,
        "ErrorType",
        "PySide.phonon.Phonon.ErrorType",
        "Phonon::ErrorType");
    if (!SbkPySide_phononTypes[SBK_PHONON_ERRORTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_ERRORTYPE_IDX],
        &Sbk_Phonon_Type, "NoError", (long) Phonon::NoError))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_ERRORTYPE_IDX],
        &Sbk_Phonon_Type, "NormalError", (long) Phonon::NormalError))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_ERRORTYPE_IDX],
        &Sbk_Phonon_Type, "FatalError", (long) Phonon::FatalError))
        return ;
    // End of 'ErrorType' enum.


    qRegisterMetaType< ::Phonon::DiscType >("Phonon::DiscType");
    qRegisterMetaType< ::Phonon::MetaData >("Phonon::MetaData");
    qRegisterMetaType< ::Phonon::Category >("Phonon::Category");
    qRegisterMetaType< ::Phonon::ObjectDescriptionType >("Phonon::ObjectDescriptionType");
    qRegisterMetaType< ::Phonon::State >("Phonon::State");
    qRegisterMetaType< ::Phonon::CaptureCategory >("Phonon::CaptureCategory");
    qRegisterMetaType< ::Phonon::ErrorType >("Phonon::ErrorType");
}
