/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qtextedit_wrapper.h"
#include "qtextedit_extraselection_wrapper.h"

// Extra includes
#include <QList>
#include <QTextCursor>
#include <QTextEdit>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcolor.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmenu.h>
#include <qmimedata.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qprinter.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qtextcursor.h>
#include <qtextdocument.h>
#include <qtextedit.h>
#include <qtextformat.h>
#include <qurl.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QTextEditWrapper::QTextEditWrapper(QWidget * parent) : QTextEdit(parent) {
    // ... middle
}

QTextEditWrapper::QTextEditWrapper(const QString & text, QWidget * parent) : QTextEdit(text, parent) {
    // ... middle
}

void QTextEditWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

bool QTextEditWrapper::canInsertFromMimeData(const QMimeData * source) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "canInsertFromMimeData"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::canInsertFromMimeData(source);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMimeData * >::toPython(source)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.canInsertFromMimeData", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::changeEvent(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::changeEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTextEditWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTextEditWrapper::contextMenuEvent(QContextMenuEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::contextMenuEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

QMimeData * QTextEditWrapper::createMimeDataFromSelection() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QMimeData*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createMimeDataFromSelection"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::createMimeDataFromSelection();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QMimeData*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QMimeData * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.createMimeDataFromSelection", Shiboken::SbkType< QMimeData >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QMimeData*)0);
    }
    ::QMimeData * cppResult = Shiboken::Converter< ::QMimeData * >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QTextEditWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((int)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((int)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.devType", "int", pyResult->ob_type->tp_name);
        return ((int)0);
    }
    int cppResult = Shiboken::Converter< int >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTextEditWrapper::dragEnterEvent(QDragEnterEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::dragEnterEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::dragLeaveEvent(QDragLeaveEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::dragLeaveEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::dragMoveEvent(QDragMoveEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::dragMoveEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::dropEvent(QDropEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::dropEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

bool QTextEditWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::event(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.event", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

bool QTextEditWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.eventFilter", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::focusInEvent(QFocusEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::focusInEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

bool QTextEditWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::focusOutEvent(QFocusEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::focusOutEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

int QTextEditWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((int)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((int)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.heightForWidth", "int", pyResult->ob_type->tp_name);
        return ((int)0);
    }
    int cppResult = Shiboken::Converter< int >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::inputMethodEvent(QInputMethodEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::inputMethodEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

QVariant QTextEditWrapper::inputMethodQuery(Qt::InputMethodQuery property) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QVariant();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::inputMethodQuery(property);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(property)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QVariant();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult = Shiboken::Converter< ::QVariant >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::insertFromMimeData(const QMimeData * source)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "insertFromMimeData"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::insertFromMimeData(source);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMimeData * >::toPython(source)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTextEditWrapper::keyPressEvent(QKeyEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::keyPressEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::keyReleaseEvent(QKeyEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::keyReleaseEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTextEditWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

QVariant QTextEditWrapper::loadResource(int type, const QUrl & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QVariant();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "loadResource"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::loadResource(type, name);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        type,
        Shiboken::Converter< ::QUrl >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QVariant();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.loadResource", "QVariant", pyResult->ob_type->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult = Shiboken::Converter< ::QVariant >::toCpp(pyResult);
    return cppResult;
}

int QTextEditWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((int)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((int)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.metric", "int", pyResult->ob_type->tp_name);
        return ((int)0);
    }
    int cppResult = Shiboken::Converter< int >::toCpp(pyResult);
    return cppResult;
}

QSize QTextEditWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QSize();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.minimumSizeHint", Shiboken::SbkType< QSize >()->tp_name, pyResult->ob_type->tp_name);
        return ::QSize();
    }
    QSize cppResult = Shiboken::Converter< ::QSize >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::mouseDoubleClickEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::mouseDoubleClickEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::mouseMoveEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::mouseMoveEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::mousePressEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::mousePressEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::mouseReleaseEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::mouseReleaseEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

QPaintEngine * QTextEditWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QPaintEngine*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QPaintEngine*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.paintEngine", Shiboken::SbkType< QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QPaintEngine*)0);
    }
    ::QPaintEngine * cppResult = Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::paintEvent(QPaintEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::paintEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::resizeEvent(QResizeEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::resizeEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTextEditWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTextEditWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

QSize QTextEditWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QSize();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::sizeHint();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.sizeHint", Shiboken::SbkType< QSize >()->tp_name, pyResult->ob_type->tp_name);
        return ::QSize();
    }
    QSize cppResult = Shiboken::Converter< ::QSize >::toCpp(pyResult);
    return cppResult;
}

void QTextEditWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QTextEditWrapper::timerEvent(QTimerEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::timerEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QTextEditWrapper::viewportEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "viewportEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::viewportEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

void QTextEditWrapper::wheelEvent(QWheelEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QTextEdit::wheelEvent(e);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(e)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject* QTextEditWrapper::metaObject() const
{
    #if QT_VERSION >= 0x040700
    if (QObject::d_ptr->metaObject) return QObject::d_ptr->metaObject;
    #endif
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return PySide::SignalManager::retriveMetaObject(reinterpret_cast<PyObject*>(pySelf));
}

int QTextEditWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTextEdit::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void* QTextEditWrapper::qt_metacast(const char* _clname)
{
        if (!_clname) return 0;
        SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void*>(const_cast< QTextEditWrapper* >(this));
        return QTextEdit::qt_metacast(_clname);
}

QTextEditWrapper::~QTextEditWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextEdit_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextEdit >()))
        return -1;

    ::QTextEditWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QTextEdit", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QTextEdit(QWidget*)
    // 1: QTextEdit(QString,QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QTextEdit(QWidget*)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QTextEdit(QWidget*)
    } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTextEdit(QString,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[1])) {
            overloadId = 1; // QTextEdit(QString,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEdit_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextEdit(QWidget*)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyArgs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyArgs[0] = value;
                    else
                        goto Sbk_QTextEdit_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QTextEdit(QWidget*)
                void* addr = PySide::nextQObjectMemoryAddr();
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = addr ? new (addr) ::QTextEditWrapper(cppArg0) : new ::QTextEditWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QTextEdit(QString,QWidget*)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QTextEdit_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget * cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[1]) : 0;

            if(!PyErr_Occurred()) {
                // QTextEdit(QString,QWidget*)
                void* addr = PySide::nextQObjectMemoryAddr();
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = addr ? new (addr) ::QTextEditWrapper(cppArg0, cppArg1) : new ::QTextEditWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextEdit >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextEdit_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QTextEdit_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", "unicode, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit", overloads);
        return -1;
}

static PyObject* Sbk_QTextEditFunc_acceptRichText(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // acceptRichText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextEdit*>(cppSelf)->acceptRichText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_alignment(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // alignment()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFlags<Qt::AlignmentFlag> cppResult = const_cast<const ::QTextEdit*>(cppSelf)->alignment();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_anchorAt(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: anchorAt(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // anchorAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_anchorAt_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // anchorAt(QPoint)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QTextEdit*>(cppSelf)->anchorAt(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_anchorAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.anchorAt", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_append(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // append(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_append_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // append(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->append(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_append_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.append", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_autoFormatting(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // autoFormatting()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFlags<QTextEdit::AutoFormattingFlag> cppResult = const_cast<const ::QTextEdit*>(cppSelf)->autoFormatting();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFlags<QTextEdit::AutoFormattingFlag> >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_canInsertFromMimeData(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: canInsertFromMimeData(const QMimeData*)const
    if (Shiboken::Converter< ::QMimeData * >::isConvertible(pyArg)) {
        overloadId = 0; // canInsertFromMimeData(const QMimeData*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_canInsertFromMimeData_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QMimeData * cppArg0 = Shiboken::Converter< ::QMimeData * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // canInsertFromMimeData(const QMimeData*)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QTextEdit*>(cppSelf)->::QTextEdit::canInsertFromMimeData(cppArg0) : const_cast<const ::QTextEdit*>(cppSelf)->canInsertFromMimeData(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_canInsertFromMimeData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMimeData", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.canInsertFromMimeData", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_canPaste(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // canPaste()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextEdit*>(cppSelf)->canPaste();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_changeEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeEvent(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_changeEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QEvent * cppArg0 = Shiboken::Converter< ::QEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // changeEvent(QEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::changeEvent(cppArg0) : cppSelf->changeEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_changeEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.changeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_clear(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // clear()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->clear();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextEditFunc_contextMenuEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter< ::QContextMenuEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QContextMenuEvent * cppArg0 = Shiboken::Converter< ::QContextMenuEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // contextMenuEvent(QContextMenuEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::contextMenuEvent(cppArg0) : cppSelf->contextMenuEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.contextMenuEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_copy(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // copy()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->copy();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextEditFunc_createMimeDataFromSelection(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // createMimeDataFromSelection()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QMimeData * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QTextEdit*>(cppSelf)->::QTextEdit::createMimeDataFromSelection() : const_cast<const ::QTextEdit*>(cppSelf)->createMimeDataFromSelection();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QMimeData * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_createStandardContextMenu(PyObject* self, PyObject* args)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createStandardContextMenu", 0, 1, &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: createStandardContextMenu()
    // 1: createStandardContextMenu(QPoint)
    if (numArgs == 0) {
        overloadId = 0; // createStandardContextMenu()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])) {
        overloadId = 1; // createStandardContextMenu(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_createStandardContextMenu_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // createStandardContextMenu()
        {

            if(!PyErr_Occurred()) {
                // createStandardContextMenu()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMenu * cppResult = cppSelf->createStandardContextMenu();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMenu * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // createStandardContextMenu(QPoint)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // createStandardContextMenu(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMenu * cppResult = cppSelf->createStandardContextMenu(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMenu * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_createStandardContextMenu_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.createStandardContextMenu", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_currentCharFormat(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // currentCharFormat()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextCharFormat cppResult = const_cast<const ::QTextEdit*>(cppSelf)->currentCharFormat();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextCharFormat >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_currentFont(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // currentFont()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFont cppResult = const_cast<const ::QTextEdit*>(cppSelf)->currentFont();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_cursorForPosition(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cursorForPosition(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // cursorForPosition(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_cursorForPosition_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // cursorForPosition(QPoint)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextCursor cppResult = const_cast<const ::QTextEdit*>(cppSelf)->cursorForPosition(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextCursor >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_cursorForPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.cursorForPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_cursorRect(PyObject* self, PyObject* args)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "cursorRect", 0, 1, &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: cursorRect()const
    // 1: cursorRect(QTextCursor)const
    if (numArgs == 0) {
        overloadId = 0; // cursorRect()const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QTextCursor >::isConvertible(pyArgs[0])) {
        overloadId = 1; // cursorRect(QTextCursor)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_cursorRect_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // cursorRect()const
        {

            if(!PyErr_Occurred()) {
                // cursorRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const ::QTextEdit*>(cppSelf)->cursorRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
            break;
        }
        case 1: // cursorRect(QTextCursor)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QTextCursor cppArg0 = Shiboken::Converter< ::QTextCursor >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // cursorRect(QTextCursor)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const ::QTextEdit*>(cppSelf)->cursorRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_cursorRect_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.cursorRect", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_cursorWidth(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // cursorWidth()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QTextEdit*>(cppSelf)->cursorWidth();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_cut(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // cut()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->cut();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextEditFunc_document(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // document()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextDocument * cppResult = const_cast<const ::QTextEdit*>(cppSelf)->document();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextDocument * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_documentTitle(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // documentTitle()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QTextEdit*>(cppSelf)->documentTitle();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_dragEnterEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QDragEnterEvent*)
    if (Shiboken::Converter< ::QDragEnterEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QDragEnterEvent * cppArg0 = Shiboken::Converter< ::QDragEnterEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // dragEnterEvent(QDragEnterEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::dragEnterEvent(cppArg0) : cppSelf->dragEnterEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragEnterEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.dragEnterEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_dragLeaveEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QDragLeaveEvent*)
    if (Shiboken::Converter< ::QDragLeaveEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QDragLeaveEvent * cppArg0 = Shiboken::Converter< ::QDragLeaveEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // dragLeaveEvent(QDragLeaveEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::dragLeaveEvent(cppArg0) : cppSelf->dragLeaveEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragLeaveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_dragMoveEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QDragMoveEvent*)
    if (Shiboken::Converter< ::QDragMoveEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QDragMoveEvent * cppArg0 = Shiboken::Converter< ::QDragMoveEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // dragMoveEvent(QDragMoveEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::dragMoveEvent(cppArg0) : cppSelf->dragMoveEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.dragMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_dropEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter< ::QDropEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_dropEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QDropEvent * cppArg0 = Shiboken::Converter< ::QDropEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // dropEvent(QDropEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::dropEvent(cppArg0) : cppSelf->dropEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.dropEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_ensureCursorVisible(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // ensureCursorVisible()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->ensureCursorVisible();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextEditFunc_event(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_event_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QEvent * cppArg0 = Shiboken::Converter< ::QEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // event(QEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::event(cppArg0) : cppSelf->event(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.event", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_extraSelections(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // extraSelections()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QTextEdit::ExtraSelection > cppResult = const_cast<const ::QTextEdit*>(cppSelf)->extraSelections();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QTextEdit::ExtraSelection > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_find(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.find(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.find(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:find", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: find(QString,QFlags<QTextDocument::FindFlag>)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // find(QString,QFlags<QTextDocument::FindFlag>)
        } else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(pyArgs[1])) {
            overloadId = 0; // find(QString,QFlags<QTextDocument::FindFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_find_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "options");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "options";
                else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QTextEditFunc_find_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.find(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        QFlags<QTextDocument::FindFlag> cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::toCpp(pyArgs[1]) : QFlags<QTextDocument::FindFlag>(0);

        if(!PyErr_Occurred()) {
            // find(QString,QFlags<QTextDocument::FindFlag>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->find(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_find_TypeError:
        const char* overloads[] = {"unicode, PySide.QtGui.QTextDocument.FindFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.find", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_focusInEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter< ::QFocusEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_focusInEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QFocusEvent * cppArg0 = Shiboken::Converter< ::QFocusEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // focusInEvent(QFocusEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::focusInEvent(cppArg0) : cppSelf->focusInEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.focusInEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_focusNextPrevChild(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // focusNextPrevChild(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::focusNextPrevChild(cppArg0) : cppSelf->focusNextPrevChild(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_focusOutEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter< ::QFocusEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QFocusEvent * cppArg0 = Shiboken::Converter< ::QFocusEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // focusOutEvent(QFocusEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::focusOutEvent(cppArg0) : cppSelf->focusOutEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.focusOutEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_fontFamily(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // fontFamily()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QTextEdit*>(cppSelf)->fontFamily();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_fontItalic(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // fontItalic()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextEdit*>(cppSelf)->fontItalic();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_fontPointSize(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // fontPointSize()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTextEdit*>(cppSelf)->fontPointSize();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_fontUnderline(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // fontUnderline()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextEdit*>(cppSelf)->fontUnderline();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_fontWeight(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // fontWeight()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QTextEdit*>(cppSelf)->fontWeight();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_inputMethodEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter< ::QInputMethodEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QInputMethodEvent * cppArg0 = Shiboken::Converter< ::QInputMethodEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // inputMethodEvent(QInputMethodEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::inputMethodEvent(cppArg0) : cppSelf->inputMethodEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.inputMethodEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_inputMethodQuery(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter< ::Qt::InputMethodQuery >::isConvertible(pyArg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        Qt::InputMethodQuery cppArg0 = Shiboken::Converter< ::Qt::InputMethodQuery >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QTextEdit*>(cppSelf)->::QTextEdit::inputMethodQuery(cppArg0) : const_cast<const ::QTextEdit*>(cppSelf)->inputMethodQuery(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVariant >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.inputMethodQuery", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_insertFromMimeData(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertFromMimeData(const QMimeData*)
    if (Shiboken::Converter< ::QMimeData * >::isConvertible(pyArg)) {
        overloadId = 0; // insertFromMimeData(const QMimeData*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_insertFromMimeData_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QMimeData * cppArg0 = Shiboken::Converter< ::QMimeData * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // insertFromMimeData(const QMimeData*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::insertFromMimeData(cppArg0) : cppSelf->insertFromMimeData(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_insertFromMimeData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMimeData", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.insertFromMimeData", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_insertHtml(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertHtml(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // insertHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_insertHtml_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // insertHtml(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->insertHtml(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_insertHtml_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.insertHtml", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_insertPlainText(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertPlainText(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // insertPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_insertPlainText_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // insertPlainText(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->insertPlainText(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_insertPlainText_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.insertPlainText", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_isReadOnly(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isReadOnly()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextEdit*>(cppSelf)->isReadOnly();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_isUndoRedoEnabled(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isUndoRedoEnabled()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextEdit*>(cppSelf)->isUndoRedoEnabled();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_keyPressEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter< ::QKeyEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QKeyEvent * cppArg0 = Shiboken::Converter< ::QKeyEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::keyPressEvent(cppArg0) : cppSelf->keyPressEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.keyPressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_keyReleaseEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter< ::QKeyEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QKeyEvent * cppArg0 = Shiboken::Converter< ::QKeyEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // keyReleaseEvent(QKeyEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::keyReleaseEvent(cppArg0) : cppSelf->keyReleaseEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_lineWrapColumnOrWidth(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // lineWrapColumnOrWidth()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QTextEdit*>(cppSelf)->lineWrapColumnOrWidth();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_lineWrapMode(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // lineWrapMode()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextEdit::LineWrapMode cppResult = const_cast<const ::QTextEdit*>(cppSelf)->lineWrapMode();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextEdit::LineWrapMode >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_loadResource(PyObject* self, PyObject* args)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "loadResource", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: loadResource(int,QUrl)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QUrl >::isConvertible(pyArgs[1])) {
        overloadId = 0; // loadResource(int,QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_loadResource_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QUrl cppArg1 = Shiboken::Converter< ::QUrl >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // loadResource(int,QUrl)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::loadResource(cppArg0, cppArg1) : cppSelf->loadResource(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVariant >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextEditFunc_loadResource_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.loadResource", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_mergeCurrentCharFormat(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeCurrentCharFormat(QTextCharFormat)
    if (Shiboken::Converter< ::QTextCharFormat >::isConvertible(pyArg)) {
        overloadId = 0; // mergeCurrentCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_mergeCurrentCharFormat_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QTextCharFormat cppArg0 = Shiboken::Converter< ::QTextCharFormat >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // mergeCurrentCharFormat(QTextCharFormat)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->mergeCurrentCharFormat(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_mergeCurrentCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.mergeCurrentCharFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_mouseDoubleClickEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QMouseEvent * cppArg0 = Shiboken::Converter< ::QMouseEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // mouseDoubleClickEvent(QMouseEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::mouseDoubleClickEvent(cppArg0) : cppSelf->mouseDoubleClickEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_mouseMoveEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QMouseEvent * cppArg0 = Shiboken::Converter< ::QMouseEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // mouseMoveEvent(QMouseEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::mouseMoveEvent(cppArg0) : cppSelf->mouseMoveEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_mousePressEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QMouseEvent * cppArg0 = Shiboken::Converter< ::QMouseEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // mousePressEvent(QMouseEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::mousePressEvent(cppArg0) : cppSelf->mousePressEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.mousePressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_mouseReleaseEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QMouseEvent * cppArg0 = Shiboken::Converter< ::QMouseEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // mouseReleaseEvent(QMouseEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::mouseReleaseEvent(cppArg0) : cppSelf->mouseReleaseEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_moveCursor(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.moveCursor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.moveCursor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:moveCursor", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
    if (Shiboken::Converter< ::QTextCursor::MoveOperation >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
        } else if (Shiboken::Converter< ::QTextCursor::MoveMode >::isConvertible(pyArgs[1])) {
            overloadId = 0; // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_moveCursor_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "mode");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "mode";
                else if (Shiboken::Converter< ::QTextCursor::MoveMode >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QTextEditFunc_moveCursor_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.moveCursor(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        QTextCursor::MoveOperation cppArg0 = Shiboken::Converter< ::QTextCursor::MoveOperation >::toCpp(pyArgs[0]);
        QTextCursor::MoveMode cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QTextCursor::MoveMode >::toCpp(pyArgs[1]) : QTextCursor::MoveAnchor;

        if(!PyErr_Occurred()) {
            // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveCursor(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_moveCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor.MoveOperation, PySide.QtGui.QTextCursor.MoveMode = QTextCursor.MoveAnchor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.moveCursor", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_overwriteMode(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // overwriteMode()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextEdit*>(cppSelf)->overwriteMode();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_paintEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter< ::QPaintEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_paintEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPaintEvent * cppArg0 = Shiboken::Converter< ::QPaintEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // paintEvent(QPaintEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::paintEvent(cppArg0) : cppSelf->paintEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.paintEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_paste(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // paste()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->paste();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextEditFunc_print_(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: print(QPrinter*)const
    if (Shiboken::Converter< ::QPrinter * >::isConvertible(pyArg)) {
        overloadId = 0; // print(QPrinter*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_print__TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPrinter * cppArg0 = Shiboken::Converter< ::QPrinter * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // print(QPrinter*)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const_cast<const ::QTextEdit*>(cppSelf)->print(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_print__TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.print_", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_redo(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // redo()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->redo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextEditFunc_resizeEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter< ::QResizeEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_resizeEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QResizeEvent * cppArg0 = Shiboken::Converter< ::QResizeEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // resizeEvent(QResizeEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::resizeEvent(cppArg0) : cppSelf->resizeEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.resizeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_scrollContentsBy(PyObject* self, PyObject* args)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollContentsBy(int,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_scrollContentsBy_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
        int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // scrollContentsBy(int,int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::scrollContentsBy(cppArg0, cppArg1) : cppSelf->scrollContentsBy(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_scrollContentsBy_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.scrollContentsBy", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_scrollToAnchor(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: scrollToAnchor(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // scrollToAnchor(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_scrollToAnchor_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // scrollToAnchor(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->scrollToAnchor(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_scrollToAnchor_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.scrollToAnchor", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_selectAll(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // selectAll()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->selectAll();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextEditFunc_setAcceptRichText(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptRichText(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setAcceptRichText(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setAcceptRichText_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setAcceptRichText(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAcceptRichText(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setAcceptRichText_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setAcceptRichText", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setAlignment(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(pyArg)) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setAlignment_TypeError;

    // Call function/method
    {
        QFlags<Qt::AlignmentFlag> cppArg0 = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setAlignment(QFlags<Qt::AlignmentFlag>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAlignment(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setAutoFormatting(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoFormatting(QFlags<QTextEdit::AutoFormattingFlag>)
    if (Shiboken::Converter< ::QFlags<QTextEdit::AutoFormattingFlag> >::isConvertible(pyArg)) {
        overloadId = 0; // setAutoFormatting(QFlags<QTextEdit::AutoFormattingFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setAutoFormatting_TypeError;

    // Call function/method
    {
        QFlags<QTextEdit::AutoFormattingFlag> cppArg0 = Shiboken::Converter< ::QFlags<QTextEdit::AutoFormattingFlag> >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setAutoFormatting(QFlags<QTextEdit::AutoFormattingFlag>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAutoFormatting(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setAutoFormatting_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextEdit.AutoFormatting", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setAutoFormatting", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setCurrentCharFormat(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentCharFormat(QTextCharFormat)
    if (Shiboken::Converter< ::QTextCharFormat >::isConvertible(pyArg)) {
        overloadId = 0; // setCurrentCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setCurrentCharFormat_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QTextCharFormat cppArg0 = Shiboken::Converter< ::QTextCharFormat >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCurrentCharFormat(QTextCharFormat)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCurrentCharFormat(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setCurrentCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setCurrentCharFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setCurrentFont(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(pyArg)) {
        overloadId = 0; // setCurrentFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setCurrentFont_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QFont cppArg0 = Shiboken::Converter< ::QFont >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCurrentFont(QFont)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCurrentFont(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setCurrentFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setCurrentFont", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setCursorWidth(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCursorWidth(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setCursorWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setCursorWidth_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCursorWidth(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCursorWidth(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setCursorWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setCursorWidth", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setDocument(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocument(QTextDocument*)
    if (Shiboken::Converter< ::QTextDocument * >::isConvertible(pyArg)) {
        overloadId = 0; // setDocument(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setDocument_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QTextDocument * cppArg0 = Shiboken::Converter< ::QTextDocument * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setDocument(QTextDocument*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setDocument(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setDocument_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setDocument", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setDocumentTitle(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocumentTitle(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setDocumentTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setDocumentTitle_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setDocumentTitle(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setDocumentTitle(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setDocumentTitle_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setDocumentTitle", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setExtraSelections(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setExtraSelections(QList<QTextEdit::ExtraSelection>)
    if (Shiboken::Converter< ::QList<QTextEdit::ExtraSelection > >::isConvertible(pyArg)) {
        overloadId = 0; // setExtraSelections(QList<QTextEdit::ExtraSelection>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setExtraSelections_TypeError;

    // Call function/method
    {
        ::QList<QTextEdit::ExtraSelection > cppArg0 = Shiboken::Converter< ::QList<QTextEdit::ExtraSelection > >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setExtraSelections(QList<QTextEdit::ExtraSelection>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setExtraSelections(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setExtraSelections_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setExtraSelections", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setFontFamily(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontFamily(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setFontFamily(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setFontFamily_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setFontFamily(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFontFamily(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setFontFamily_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setFontFamily", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setFontItalic(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontItalic(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setFontItalic(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setFontItalic_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setFontItalic(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFontItalic(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setFontItalic_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setFontItalic", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setFontPointSize(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontPointSize(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setFontPointSize(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setFontPointSize_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setFontPointSize(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFontPointSize(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setFontPointSize_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setFontPointSize", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setFontUnderline(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontUnderline(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setFontUnderline(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setFontUnderline_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setFontUnderline(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFontUnderline(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setFontUnderline_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setFontUnderline", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setFontWeight(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontWeight(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setFontWeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setFontWeight_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setFontWeight(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFontWeight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setFontWeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setFontWeight", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setHtml(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHtml(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setHtml_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setHtml(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHtml(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setHtml_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setHtml", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setLineWrapColumnOrWidth(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLineWrapColumnOrWidth(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setLineWrapColumnOrWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setLineWrapColumnOrWidth_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLineWrapColumnOrWidth(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLineWrapColumnOrWidth(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setLineWrapColumnOrWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setLineWrapColumnOrWidth", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setLineWrapMode(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLineWrapMode(QTextEdit::LineWrapMode)
    if (Shiboken::Converter< ::QTextEdit::LineWrapMode >::isConvertible(pyArg)) {
        overloadId = 0; // setLineWrapMode(QTextEdit::LineWrapMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setLineWrapMode_TypeError;

    // Call function/method
    {
        QTextEdit::LineWrapMode cppArg0 = Shiboken::Converter< ::QTextEdit::LineWrapMode >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLineWrapMode(QTextEdit::LineWrapMode)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLineWrapMode(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setLineWrapMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextEdit.LineWrapMode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setLineWrapMode", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setOverwriteMode(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOverwriteMode(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setOverwriteMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setOverwriteMode_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setOverwriteMode(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setOverwriteMode(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setOverwriteMode_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setOverwriteMode", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setPlainText(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPlainText(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setPlainText_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setPlainText(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPlainText(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setPlainText_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setPlainText", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setReadOnly(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadOnly(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setReadOnly_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setReadOnly(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setReadOnly(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setReadOnly_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setReadOnly", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setTabChangesFocus(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabChangesFocus(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setTabChangesFocus(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setTabChangesFocus_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTabChangesFocus(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTabChangesFocus(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setTabChangesFocus_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setTabChangesFocus", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setTabStopWidth(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabStopWidth(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setTabStopWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setTabStopWidth_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTabStopWidth(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTabStopWidth(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setTabStopWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setTabStopWidth", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setText(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setText(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setText_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setText(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setText(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setText_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setText", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setTextBackgroundColor(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextBackgroundColor(QColor)
    if (Shiboken::Converter< ::QColor >::isConvertible(pyArg)) {
        overloadId = 0; // setTextBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setTextBackgroundColor_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QColor cppArg0 = Shiboken::Converter< ::QColor >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTextBackgroundColor(QColor)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTextBackgroundColor(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setTextBackgroundColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setTextBackgroundColor", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setTextColor(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextColor(QColor)
    if (Shiboken::Converter< ::QColor >::isConvertible(pyArg)) {
        overloadId = 0; // setTextColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setTextColor_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QColor cppArg0 = Shiboken::Converter< ::QColor >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTextColor(QColor)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTextColor(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setTextColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setTextColor", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setTextCursor(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextCursor(QTextCursor)
    if (Shiboken::Converter< ::QTextCursor >::isConvertible(pyArg)) {
        overloadId = 0; // setTextCursor(QTextCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setTextCursor_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QTextCursor cppArg0 = Shiboken::Converter< ::QTextCursor >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTextCursor(QTextCursor)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTextCursor(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setTextCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setTextCursor", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setTextInteractionFlags(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::TextInteractionFlag> >::isConvertible(pyArg)) {
        overloadId = 0; // setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setTextInteractionFlags_TypeError;

    // Call function/method
    {
        QFlags<Qt::TextInteractionFlag> cppArg0 = Shiboken::Converter< ::QFlags<Qt::TextInteractionFlag> >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTextInteractionFlags(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setTextInteractionFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TextInteractionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setTextInteractionFlags", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setUndoRedoEnabled(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUndoRedoEnabled(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setUndoRedoEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setUndoRedoEnabled_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setUndoRedoEnabled(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setUndoRedoEnabled(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setUndoRedoEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setUndoRedoEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_setWordWrapMode(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWordWrapMode(QTextOption::WrapMode)
    if (Shiboken::Converter< ::QTextOption::WrapMode >::isConvertible(pyArg)) {
        overloadId = 0; // setWordWrapMode(QTextOption::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_setWordWrapMode_TypeError;

    // Call function/method
    {
        QTextOption::WrapMode cppArg0 = Shiboken::Converter< ::QTextOption::WrapMode >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setWordWrapMode(QTextOption::WrapMode)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setWordWrapMode(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_setWordWrapMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextOption.WrapMode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.setWordWrapMode", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_showEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: showEvent(QShowEvent*)
    if (Shiboken::Converter< ::QShowEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_showEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QShowEvent * cppArg0 = Shiboken::Converter< ::QShowEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // showEvent(QShowEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::showEvent(cppArg0) : cppSelf->showEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_showEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QShowEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.showEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_tabChangesFocus(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // tabChangesFocus()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextEdit*>(cppSelf)->tabChangesFocus();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_tabStopWidth(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // tabStopWidth()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QTextEdit*>(cppSelf)->tabStopWidth();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_textBackgroundColor(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // textBackgroundColor()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QColor cppResult = const_cast<const ::QTextEdit*>(cppSelf)->textBackgroundColor();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_textColor(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // textColor()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QColor cppResult = const_cast<const ::QTextEdit*>(cppSelf)->textColor();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_textCursor(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // textCursor()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextCursor cppResult = const_cast<const ::QTextEdit*>(cppSelf)->textCursor();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextCursor >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_textInteractionFlags(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // textInteractionFlags()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFlags<Qt::TextInteractionFlag> cppResult = const_cast<const ::QTextEdit*>(cppSelf)->textInteractionFlags();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFlags<Qt::TextInteractionFlag> >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_timerEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: timerEvent(QTimerEvent*)
    if (Shiboken::Converter< ::QTimerEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_timerEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QTimerEvent * cppArg0 = Shiboken::Converter< ::QTimerEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // timerEvent(QTimerEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::timerEvent(cppArg0) : cppSelf->timerEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_timerEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimerEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.timerEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_toHtml(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toHtml()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QTextEdit*>(cppSelf)->toHtml();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_toPlainText(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toPlainText()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QTextEdit*>(cppSelf)->toPlainText();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_undo(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // undo()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->undo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextEditFunc_wheelEvent(PyObject* self, PyObject* pyArg)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QWheelEvent*)
    if (Shiboken::Converter< ::QWheelEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_wheelEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QWheelEvent * cppArg0 = Shiboken::Converter< ::QWheelEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // wheelEvent(QWheelEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QTextEdit::wheelEvent(cppArg0) : cppSelf->wheelEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextEdit.wheelEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_wordWrapMode(PyObject* self)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // wordWrapMode()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextOption::WrapMode cppResult = const_cast<const ::QTextEdit*>(cppSelf)->wordWrapMode();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextOption::WrapMode >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextEditFunc_zoomIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomIn(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:zoomIn", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: zoomIn(int)
    if (numArgs == 0) {
        overloadId = 0; // zoomIn(int)
    } else if (SbkNumber_Check(pyArgs[0])) {
        overloadId = 0; // zoomIn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_zoomIn_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "range");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "range";
                else if (SbkNumber_Check(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QTextEditFunc_zoomIn_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomIn(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = pyArgs[0] ? Shiboken::Converter< int >::toCpp(pyArgs[0]) : 1;

        if(!PyErr_Occurred()) {
            // zoomIn(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->zoomIn(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_zoomIn_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.zoomIn", overloads);
        return 0;
}

static PyObject* Sbk_QTextEditFunc_zoomOut(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTextEdit* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextEdit* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomOut(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:zoomOut", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: zoomOut(int)
    if (numArgs == 0) {
        overloadId = 0; // zoomOut(int)
    } else if (SbkNumber_Check(pyArgs[0])) {
        overloadId = 0; // zoomOut(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEditFunc_zoomOut_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "range");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "range";
                else if (SbkNumber_Check(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QTextEditFunc_zoomOut_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomOut(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = pyArgs[0] ? Shiboken::Converter< int >::toCpp(pyArgs[0]) : 1;

        if(!PyErr_Occurred()) {
            // zoomOut(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->zoomOut(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextEditFunc_zoomOut_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.zoomOut", overloads);
        return 0;
}

static PyMethodDef Sbk_QTextEdit_methods[] = {
    {"acceptRichText", (PyCFunction)Sbk_QTextEditFunc_acceptRichText, METH_NOARGS},
    {"alignment", (PyCFunction)Sbk_QTextEditFunc_alignment, METH_NOARGS},
    {"anchorAt", (PyCFunction)Sbk_QTextEditFunc_anchorAt, METH_O},
    {"append", (PyCFunction)Sbk_QTextEditFunc_append, METH_O},
    {"autoFormatting", (PyCFunction)Sbk_QTextEditFunc_autoFormatting, METH_NOARGS},
    {"canInsertFromMimeData", (PyCFunction)Sbk_QTextEditFunc_canInsertFromMimeData, METH_O},
    {"canPaste", (PyCFunction)Sbk_QTextEditFunc_canPaste, METH_NOARGS},
    {"changeEvent", (PyCFunction)Sbk_QTextEditFunc_changeEvent, METH_O},
    {"clear", (PyCFunction)Sbk_QTextEditFunc_clear, METH_NOARGS},
    {"contextMenuEvent", (PyCFunction)Sbk_QTextEditFunc_contextMenuEvent, METH_O},
    {"copy", (PyCFunction)Sbk_QTextEditFunc_copy, METH_NOARGS},
    {"createMimeDataFromSelection", (PyCFunction)Sbk_QTextEditFunc_createMimeDataFromSelection, METH_NOARGS},
    {"createStandardContextMenu", (PyCFunction)Sbk_QTextEditFunc_createStandardContextMenu, METH_VARARGS},
    {"currentCharFormat", (PyCFunction)Sbk_QTextEditFunc_currentCharFormat, METH_NOARGS},
    {"currentFont", (PyCFunction)Sbk_QTextEditFunc_currentFont, METH_NOARGS},
    {"cursorForPosition", (PyCFunction)Sbk_QTextEditFunc_cursorForPosition, METH_O},
    {"cursorRect", (PyCFunction)Sbk_QTextEditFunc_cursorRect, METH_VARARGS},
    {"cursorWidth", (PyCFunction)Sbk_QTextEditFunc_cursorWidth, METH_NOARGS},
    {"cut", (PyCFunction)Sbk_QTextEditFunc_cut, METH_NOARGS},
    {"document", (PyCFunction)Sbk_QTextEditFunc_document, METH_NOARGS},
    {"documentTitle", (PyCFunction)Sbk_QTextEditFunc_documentTitle, METH_NOARGS},
    {"dragEnterEvent", (PyCFunction)Sbk_QTextEditFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)Sbk_QTextEditFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)Sbk_QTextEditFunc_dragMoveEvent, METH_O},
    {"dropEvent", (PyCFunction)Sbk_QTextEditFunc_dropEvent, METH_O},
    {"ensureCursorVisible", (PyCFunction)Sbk_QTextEditFunc_ensureCursorVisible, METH_NOARGS},
    {"event", (PyCFunction)Sbk_QTextEditFunc_event, METH_O},
    {"extraSelections", (PyCFunction)Sbk_QTextEditFunc_extraSelections, METH_NOARGS},
    {"find", (PyCFunction)Sbk_QTextEditFunc_find, METH_VARARGS|METH_KEYWORDS},
    {"focusInEvent", (PyCFunction)Sbk_QTextEditFunc_focusInEvent, METH_O},
    {"focusNextPrevChild", (PyCFunction)Sbk_QTextEditFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)Sbk_QTextEditFunc_focusOutEvent, METH_O},
    {"fontFamily", (PyCFunction)Sbk_QTextEditFunc_fontFamily, METH_NOARGS},
    {"fontItalic", (PyCFunction)Sbk_QTextEditFunc_fontItalic, METH_NOARGS},
    {"fontPointSize", (PyCFunction)Sbk_QTextEditFunc_fontPointSize, METH_NOARGS},
    {"fontUnderline", (PyCFunction)Sbk_QTextEditFunc_fontUnderline, METH_NOARGS},
    {"fontWeight", (PyCFunction)Sbk_QTextEditFunc_fontWeight, METH_NOARGS},
    {"inputMethodEvent", (PyCFunction)Sbk_QTextEditFunc_inputMethodEvent, METH_O},
    {"inputMethodQuery", (PyCFunction)Sbk_QTextEditFunc_inputMethodQuery, METH_O},
    {"insertFromMimeData", (PyCFunction)Sbk_QTextEditFunc_insertFromMimeData, METH_O},
    {"insertHtml", (PyCFunction)Sbk_QTextEditFunc_insertHtml, METH_O},
    {"insertPlainText", (PyCFunction)Sbk_QTextEditFunc_insertPlainText, METH_O},
    {"isReadOnly", (PyCFunction)Sbk_QTextEditFunc_isReadOnly, METH_NOARGS},
    {"isUndoRedoEnabled", (PyCFunction)Sbk_QTextEditFunc_isUndoRedoEnabled, METH_NOARGS},
    {"keyPressEvent", (PyCFunction)Sbk_QTextEditFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)Sbk_QTextEditFunc_keyReleaseEvent, METH_O},
    {"lineWrapColumnOrWidth", (PyCFunction)Sbk_QTextEditFunc_lineWrapColumnOrWidth, METH_NOARGS},
    {"lineWrapMode", (PyCFunction)Sbk_QTextEditFunc_lineWrapMode, METH_NOARGS},
    {"loadResource", (PyCFunction)Sbk_QTextEditFunc_loadResource, METH_VARARGS},
    {"mergeCurrentCharFormat", (PyCFunction)Sbk_QTextEditFunc_mergeCurrentCharFormat, METH_O},
    {"mouseDoubleClickEvent", (PyCFunction)Sbk_QTextEditFunc_mouseDoubleClickEvent, METH_O},
    {"mouseMoveEvent", (PyCFunction)Sbk_QTextEditFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)Sbk_QTextEditFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)Sbk_QTextEditFunc_mouseReleaseEvent, METH_O},
    {"moveCursor", (PyCFunction)Sbk_QTextEditFunc_moveCursor, METH_VARARGS|METH_KEYWORDS},
    {"overwriteMode", (PyCFunction)Sbk_QTextEditFunc_overwriteMode, METH_NOARGS},
    {"paintEvent", (PyCFunction)Sbk_QTextEditFunc_paintEvent, METH_O},
    {"paste", (PyCFunction)Sbk_QTextEditFunc_paste, METH_NOARGS},
    {"print_", (PyCFunction)Sbk_QTextEditFunc_print_, METH_O},
    {"redo", (PyCFunction)Sbk_QTextEditFunc_redo, METH_NOARGS},
    {"resizeEvent", (PyCFunction)Sbk_QTextEditFunc_resizeEvent, METH_O},
    {"scrollContentsBy", (PyCFunction)Sbk_QTextEditFunc_scrollContentsBy, METH_VARARGS},
    {"scrollToAnchor", (PyCFunction)Sbk_QTextEditFunc_scrollToAnchor, METH_O},
    {"selectAll", (PyCFunction)Sbk_QTextEditFunc_selectAll, METH_NOARGS},
    {"setAcceptRichText", (PyCFunction)Sbk_QTextEditFunc_setAcceptRichText, METH_O},
    {"setAlignment", (PyCFunction)Sbk_QTextEditFunc_setAlignment, METH_O},
    {"setAutoFormatting", (PyCFunction)Sbk_QTextEditFunc_setAutoFormatting, METH_O},
    {"setCurrentCharFormat", (PyCFunction)Sbk_QTextEditFunc_setCurrentCharFormat, METH_O},
    {"setCurrentFont", (PyCFunction)Sbk_QTextEditFunc_setCurrentFont, METH_O},
    {"setCursorWidth", (PyCFunction)Sbk_QTextEditFunc_setCursorWidth, METH_O},
    {"setDocument", (PyCFunction)Sbk_QTextEditFunc_setDocument, METH_O},
    {"setDocumentTitle", (PyCFunction)Sbk_QTextEditFunc_setDocumentTitle, METH_O},
    {"setExtraSelections", (PyCFunction)Sbk_QTextEditFunc_setExtraSelections, METH_O},
    {"setFontFamily", (PyCFunction)Sbk_QTextEditFunc_setFontFamily, METH_O},
    {"setFontItalic", (PyCFunction)Sbk_QTextEditFunc_setFontItalic, METH_O},
    {"setFontPointSize", (PyCFunction)Sbk_QTextEditFunc_setFontPointSize, METH_O},
    {"setFontUnderline", (PyCFunction)Sbk_QTextEditFunc_setFontUnderline, METH_O},
    {"setFontWeight", (PyCFunction)Sbk_QTextEditFunc_setFontWeight, METH_O},
    {"setHtml", (PyCFunction)Sbk_QTextEditFunc_setHtml, METH_O},
    {"setLineWrapColumnOrWidth", (PyCFunction)Sbk_QTextEditFunc_setLineWrapColumnOrWidth, METH_O},
    {"setLineWrapMode", (PyCFunction)Sbk_QTextEditFunc_setLineWrapMode, METH_O},
    {"setOverwriteMode", (PyCFunction)Sbk_QTextEditFunc_setOverwriteMode, METH_O},
    {"setPlainText", (PyCFunction)Sbk_QTextEditFunc_setPlainText, METH_O},
    {"setReadOnly", (PyCFunction)Sbk_QTextEditFunc_setReadOnly, METH_O},
    {"setTabChangesFocus", (PyCFunction)Sbk_QTextEditFunc_setTabChangesFocus, METH_O},
    {"setTabStopWidth", (PyCFunction)Sbk_QTextEditFunc_setTabStopWidth, METH_O},
    {"setText", (PyCFunction)Sbk_QTextEditFunc_setText, METH_O},
    {"setTextBackgroundColor", (PyCFunction)Sbk_QTextEditFunc_setTextBackgroundColor, METH_O},
    {"setTextColor", (PyCFunction)Sbk_QTextEditFunc_setTextColor, METH_O},
    {"setTextCursor", (PyCFunction)Sbk_QTextEditFunc_setTextCursor, METH_O},
    {"setTextInteractionFlags", (PyCFunction)Sbk_QTextEditFunc_setTextInteractionFlags, METH_O},
    {"setUndoRedoEnabled", (PyCFunction)Sbk_QTextEditFunc_setUndoRedoEnabled, METH_O},
    {"setWordWrapMode", (PyCFunction)Sbk_QTextEditFunc_setWordWrapMode, METH_O},
    {"showEvent", (PyCFunction)Sbk_QTextEditFunc_showEvent, METH_O},
    {"tabChangesFocus", (PyCFunction)Sbk_QTextEditFunc_tabChangesFocus, METH_NOARGS},
    {"tabStopWidth", (PyCFunction)Sbk_QTextEditFunc_tabStopWidth, METH_NOARGS},
    {"textBackgroundColor", (PyCFunction)Sbk_QTextEditFunc_textBackgroundColor, METH_NOARGS},
    {"textColor", (PyCFunction)Sbk_QTextEditFunc_textColor, METH_NOARGS},
    {"textCursor", (PyCFunction)Sbk_QTextEditFunc_textCursor, METH_NOARGS},
    {"textInteractionFlags", (PyCFunction)Sbk_QTextEditFunc_textInteractionFlags, METH_NOARGS},
    {"timerEvent", (PyCFunction)Sbk_QTextEditFunc_timerEvent, METH_O},
    {"toHtml", (PyCFunction)Sbk_QTextEditFunc_toHtml, METH_NOARGS},
    {"toPlainText", (PyCFunction)Sbk_QTextEditFunc_toPlainText, METH_NOARGS},
    {"undo", (PyCFunction)Sbk_QTextEditFunc_undo, METH_NOARGS},
    {"wheelEvent", (PyCFunction)Sbk_QTextEditFunc_wheelEvent, METH_O},
    {"wordWrapMode", (PyCFunction)Sbk_QTextEditFunc_wordWrapMode, METH_NOARGS},
    {"zoomIn", (PyCFunction)Sbk_QTextEditFunc_zoomIn, METH_VARARGS|METH_KEYWORDS},
    {"zoomOut", (PyCFunction)Sbk_QTextEditFunc_zoomOut, METH_VARARGS|METH_KEYWORDS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QTextEdit_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QTextEdit_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
static void* Sbk_QTextEditSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QTextEdit* me = reinterpret_cast< ::QTextEdit*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast< ::QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast< ::QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast< ::QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast< ::QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast< ::QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextEdit_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QTextEdit",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QTextEdit_traverse,
    /*tp_clear*/            Sbk_QTextEdit_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextEdit_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextEdit_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QTextEdit_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QTextEdit*>(reinterpret_cast< ::QObject*>(cptr));
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QPaintDevice >()))
        return dynamic_cast< ::QTextEdit*>(reinterpret_cast< ::QPaintDevice*>(cptr));
    return 0;
}

PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___and__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QTextEdit::AutoFormatting >::toPython(
        Shiboken::Converter< ::QTextEdit::AutoFormatting>::toCpp(self)
        & Shiboken::Converter< ::QTextEdit::AutoFormatting >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___or__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QTextEdit::AutoFormatting >::toPython(
        Shiboken::Converter< ::QTextEdit::AutoFormatting>::toCpp(self)
        | Shiboken::Converter< ::QTextEdit::AutoFormatting >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___xor__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< ::QTextEdit::AutoFormatting >::toPython(
        Shiboken::Converter< ::QTextEdit::AutoFormatting>::toCpp(self)
        ^ Shiboken::Converter< ::QTextEdit::AutoFormatting >::toCpp(pyArg)
    );
}

PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___invert__(PyObject* self, PyObject* pyArg)
{
    return Shiboken::Converter< QTextEdit::AutoFormatting >::toPython(
        ~Shiboken::Converter< ::QTextEdit::AutoFormatting >::toCpp(self)
    );
}

static PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_long(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QTextEdit::AutoFormatting>::toCpp(v);
    return PyLong_FromLong(val);
}
static int SbkPySide_QtGui_QTextEdit_AutoFormattingFlag__nonzero(PyObject* v)
{
    long val = (long) Shiboken::Converter< ::QTextEdit::AutoFormatting>::toCpp(v);
    return val != 0;
}

static PyNumberMethods SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    #ifndef IS_PY3K
    /* nb_divide */             0,
    #endif
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              SbkPySide_QtGui_QTextEdit_AutoFormattingFlag__nonzero,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___or__,
    #ifndef IS_PY3K
    /* nb_coerce */             0,
    #endif
    /*nb_int*/                  SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_long,
    #ifdef IS_PY3K
    /*nb_reserved*/             0,
    /*nb_float*/                0,
    #else
    /*nb_long*/                 SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_long,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    #endif
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    #ifndef IS_PY3K
    /*nb_inplace_divide*/       0,
    #endif
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QTextEdit_AutoFormatting_Type = {
    PyVarObject_HEAD_INIT(&PyType_Type, 0)
    /*tp_name*/             "AutoFormatting",
    /*tp_basicsize*/        sizeof(PySideQFlagsObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      &PySideQFlagsRichCompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              &PySideQFlagsNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QTextEdit(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextEdit_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QTextEdit", "QTextEdit*",
        &Sbk_QTextEdit_Type, &Shiboken::callCppDestructor< ::QTextEdit >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX])) {
        return;
    }

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QTextEdit_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QTextEdit_Type, &Sbk_QTextEditSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QTextEdit_Type, &Sbk_QTextEdit_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'AutoFormattingFlag'.
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QTEXTEDIT_AUTOFORMATTINGFLAG__IDX] = &SbkPySide_QtGui_QTextEdit_AutoFormatting_Type;
    SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_AUTOFORMATTINGFLAG_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QTextEdit_Type,
        "AutoFormattingFlag",
        "PySide.QtGui.QTextEdit.AutoFormattingFlag",
        "QTextEdit::AutoFormattingFlag",
        SbkPySide_QtGuiTypes[SBK_QFLAGS_QTEXTEDIT_AUTOFORMATTINGFLAG__IDX]);
    if (!SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_AUTOFORMATTINGFLAG_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_AUTOFORMATTINGFLAG_IDX],
        &Sbk_QTextEdit_Type, "AutoNone", (long) QTextEdit::AutoNone))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_AUTOFORMATTINGFLAG_IDX],
        &Sbk_QTextEdit_Type, "AutoBulletList", (long) QTextEdit::AutoBulletList))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_AUTOFORMATTINGFLAG_IDX],
        &Sbk_QTextEdit_Type, "AutoAll", (long) QTextEdit::AutoAll))
        return ;
    // End of 'AutoFormattingFlag' enum.

    // Initialization of enum 'LineWrapMode'.
    SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_LINEWRAPMODE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QTextEdit_Type,
        "LineWrapMode",
        "PySide.QtGui.QTextEdit.LineWrapMode",
        "QTextEdit::LineWrapMode");
    if (!SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_LINEWRAPMODE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_LINEWRAPMODE_IDX],
        &Sbk_QTextEdit_Type, "NoWrap", (long) QTextEdit::NoWrap))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_LINEWRAPMODE_IDX],
        &Sbk_QTextEdit_Type, "WidgetWidth", (long) QTextEdit::WidgetWidth))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_LINEWRAPMODE_IDX],
        &Sbk_QTextEdit_Type, "FixedPixelWidth", (long) QTextEdit::FixedPixelWidth))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_LINEWRAPMODE_IDX],
        &Sbk_QTextEdit_Type, "FixedColumnWidth", (long) QTextEdit::FixedColumnWidth))
        return ;
    // End of 'LineWrapMode' enum.

    PySide::Signal::registerSignals(&Sbk_QTextEdit_Type, &::QTextEdit::staticMetaObject);

    Shiboken::TypeResolver::createObjectTypeResolver< ::QTextEdit >("QTextEdit*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QTextEdit >(typeid(::QTextEdit).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QTextEdit >(typeid(::QTextEditWrapper).name());
    qRegisterMetaType< ::QTextEdit::AutoFormattingFlag >("QTextEdit::AutoFormattingFlag");
    qRegisterMetaType< ::QTextEdit::AutoFormatting >("QTextEdit::AutoFormatting");
    qRegisterMetaType< ::QTextEdit::LineWrapMode >("QTextEdit::LineWrapMode");
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QTextEdit_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QTextEdit_Type, &::QTextEdit::staticMetaObject, sizeof(::QTextEdit));
}
