/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtopengl_python.h"

#include "qglshaderprogram_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcolor.h>
#include <qcoreevent.h>
#include <qgenericmatrix.h>
#include <qgl.h>
#include <qglshaderprogram.h>
#include <qmatrix4x4.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qthread.h>
#include <qtransform.h>
#include <qvector2d.h>
#include <qvector3d.h>
#include <qvector4d.h>


// Native ---------------------------------------------------------

QGLShaderProgramWrapper::QGLShaderProgramWrapper(QObject * parent) : QGLShaderProgram(parent) {
    // ... middle
}

QGLShaderProgramWrapper::QGLShaderProgramWrapper(const QGLContext * context, QObject * parent) : QGLShaderProgram(context, parent) {
    // ... middle
}

void QGLShaderProgramWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QGLShaderProgramWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGLShaderProgramWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QGLShaderProgramWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QGLShaderProgramWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.event", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QGLShaderProgramWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.eventFilter", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

bool QGLShaderProgramWrapper::link()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "link"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QGLShaderProgram::link();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.link", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

void QGLShaderProgramWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject* QGLShaderProgramWrapper::metaObject() const
{
    #if QT_VERSION >= 0x040700
    if (QObject::d_ptr->metaObject) return QObject::d_ptr->metaObject;
    #endif
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return PySide::SignalManager::retriveMetaObject(reinterpret_cast<PyObject*>(pySelf));
}

int QGLShaderProgramWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGLShaderProgram::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void* QGLShaderProgramWrapper::qt_metacast(const char* _clname)
{
        if (!_clname) return 0;
        SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void*>(const_cast< QGLShaderProgramWrapper* >(this));
        return QGLShaderProgram::qt_metacast(_clname);
}

QGLShaderProgramWrapper::~QGLShaderProgramWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLShaderProgram_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGLShaderProgram >()))
        return -1;

    ::QGLShaderProgramWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QGLShaderProgram", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QGLShaderProgram(QObject*)
    // 1: QGLShaderProgram(const QGLContext*,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGLShaderProgram(QObject*)
    } else if (Shiboken::Converter< ::QGLContext * >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QGLShaderProgram(const QGLContext*,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[1])) {
            overloadId = 1; // QGLShaderProgram(const QGLContext*,QObject*)
        }
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QGLShaderProgram(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgram_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QGLShaderProgram(QObject*)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyArgs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyArgs[0] = value;
                    else
                        goto Sbk_QGLShaderProgram_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QGLShaderProgram(QObject*)
                void* addr = PySide::nextQObjectMemoryAddr();
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = addr ? new (addr) ::QGLShaderProgramWrapper(cppArg0) : new ::QGLShaderProgramWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QGLShaderProgram(const QGLContext*,QObject*)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QGLShaderProgram_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGLContext * cppArg0 = Shiboken::Converter< ::QGLContext * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject * cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[1]) : 0;

            if(!PyErr_Occurred()) {
                // QGLShaderProgram(const QGLContext*,QObject*)
                void* addr = PySide::nextQObjectMemoryAddr();
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = addr ? new (addr) ::QGLShaderProgramWrapper(cppArg0, cppArg1) : new ::QGLShaderProgramWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGLShaderProgram >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLShaderProgram_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QGLShaderProgram_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "PySide.QtOpenGL.QGLContext, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram", overloads);
        return -1;
}

static PyObject* Sbk_QGLShaderProgramFunc_addShader(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addShader(QGLShader*)
    if (Shiboken::Converter< ::QGLShader * >::isConvertible(pyArg)) {
        overloadId = 0; // addShader(QGLShader*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_addShader_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QGLShader * cppArg0 = Shiboken::Converter< ::QGLShader * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // addShader(QGLShader*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->addShader(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_addShader_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.addShader", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_addShaderFromSourceCode(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addShaderFromSourceCode", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
    // 1: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
    // 2: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
    if (Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyArgs[0])) {
        if (numArgs == 2
            && Shiboken::Converter< const char * >::isConvertible(pyArgs[1])) {
            overloadId = 2; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 1; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[1])) {
            overloadId = 0; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_addShaderFromSourceCode_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
        {
            QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QByteArray cppArg1 = Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
        case 1: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
        {
            QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyArgs[0]);
            ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
        case 2: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
        {
            QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyArgs[0]);
            const char * cppArg1 = Shiboken::Converter< const char * >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_addShaderFromSourceCode_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, PySide.QtCore.QByteArray", "PySide.QtOpenGL.QGLShader.ShaderType, unicode", "PySide.QtOpenGL.QGLShader.ShaderType, "SBK_STR_NAME"", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.addShaderFromSourceCode", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_addShaderFromSourceFile(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addShaderFromSourceFile", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
    if (numArgs == 2
        && Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
        overloadId = 0; // addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_addShaderFromSourceFile_TypeError;

    // Call function/method
    {
        QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyArgs[0]);
        ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->addShaderFromSourceFile(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_addShaderFromSourceFile_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, unicode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.addShaderFromSourceFile", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_attributeLocation(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: attributeLocation(QByteArray)const
    // 1: attributeLocation(QString)const
    // 2: attributeLocation(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(pyArg)) {
        overloadId = 2; // attributeLocation(const char*)const
    } else if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 1; // attributeLocation(QString)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArg)) {
        overloadId = 0; // attributeLocation(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_attributeLocation_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // attributeLocation(QByteArray)const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // attributeLocation(QByteArray)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->attributeLocation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
        case 1: // attributeLocation(QString)const
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // attributeLocation(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->attributeLocation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
        case 2: // attributeLocation(const char*)const
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // attributeLocation(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->attributeLocation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_attributeLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "unicode", ""SBK_STR_NAME"", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.attributeLocation", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_bind(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // bind()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->bind();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_bindAttributeLocation(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "bindAttributeLocation", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: bindAttributeLocation(QByteArray,int)
    // 1: bindAttributeLocation(QString,int)
    // 2: bindAttributeLocation(const char*,int)
    if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 2; // bindAttributeLocation(const char*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 1; // bindAttributeLocation(QString,int)
    } else if (numArgs == 2
        && Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 0; // bindAttributeLocation(QByteArray,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_bindAttributeLocation_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // bindAttributeLocation(QByteArray,int)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // bindAttributeLocation(QByteArray,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->bindAttributeLocation(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // bindAttributeLocation(QString,int)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // bindAttributeLocation(QString,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->bindAttributeLocation(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // bindAttributeLocation(const char*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // bindAttributeLocation(const char*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->bindAttributeLocation(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_bindAttributeLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int", "unicode, int", ""SBK_STR_NAME", int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.bindAttributeLocation", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_disableAttributeArray(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: disableAttributeArray(const char*)
    // 1: disableAttributeArray(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 1; // disableAttributeArray(int)
    } else if (Shiboken::Converter< const char * >::isConvertible(pyArg)) {
        overloadId = 0; // disableAttributeArray(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_disableAttributeArray_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // disableAttributeArray(const char*)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // disableAttributeArray(const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->disableAttributeArray(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // disableAttributeArray(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // disableAttributeArray(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->disableAttributeArray(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_disableAttributeArray_TypeError:
        const char* overloads[] = {""SBK_STR_NAME"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.disableAttributeArray", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_enableAttributeArray(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: enableAttributeArray(const char*)
    // 1: enableAttributeArray(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 1; // enableAttributeArray(int)
    } else if (Shiboken::Converter< const char * >::isConvertible(pyArg)) {
        overloadId = 0; // enableAttributeArray(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_enableAttributeArray_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // enableAttributeArray(const char*)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // enableAttributeArray(const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->enableAttributeArray(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // enableAttributeArray(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // enableAttributeArray(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->enableAttributeArray(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_enableAttributeArray_TypeError:
        const char* overloads[] = {""SBK_STR_NAME"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.enableAttributeArray", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_geometryInputType(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // geometryInputType()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            unsigned int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->geometryInputType();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_geometryOutputType(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // geometryOutputType()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            unsigned int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->geometryOutputType();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_geometryOutputVertexCount(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // geometryOutputVertexCount()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->geometryOutputVertexCount();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:hasOpenGLShaderPrograms", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: hasOpenGLShaderPrograms(const QGLContext*)
    if (numArgs == 0) {
        overloadId = 0; // hasOpenGLShaderPrograms(const QGLContext*)
    } else if (Shiboken::Converter< ::QGLContext * >::isConvertible(pyArgs[0])) {
        overloadId = 0; // hasOpenGLShaderPrograms(const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "context");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "context";
                else if (Shiboken::Converter< ::QGLContext * >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QGLContext * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QGLContext * >::toCpp(pyArgs[0]) : 0;

        if(!PyErr_Occurred()) {
            // hasOpenGLShaderPrograms(const QGLContext*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = QGLShaderProgram::hasOpenGLShaderPrograms(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_isLinked(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isLinked()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->isLinked();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_link(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // link()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QGLShaderProgram::link() : cppSelf->link();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_log(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // log()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->log();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_maxGeometryOutputVertices(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // maxGeometryOutputVertices()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->maxGeometryOutputVertices();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_programId(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // programId()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            unsigned int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->programId();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_release(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // release()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->release();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLShaderProgramFunc_removeAllShaders(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // removeAllShaders()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->removeAllShaders();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLShaderProgramFunc_removeShader(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeShader(QGLShader*)
    if (Shiboken::Converter< ::QGLShader * >::isConvertible(pyArg)) {
        overloadId = 0; // removeShader(QGLShader*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_removeShader_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QGLShader * cppArg0 = Shiboken::Converter< ::QGLShader * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // removeShader(QGLShader*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->removeShader(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_removeShader_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.removeShader", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeArray(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setAttributeArray", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeArray(const char*,const float*,int,int)
    // 1: setAttributeArray(int,const float*,int,int)
    if (numArgs >= 3
        && SbkNumber_Check(pyArgs[0])
        && PyFloat_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])) {
        if (numArgs == 3) {
            overloadId = 1; // setAttributeArray(int,const float*,int,int)
        } else if (SbkNumber_Check(pyArgs[3])) {
            overloadId = 1; // setAttributeArray(int,const float*,int,int)
        }
    } else if (numArgs >= 3
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PyFloat_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setAttributeArray(const char*,const float*,int,int)
        } else if (SbkNumber_Check(pyArgs[3])) {
            overloadId = 0; // setAttributeArray(const char*,const float*,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeArray(const char*,const float*,int,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[3])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[3] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float * cppArg1 = Shiboken::Converter< float * >::toCpp(pyArgs[1]);
            int cppArg2 = Shiboken::Converter< int >::toCpp(pyArgs[2]);
            int cppArg3 = pyArgs[3] ? Shiboken::Converter< int >::toCpp(pyArgs[3]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeArray(const char*,const float*,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setAttributeArray(int,const float*,int,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[3])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[3] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float * cppArg1 = Shiboken::Converter< float * >::toCpp(pyArgs[1]);
            int cppArg2 = Shiboken::Converter< int >::toCpp(pyArgs[2]);
            int cppArg3 = pyArgs[3] ? Shiboken::Converter< int >::toCpp(pyArgs[3]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeArray(int,const float*,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtCore.float, int, int = 0", "int, PySide.QtCore.float, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeArray2D(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray2D(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray2D(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setAttributeArray2D", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeArray(const char*,const QVector2D*,int)
    // 1: setAttributeArray(int,const QVector2D*,int)
    if (numArgs >= 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // setAttributeArray(int,const QVector2D*,int)
        } else if (SbkNumber_Check(pyArgs[2])) {
            overloadId = 1; // setAttributeArray(int,const QVector2D*,int)
        }
    } else if (numArgs >= 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setAttributeArray(const char*,const QVector2D*,int)
        } else if (SbkNumber_Check(pyArgs[2])) {
            overloadId = 0; // setAttributeArray(const char*,const QVector2D*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeArray2D_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeArray(const char*,const QVector2D*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeArray2D_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray2D(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            int cppArg2 = pyArgs[2] ? Shiboken::Converter< int >::toCpp(pyArgs[2]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeArray(const char*,const QVector2D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector2D *_list = new QVector2D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector2D >::toCpp(pv);
                }
                }
                cppSelf->setAttributeArray(cppArg0, _list, cppArg2);
                delete[] _list;
                } else {
                cppSelf->setAttributeArray(cppArg0, (QVector2D*)NULL, cppArg2);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setAttributeArray(int,const QVector2D*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeArray2D_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray2D(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            int cppArg2 = pyArgs[2] ? Shiboken::Converter< int >::toCpp(pyArgs[2]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeArray(int,const QVector2D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector2D *_list = new QVector2D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector2D >::toCpp(pv);
                }
                }
                cppSelf->setAttributeArray(cppArg0, _list, cppArg2);
                delete[] _list;
                } else {
                cppSelf->setAttributeArray(cppArg0, (QVector2D*)NULL, cppArg2);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeArray2D_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QVector2D, int = 0", "int, PySide.QtGui.QVector2D, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray2D", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeArray3D(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray3D(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray3D(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setAttributeArray3D", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeArray(const char*,const QVector3D*,int)
    // 1: setAttributeArray(int,const QVector3D*,int)
    if (numArgs >= 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // setAttributeArray(int,const QVector3D*,int)
        } else if (SbkNumber_Check(pyArgs[2])) {
            overloadId = 1; // setAttributeArray(int,const QVector3D*,int)
        }
    } else if (numArgs >= 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setAttributeArray(const char*,const QVector3D*,int)
        } else if (SbkNumber_Check(pyArgs[2])) {
            overloadId = 0; // setAttributeArray(const char*,const QVector3D*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeArray3D_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeArray(const char*,const QVector3D*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeArray3D_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray3D(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            int cppArg2 = pyArgs[2] ? Shiboken::Converter< int >::toCpp(pyArgs[2]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeArray(const char*,const QVector3D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector3D *_list = new QVector3D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector3D >::toCpp(pv);
                }
                }
                cppSelf->setAttributeArray(cppArg0, _list, cppArg2);
                delete[] _list;
                } else {
                cppSelf->setAttributeArray(cppArg0, (QVector3D*)NULL, cppArg2);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setAttributeArray(int,const QVector3D*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeArray3D_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray3D(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            int cppArg2 = pyArgs[2] ? Shiboken::Converter< int >::toCpp(pyArgs[2]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeArray(int,const QVector3D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector3D *_list = new QVector3D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector3D >::toCpp(pv);
                }
                }
                cppSelf->setAttributeArray(cppArg0, _list, cppArg2);
                delete[] _list;
                } else {
                cppSelf->setAttributeArray(cppArg0, (QVector3D*)NULL, cppArg2);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeArray3D_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QVector3D, int = 0", "int, PySide.QtGui.QVector3D, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray3D", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeArray4D(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray4D(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray4D(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setAttributeArray4D", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeArray(const char*,const QVector4D*,int)
    // 1: setAttributeArray(int,const QVector4D*,int)
    if (numArgs >= 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // setAttributeArray(int,const QVector4D*,int)
        } else if (SbkNumber_Check(pyArgs[2])) {
            overloadId = 1; // setAttributeArray(int,const QVector4D*,int)
        }
    } else if (numArgs >= 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setAttributeArray(const char*,const QVector4D*,int)
        } else if (SbkNumber_Check(pyArgs[2])) {
            overloadId = 0; // setAttributeArray(const char*,const QVector4D*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeArray4D_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeArray(const char*,const QVector4D*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeArray4D_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray4D(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            int cppArg2 = pyArgs[2] ? Shiboken::Converter< int >::toCpp(pyArgs[2]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeArray(const char*,const QVector4D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector4D *_list = new QVector4D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector4D >::toCpp(pv);
                }
                }
                cppSelf->setAttributeArray(cppArg0, _list, cppArg2);
                delete[] _list;
                } else {
                cppSelf->setAttributeArray(cppArg0, (QVector4D*)NULL, cppArg2);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setAttributeArray(int,const QVector4D*,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeArray4D_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray4D(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            int cppArg2 = pyArgs[2] ? Shiboken::Converter< int >::toCpp(pyArgs[2]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeArray(int,const QVector4D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector4D *_list = new QVector4D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector4D >::toCpp(pv);
                }
                }
                cppSelf->setAttributeArray(cppArg0, _list, cppArg2);
                delete[] _list;
                } else {
                cppSelf->setAttributeArray(cppArg0, (QVector4D*)NULL, cppArg2);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeArray4D_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QVector4D, int = 0", "int, PySide.QtGui.QVector4D, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray4D", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeBuffer(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:setAttributeBuffer", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeBuffer(const char*,uint,int,int,int)
    // 1: setAttributeBuffer(int,uint,int,int,int)
    if (numArgs >= 4
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // setAttributeBuffer(int,uint,int,int,int)
        } else if (SbkNumber_Check(pyArgs[4])) {
            overloadId = 1; // setAttributeBuffer(int,uint,int,int,int)
        }
    } else if (numArgs >= 4
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // setAttributeBuffer(const char*,uint,int,int,int)
        } else if (SbkNumber_Check(pyArgs[4])) {
            overloadId = 0; // setAttributeBuffer(const char*,uint,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeBuffer_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeBuffer(const char*,uint,int,int,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[4])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[4] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeBuffer_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            unsigned int cppArg1 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[1]);
            int cppArg2 = Shiboken::Converter< int >::toCpp(pyArgs[2]);
            int cppArg3 = Shiboken::Converter< int >::toCpp(pyArgs[3]);
            int cppArg4 = pyArgs[4] ? Shiboken::Converter< int >::toCpp(pyArgs[4]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeBuffer(const char*,uint,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeBuffer(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setAttributeBuffer(int,uint,int,int,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "stride");
                if (value) {
                    if (pyArgs[4])
                        errorArgName = "stride";
                    else if (SbkNumber_Check(value))
                        pyArgs[4] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_setAttributeBuffer_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            unsigned int cppArg1 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[1]);
            int cppArg2 = Shiboken::Converter< int >::toCpp(pyArgs[2]);
            int cppArg3 = Shiboken::Converter< int >::toCpp(pyArgs[3]);
            int cppArg4 = pyArgs[4] ? Shiboken::Converter< int >::toCpp(pyArgs[4]) : 0;

            if(!PyErr_Occurred()) {
                // setAttributeBuffer(int,uint,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeBuffer(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeBuffer_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", unsigned int, int, int, int = 0", "int, unsigned int, int, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeValue(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttributeValue", 2, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeValue(const char*,QColor)
    // 1: setAttributeValue(const char*,QVector2D)
    // 2: setAttributeValue(const char*,QVector3D)
    // 3: setAttributeValue(const char*,QVector4D)
    // 4: setAttributeValue(const char*,float)
    // 5: setAttributeValue(const char*,float,float)
    // 6: setAttributeValue(const char*,float,float,float)
    // 7: setAttributeValue(const char*,float,float,float,float)
    // 8: setAttributeValue(int,QColor)
    // 9: setAttributeValue(int,QVector2D)
    // 10: setAttributeValue(int,QVector3D)
    // 11: setAttributeValue(int,QVector4D)
    // 12: setAttributeValue(int,float)
    // 13: setAttributeValue(int,float,float)
    // 14: setAttributeValue(int,float,float,float)
    // 15: setAttributeValue(int,float,float,float,float)
    if (SbkNumber_Check(pyArgs[0])) {
        if (SbkNumber_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 12; // setAttributeValue(int,float)
            } else if (SbkNumber_Check(pyArgs[2])) {
                if (numArgs == 3) {
                    overloadId = 13; // setAttributeValue(int,float,float)
                } else if (SbkNumber_Check(pyArgs[3])) {
                    if (numArgs == 4) {
                        overloadId = 14; // setAttributeValue(int,float,float,float)
                    } else if (numArgs == 5
                        && SbkNumber_Check(pyArgs[4])) {
                        overloadId = 15; // setAttributeValue(int,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector2D >::isConvertible(pyArgs[1])) {
            overloadId = 9; // setAttributeValue(int,QVector2D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector3D >::isConvertible(pyArgs[1])) {
            overloadId = 10; // setAttributeValue(int,QVector3D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector4D >::isConvertible(pyArgs[1])) {
            overloadId = 11; // setAttributeValue(int,QVector4D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QColor >::isConvertible(pyArgs[1])) {
            overloadId = 8; // setAttributeValue(int,QColor)
        }
    } else if (Shiboken::Converter< const char * >::isConvertible(pyArgs[0])) {
        if (SbkNumber_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // setAttributeValue(const char*,float)
            } else if (SbkNumber_Check(pyArgs[2])) {
                if (numArgs == 3) {
                    overloadId = 5; // setAttributeValue(const char*,float,float)
                } else if (SbkNumber_Check(pyArgs[3])) {
                    if (numArgs == 4) {
                        overloadId = 6; // setAttributeValue(const char*,float,float,float)
                    } else if (numArgs == 5
                        && SbkNumber_Check(pyArgs[4])) {
                        overloadId = 7; // setAttributeValue(const char*,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector2D >::isConvertible(pyArgs[1])) {
            overloadId = 1; // setAttributeValue(const char*,QVector2D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector3D >::isConvertible(pyArgs[1])) {
            overloadId = 2; // setAttributeValue(const char*,QVector3D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector4D >::isConvertible(pyArgs[1])) {
            overloadId = 3; // setAttributeValue(const char*,QVector4D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QColor >::isConvertible(pyArgs[1])) {
            overloadId = 0; // setAttributeValue(const char*,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeValue_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeValue(const char*,QColor)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QColor cppArg1 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setAttributeValue(const char*,QVector2D)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector2D cppArg1 = Shiboken::Converter< ::QVector2D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,QVector2D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // setAttributeValue(const char*,QVector3D)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector3D cppArg1 = Shiboken::Converter< ::QVector3D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // setAttributeValue(const char*,QVector4D)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector4D cppArg1 = Shiboken::Converter< ::QVector4D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // setAttributeValue(const char*,float)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 5: // setAttributeValue(const char*,float,float)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 6: // setAttributeValue(const char*,float,float,float)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);
            float cppArg3 = Shiboken::Converter< float >::toCpp(pyArgs[3]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,float,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 7: // setAttributeValue(const char*,float,float,float,float)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);
            float cppArg3 = Shiboken::Converter< float >::toCpp(pyArgs[3]);
            float cppArg4 = Shiboken::Converter< float >::toCpp(pyArgs[4]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,float,float,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 8: // setAttributeValue(int,QColor)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QColor cppArg1 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(int,QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 9: // setAttributeValue(int,QVector2D)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector2D cppArg1 = Shiboken::Converter< ::QVector2D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(int,QVector2D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 10: // setAttributeValue(int,QVector3D)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector3D cppArg1 = Shiboken::Converter< ::QVector3D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(int,QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 11: // setAttributeValue(int,QVector4D)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector4D cppArg1 = Shiboken::Converter< ::QVector4D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(int,QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 12: // setAttributeValue(int,float)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(int,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 13: // setAttributeValue(int,float,float)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(int,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 14: // setAttributeValue(int,float,float,float)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);
            float cppArg3 = Shiboken::Converter< float >::toCpp(pyArgs[3]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(int,float,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 15: // setAttributeValue(int,float,float,float,float)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);
            float cppArg3 = Shiboken::Converter< float >::toCpp(pyArgs[3]);
            float cppArg4 = Shiboken::Converter< float >::toCpp(pyArgs[4]);

            if(!PyErr_Occurred()) {
                // setAttributeValue(int,float,float,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeValue_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QColor", ""SBK_STR_NAME", PySide.QtGui.QVector2D", ""SBK_STR_NAME", PySide.QtGui.QVector3D", ""SBK_STR_NAME", PySide.QtGui.QVector4D", ""SBK_STR_NAME", float", ""SBK_STR_NAME", float, float", ""SBK_STR_NAME", float, float, float", ""SBK_STR_NAME", float, float, float, float", "int, PySide.QtGui.QColor", "int, PySide.QtGui.QVector2D", "int, PySide.QtGui.QVector3D", "int, PySide.QtGui.QVector4D", "int, float", "int, float, float", "int, float, float, float", "int, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeValue", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setGeometryInputType(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryInputType(uint)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setGeometryInputType(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setGeometryInputType_TypeError;

    // Call function/method
    {
        unsigned int cppArg0 = Shiboken::Converter< unsigned int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setGeometryInputType(uint)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setGeometryInputType(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setGeometryInputType_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryInputType", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setGeometryOutputType(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryOutputType(uint)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setGeometryOutputType(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setGeometryOutputType_TypeError;

    // Call function/method
    {
        unsigned int cppArg0 = Shiboken::Converter< unsigned int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setGeometryOutputType(uint)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setGeometryOutputType(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setGeometryOutputType_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryOutputType", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setGeometryOutputVertexCount(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryOutputVertexCount(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setGeometryOutputVertexCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setGeometryOutputVertexCount_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setGeometryOutputVertexCount(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setGeometryOutputVertexCount(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setGeometryOutputVertexCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryOutputVertexCount", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValue(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValue", 2, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValue(const char*,QColor)
    // 1: setUniformValue(const char*,QMatrix2x2)
    // 2: setUniformValue(const char*,QMatrix2x3)
    // 3: setUniformValue(const char*,QMatrix2x4)
    // 4: setUniformValue(const char*,QMatrix3x2)
    // 5: setUniformValue(const char*,QMatrix3x3)
    // 6: setUniformValue(const char*,QMatrix3x4)
    // 7: setUniformValue(const char*,QMatrix4x2)
    // 8: setUniformValue(const char*,QMatrix4x3)
    // 9: setUniformValue(const char*,QMatrix4x4)
    // 10: setUniformValue(const char*,QPoint)
    // 11: setUniformValue(const char*,QPointF)
    // 12: setUniformValue(const char*,QSize)
    // 13: setUniformValue(const char*,QSizeF)
    // 14: setUniformValue(const char*,QTransform)
    // 15: setUniformValue(const char*,QVector2D)
    // 16: setUniformValue(const char*,QVector3D)
    // 17: setUniformValue(const char*,QVector4D)
    // 18: setUniformValue(const char*,float)
    // 19: setUniformValue(const char*,float,float)
    // 20: setUniformValue(const char*,float,float,float)
    // 21: setUniformValue(const char*,float,float,float,float)
    // 22: setUniformValue(const char*,int)
    // 23: setUniformValue(const char*,uint)
    // 24: setUniformValue(int,QColor)
    // 25: setUniformValue(int,QMatrix2x2)
    // 26: setUniformValue(int,QMatrix2x3)
    // 27: setUniformValue(int,QMatrix2x4)
    // 28: setUniformValue(int,QMatrix3x2)
    // 29: setUniformValue(int,QMatrix3x3)
    // 30: setUniformValue(int,QMatrix3x4)
    // 31: setUniformValue(int,QMatrix4x2)
    // 32: setUniformValue(int,QMatrix4x3)
    // 33: setUniformValue(int,QMatrix4x4)
    // 34: setUniformValue(int,QPoint)
    // 35: setUniformValue(int,QPointF)
    // 36: setUniformValue(int,QSize)
    // 37: setUniformValue(int,QSizeF)
    // 38: setUniformValue(int,QTransform)
    // 39: setUniformValue(int,QVector2D)
    // 40: setUniformValue(int,QVector3D)
    // 41: setUniformValue(int,QVector4D)
    // 42: setUniformValue(int,float)
    // 43: setUniformValue(int,float,float)
    // 44: setUniformValue(int,float,float,float)
    // 45: setUniformValue(int,float,float,float,float)
    // 46: setUniformValue(int,int)
    // 47: setUniformValue(int,uint)
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 47; // setUniformValue(int,uint)
        } else if (PyFloat_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 42; // setUniformValue(int,float)
            } else if (SbkNumber_Check(pyArgs[2])) {
                if (numArgs == 3) {
                    overloadId = 43; // setUniformValue(int,float,float)
                } else if (SbkNumber_Check(pyArgs[3])) {
                    if (numArgs == 4) {
                        overloadId = 44; // setUniformValue(int,float,float,float)
                    } else if (numArgs == 5
                        && SbkNumber_Check(pyArgs[4])) {
                        overloadId = 45; // setUniformValue(int,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 46; // setUniformValue(int,int)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector2D >::isConvertible(pyArgs[1])) {
            overloadId = 39; // setUniformValue(int,QVector2D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector3D >::isConvertible(pyArgs[1])) {
            overloadId = 40; // setUniformValue(int,QVector3D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector4D >::isConvertible(pyArgs[1])) {
            overloadId = 41; // setUniformValue(int,QVector4D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QTransform >::isConvertible(pyArgs[1])) {
            overloadId = 38; // setUniformValue(int,QTransform)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QSize >::isConvertible(pyArgs[1])) {
            overloadId = 36; // setUniformValue(int,QSize)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QSizeF >::isConvertible(pyArgs[1])) {
            overloadId = 37; // setUniformValue(int,QSizeF)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[1])) {
            overloadId = 34; // setUniformValue(int,QPoint)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[1])) {
            overloadId = 35; // setUniformValue(int,QPointF)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix4x4 >::isConvertible(pyArgs[1])) {
            overloadId = 33; // setUniformValue(int,QMatrix4x4)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix4x3 >::isConvertible(pyArgs[1])) {
            overloadId = 32; // setUniformValue(int,QMatrix4x3)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix4x2 >::isConvertible(pyArgs[1])) {
            overloadId = 31; // setUniformValue(int,QMatrix4x2)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix3x4 >::isConvertible(pyArgs[1])) {
            overloadId = 30; // setUniformValue(int,QMatrix3x4)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix3x3 >::isConvertible(pyArgs[1])) {
            overloadId = 29; // setUniformValue(int,QMatrix3x3)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix3x2 >::isConvertible(pyArgs[1])) {
            overloadId = 28; // setUniformValue(int,QMatrix3x2)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix2x4 >::isConvertible(pyArgs[1])) {
            overloadId = 27; // setUniformValue(int,QMatrix2x4)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix2x3 >::isConvertible(pyArgs[1])) {
            overloadId = 26; // setUniformValue(int,QMatrix2x3)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix2x2 >::isConvertible(pyArgs[1])) {
            overloadId = 25; // setUniformValue(int,QMatrix2x2)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QColor >::isConvertible(pyArgs[1])) {
            overloadId = 24; // setUniformValue(int,QColor)
        }
    } else if (Shiboken::Converter< const char * >::isConvertible(pyArgs[0])) {
        if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 23; // setUniformValue(const char*,uint)
        } else if (PyFloat_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 18; // setUniformValue(const char*,float)
            } else if (SbkNumber_Check(pyArgs[2])) {
                if (numArgs == 3) {
                    overloadId = 19; // setUniformValue(const char*,float,float)
                } else if (SbkNumber_Check(pyArgs[3])) {
                    if (numArgs == 4) {
                        overloadId = 20; // setUniformValue(const char*,float,float,float)
                    } else if (numArgs == 5
                        && SbkNumber_Check(pyArgs[4])) {
                        overloadId = 21; // setUniformValue(const char*,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 22; // setUniformValue(const char*,int)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector2D >::isConvertible(pyArgs[1])) {
            overloadId = 15; // setUniformValue(const char*,QVector2D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector3D >::isConvertible(pyArgs[1])) {
            overloadId = 16; // setUniformValue(const char*,QVector3D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QVector4D >::isConvertible(pyArgs[1])) {
            overloadId = 17; // setUniformValue(const char*,QVector4D)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QTransform >::isConvertible(pyArgs[1])) {
            overloadId = 14; // setUniformValue(const char*,QTransform)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QSize >::isConvertible(pyArgs[1])) {
            overloadId = 12; // setUniformValue(const char*,QSize)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QSizeF >::isConvertible(pyArgs[1])) {
            overloadId = 13; // setUniformValue(const char*,QSizeF)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[1])) {
            overloadId = 10; // setUniformValue(const char*,QPoint)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[1])) {
            overloadId = 11; // setUniformValue(const char*,QPointF)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix4x4 >::isConvertible(pyArgs[1])) {
            overloadId = 9; // setUniformValue(const char*,QMatrix4x4)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix4x3 >::isConvertible(pyArgs[1])) {
            overloadId = 8; // setUniformValue(const char*,QMatrix4x3)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix4x2 >::isConvertible(pyArgs[1])) {
            overloadId = 7; // setUniformValue(const char*,QMatrix4x2)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix3x4 >::isConvertible(pyArgs[1])) {
            overloadId = 6; // setUniformValue(const char*,QMatrix3x4)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix3x3 >::isConvertible(pyArgs[1])) {
            overloadId = 5; // setUniformValue(const char*,QMatrix3x3)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix3x2 >::isConvertible(pyArgs[1])) {
            overloadId = 4; // setUniformValue(const char*,QMatrix3x2)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix2x4 >::isConvertible(pyArgs[1])) {
            overloadId = 3; // setUniformValue(const char*,QMatrix2x4)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix2x3 >::isConvertible(pyArgs[1])) {
            overloadId = 2; // setUniformValue(const char*,QMatrix2x3)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QMatrix2x2 >::isConvertible(pyArgs[1])) {
            overloadId = 1; // setUniformValue(const char*,QMatrix2x2)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QColor >::isConvertible(pyArgs[1])) {
            overloadId = 0; // setUniformValue(const char*,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValue_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValue(const char*,QColor)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QColor cppArg1 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setUniformValue(const char*,QMatrix2x2)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix2x2 cppArg1 = Shiboken::Converter< ::QMatrix2x2 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix2x2)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // setUniformValue(const char*,QMatrix2x3)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix2x3 cppArg1 = Shiboken::Converter< ::QMatrix2x3 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix2x3)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // setUniformValue(const char*,QMatrix2x4)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix2x4 cppArg1 = Shiboken::Converter< ::QMatrix2x4 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix2x4)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // setUniformValue(const char*,QMatrix3x2)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix3x2 cppArg1 = Shiboken::Converter< ::QMatrix3x2 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix3x2)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 5: // setUniformValue(const char*,QMatrix3x3)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix3x3 cppArg1 = Shiboken::Converter< ::QMatrix3x3 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix3x3)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 6: // setUniformValue(const char*,QMatrix3x4)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix3x4 cppArg1 = Shiboken::Converter< ::QMatrix3x4 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix3x4)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 7: // setUniformValue(const char*,QMatrix4x2)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix4x2 cppArg1 = Shiboken::Converter< ::QMatrix4x2 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix4x2)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 8: // setUniformValue(const char*,QMatrix4x3)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix4x3 cppArg1 = Shiboken::Converter< ::QMatrix4x3 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix4x3)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 9: // setUniformValue(const char*,QMatrix4x4)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix4x4 cppArg1 = Shiboken::Converter< ::QMatrix4x4 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix4x4)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 10: // setUniformValue(const char*,QPoint)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QPoint cppArg1 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 11: // setUniformValue(const char*,QPointF)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QPointF cppArg1 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 12: // setUniformValue(const char*,QSize)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QSize cppArg1 = Shiboken::Converter< ::QSize >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 13: // setUniformValue(const char*,QSizeF)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QSizeF cppArg1 = Shiboken::Converter< ::QSizeF >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QSizeF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 14: // setUniformValue(const char*,QTransform)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QTransform cppArg1 = Shiboken::Converter< ::QTransform >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QTransform)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 15: // setUniformValue(const char*,QVector2D)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector2D cppArg1 = Shiboken::Converter< ::QVector2D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QVector2D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 16: // setUniformValue(const char*,QVector3D)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector3D cppArg1 = Shiboken::Converter< ::QVector3D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 17: // setUniformValue(const char*,QVector4D)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector4D cppArg1 = Shiboken::Converter< ::QVector4D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 18: // setUniformValue(const char*,float)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 19: // setUniformValue(const char*,float,float)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 20: // setUniformValue(const char*,float,float,float)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);
            float cppArg3 = Shiboken::Converter< float >::toCpp(pyArgs[3]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,float,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 21: // setUniformValue(const char*,float,float,float,float)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);
            float cppArg3 = Shiboken::Converter< float >::toCpp(pyArgs[3]);
            float cppArg4 = Shiboken::Converter< float >::toCpp(pyArgs[4]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,float,float,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 22: // setUniformValue(const char*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 23: // setUniformValue(const char*,uint)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            unsigned int cppArg1 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(const char*,uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 24: // setUniformValue(int,QColor)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QColor cppArg1 = Shiboken::Converter< ::QColor >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 25: // setUniformValue(int,QMatrix2x2)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix2x2 cppArg1 = Shiboken::Converter< ::QMatrix2x2 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix2x2)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 26: // setUniformValue(int,QMatrix2x3)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix2x3 cppArg1 = Shiboken::Converter< ::QMatrix2x3 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix2x3)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 27: // setUniformValue(int,QMatrix2x4)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix2x4 cppArg1 = Shiboken::Converter< ::QMatrix2x4 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix2x4)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 28: // setUniformValue(int,QMatrix3x2)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix3x2 cppArg1 = Shiboken::Converter< ::QMatrix3x2 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix3x2)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 29: // setUniformValue(int,QMatrix3x3)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix3x3 cppArg1 = Shiboken::Converter< ::QMatrix3x3 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix3x3)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 30: // setUniformValue(int,QMatrix3x4)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix3x4 cppArg1 = Shiboken::Converter< ::QMatrix3x4 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix3x4)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 31: // setUniformValue(int,QMatrix4x2)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix4x2 cppArg1 = Shiboken::Converter< ::QMatrix4x2 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix4x2)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 32: // setUniformValue(int,QMatrix4x3)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix4x3 cppArg1 = Shiboken::Converter< ::QMatrix4x3 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix4x3)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 33: // setUniformValue(int,QMatrix4x4)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QMatrix4x4 cppArg1 = Shiboken::Converter< ::QMatrix4x4 >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix4x4)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 34: // setUniformValue(int,QPoint)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QPoint cppArg1 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 35: // setUniformValue(int,QPointF)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QPointF cppArg1 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 36: // setUniformValue(int,QSize)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QSize cppArg1 = Shiboken::Converter< ::QSize >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 37: // setUniformValue(int,QSizeF)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QSizeF cppArg1 = Shiboken::Converter< ::QSizeF >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QSizeF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 38: // setUniformValue(int,QTransform)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QTransform cppArg1 = Shiboken::Converter< ::QTransform >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QTransform)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 39: // setUniformValue(int,QVector2D)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector2D cppArg1 = Shiboken::Converter< ::QVector2D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QVector2D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 40: // setUniformValue(int,QVector3D)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector3D cppArg1 = Shiboken::Converter< ::QVector3D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 41: // setUniformValue(int,QVector4D)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QVector4D cppArg1 = Shiboken::Converter< ::QVector4D >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 42: // setUniformValue(int,float)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 43: // setUniformValue(int,float,float)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 44: // setUniformValue(int,float,float,float)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);
            float cppArg3 = Shiboken::Converter< float >::toCpp(pyArgs[3]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,float,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 45: // setUniformValue(int,float,float,float,float)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float cppArg1 = Shiboken::Converter< float >::toCpp(pyArgs[1]);
            float cppArg2 = Shiboken::Converter< float >::toCpp(pyArgs[2]);
            float cppArg3 = Shiboken::Converter< float >::toCpp(pyArgs[3]);
            float cppArg4 = Shiboken::Converter< float >::toCpp(pyArgs[4]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,float,float,float,float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 46: // setUniformValue(int,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 47: // setUniformValue(int,uint)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            unsigned int cppArg1 = Shiboken::Converter< unsigned int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // setUniformValue(int,uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValue_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QColor", ""SBK_STR_NAME", PySide.QtGui.QMatrix2x2", ""SBK_STR_NAME", PySide.QtGui.QMatrix2x3", ""SBK_STR_NAME", PySide.QtGui.QMatrix2x4", ""SBK_STR_NAME", PySide.QtGui.QMatrix3x2", ""SBK_STR_NAME", PySide.QtGui.QMatrix3x3", ""SBK_STR_NAME", PySide.QtGui.QMatrix3x4", ""SBK_STR_NAME", PySide.QtGui.QMatrix4x2", ""SBK_STR_NAME", PySide.QtGui.QMatrix4x3", ""SBK_STR_NAME", PySide.QtGui.QMatrix4x4", ""SBK_STR_NAME", PySide.QtCore.QPoint", ""SBK_STR_NAME", PySide.QtCore.QPointF", ""SBK_STR_NAME", PySide.QtCore.QSize", ""SBK_STR_NAME", PySide.QtCore.QSizeF", ""SBK_STR_NAME", PySide.QtGui.QTransform", ""SBK_STR_NAME", PySide.QtGui.QVector2D", ""SBK_STR_NAME", PySide.QtGui.QVector3D", ""SBK_STR_NAME", PySide.QtGui.QVector4D", ""SBK_STR_NAME", float", ""SBK_STR_NAME", float, float", ""SBK_STR_NAME", float, float, float", ""SBK_STR_NAME", float, float, float, float", ""SBK_STR_NAME", int", ""SBK_STR_NAME", unsigned int", "int, PySide.QtGui.QColor", "int, PySide.QtGui.QMatrix2x2", "int, PySide.QtGui.QMatrix2x3", "int, PySide.QtGui.QMatrix2x4", "int, PySide.QtGui.QMatrix3x2", "int, PySide.QtGui.QMatrix3x3", "int, PySide.QtGui.QMatrix3x4", "int, PySide.QtGui.QMatrix4x2", "int, PySide.QtGui.QMatrix4x3", "int, PySide.QtGui.QMatrix4x4", "int, PySide.QtCore.QPoint", "int, PySide.QtCore.QPointF", "int, PySide.QtCore.QSize", "int, PySide.QtCore.QSizeF", "int, PySide.QtGui.QTransform", "int, PySide.QtGui.QVector2D", "int, PySide.QtGui.QVector3D", "int, PySide.QtGui.QVector4D", "int, float", "int, float, float", "int, float, float, float", "int, float, float, float, float", "int, int", "int, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValue", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const float*,int,int)
    // 1: setUniformValueArray(int,const float*,int,int)
    if (numArgs == 4
        && SbkNumber_Check(pyArgs[0])
        && PyFloat_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        overloadId = 1; // setUniformValueArray(int,const float*,int,int)
    } else if (numArgs == 4
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PyFloat_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        overloadId = 0; // setUniformValueArray(const char*,const float*,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const float*,int,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);
            float * cppArg1 = Shiboken::Converter< float * >::toCpp(pyArgs[1]);
            int cppArg2 = Shiboken::Converter< int >::toCpp(pyArgs[2]);
            int cppArg3 = Shiboken::Converter< int >::toCpp(pyArgs[3]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const float*,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setUniformValueArray(int,const float*,int,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            float * cppArg1 = Shiboken::Converter< float * >::toCpp(pyArgs[1]);
            int cppArg2 = Shiboken::Converter< int >::toCpp(pyArgs[2]);
            int cppArg3 = Shiboken::Converter< int >::toCpp(pyArgs[3]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const float*,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtCore.float, int, int", "int, PySide.QtCore.float, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray2D(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray2D", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QVector2D*,int)
    // 1: setUniformValueArray(int,const QVector2D*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QVector2D*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QVector2D*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray2D_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QVector2D*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QVector2D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector2D *_list = new QVector2D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector2D >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QVector2D*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QVector2D*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QVector2D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector2D *_list = new QVector2D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector2D >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QVector2D*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray2D_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QVector2D, int", "int, PySide.QtGui.QVector2D, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray2D", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray2x2(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray2x2", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix2x2*,int)
    // 1: setUniformValueArray(int,const QMatrix2x2*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix2x2*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix2x2*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray2x2_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix2x2*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix2x2*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix2x2 *_list = new QMatrix2x2[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix2x2 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix2x2*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix2x2*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix2x2*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix2x2 *_list = new QMatrix2x2[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix2x2 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix2x2*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray2x2_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix2x2, int", "int, PySide.QtGui.QMatrix2x2, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray2x2", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray2x3(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray2x3", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix2x3*,int)
    // 1: setUniformValueArray(int,const QMatrix2x3*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix2x3*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix2x3*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray2x3_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix2x3*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix2x3*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix2x3 *_list = new QMatrix2x3[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix2x3 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix2x3*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix2x3*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix2x3*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix2x3 *_list = new QMatrix2x3[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix2x3 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix2x3*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray2x3_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix2x3, int", "int, PySide.QtGui.QMatrix2x3, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray2x3", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray2x4(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray2x4", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix2x4*,int)
    // 1: setUniformValueArray(int,const QMatrix2x4*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix2x4*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix2x4*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray2x4_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix2x4*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix2x4*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix2x4 *_list = new QMatrix2x4[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix2x4 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix2x4*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix2x4*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix2x4*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix2x4 *_list = new QMatrix2x4[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix2x4 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix2x4*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray2x4_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix2x4, int", "int, PySide.QtGui.QMatrix2x4, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray2x4", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray3D(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray3D", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QVector3D*,int)
    // 1: setUniformValueArray(int,const QVector3D*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QVector3D*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QVector3D*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray3D_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QVector3D*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QVector3D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector3D *_list = new QVector3D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector3D >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QVector3D*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QVector3D*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QVector3D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector3D *_list = new QVector3D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector3D >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QVector3D*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray3D_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QVector3D, int", "int, PySide.QtGui.QVector3D, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray3D", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray3x2(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray3x2", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix3x2*,int)
    // 1: setUniformValueArray(int,const QMatrix3x2*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix3x2*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix3x2*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray3x2_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix3x2*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix3x2*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix3x2 *_list = new QMatrix3x2[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix3x2 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix3x2*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix3x2*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix3x2*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix3x2 *_list = new QMatrix3x2[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix3x2 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix3x2*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray3x2_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix3x2, int", "int, PySide.QtGui.QMatrix3x2, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray3x2", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray3x3(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray3x3", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix3x3*,int)
    // 1: setUniformValueArray(int,const QMatrix3x3*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix3x3*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix3x3*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray3x3_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix3x3*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix3x3*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix3x3 *_list = new QMatrix3x3[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix3x3 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix3x3*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix3x3*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix3x3*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix3x3 *_list = new QMatrix3x3[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix3x3 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix3x3*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray3x3_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix3x3, int", "int, PySide.QtGui.QMatrix3x3, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray3x3", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray3x4(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray3x4", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix3x4*,int)
    // 1: setUniformValueArray(int,const QMatrix3x4*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix3x4*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix3x4*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray3x4_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix3x4*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix3x4*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix3x4 *_list = new QMatrix3x4[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix3x4 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix3x4*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix3x4*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix3x4*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix3x4 *_list = new QMatrix3x4[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix3x4 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix3x4*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray3x4_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix3x4, int", "int, PySide.QtGui.QMatrix3x4, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray3x4", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray4D(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray4D", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QVector4D*,int)
    // 1: setUniformValueArray(int,const QVector4D*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QVector4D*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QVector4D*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray4D_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QVector4D*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QVector4D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector4D *_list = new QVector4D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector4D >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QVector4D*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QVector4D*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QVector4D*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QVector4D *_list = new QVector4D[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QVector4D >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QVector4D*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray4D_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QVector4D, int", "int, PySide.QtGui.QVector4D, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray4D", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray4x2(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray4x2", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix4x2*,int)
    // 1: setUniformValueArray(int,const QMatrix4x2*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix4x2*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix4x2*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray4x2_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix4x2*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix4x2*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix4x2 *_list = new QMatrix4x2[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix4x2 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix4x2*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix4x2*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix4x2*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix4x2 *_list = new QMatrix4x2[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix4x2 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix4x2*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray4x2_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix4x2, int", "int, PySide.QtGui.QMatrix4x2, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray4x2", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray4x3(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray4x3", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix4x3*,int)
    // 1: setUniformValueArray(int,const QMatrix4x3*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix4x3*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix4x3*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray4x3_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix4x3*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix4x3*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix4x3 *_list = new QMatrix4x3[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix4x3 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix4x3*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix4x3*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix4x3*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix4x3 *_list = new QMatrix4x3[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix4x3 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix4x3*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray4x3_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix4x3, int", "int, PySide.QtGui.QMatrix4x3, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray4x3", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray4x4(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray4x4", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix4x4*,int)
    // 1: setUniformValueArray(int,const QMatrix4x4*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const QMatrix4x4*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const QMatrix4x4*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray4x4_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const QMatrix4x4*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix4x4*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix4x4 *_list = new QMatrix4x4[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix4x4 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix4x4*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const QMatrix4x4*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix4x4*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                QMatrix4x4 *_list = new QMatrix4x4[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< ::QMatrix4x4 >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (QMatrix4x4*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray4x4_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtGui.QMatrix4x4, int", "int, PySide.QtGui.QMatrix4x4, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray4x4", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArrayInt(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArrayInt", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const int*,int)
    // 1: setUniformValueArray(int,const int*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const int*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const int*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArrayInt_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const int*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const int*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                GLint *_list = new GLint[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< GLint >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (GLint*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const int*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const int*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                GLint *_list = new GLint[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< GLint >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (GLint*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArrayInt_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtCore.int, int", "int, PySide.QtCore.int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArrayInt", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArrayUint(PyObject* self, PyObject* args)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArrayUint", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const uint*,int)
    // 1: setUniformValueArray(int,const uint*,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 1; // setUniformValueArray(int,const uint*,int)
    } else if (numArgs == 2
        && Shiboken::Converter< const char * >::isConvertible(pyArgs[0])
        && PySequence_Check(pyArgs[1])) {
        overloadId = 0; // setUniformValueArray(const char*,const uint*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArrayUint_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char*,const uint*,int)
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const uint*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                GLuint *_list = new GLuint[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< GLuint >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (GLuint*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
        case 1: // setUniformValueArray(int,const uint*,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const uint*,int)
                // Begin code injection

                // TEMPLATE - callArrayFunction - START
                int _size = PySequence_Size(pyArgs[2-1]);
                if (_size) {
                GLuint *_list = new GLuint[_size];
                if (_size) {
                Shiboken::AutoDecRef fast(PySequence_Fast(pyArgs[2-1], "Failed to parse sequence with type %VECTOR_TYPE."));
                for(int i=0; i < _size; i++) {
                    PyObject* pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                    _list[i] = Shiboken::Converter< GLuint >::toCpp(pv);
                }
                }
                cppSelf->setUniformValueArray(cppArg0, _list, _size);
                delete[] _list;
                } else {
                cppSelf->setUniformValueArray(cppArg0, (GLuint*)NULL, 0);
                }
                // TEMPLATE - callArrayFunction - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArrayUint_TypeError:
        const char* overloads[] = {""SBK_STR_NAME", PySide.QtCore.unsigned int, int", "int, PySide.QtCore.unsigned int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArrayUint", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_shaders(PyObject* self)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // shaders()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QGLShader * > cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->shaders();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QGLShader * > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_uniformLocation(PyObject* self, PyObject* pyArg)
{
    ::QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QGLShaderProgram* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: uniformLocation(QByteArray)const
    // 1: uniformLocation(QString)const
    // 2: uniformLocation(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(pyArg)) {
        overloadId = 2; // uniformLocation(const char*)const
    } else if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 1; // uniformLocation(QString)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArg)) {
        overloadId = 0; // uniformLocation(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_uniformLocation_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // uniformLocation(QByteArray)const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // uniformLocation(QByteArray)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->uniformLocation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
        case 1: // uniformLocation(QString)const
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // uniformLocation(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->uniformLocation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
        case 2: // uniformLocation(const char*)const
        {
            const char * cppArg0 = Shiboken::Converter< const char * >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // uniformLocation(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QGLShaderProgram*>(cppSelf)->uniformLocation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_uniformLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "unicode", ""SBK_STR_NAME"", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtOpenGL.QGLShaderProgram.uniformLocation", overloads);
        return 0;
}

static PyMethodDef Sbk_QGLShaderProgram_methods[] = {
    {"addShader", (PyCFunction)Sbk_QGLShaderProgramFunc_addShader, METH_O},
    {"addShaderFromSourceCode", (PyCFunction)Sbk_QGLShaderProgramFunc_addShaderFromSourceCode, METH_VARARGS},
    {"addShaderFromSourceFile", (PyCFunction)Sbk_QGLShaderProgramFunc_addShaderFromSourceFile, METH_VARARGS},
    {"attributeLocation", (PyCFunction)Sbk_QGLShaderProgramFunc_attributeLocation, METH_O},
    {"bind", (PyCFunction)Sbk_QGLShaderProgramFunc_bind, METH_NOARGS},
    {"bindAttributeLocation", (PyCFunction)Sbk_QGLShaderProgramFunc_bindAttributeLocation, METH_VARARGS},
    {"disableAttributeArray", (PyCFunction)Sbk_QGLShaderProgramFunc_disableAttributeArray, METH_O},
    {"enableAttributeArray", (PyCFunction)Sbk_QGLShaderProgramFunc_enableAttributeArray, METH_O},
    {"geometryInputType", (PyCFunction)Sbk_QGLShaderProgramFunc_geometryInputType, METH_NOARGS},
    {"geometryOutputType", (PyCFunction)Sbk_QGLShaderProgramFunc_geometryOutputType, METH_NOARGS},
    {"geometryOutputVertexCount", (PyCFunction)Sbk_QGLShaderProgramFunc_geometryOutputVertexCount, METH_NOARGS},
    {"hasOpenGLShaderPrograms", (PyCFunction)Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"isLinked", (PyCFunction)Sbk_QGLShaderProgramFunc_isLinked, METH_NOARGS},
    {"link", (PyCFunction)Sbk_QGLShaderProgramFunc_link, METH_NOARGS},
    {"log", (PyCFunction)Sbk_QGLShaderProgramFunc_log, METH_NOARGS},
    {"maxGeometryOutputVertices", (PyCFunction)Sbk_QGLShaderProgramFunc_maxGeometryOutputVertices, METH_NOARGS},
    {"programId", (PyCFunction)Sbk_QGLShaderProgramFunc_programId, METH_NOARGS},
    {"release", (PyCFunction)Sbk_QGLShaderProgramFunc_release, METH_NOARGS},
    {"removeAllShaders", (PyCFunction)Sbk_QGLShaderProgramFunc_removeAllShaders, METH_NOARGS},
    {"removeShader", (PyCFunction)Sbk_QGLShaderProgramFunc_removeShader, METH_O},
    {"setAttributeArray", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeArray, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeArray2D", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeArray2D, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeArray3D", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeArray3D, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeArray4D", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeArray4D, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeBuffer", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeBuffer, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeValue", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeValue, METH_VARARGS},
    {"setGeometryInputType", (PyCFunction)Sbk_QGLShaderProgramFunc_setGeometryInputType, METH_O},
    {"setGeometryOutputType", (PyCFunction)Sbk_QGLShaderProgramFunc_setGeometryOutputType, METH_O},
    {"setGeometryOutputVertexCount", (PyCFunction)Sbk_QGLShaderProgramFunc_setGeometryOutputVertexCount, METH_O},
    {"setUniformValue", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValue, METH_VARARGS},
    {"setUniformValueArray", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray, METH_VARARGS},
    {"setUniformValueArray2D", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray2D, METH_VARARGS},
    {"setUniformValueArray2x2", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray2x2, METH_VARARGS},
    {"setUniformValueArray2x3", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray2x3, METH_VARARGS},
    {"setUniformValueArray2x4", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray2x4, METH_VARARGS},
    {"setUniformValueArray3D", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray3D, METH_VARARGS},
    {"setUniformValueArray3x2", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray3x2, METH_VARARGS},
    {"setUniformValueArray3x3", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray3x3, METH_VARARGS},
    {"setUniformValueArray3x4", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray3x4, METH_VARARGS},
    {"setUniformValueArray4D", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray4D, METH_VARARGS},
    {"setUniformValueArray4x2", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray4x2, METH_VARARGS},
    {"setUniformValueArray4x3", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray4x3, METH_VARARGS},
    {"setUniformValueArray4x4", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray4x4, METH_VARARGS},
    {"setUniformValueArrayInt", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArrayInt, METH_VARARGS},
    {"setUniformValueArrayUint", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArrayUint, METH_VARARGS},
    {"shaders", (PyCFunction)Sbk_QGLShaderProgramFunc_shaders, METH_NOARGS},
    {"uniformLocation", (PyCFunction)Sbk_QGLShaderProgramFunc_uniformLocation, METH_O},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QGLShaderProgram_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QGLShaderProgram_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLShaderProgram_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtOpenGL.QGLShaderProgram",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QGLShaderProgram_traverse,
    /*tp_clear*/            Sbk_QGLShaderProgram_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLShaderProgram_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLShaderProgram_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QGLShaderProgram_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QGLShaderProgram*>(reinterpret_cast< ::QObject*>(cptr));
    return 0;
}


void init_QGLShaderProgram(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLSHADERPROGRAM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLShaderProgram_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QGLShaderProgram", "QGLShaderProgram*",
        &Sbk_QGLShaderProgram_Type, &Shiboken::callCppDestructor< ::QGLShaderProgram >, (SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX])) {
        return;
    }

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QGLShaderProgram_Type, &Sbk_QGLShaderProgram_typeDiscovery);

    PySide::Signal::registerSignals(&Sbk_QGLShaderProgram_Type, &::QGLShaderProgram::staticMetaObject);

    Shiboken::TypeResolver::createObjectTypeResolver< ::QGLShaderProgram >("QGLShaderProgram*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QGLShaderProgram >(typeid(::QGLShaderProgram).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QGLShaderProgram >(typeid(::QGLShaderProgramWrapper).name());
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QGLShaderProgram_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QGLShaderProgram_Type, &::QGLShaderProgram::staticMetaObject, sizeof(::QGLShaderProgram));
}
